@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -59,7 +53,7 @@ XFormView::XFormView(QWidget *parent)
     m_scale = 1.0;
     m_shear = 0.0;
 
-    pixmap = QPixmap(":/res/bg1.jpg");
+    pixmap = QPixmap(":/trolltech/arthurplugin/bg1.jpg");
     pts = new HoverPoints(this, HoverPoints::CircleShape);
     pts->setConnectionType(HoverPoints::LineConnection);
     pts->setEditable(false);
@@ -155,34 +149,34 @@ void XFormView::setAnimation(bool animate)
 
 void XFormView::changeRotation(int r)
 {
-    setRotation(double(r)/10.0);
+    setRotation(qreal(r) / 10);
 }
 
 void XFormView::changeScale(int s)
 {
-    setScale(double(s)/1000.0);
+    setScale(qreal(s) / 1000);
 }
 
 void XFormView::changeShear(int s)
 {
-    setShear(double(s)/1000.0);
+    setShear(qreal(s) / 1000);
 }
 
-void XFormView::setShear(double s)
+void XFormView::setShear(qreal s)
 {
     m_shear = s;
     update();
 }
 
-void XFormView::setScale(double s)
+void XFormView::setScale(qreal s)
 {
     m_scale = s;
     update();
 }
 
-void XFormView::setRotation(double r)
+void XFormView::setRotation(qreal r)
 {
-    double old_rot = m_rotation;
+    qreal old_rot = m_rotation;
     m_rotation = r;
 
     QPointF center(pts->points().at(0));
@@ -206,8 +200,8 @@ void XFormView::timerEvent(QTimerEvent *e)
         pts->setPoints(pts->points() * m);
 
         setUpdatesEnabled(false);
-        static double scale_inc = 0.003;
-        static double shear_inc = -0.001;
+        static qreal scale_inc = 0.003;
+        static qreal shear_inc = -0.001;
         emit scaleChanged(int((m_scale + scale_inc) * 1000));
         emit shearChanged(int((m_shear + shear_inc) * 1000));
         if (m_scale >= 4.0 || m_scale <= 0.1)
@@ -222,8 +216,8 @@ void XFormView::timerEvent(QTimerEvent *e)
 
 void XFormView::wheelEvent(QWheelEvent *e)
 {
-    m_scale += e->delta()/600.0;
-    m_scale = qMax(.1, qMin(4.0, m_scale));
+    m_scale += e->delta() / qreal(600);
+    m_scale = qMax(qreal(0.1), qMin(qreal(4), m_scale));
     emit scaleChanged(int(m_scale*1000));
 }
 
@@ -240,7 +234,7 @@ void XFormView::reset()
 
 void XFormView::drawPixmapType(QPainter *painter)
 {
-    QPointF center(pixmap.width()/2.0, pixmap.height()/2.0);
+    QPointF center(pixmap.width() / qreal(2), pixmap.height() / qreal(2));
     painter->translate(ctrlPoints.at(0) - center);
 
     painter->translate(center);
@@ -863,8 +857,8 @@ XFormWidget::XFormWidget(QWidget *parent)
 #ifdef QT_OPENGL_SUPPORT
     connect(enableOpenGLButton, SIGNAL(clicked(bool)), view, SLOT(enableOpenGL(bool)));
 #endif
-    view->loadSourceFile(":res/xform.cpp");
-    view->loadDescription(":res/xform.html");
+    view->loadSourceFile(":/trolltech/arthurplugin/xform.cpp");
+    view->loadDescription(":/trolltech/arthurplugin/xform.html");
 
     // defaults
     view->reset();
