@@ -1,38 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -40,6 +39,7 @@
 
 #include "renderarea.h"
 
+//! [0]
 RenderArea::RenderArea(QWidget *parent)
     : QWidget(parent)
 {
@@ -51,47 +51,63 @@ RenderArea::RenderArea(QWidget *parent)
     setBackgroundRole(QPalette::Base);
     setAutoFillBackground(true);
 }
+//! [0]
 
+//! [1]
 QSize RenderArea::minimumSizeHint() const
 {
     return QSize(100, 100);
 }
+//! [1]
 
+//! [2]
 QSize RenderArea::sizeHint() const
 {
     return QSize(400, 200);
 }
+//! [2]
 
+//! [3]
 void RenderArea::setShape(Shape shape)
 {
     this->shape = shape;
     update();
 }
+//! [3]
 
+//! [4]
 void RenderArea::setPen(const QPen &pen)
 {
     this->pen = pen;
     update();
 }
+//! [4]
 
+//! [5]
 void RenderArea::setBrush(const QBrush &brush)
 {
     this->brush = brush;
     update();
 }
+//! [5]
 
+//! [6]
 void RenderArea::setAntialiased(bool antialiased)
 {
     this->antialiased = antialiased;
     update();
 }
+//! [6]
 
+//! [7]
 void RenderArea::setTransformed(bool transformed)
 {
     this->transformed = transformed;
     update();
 }
+//! [7]
 
+//! [8]
 void RenderArea::paintEvent(QPaintEvent * /* event */)
 {
     static const QPoint points[4] = {
@@ -108,28 +124,35 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
     path.lineTo(20, 30);
     path.cubicTo(80, 0, 50, 50, 80, 80);
 
-    int startAngle = 30 * 16;
+    int startAngle = 20 * 16;
     int arcLength = 120 * 16;
+//! [8]
 
+//! [9]
     QPainter painter(this);
     painter.setPen(pen);
     painter.setBrush(brush);
     if (antialiased) {
         painter.setRenderHint(QPainter::Antialiasing, true);
+//! [9]
         painter.translate(+0.5, +0.5);
     }
 
+//! [10]
     for (int x = 0; x < width(); x += 100) {
         for (int y = 0; y < height(); y += 100) {
             painter.save();
             painter.translate(x, y);
+//! [10] //! [11]
             if (transformed) {
                 painter.translate(50, 50);
                 painter.rotate(60.0);
                 painter.scale(0.6, 0.9);
                 painter.translate(-50, -50);
             }
+//! [11]
 
+//! [12]
             switch (shape) {
             case Line:
                 painter.drawLine(rect.bottomLeft(), rect.topRight());
@@ -146,8 +169,8 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
             case Rect:
                 painter.drawRect(rect);
                 break;
-            case RoundRect:
-                painter.drawRoundRect(rect);
+            case RoundedRect:
+                painter.drawRoundedRect(rect, 25, 25, Qt::RelativeSize);
                 break;
             case Ellipse:
                 painter.drawEllipse(rect);
@@ -170,6 +193,7 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
             case Pixmap:
                 painter.drawPixmap(10, 10, pixmap);
             }
+//! [12] //! [13]
             painter.restore();
         }
     }
@@ -178,3 +202,4 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
     painter.setBrush(Qt::NoBrush);
     painter.drawRect(QRect(0, 0, width() - 1, height() - 1));
 }
+//! [13]
