@@ -1,38 +1,64 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
-#include <QtGui>
 
 #include "interfaces.h"
 #include "mainwindow.h"
 #include "paintarea.h"
 #include "plugindialog.h"
 
-MainWindow::MainWindow()
-{
-    paintArea = new PaintArea;
+#include <QPluginLoader>
+#include <QTimer>
 
-    scrollArea = new QScrollArea;
+#include <QScrollArea>
+#include <QMessageBox>
+#include <QActionGroup>
+#include <QAction>
+#include <QMenu>
+#include <QMenuBar>
+#include <QFileDialog>
+#include <QColorDialog>
+#include <QInputDialog>
+#include <QApplication>
+
+MainWindow::MainWindow() :
+    paintArea(new PaintArea),
+    scrollArea(new QScrollArea)
+{
     scrollArea->setBackgroundRole(QPalette::Dark);
     scrollArea->setWidget(paintArea);
     setCentralWidget(scrollArea);
@@ -51,8 +77,9 @@ MainWindow::MainWindow()
 
 void MainWindow::open()
 {
-    QString fileName = QFileDialog::getOpenFileName(this,
-                                    tr("Open File"), QDir::currentPath());
+    const QString fileName = QFileDialog::getOpenFileName(this,
+                                                          tr("Open File"), 
+                                                          QDir::currentPath());
     if (!fileName.isEmpty()) {
         if (!paintArea->openImage(fileName)) {
             QMessageBox::information(this, tr("Plug & Paint"),
@@ -65,10 +92,10 @@ void MainWindow::open()
 
 bool MainWindow::saveAs()
 {
-    QString initialPath = QDir::currentPath() + "/untitled.png";
+    const QString initialPath = QDir::currentPath() + "/untitled.png";
 
-    QString fileName = QFileDialog::getSaveFileName(this, tr("Save As"),
-                                                    initialPath);
+    const QString fileName = QFileDialog::getSaveFileName(this, tr("Save As"),
+                                                          initialPath);
     if (fileName.isEmpty()) {
         return false;
     } else {
@@ -78,7 +105,7 @@ bool MainWindow::saveAs()
 
 void MainWindow::brushColor()
 {
-    QColor newColor = QColorDialog::getColor(paintArea->brushColor());
+    const QColor newColor = QColorDialog::getColor(paintArea->brushColor());
     if (newColor.isValid())
         paintArea->setBrushColor(newColor);
 }
@@ -86,43 +113,49 @@ void MainWindow::brushColor()
 void MainWindow::brushWidth()
 {
     bool ok;
-    int newWidth = QInputDialog::getInteger(this, tr("Plug & Paint"),
-                                            tr("Select brush width:"),
-                                            paintArea->brushWidth(),
-                                            1, 50, 1, &ok);
+    const int newWidth = QInputDialog::getInteger(this, tr("Plug & Paint"),
+                                                  tr("Select brush width:"),
+                                                  paintArea->brushWidth(),
+                                                  1, 50, 1, &ok);
     if (ok)
         paintArea->setBrushWidth(newWidth);
 }
 
+//! [0]
 void MainWindow::changeBrush()
 {
     QAction *action = qobject_cast<QAction *>(sender());
     BrushInterface *iBrush = qobject_cast<BrushInterface *>(action->parent());
-    QString brush = action->text();
+    const QString brush = action->text();
 
     paintArea->setBrush(iBrush, brush);
 }
+//! [0]
 
+//! [1]
 void MainWindow::insertShape()
 {
     QAction *action = qobject_cast<QAction *>(sender());
     ShapeInterface *iShape = qobject_cast<ShapeInterface *>(action->parent());
 
-    QPainterPath path = iShape->generateShape(action->text(), this);
+    const QPainterPath path = iShape->generateShape(action->text(), this);
     if (!path.isEmpty())
         paintArea->insertShape(path);
 }
+//! [1]
 
+//! [2]
 void MainWindow::applyFilter()
 {
     QAction *action = qobject_cast<QAction *>(sender());
     FilterInterface *iFilter =
             qobject_cast<FilterInterface *>(action->parent());
 
-    QImage image = iFilter->filterImage(action->text(), paintArea->image(),
-                                        this);
+    const QImage image = iFilter->filterImage(action->text(), paintArea->image(),
+                                              this);
     paintArea->setImage(image);
 }
+//! [2]
 
 void MainWindow::about()
 {
@@ -131,11 +164,13 @@ void MainWindow::about()
                "applications that can be extended through plugins."));
 }
 
+//! [3]
 void MainWindow::aboutPlugins()
 {
     PluginDialog dialog(pluginsDir.path(), pluginFileNames, this);
     dialog.exec();
 }
+//! [3]
 
 void MainWindow::createActions()
 {
@@ -194,10 +229,12 @@ void MainWindow::createMenus()
     helpMenu->addAction(aboutPluginsAct);
 }
 
+//! [4]
 void MainWindow::loadPlugins()
 {
     foreach (QObject *plugin, QPluginLoader::staticInstances())
         populateMenus(plugin);
+//! [4] //! [5]
 
     pluginsDir = QDir(qApp->applicationDirPath());
 
@@ -212,21 +249,29 @@ void MainWindow::loadPlugins()
     }
 #endif
     pluginsDir.cd("plugins");
+//! [5]
 
+//! [6]
     foreach (QString fileName, pluginsDir.entryList(QDir::Files)) {
         QPluginLoader loader(pluginsDir.absoluteFilePath(fileName));
         QObject *plugin = loader.instance();
         if (plugin) {
             populateMenus(plugin);
             pluginFileNames += fileName;
+//! [6] //! [7]
         }
+//! [7] //! [8]
     }
+//! [8]
 
+//! [9]
     brushMenu->setEnabled(!brushActionGroup->actions().isEmpty());
     shapesMenu->setEnabled(!shapesMenu->actions().isEmpty());
     filterMenu->setEnabled(!filterMenu->actions().isEmpty());
 }
+//! [9]
 
+//! [10]
 void MainWindow::populateMenus(QObject *plugin)
 {
     BrushInterface *iBrush = qobject_cast<BrushInterface *>(plugin);
@@ -242,6 +287,7 @@ void MainWindow::populateMenus(QObject *plugin)
     if (iFilter)
         addToMenu(plugin, iFilter->filters(), filterMenu, SLOT(applyFilter()));
 }
+//! [10]
 
 void MainWindow::addToMenu(QObject *plugin, const QStringList &texts,
                            QMenu *menu, const char *member,
