@@ -13,19 +13,17 @@
 #include "harfbuzz-impl.h"
 #include "harfbuzz-gdef-private.h"
 #include "harfbuzz-open-private.h"
+#include "harfbuzz-stream.h"
 
-static FT_Error  Load_AttachList( HB_AttachList*  al,
-				  FT_Stream        stream );
-static FT_Error  Load_LigCaretList( HB_LigCaretList*  lcl,
-				    FT_Stream          stream );
+static HB_Error  Load_AttachList( HB_AttachList*  al,
+				  HB_Stream        stream );
+static HB_Error  Load_LigCaretList( HB_LigCaretList*  lcl,
+				    HB_Stream          stream );
 
-static void  Free_AttachList( HB_AttachList*  al,
-			      FT_Memory        memory );
-static void  Free_LigCaretList( HB_LigCaretList*  lcl,
-				FT_Memory          memory );
+static void  Free_AttachList( HB_AttachList*  al);
+static void  Free_LigCaretList( HB_LigCaretList*  lcl);
 
-static void  Free_NewGlyphClasses( HB_GDEFHeader*  gdef,
-				   FT_Memory        memory );
+static void  Free_NewGlyphClasses( HB_GDEFHeader*  gdef);
 
 
 
@@ -37,7 +35,7 @@ static void  Free_NewGlyphClasses( HB_GDEFHeader*  gdef,
 #define GDEF_ID  Build_Extension_ID( 'G', 'D', 'E', 'F' )
 
 
-static FT_Error  GDEF_Create( void*  ext,
+static HB_Error  GDEF_Create( void*  ext,
 			      PFace  face )
 {
   DEFINE_LOAD_LOCALS( face->stream );
@@ -49,7 +47,7 @@ static FT_Error  GDEF_Create( void*  ext,
   /* by convention */
 
   if ( !gdef )
-    return FT_Err_Ok;
+    return HB_Err_Ok;
 
   /* a null offset indicates that there is no GDEF table */
 
@@ -59,7 +57,7 @@ static FT_Error  GDEF_Create( void*  ext,
 
   table = HB_LookUp_Table( face, TTAG_GDEF );
   if ( table < 0 )
-    return FT_Err_Ok;             /* The table is optional */
+    return HB_Err_Ok;             /* The table is optional */
 
   if ( FILE_Seek( face->dirTables[table].Offset ) ||
        ACCESS_Frame( 4L ) )
@@ -72,11 +70,11 @@ static FT_Error  GDEF_Create( void*  ext,
 
   gdef->loaded = FALSE;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
-static FT_Error  GDEF_Destroy( void*  ext,
+static HB_Error  GDEF_Destroy( void*  ext,
 			       PFace  face )
 {
   HB_GDEFHeader*  gdef = (HB_GDEFHeader*)ext;
@@ -85,30 +83,30 @@ static FT_Error  GDEF_Destroy( void*  ext,
   /* by convention */
 
   if ( !gdef )
-    return FT_Err_Ok;
+    return HB_Err_Ok;
 
   if ( gdef->loaded )
   {
-    Free_LigCaretList( &gdef->LigCaretList, memory );
-    Free_AttachList( &gdef->AttachList, memory );
-    _HB_OPEN_Free_ClassDefinition( &gdef->GlyphClassDef, memory );
-    _HB_OPEN_Free_ClassDefinition( &gdef->MarkAttachClassDef, memory );
+    Free_LigCaretList( &gdef->LigCaretList );
+    Free_AttachList( &gdef->AttachList );
+    _HB_OPEN_Free_ClassDefinition( &gdef->GlyphClassDef );
+    _HB_OPEN_Free_ClassDefinition( &gdef->MarkAttachClassDef );
 
-    Free_NewGlyphClasses( gdef, memory );
+    Free_NewGlyphClasses( gdef );
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
 
-FT_Error  HB_Init_GDEF_Extension( HB_Engine  engine )
+HB_Error  HB_Init_GDEF_Extension( HB_Engine  engine )
 {
   PEngine_Instance  _engine = HANDLE_Engine( engine );
 
 
   if ( !_engine )
-    return FT_Err_Invalid_Engine;
+    return HB_Err_Invalid_Engine;
 
   return  HB_Register_Extension( _engine,
 				 GDEF_ID,
@@ -130,22 +128,18 @@ FT_Error  HB_Init_GDEF_Extension( HB_Engine  engine )
 
 
 
-FT_Error  HB_New_GDEF_Table( FT_Face          face,
-			     HB_GDEFHeader** retptr )
+HB_Error  HB_New_GDEF_Table( HB_GDEFHeader** retptr )
 {
-  FT_Error         error;
-  FT_Memory        memory = face->memory;
+  HB_Error         error;
 
   HB_GDEFHeader*  gdef;
 
   if ( !retptr )
-    return FT_Err_Invalid_Argument;
+    return HB_Err_Invalid_Argument;
 
   if ( ALLOC( gdef, sizeof( *gdef ) ) )
     return error;
 
-  gdef->memory = face->memory;
-
   gdef->GlyphClassDef.loaded = FALSE;
   gdef->AttachList.loaded = FALSE;
   gdef->LigCaretList.loaded = FALSE;
@@ -157,28 +151,23 @@ FT_Error  HB_New_GDEF_Table( FT_Face          face,
 
   *retptr = gdef;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
-FT_Error  HB_Load_GDEF_Table( FT_Face          face,
+HB_Error  HB_Load_GDEF_Table( HB_Stream stream, 
 			      HB_GDEFHeader** retptr )
 {
-  FT_Error         error;
-  FT_Memory        memory = face->memory;
-  FT_Stream        stream = face->stream;
-  FT_ULong         cur_offset, new_offset, base_offset;
+  HB_Error         error;
+  HB_UInt         cur_offset, new_offset, base_offset;
 
   HB_GDEFHeader*  gdef;
 
 
   if ( !retptr )
-    return FT_Err_Invalid_Argument;
+    return HB_Err_Invalid_Argument;
 
-  if (( error = _hb_ftglue_face_goto_table( face, TTAG_GDEF, stream ) ))
-    return error;
-
-  if (( error = HB_New_GDEF_Table ( face, &gdef ) ))
+  if (( error = HB_New_GDEF_Table ( &gdef ) ))
     return error;
 
   base_offset = FILE_Pos();
@@ -204,7 +193,7 @@ FT_Error  HB_Load_GDEF_Table( FT_Face          face,
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
 	 ( error = _HB_OPEN_Load_ClassDefinition( &gdef->GlyphClassDef, 5,
-					 stream ) ) != FT_Err_Ok )
+					 stream ) ) != HB_Err_Ok )
       goto Fail0;
     (void)FILE_Seek( cur_offset );
   }
@@ -223,7 +212,7 @@ FT_Error  HB_Load_GDEF_Table( FT_Face          face,
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
 	 ( error = Load_AttachList( &gdef->AttachList,
-				    stream ) ) != FT_Err_Ok )
+				    stream ) ) != HB_Err_Ok )
       goto Fail1;
     (void)FILE_Seek( cur_offset );
   }
@@ -242,7 +231,7 @@ FT_Error  HB_Load_GDEF_Table( FT_Face          face,
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
 	 ( error = Load_LigCaretList( &gdef->LigCaretList,
-				      stream ) ) != FT_Err_Ok )
+				      stream ) ) != HB_Err_Ok )
       goto Fail2;
     (void)FILE_Seek( cur_offset );
   }
@@ -265,16 +254,16 @@ FT_Error  HB_Load_GDEF_Table( FT_Face          face,
 
   *retptr = gdef;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 
 Fail3:
-  Free_LigCaretList( &gdef->LigCaretList, memory );
+  Free_LigCaretList( &gdef->LigCaretList );
   
 Fail2:
-  Free_AttachList( &gdef->AttachList, memory );
+  Free_AttachList( &gdef->AttachList );
 
 Fail1:
-  _HB_OPEN_Free_ClassDefinition( &gdef->GlyphClassDef, memory );
+  _HB_OPEN_Free_ClassDefinition( &gdef->GlyphClassDef );
 
 Fail0:
   FREE( gdef );
@@ -283,20 +272,18 @@ Fail0:
 }
 
 
-FT_Error  HB_Done_GDEF_Table ( HB_GDEFHeader* gdef ) 
-{
-  FT_Memory memory = gdef->memory;
+HB_Error  HB_Done_GDEF_Table ( HB_GDEFHeader* gdef ) 
+{  
+  Free_LigCaretList( &gdef->LigCaretList );
+  Free_AttachList( &gdef->AttachList );
+  _HB_OPEN_Free_ClassDefinition( &gdef->GlyphClassDef );
+  _HB_OPEN_Free_ClassDefinition( &gdef->MarkAttachClassDef );
   
-  Free_LigCaretList( &gdef->LigCaretList, memory );
-  Free_AttachList( &gdef->AttachList, memory );
-  _HB_OPEN_Free_ClassDefinition( &gdef->GlyphClassDef, memory );
-  _HB_OPEN_Free_ClassDefinition( &gdef->MarkAttachClassDef, memory );
-  
-  Free_NewGlyphClasses( gdef, memory );
+  Free_NewGlyphClasses( gdef );
 
   FREE( gdef );
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
@@ -309,14 +296,13 @@ FT_Error  HB_Done_GDEF_Table ( HB_GDEFHeader* gdef )
 
 /* AttachPoint */
 
-static FT_Error  Load_AttachPoint( HB_AttachPoint*  ap,
-				   FT_Stream         stream )
+static HB_Error  Load_AttachPoint( HB_AttachPoint*  ap,
+				   HB_Stream         stream )
 {
-  FT_Memory memory = stream->memory;
-  FT_Error  error;
+  HB_Error  error;
 
-  FT_UShort   n, count;
-  FT_UShort*  pi;
+  HB_UShort   n, count;
+  HB_UShort*  pi;
 
 
   if ( ACCESS_Frame( 2L ) )
@@ -330,7 +316,7 @@ static FT_Error  Load_AttachPoint( HB_AttachPoint*  ap,
 
   if ( count )
   {
-    if ( ALLOC_ARRAY( ap->PointIndex, count, FT_UShort ) )
+    if ( ALLOC_ARRAY( ap->PointIndex, count, HB_UShort ) )
       return error;
 
     pi = ap->PointIndex;
@@ -347,12 +333,11 @@ static FT_Error  Load_AttachPoint( HB_AttachPoint*  ap,
     FORGET_Frame();
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
-static void  Free_AttachPoint( HB_AttachPoint*  ap,
-			       FT_Memory        memory )
+static void  Free_AttachPoint( HB_AttachPoint*  ap )
 {
   FREE( ap->PointIndex );
 }
@@ -360,14 +345,13 @@ static void  Free_AttachPoint( HB_AttachPoint*  ap,
 
 /* AttachList */
 
-static FT_Error  Load_AttachList( HB_AttachList*  al,
-				  FT_Stream        stream )
+static HB_Error  Load_AttachList( HB_AttachList*  al,
+				  HB_Stream        stream )
 {
-  FT_Memory memory = stream->memory;
-  FT_Error  error;
+  HB_Error  error;
 
-  FT_UShort         n, m, count;
-  FT_ULong          cur_offset, new_offset, base_offset;
+  HB_UShort         n, m, count;
+  HB_UInt          cur_offset, new_offset, base_offset;
 
   HB_AttachPoint*  ap;
 
@@ -383,7 +367,7 @@ static FT_Error  Load_AttachList( HB_AttachList*  al,
 
   cur_offset = FILE_Pos();
   if ( FILE_Seek( new_offset ) ||
-       ( error = _HB_OPEN_Load_Coverage( &al->Coverage, stream ) ) != FT_Err_Ok )
+       ( error = _HB_OPEN_Load_Coverage( &al->Coverage, stream ) ) != HB_Err_Ok )
     return error;
   (void)FILE_Seek( cur_offset );
 
@@ -412,31 +396,30 @@ static FT_Error  Load_AttachList( HB_AttachList*  al,
 
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
-	 ( error = Load_AttachPoint( &ap[n], stream ) ) != FT_Err_Ok )
+	 ( error = Load_AttachPoint( &ap[n], stream ) ) != HB_Err_Ok )
       goto Fail1;
     (void)FILE_Seek( cur_offset );
   }
 
   al->loaded = TRUE;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 
 Fail1:
   for ( m = 0; m < n; m++ )
-    Free_AttachPoint( &ap[m], memory );
+    Free_AttachPoint( &ap[m] );
 
   FREE( ap );
 
 Fail2:
-  _HB_OPEN_Free_Coverage( &al->Coverage, memory );
+  _HB_OPEN_Free_Coverage( &al->Coverage );
   return error;
 }
 
 
-static void  Free_AttachList( HB_AttachList*  al,
-			      FT_Memory        memory )
+static void  Free_AttachList( HB_AttachList*  al)
 {
-  FT_UShort         n, count;
+  HB_UShort         n, count;
 
   HB_AttachPoint*  ap;
 
@@ -450,12 +433,12 @@ static void  Free_AttachList( HB_AttachList*  al,
     ap    = al->AttachPoint;
 
     for ( n = 0; n < count; n++ )
-      Free_AttachPoint( &ap[n], memory );
+      Free_AttachPoint( &ap[n] );
 
     FREE( ap );
   }
 
-  _HB_OPEN_Free_Coverage( &al->Coverage, memory );
+  _HB_OPEN_Free_Coverage( &al->Coverage );
 }
 
 
@@ -470,12 +453,12 @@ static void  Free_AttachList( HB_AttachList*  al,
 /* CaretValueFormat3 */
 /* CaretValueFormat4 */
 
-static FT_Error  Load_CaretValue( HB_CaretValue*  cv,
-				  FT_Stream        stream )
+static HB_Error  Load_CaretValue( HB_CaretValue*  cv,
+				  HB_Stream        stream )
 {
-  FT_Error  error;
+  HB_Error  error;
 
-  FT_ULong cur_offset, new_offset, base_offset;
+  HB_UInt cur_offset, new_offset, base_offset;
 
 
   base_offset = FILE_Pos();
@@ -522,7 +505,7 @@ static FT_Error  Load_CaretValue( HB_CaretValue*  cv,
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
 	 ( error = _HB_OPEN_Load_Device( &cv->cvf.cvf3.Device,
-				stream ) ) != FT_Err_Ok )
+				stream ) ) != HB_Err_Ok )
       return error;
     (void)FILE_Seek( cur_offset );
 
@@ -541,28 +524,26 @@ static FT_Error  Load_CaretValue( HB_CaretValue*  cv,
     return HB_Err_Invalid_GDEF_SubTable_Format;
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
-static void  Free_CaretValue( HB_CaretValue*  cv,
-			      FT_Memory        memory )
+static void  Free_CaretValue( HB_CaretValue*  cv)
 {
   if ( cv->CaretValueFormat == 3 )
-    _HB_OPEN_Free_Device( &cv->cvf.cvf3.Device, memory );
+    _HB_OPEN_Free_Device( &cv->cvf.cvf3.Device );
 }
 
 
 /* LigGlyph */
 
-static FT_Error  Load_LigGlyph( HB_LigGlyph*  lg,
-				FT_Stream      stream )
+static HB_Error  Load_LigGlyph( HB_LigGlyph*  lg,
+				HB_Stream      stream )
 {
-  FT_Memory memory = stream->memory;
-  FT_Error  error;
+  HB_Error  error;
 
-  FT_UShort        n, m, count;
-  FT_ULong         cur_offset, new_offset, base_offset;
+  HB_UShort        n, m, count;
+  HB_UInt         cur_offset, new_offset, base_offset;
 
   HB_CaretValue*  cv;
 
@@ -594,26 +575,25 @@ static FT_Error  Load_LigGlyph( HB_LigGlyph*  lg,
 
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
-	 ( error = Load_CaretValue( &cv[n], stream ) ) != FT_Err_Ok )
+	 ( error = Load_CaretValue( &cv[n], stream ) ) != HB_Err_Ok )
       goto Fail;
     (void)FILE_Seek( cur_offset );
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 
 Fail:
   for ( m = 0; m < n; m++ )
-    Free_CaretValue( &cv[m], memory );
+    Free_CaretValue( &cv[m] );
 
   FREE( cv );
   return error;
 }
 
 
-static void  Free_LigGlyph( HB_LigGlyph*  lg,
-			    FT_Memory      memory )
+static void  Free_LigGlyph( HB_LigGlyph*  lg)
 {
-  FT_UShort        n, count;
+  HB_UShort        n, count;
 
   HB_CaretValue*  cv;
 
@@ -624,7 +604,7 @@ static void  Free_LigGlyph( HB_LigGlyph*  lg,
     cv    = lg->CaretValue;
 
     for ( n = 0; n < count; n++ )
-      Free_CaretValue( &cv[n], memory );
+      Free_CaretValue( &cv[n] );
 
     FREE( cv );
   }
@@ -633,14 +613,13 @@ static void  Free_LigGlyph( HB_LigGlyph*  lg,
 
 /* LigCaretList */
 
-static FT_Error  Load_LigCaretList( HB_LigCaretList*  lcl,
-				    FT_Stream          stream )
+static HB_Error  Load_LigCaretList( HB_LigCaretList*  lcl,
+				    HB_Stream          stream )
 {
-  FT_Memory memory = stream->memory;
-  FT_Error  error;
+  HB_Error  error;
 
-  FT_UShort      m, n, count;
-  FT_ULong       cur_offset, new_offset, base_offset;
+  HB_UShort      m, n, count;
+  HB_UInt       cur_offset, new_offset, base_offset;
 
   HB_LigGlyph*  lg;
 
@@ -656,7 +635,7 @@ static FT_Error  Load_LigCaretList( HB_LigCaretList*  lcl,
 
   cur_offset = FILE_Pos();
   if ( FILE_Seek( new_offset ) ||
-       ( error = _HB_OPEN_Load_Coverage( &lcl->Coverage, stream ) ) != FT_Err_Ok )
+       ( error = _HB_OPEN_Load_Coverage( &lcl->Coverage, stream ) ) != HB_Err_Ok )
     return error;
   (void)FILE_Seek( cur_offset );
 
@@ -685,31 +664,30 @@ static FT_Error  Load_LigCaretList( HB_LigCaretList*  lcl,
 
     cur_offset = FILE_Pos();
     if ( FILE_Seek( new_offset ) ||
-	 ( error = Load_LigGlyph( &lg[n], stream ) ) != FT_Err_Ok )
+	 ( error = Load_LigGlyph( &lg[n], stream ) ) != HB_Err_Ok )
       goto Fail1;
     (void)FILE_Seek( cur_offset );
   }
 
   lcl->loaded = TRUE;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 
 Fail1:
   for ( m = 0; m < n; m++ )
-    Free_LigGlyph( &lg[m], memory );
+    Free_LigGlyph( &lg[m] );
 
   FREE( lg );
 
 Fail2:
-  _HB_OPEN_Free_Coverage( &lcl->Coverage, memory );
+  _HB_OPEN_Free_Coverage( &lcl->Coverage );
   return error;
 }
 
 
-static void  Free_LigCaretList( HB_LigCaretList*  lcl,
-				FT_Memory           memory )
+static void  Free_LigCaretList( HB_LigCaretList*  lcl )
 {
-  FT_UShort      n, count;
+  HB_UShort      n, count;
 
   HB_LigGlyph*  lg;
 
@@ -723,12 +701,12 @@ static void  Free_LigCaretList( HB_LigCaretList*  lcl,
     lg    = lcl->LigGlyph;
 
     for ( n = 0; n < count; n++ )
-      Free_LigGlyph( &lg[n], memory );
+      Free_LigGlyph( &lg[n] );
 
     FREE( lg );
   }
 
-  _HB_OPEN_Free_Coverage( &lcl->Coverage, memory );
+  _HB_OPEN_Free_Coverage( &lcl->Coverage );
 }
 
 
@@ -738,15 +716,15 @@ static void  Free_LigCaretList( HB_LigCaretList*  lcl,
  ***********/
 
 
-static FT_UShort  Get_New_Class( HB_GDEFHeader*  gdef,
-				 FT_UShort        glyphID,
-				 FT_UShort        index )
+static HB_UShort  Get_New_Class( HB_GDEFHeader*  gdef,
+				 HB_UShort        glyphID,
+				 HB_UShort        index )
 {
-  FT_UShort              glyph_index, array_index, count;
-  FT_UShort              byte, bits;
+  HB_UShort              glyph_index, array_index, count;
+  HB_UShort              byte, bits;
   
   HB_ClassRangeRecord*  gcrr;
-  FT_UShort**            ngc;
+  HB_UShort**            ngc;
 
 
   if ( glyphID >= gdef->LastGlyph )
@@ -778,17 +756,17 @@ static FT_UShort  Get_New_Class( HB_GDEFHeader*  gdef,
 
 
 
-FT_Error  HB_GDEF_Get_Glyph_Property( HB_GDEFHeader*  gdef,
-				      FT_UShort        glyphID,
-				      FT_UShort*       property )
+HB_Error  HB_GDEF_Get_Glyph_Property( HB_GDEFHeader*  gdef,
+				      HB_UShort        glyphID,
+				      HB_UShort*       property )
 {
-  FT_UShort class, index;
+  HB_UShort class, index;
 
-  FT_Error  error;
+  HB_Error  error;
 
 
   if ( !gdef || !property )
-    return FT_Err_Invalid_Argument;
+    return HB_Err_Invalid_Argument;
 
   /* first, we check for mark attach classes */
 
@@ -800,7 +778,7 @@ FT_Error  HB_GDEF_Get_Glyph_Property( HB_GDEFHeader*  gdef,
     if ( !error )
     {
       *property = class << 8;
-      return FT_Err_Ok;
+      return HB_Err_Ok;
     }
   }
 
@@ -837,18 +815,17 @@ FT_Error  HB_GDEF_Get_Glyph_Property( HB_GDEFHeader*  gdef,
     break;
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
-static FT_Error  Make_ClassRange( HB_ClassDefinition*  cd,
-				  FT_UShort             start,
-				  FT_UShort             end,
-				  FT_UShort             class,
-				  FT_Memory             memory )
+static HB_Error  Make_ClassRange( HB_ClassDefinition*  cd,
+				  HB_UShort             start,
+				  HB_UShort             end,
+				  HB_UShort             class )
 {
-  FT_Error               error;
-  FT_UShort              index;
+  HB_Error               error;
+  HB_UShort              index;
 
   HB_ClassDefFormat2*   cdf2;
   HB_ClassRangeRecord*  crr;
@@ -873,31 +850,29 @@ static FT_Error  Make_ClassRange( HB_ClassDefinition*  cd,
 
   cd->Defined[class] = TRUE;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
 
-FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
-					 FT_UShort        num_glyphs,
-					 FT_UShort        glyph_count,
-					 FT_UShort*       glyph_array,
-					 FT_UShort*       class_array )
+HB_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
+					 HB_UShort        num_glyphs,
+					 HB_UShort        glyph_count,
+					 HB_UShort*       glyph_array,
+					 HB_UShort*       class_array )
 {
-  FT_UShort              start, curr_glyph, curr_class;
-  FT_UShort              n, m, count;
-  FT_Error               error;
-  FT_Memory              memory;
+  HB_UShort              start, curr_glyph, curr_class;
+  HB_UShort              n, m, count;
+  HB_Error               error;
 
   HB_ClassDefinition*   gcd;
   HB_ClassRangeRecord*  gcrr;
-  FT_UShort**            ngc;
+  HB_UShort**            ngc;
 
 
   if ( !gdef || !glyph_array || !class_array )
-    return FT_Err_Invalid_Argument;
+    return HB_Err_Invalid_Argument;
 
-  memory = gdef->memory;
   gcd = &gdef->GlyphClassDef;
 
   /* We build a format 2 table */
@@ -906,7 +881,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
 
   /* A GlyphClassDef table contains at most 5 different class values */
 
-  if ( ALLOC_ARRAY( gcd->Defined, 5, FT_Bool ) )
+  if ( ALLOC_ARRAY( gcd->Defined, 5, HB_Bool ) )
     return error;
 
   gcd->cd.cd2.ClassRangeCount  = 0;
@@ -918,7 +893,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
 
   if ( curr_class >= 5 )
   {
-    error = FT_Err_Invalid_Argument;
+    error = HB_Err_Invalid_Argument;
     goto Fail4;
   }
 
@@ -932,15 +907,14 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
       {
 	if ( ( error = Make_ClassRange( gcd, start,
 					curr_glyph,
-					curr_class,
-					memory ) ) != FT_Err_Ok )
+					curr_class) ) != HB_Err_Ok )
 	  goto Fail3;
       }
       else
       {
 	if ( curr_glyph == 0xFFFF )
 	{
-	  error = FT_Err_Invalid_Argument;
+	  error = HB_Err_Invalid_Argument;
 	  goto Fail3;
 	}
 	else
@@ -951,13 +925,12 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
     {
       if ( ( error = Make_ClassRange( gcd, start,
 				      curr_glyph - 1,
-				      curr_class,
-				      memory ) ) != FT_Err_Ok )
+				      curr_class) ) != HB_Err_Ok )
 	goto Fail3;
 
       if ( curr_glyph > glyph_array[n] )
       {
-	error = FT_Err_Invalid_Argument;
+	error = HB_Err_Invalid_Argument;
 	goto Fail3;
       }
 
@@ -967,7 +940,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
 
       if ( curr_class >= 5 )
       {
-	error = FT_Err_Invalid_Argument;
+	error = HB_Err_Invalid_Argument;
 	goto Fail3;
       }
 
@@ -975,15 +948,14 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
       {
 	if ( ( error = Make_ClassRange( gcd, start,
 					curr_glyph,
-					curr_class,
-					memory ) ) != FT_Err_Ok )
+					curr_class) ) != HB_Err_Ok )
 	  goto Fail3;
       }
       else
       {
 	if ( curr_glyph == 0xFFFF )
 	{
-	  error = FT_Err_Invalid_Argument;
+	  error = HB_Err_Invalid_Argument;
 	  goto Fail3;
 	}
 	else
@@ -996,7 +968,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
      process                                                            */
 
   if ( ALLOC_ARRAY( gdef->NewGlyphClasses,
-		    gcd->cd.cd2.ClassRangeCount + 1, FT_UShort* ) )
+		    gcd->cd.cd2.ClassRangeCount + 1, HB_UShort* ) )
     goto Fail3;
 
   count = gcd->cd.cd2.ClassRangeCount;
@@ -1010,7 +982,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
   {
       if ( gcrr[0].Start )
       {
-	if ( ALLOC_ARRAY( ngc[0], ( gcrr[0].Start + 3 ) / 4, FT_UShort ) )
+	if ( ALLOC_ARRAY( ngc[0], ( gcrr[0].Start + 3 ) / 4, HB_UShort ) )
 	  goto Fail2;
       }
 
@@ -1019,7 +991,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
 	if ( gcrr[n].Start - gcrr[n - 1].End > 1 )
 	  if ( ALLOC_ARRAY( ngc[n],
 			    ( gcrr[n].Start - gcrr[n - 1].End + 2 ) / 4,
-			    FT_UShort ) )
+			    HB_UShort ) )
 	    goto Fail1;
       }
 
@@ -1027,7 +999,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
       {
 	if ( ALLOC_ARRAY( ngc[count],
 			  ( num_glyphs - gcrr[count - 1].End + 2 ) / 4,
-			  FT_UShort ) )
+			  HB_UShort ) )
 	    goto Fail1;
       }
   }
@@ -1035,7 +1007,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
   {
       if ( ALLOC_ARRAY( ngc[count],
 			( num_glyphs + 3 ) / 4,
-			FT_UShort ) )
+			HB_UShort ) )
 	  goto Fail2;
   }
       
@@ -1046,7 +1018,7 @@ FT_Error  HB_GDEF_Build_ClassDefinition( HB_GDEFHeader*  gdef,
 
   gcd->loaded = TRUE;
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 
 Fail1:
   for ( m = 0; m < n; m++ )
@@ -1064,11 +1036,10 @@ Fail4:
 }
 
 
-static void  Free_NewGlyphClasses( HB_GDEFHeader*  gdef,
-				   FT_Memory        memory )
+static void  Free_NewGlyphClasses( HB_GDEFHeader*  gdef )
 {
-  FT_UShort**  ngc;
-  FT_UShort    n, count;
+  HB_UShort**  ngc;
+  HB_UShort    n, count;
 
 
   if ( gdef->NewGlyphClasses )
@@ -1084,17 +1055,17 @@ static void  Free_NewGlyphClasses( HB_GDEFHeader*  gdef,
 }
 
 
-FT_Error  _HB_GDEF_Add_Glyph_Property( HB_GDEFHeader*  gdef,
-			      FT_UShort        glyphID,
-			      FT_UShort        property )
+HB_Error  _HB_GDEF_Add_Glyph_Property( HB_GDEFHeader*  gdef,
+			      HB_UShort        glyphID,
+			      HB_UShort        property )
 {
-  FT_Error               error;
-  FT_UShort              class, new_class, index;
-  FT_UShort              byte, bits, mask;
-  FT_UShort              array_index, glyph_index, count;
+  HB_Error               error;
+  HB_UShort              class, new_class, index;
+  HB_UShort              byte, bits, mask;
+  HB_UShort              array_index, glyph_index, count;
 
   HB_ClassRangeRecord*  gcrr;
-  FT_UShort**            ngc;
+  HB_UShort**            ngc;
 
 
   error = _HB_OPEN_Get_Class( &gdef->GlyphClassDef, glyphID, &class, &index );
@@ -1129,7 +1100,7 @@ FT_Error  _HB_GDEF_Add_Glyph_Property( HB_GDEFHeader*  gdef,
     break;
 
   default:
-    return FT_Err_Invalid_Argument;
+    return HB_Err_Invalid_Argument;
   }
 
   count = gdef->GlyphClassDef.cd.cd2.ClassRangeCount;
@@ -1165,21 +1136,21 @@ FT_Error  _HB_GDEF_Add_Glyph_Property( HB_GDEFHeader*  gdef,
     ngc[array_index][glyph_index / 4] |= bits;
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
 
-FT_Error  _HB_GDEF_Check_Property( HB_GDEFHeader*  gdef,
+HB_Error  _HB_GDEF_Check_Property( HB_GDEFHeader*  gdef,
 			  HB_GlyphItem    gitem,
-			  FT_UShort        flags,
-			  FT_UShort*       property )
+			  HB_UShort        flags,
+			  HB_UShort*       property )
 {
-  FT_Error  error;
+  HB_Error  error;
 
   if ( gdef )
   {
-    FT_UShort basic_glyph_class;
-    FT_UShort desired_attachment_class;
+    HB_UShort basic_glyph_class;
+    HB_UShort desired_attachment_class;
 
     if ( gitem->gproperties == HB_GLYPH_PROPERTIES_UNKNOWN )
     {
@@ -1221,8 +1192,46 @@ FT_Error  _HB_GDEF_Check_Property( HB_GDEFHeader*  gdef,
       *property = 0;
   }
 
-  return FT_Err_Ok;
+  return HB_Err_Ok;
 }
 
+HB_Error _HB_GDEF_LoadMarkAttachClassDef_From_LookupFlags( HB_GDEFHeader* gdef,
+							   HB_Stream      stream,
+							   HB_Lookup*     lo,
+							   HB_UShort      num_lookups)
+{
+  HB_Error   error = HB_Err_Ok;
+  HB_UShort  i;
+
+  /* We now check the LookupFlags for values larger than 0xFF to find
+     out whether we need to load the `MarkAttachClassDef' field of the
+     GDEF table -- this hack is necessary for OpenType 1.2 tables since
+     the version field of the GDEF table hasn't been incremented.
+
+     For constructed GDEF tables, we only load it if
+     `MarkAttachClassDef_offset' is not zero (nevertheless, a build of
+     a constructed mark attach table is not supported currently).       */
+
+  if ( gdef &&
+       gdef->MarkAttachClassDef_offset && !gdef->MarkAttachClassDef.loaded )
+  {
+    for ( i = 0; i < num_lookups; i++ )
+    {
+
+      if ( lo[i].LookupFlag & HB_LOOKUP_FLAG_IGNORE_SPECIAL_MARKS )
+      {
+	if ( FILE_Seek( gdef->MarkAttachClassDef_offset ) ||
+	     ( error = _HB_OPEN_Load_ClassDefinition( &gdef->MarkAttachClassDef,
+					     256, stream ) ) != HB_Err_Ok )
+	  goto Done;
+
+	break;
+      }
+    }
+  }
+
+Done:
+  return error;
+}
 
 /* END */
