@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-Copyright (C) 2007 Trolltech ASA. All rights reserved.
+Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
 
 This library is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
@@ -278,7 +278,7 @@ namespace Phonon
                 ComPointer<IMemInputPin> input(pin, IID_IMemInputPin);
                 if (input) {
                     ComPointer<IMemAllocator> alloc;
-                    input->GetAllocator(&alloc);
+                    input->GetAllocator(alloc.pparam());
                     if (alloc) {
                         //be default we take the allocator from the input pin
                         //we have no reason to force using our own
