@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-Copyright (C) 2007 Trolltech ASA. All rights reserved.
+Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
 
 This library is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
@@ -472,7 +472,7 @@ namespace Phonon
             HRESULT hr = sample->GetTime(&start, &stop);
 
             ComPointer<IReferenceClock> clock;
-            GetSyncSource(&clock);
+            GetSyncSource(clock.pparam());
             if (SUCCEEDED(hr) && state() == State_Running && clock) {
                 REFERENCE_TIME current;
                 clock->GetTime(&current);
