@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-    Copyright (C) 2007 Trolltech ASA. All rights reserved.
+    Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
 
     This library is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -112,15 +112,11 @@ bool QuickTimeVideoPlayer::setGLContext(AGLContext aglContext, AGLPixelFormat ag
         BACKEND_ASSERT3(cglContext, "Could not get current CoreVideo GL context (OpenGL)", FATAL_ERROR, false)
 
         Q_UNUSED(aglPixelFormat);
-#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_5
-        GLint attributeCount = 2;
-#else
         long attributeCount = 2;
-#endif
         CGLPixelFormatAttribute pfa[attributeCount];
         pfa[0] = kCGLPFAWindow;
         pfa[1] = (CGLPixelFormatAttribute) 0;
-        err = CGLChoosePixelFormat(pfa, &cglPixelFormat, &attributeCount);
+        err = CGLChoosePixelFormat(pfa, &cglPixelFormat, (GLint *)&attributeCount);
         BACKEND_ASSERT3(err == noErr, "Could not create pixel format (OpenGL)", FATAL_ERROR, false)
     }
 
@@ -451,7 +447,7 @@ void QuickTimeVideoPlayer::openMovieFromFile()
 
 void QuickTimeVideoPlayer::openMovieFromUrl()
 {
-    QCFString urlString = QCFString(m_mediaSource.url().toString());
+    QCFString urlString = QCFString(m_mediaSource.url().toEncoded());
     CFURLRef url = CFURLCreateWithString(0, urlString, 0);
     DataReferenceRecord dataRef = {0, 0};
     QTNewDataReferenceFromCFURL(url, 0, &dataRef.dataRef, &dataRef.dataRefType);
