@@ -54,6 +54,7 @@
 #include "PlatformKeyboardEvent.h"
 #include "PlatformScrollBar.h"
 #include "PlatformWheelEvent.h"
+#include "RenderFrameSet.h"
 #include "RenderWidget.h"
 #include "SelectionController.h"
 #include "Settings.h"
@@ -657,6 +658,14 @@ Cursor EventHandler::selectCursor(const MouseEventWithHitTestResults& event, Pla
     RenderObject* renderer = node ? node->renderer() : 0;
     RenderStyle* style = renderer ? renderer->style() : 0;
 
+    if (renderer && renderer->isFrameSet()) {
+        RenderFrameSet* fs = static_cast<RenderFrameSet*>(renderer);
+        if (fs->canResizeRow(event.localPoint()))
+            return rowResizeCursor();
+        if (fs->canResizeColumn(event.localPoint()))
+            return columnResizeCursor();
+    }
+
     if (style && style->cursors()) {
         const CursorList* cursors = style->cursors();
         for (unsigned i = 0; i < cursors->size(); ++i) {
