@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2007 Apple Inc.  All rights reserved.
  * Copyright (C) 2007 Staikos Computing Services Inc. <info@staikos.net>
- * Copyright (C) 2007 Trolltech ASA
+ * Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies)
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -183,6 +183,10 @@ void PlatformScrollbar::paint(GraphicsContext* graphicsContext, const IntRect& d
 #else
     p->translate(topLeft);
     m_opt.rect.moveTo(QPoint(0, 0));
+
+    // The QStyle expects the background to be already filled
+    p->fillRect(m_opt.rect, m_opt.palette.background());
+
     QApplication::style()->drawComplexControl(QStyle::CC_ScrollBar, &m_opt, p, 0);
     m_opt.rect.moveTo(topLeft);
 #endif
@@ -238,12 +242,6 @@ bool PlatformScrollbar::handleMouseMoveEvent(const PlatformMouseEvent& evt)
     QStyle::SubControl sc = QApplication::style()->hitTestComplexControl(QStyle::CC_ScrollBar, &m_opt, pos, 0);
     m_opt.rect.moveTo(topLeft);
 
-    if (sc == m_pressedPart) {
-        m_opt.state |= QStyle::State_Sunken;
-    } else {
-        m_opt.state &= ~QStyle::State_Sunken;
-    }
-
     if (m_pressedPart == QStyle::SC_ScrollBarSlider) {
         // Drag the thumb.
         int thumbPos = thumbPosition();
@@ -267,7 +265,7 @@ bool PlatformScrollbar::handleMouseMoveEvent(const PlatformMouseEvent& evt)
             setValue((int)((float)(thumbPos + delta) * (m_totalSize - m_visibleSize) / (trackLen - thumbLen)));
             m_pressedPos += thumbPosition() - thumbPos;
         }
-        
+
         return true;
     }
 
@@ -291,7 +289,7 @@ bool PlatformScrollbar::handleMouseMoveEvent(const PlatformMouseEvent& evt)
             invalidate();
         }
         m_hoveredPart = sc;
-    } 
+    }
 
     return true;
 }
@@ -300,6 +298,7 @@ bool PlatformScrollbar::handleMouseOutEvent(const PlatformMouseEvent& evt)
 {
     m_opt.state &= ~QStyle::State_MouseOver;
     m_opt.state &= ~QStyle::State_Sunken;
+    m_hoveredPart = QStyle::SC_None;
     invalidate();
     return true;
 }
@@ -345,8 +344,18 @@ bool PlatformScrollbar::handleMousePressEvent(const PlatformMouseEvent& evt)
     return true;
 }
 
-bool PlatformScrollbar::handleMouseReleaseEvent(const PlatformMouseEvent&)
+bool PlatformScrollbar::handleMouseReleaseEvent(const PlatformMouseEvent& evt)
 {
+    const QPoint pos = convertFromContainingWindow(evt.pos());
+    const QPoint topLeft = m_opt.rect.topLeft();
+    m_opt.rect.moveTo(QPoint(0, 0));
+    QStyle::SubControl scAtMousePoint = QApplication::style()->hitTestComplexControl(QStyle::CC_ScrollBar, &m_opt, pos, 0);
+    m_opt.rect.moveTo(topLeft);
+
+    m_hoveredPart = scAtMousePoint;
+    if (m_hoveredPart == QStyle::SC_None)
+        m_opt.state &= ~QStyle::State_MouseOver;
+
     m_opt.state &= ~QStyle::State_Sunken;
     m_pressedPart = QStyle::SC_None;
     m_pressedPos = 0;
@@ -357,6 +366,7 @@ bool PlatformScrollbar::handleMouseReleaseEvent(const PlatformMouseEvent&)
 
 bool PlatformScrollbar::handleContextMenuEvent(const PlatformMouseEvent& event)
 {
+#ifndef QT_NO_CONTEXTMENU
     bool horizontal = (m_orientation == HorizontalScrollbar);
 
     QMenu menu;
@@ -394,7 +404,7 @@ bool PlatformScrollbar::handleContextMenuEvent(const PlatformMouseEvent& event)
         scroll(horizontal ? ScrollLeft : ScrollUp, ScrollByLine, 1);
     else if (actionSelected == actScrollDown)
         scroll(horizontal ? ScrollRight : ScrollDown, ScrollByLine, 1);
-
+#endif // QT_NO_CONTEXTMENU
     return true;
 }
 
