@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2007 Trolltech ASA
+    Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies)
     Copyright (C) 2007 Staikos Computing Services Inc.
     Copyright (C) 2007 Apple Inc.
 
@@ -62,6 +62,7 @@
 
 #include <QApplication>
 #include <QBasicTimer>
+#include <QBitArray>
 #include <QDebug>
 #include <QDragEnterEvent>
 #include <QDragLeaveEvent>
@@ -87,6 +88,18 @@
 
 using namespace WebCore;
 
+#ifndef QT_NO_CURSOR
+SetCursorEvent::SetCursorEvent(const QCursor& cursor)
+    : QEvent(static_cast<QEvent::Type>(EventType))
+    , m_cursor(cursor)
+{}
+
+QCursor SetCursorEvent::cursor() const
+{
+    return m_cursor;
+}
+#endif
+
 // If you change this make sure to also adjust the docs for QWebPage::userAgentForUrl
 #define WEBKIT_VERSION "523.15"
 
@@ -117,7 +130,6 @@ static inline Qt::DropAction dragOpToDropAction(unsigned actions)
 QWebPagePrivate::QWebPagePrivate(QWebPage *qq)
     : q(qq)
     , view(0)
-    , modified(false)
     , viewportSize(QSize(0,0))
     , hasFocus(false)
 {
@@ -132,10 +144,13 @@ QWebPagePrivate::QWebPagePrivate(QWebPage *qq)
 
     settings = new QWebSettings(page->settings());
 
+#ifndef QT_NO_UNDOSTACK
     undoStack = 0;
+#endif
     mainFrame = 0;
 #if QT_VERSION < 0x040400
     networkInterface = 0;
+    pluginFactory = 0;
 #else
     networkManager = 0;
     pluginFactory = 0;
@@ -143,7 +158,9 @@ QWebPagePrivate::QWebPagePrivate(QWebPage *qq)
     insideOpenCall = false;
     forwardUnsupportedContent = false;
     linkPolicy = QWebPage::DontDelegateLinks;
+#ifndef QT_NO_CONTEXTMENU
     currentContextMenu = 0;
+#endif
 
     history.d = new QWebHistoryPrivate(page->backForwardList());
     memset(actions, 0, sizeof(actions));
@@ -151,8 +168,12 @@ QWebPagePrivate::QWebPagePrivate(QWebPage *qq)
 
 QWebPagePrivate::~QWebPagePrivate()
 {
+#ifndef QT_NO_CONTEXTMENU
     delete currentContextMenu;
+#endif
+#ifndef QT_NO_UNDOSTACK
     delete undoStack;
+#endif
     delete settings;
     delete page;
 }
@@ -219,7 +240,9 @@ static QWebPage::WebAction webActionForContextMenuAction(WebCore::ContextMenuAct
     return QWebPage::NoWebAction;
 }
 
-QMenu *QWebPagePrivate::createContextMenu(const WebCore::ContextMenu *webcoreMenu, const QList<WebCore::ContextMenuItem> *items)
+#ifndef QT_NO_CONTEXTMENU
+QMenu *QWebPagePrivate::createContextMenu(const WebCore::ContextMenu *webcoreMenu,
+        const QList<WebCore::ContextMenuItem> *items, QBitArray *visitedWebActions)
 {
     QMenu* menu = new QMenu(view);
     for (int i = 0; i < items->count(); ++i) {
@@ -236,6 +259,7 @@ QMenu *QWebPagePrivate::createContextMenu(const WebCore::ContextMenu *webcoreMen
                     a->setChecked(desc.checked);
 
                     menu->addAction(a);
+                    visitedWebActions->setBit(action);
                 }
                 break;
             }
@@ -243,7 +267,7 @@ QMenu *QWebPagePrivate::createContextMenu(const WebCore::ContextMenu *webcoreMen
                 menu->addSeparator();
                 break;
             case WebCore::SubmenuType: {
-                QMenu *subMenu = createContextMenu(webcoreMenu, item.platformSubMenu());
+                QMenu *subMenu = createContextMenu(webcoreMenu, item.platformSubMenu(), visitedWebActions);
 
                 bool anyEnabledAction = false;
 
@@ -266,6 +290,7 @@ QMenu *QWebPagePrivate::createContextMenu(const WebCore::ContextMenu *webcoreMen
     }
     return menu;
 }
+#endif // QT_NO_CONTEXTMENU
 
 QWebFrame *QWebPagePrivate::frameAt(const QPoint &pos) const
 {
@@ -326,10 +351,12 @@ void QWebPagePrivate::updateAction(QWebPage::WebAction action)
         case QWebPage::Paste:
             enabled = editor->canPaste();
             break;
+#ifndef QT_NO_UNDOSTACK
         case QWebPage::Undo:
         case QWebPage::Redo:
             // those two are handled by QUndoStack
             break;
+#endif // QT_NO_UNDOSTACK
         default: break;
     }
 
@@ -427,10 +454,12 @@ void QWebPagePrivate::mouseReleaseEvent(QMouseEvent *ev)
         if (ev->button() == Qt::LeftButton) {
             if(focusFrame && (focusFrame->editor()->canCopy() || focusFrame->editor()->canDHTMLCopy())) {
                 focusFrame->editor()->copy();
+                ev->setAccepted(true);
             }
         } else if (ev->button() == Qt::MidButton) {
             if(focusFrame && (focusFrame->editor()->canPaste() || focusFrame->editor()->canDHTMLPaste())) {
                 focusFrame->editor()->paste();
+                ev->setAccepted(true);
             }
         }
         Pasteboard::generalPasteboard()->setSelectionMode(oldSelectionMode);
@@ -438,6 +467,7 @@ void QWebPagePrivate::mouseReleaseEvent(QMouseEvent *ev)
 #endif
 }
 
+#ifndef QT_NO_CONTEXTMENU
 void QWebPagePrivate::contextMenuEvent(QContextMenuEvent *ev)
 {
     if (currentContextMenu) {
@@ -446,7 +476,9 @@ void QWebPagePrivate::contextMenuEvent(QContextMenuEvent *ev)
         currentContextMenu = 0;
     }
 }
+#endif // QT_NO_CONTEXTMENU
 
+#ifndef QT_NO_WHEELEVENT
 void QWebPagePrivate::wheelEvent(QWheelEvent *ev)
 {
     WebCore::Frame* frame = QWebFramePrivate::core(mainFrame);
@@ -457,7 +489,9 @@ void QWebPagePrivate::wheelEvent(QWheelEvent *ev)
     bool accepted = frame->eventHandler()->handleWheelEvent(pev);
     ev->setAccepted(accepted);
 }
+#endif // QT_NO_WHEELEVENT
 
+#ifndef QT_NO_SHORTCUT
 static QWebPage::WebAction editorActionForKeyEvent(QKeyEvent* event)
 {
     static struct {
@@ -504,12 +538,14 @@ static QWebPage::WebAction editorActionForKeyEvent(QKeyEvent* event)
 
     return QWebPage::NoWebAction;
 }
+#endif // QT_NO_SHORTCUT
 
 void QWebPagePrivate::keyPressEvent(QKeyEvent *ev)
 {
     bool handled = false;
     WebCore::Frame* frame = page->focusController()->focusedOrMainFrame();
     WebCore::Editor* editor = frame->editor();
+#ifndef QT_NO_SHORTCUT
     if (editor->canEdit()) {
         QWebPage::WebAction action = editorActionForKeyEvent(ev);
         if (action != QWebPage::NoWebAction) {
@@ -517,51 +553,18 @@ void QWebPagePrivate::keyPressEvent(QKeyEvent *ev)
             handled = true;
         }
     }
+#endif // QT_NO_SHORTCUT
     if (!handled)
         handled = frame->eventHandler()->keyEvent(ev);
     if (!handled) {
         handled = true;
-        PlatformScrollbar *h, *v;
-        h = q->currentFrame()->d->horizontalScrollBar();
-        v = q->currentFrame()->d->verticalScrollBar();
         QFont defaultFont;
         if (view)
             defaultFont = view->font();
         QFontMetrics fm(defaultFont);
         int fontHeight = fm.height();
-        if (ev == QKeySequence::MoveToNextPage
-            || ev->key() == Qt::Key_Space) {
-            if (v)
-                v->setValue(v->value() + q->viewportSize().height() - fontHeight * 2);
-        } else if (ev == QKeySequence::MoveToPreviousPage) {
-            if (v)
-                v->setValue(v->value() - q->viewportSize().height() + fontHeight * 2);
-        } else if (ev->key() == Qt::Key_Up && ev->modifiers() & Qt::ControlModifier
-                   || ev->key() == Qt::Key_Home) {
-            if (v)
-                v->setValue(0);
-        } else if (ev->key() == Qt::Key_Down && ev->modifiers() & Qt::ControlModifier
-                   || ev->key() == Qt::Key_End) {
-            if (v)
-                v->setValue(INT_MAX);
-        } else {
+        if (!handleScrolling(ev)) {
             switch (ev->key()) {
-            case Qt::Key_Up:
-                if (v)
-                    v->setValue(v->value() - fontHeight);
-                break;
-            case Qt::Key_Down:
-                if (v)
-                    v->setValue(v->value() + fontHeight);
-                break;
-            case Qt::Key_Left:
-                if (h)
-                    h->setValue(h->value() - fontHeight);
-                break;
-            case Qt::Key_Right:
-                if (h)
-                    h->setValue(h->value() + fontHeight);
-                break;
             case Qt::Key_Backspace:
                 if (ev->modifiers() == Qt::ShiftModifier)
                     q->triggerAction(QWebPage::Forward);
@@ -664,11 +667,22 @@ void QWebPagePrivate::dropEvent(QDropEvent *ev)
 #endif
 }
 
+void QWebPagePrivate::leaveEvent(QEvent *ev)
+{
+    // Fake a mouse move event just outside of the widget, since all
+    // the interesting mouse-out behavior like invalidating scrollbars
+    // is handled by the WebKit event handler's mouseMoved function.
+    QMouseEvent fakeEvent(QEvent::MouseMove, QCursor::pos(), Qt::NoButton, Qt::NoButton, Qt::NoModifier);
+    mouseMoveEvent(&fakeEvent);
+}
+
 /*!
     \property QWebPage::palette
     \brief the page's palette
 
     The background brush of the palette is used to draw the background of the main frame.
+
+    By default, this property contains the application's default palette.
 */
 void QWebPage::setPalette(const QPalette &pal)
 {
@@ -741,6 +755,58 @@ void QWebPagePrivate::shortcutOverrideEvent(QKeyEvent* event)
     }
 }
 
+bool QWebPagePrivate::handleScrolling(QKeyEvent *ev)
+{
+    ScrollDirection direction;
+    ScrollGranularity granularity;
+
+#ifndef QT_NO_SHORTCUT
+    if (ev == QKeySequence::MoveToNextPage
+        || ev->key() == Qt::Key_Space) {
+        granularity = ScrollByPage;
+        direction = ScrollDown;
+    } else if (ev == QKeySequence::MoveToPreviousPage) {
+        granularity = ScrollByPage;
+        direction = ScrollUp;
+    } else
+#endif // QT_NO_SHORTCUT
+    if (ev->key() == Qt::Key_Up && ev->modifiers() & Qt::ControlModifier
+               || ev->key() == Qt::Key_Home) {
+        granularity = ScrollByDocument;
+        direction = ScrollUp;
+    } else if (ev->key() == Qt::Key_Down && ev->modifiers() & Qt::ControlModifier
+               || ev->key() == Qt::Key_End) {
+        granularity = ScrollByDocument;
+        direction = ScrollDown;
+    } else {
+        switch (ev->key()) {
+            case Qt::Key_Up:
+                granularity = ScrollByLine;
+                direction = ScrollUp;
+                break;
+            case Qt::Key_Down:
+                granularity = ScrollByLine;
+                direction = ScrollDown;
+                break;
+            case Qt::Key_Left:
+                granularity = ScrollByLine;
+                direction = ScrollLeft;
+                break;
+            case Qt::Key_Right:
+                granularity = ScrollByLine;
+                direction = ScrollRight;
+                break;
+            default:
+                return false;
+        }
+    }
+
+    if (!mainFrame->d->frame->eventHandler()->scrollOverflow(direction, granularity))
+        mainFrame->d->frame->view()->scroll(direction, granularity);
+
+    return true;
+}
+
 /*!
   This method is used by the input method to query a set of properties of the page
   to be able to support complex input method operations as support for surrounding
@@ -917,8 +983,8 @@ QVariant QWebPage::inputMethodQuery(Qt::InputMethodQuery property) const
     loadProgress() signal, on the other hand, is emitted whenever an element
     of the web page completes loading, such as an embedded image, a script,
     etc. Finally, the loadFinished() signal is emitted when the page has
-    loaded completely. It's argument - either \c true or \c false - indicates
-    load success or failure.
+    loaded completely. Its argument, either true or false, indicates whether
+    or not the load operation succeeded.
 
     \section1 Using QWebPage in a Widget-less Environment
 
@@ -1049,7 +1115,9 @@ void QWebPage::javaScriptConsoleMessage(const QString& message, int lineNumber,
 */
 void QWebPage::javaScriptAlert(QWebFrame *frame, const QString& msg)
 {
+#ifndef QT_NO_MESSAGEBOX
     QMessageBox::information(d->view, mainFrame()->title(), msg, QMessageBox::Ok);
+#endif
 }
 
 /*!
@@ -1060,7 +1128,11 @@ void QWebPage::javaScriptAlert(QWebFrame *frame, const QString& msg)
 */
 bool QWebPage::javaScriptConfirm(QWebFrame *frame, const QString& msg)
 {
+#ifdef QT_NO_MESSAGEBOX
+    return true;
+#else
     return QMessageBox::Yes == QMessageBox::information(d->view, mainFrame()->title(), msg, QMessageBox::Yes, QMessageBox::No);
+#endif
 }
 
 /*!
@@ -1345,6 +1417,9 @@ QSize QWebPage::viewportSize() const
 
     The size affects for example the visibility of scrollbars
     if the document is larger than the viewport.
+
+    By default, for a newly-created Web page, this property contains a size with
+    zero width and height.
 */
 void QWebPage::setViewportSize(const QSize &size) const
 {
@@ -1403,6 +1478,8 @@ bool QWebPage::acceptNavigationRequest(QWebFrame *frame, const QWebNetworkReques
     \property QWebPage::selectedText
     \brief the text currently selected
 
+    By default, this property contains an empty string.
+
     \sa selectionChanged()
 */
 QString QWebPage::selectedText() const
@@ -1494,7 +1571,7 @@ QAction *QWebPage::action(WebAction action) const
         case Paste:
             text = contextMenuItemTagPaste();
             break;
-
+#ifndef QT_NO_UNDOSTACK
         case Undo: {
             QAction *a = undoStack()->createUndoAction(d->q);
             d->actions[action] = a;
@@ -1505,6 +1582,7 @@ QAction *QWebPage::action(WebAction action) const
             d->actions[action] = a;
             return a;
         }
+#endif // QT_NO_UNDOSTACK
         case MoveToNextChar:
         case MoveToPreviousChar:
         case MoveToNextWord:
@@ -1586,12 +1664,21 @@ QAction *QWebPage::action(WebAction action) const
 /*!
     \property QWebPage::modified
     \brief whether the page contains unsubmitted form data
+
+    By default, this property is false.
 */
 bool QWebPage::isModified() const
 {
-    return d->modified;
+#ifdef QT_NO_UNDOSTACK
+    return false;
+#else
+    if (!d->undoStack)
+        return false;
+    return d->undoStack->canUndo();
+#endif // QT_NO_UNDOSTACK
 }
 
+#ifndef QT_NO_UNDOSTACK
 /*!
     Returns a pointer to the undo stack used for editable content.
 */
@@ -1602,6 +1689,7 @@ QUndoStack *QWebPage::undoStack() const
 
     return d->undoStack;
 }
+#endif // QT_NO_UNDOSTACK
 
 /*! \reimp
 */
@@ -1623,12 +1711,16 @@ bool QWebPage::event(QEvent *ev)
     case QEvent::MouseButtonRelease:
         d->mouseReleaseEvent(static_cast<QMouseEvent*>(ev));
         break;
+#ifndef QT_NO_CONTEXTMENU
     case QEvent::ContextMenu:
         d->contextMenuEvent(static_cast<QContextMenuEvent*>(ev));
         break;
+#endif
+#ifndef QT_NO_WHEELEVENT
     case QEvent::Wheel:
         d->wheelEvent(static_cast<QWheelEvent*>(ev));
         break;
+#endif
     case QEvent::KeyPress:
         d->keyPressEvent(static_cast<QKeyEvent*>(ev));
         break;
@@ -1660,6 +1752,9 @@ bool QWebPage::event(QEvent *ev)
     case QEvent::ShortcutOverride:
         d->shortcutOverrideEvent(static_cast<QKeyEvent*>(ev));
         break;
+    case QEvent::Leave:
+        d->leaveEvent(ev);
+        break;
     default:
         return QObject::event(ev);
     }
@@ -1725,6 +1820,7 @@ QWebPage::LinkDelegationPolicy QWebPage::linkDelegationPolicy() const
     return d->linkPolicy;
 }
 
+#ifndef QT_NO_CONTEXTMENU
 /*!
     Filters the context menu event, \a event, through handlers for scrollbars and
     custom event handlers in the web page. Returns true if the event was handled;
@@ -1754,6 +1850,7 @@ bool QWebPage::swallowContextMenuEvent(QContextMenuEvent *event)
 
     return !menu;
 }
+#endif // QT_NO_CONTEXTMENU
 
 /*!
     Updates the page's actions depending on the position \a pos. For example if \a pos is over an image
@@ -1761,13 +1858,14 @@ bool QWebPage::swallowContextMenuEvent(QContextMenuEvent *event)
 */
 void QWebPage::updatePositionDependentActions(const QPoint &pos)
 {
-    // disable position dependent actions first and enable them if WebCore adds them enabled to the context menu.
-
+    // First we disable all actions, but keep track of which ones were originally enabled.
+    QBitArray originallyEnabledWebActions(QWebPage::WebActionCount);
     for (int i = ContextMenuItemTagNoAction; i < ContextMenuItemBaseApplicationTag; ++i) {
         QWebPage::WebAction action = webActionForContextMenuAction(WebCore::ContextMenuAction(i));
-        QAction *a = this->action(action);
-        if (a)
+        if (QAction *a = this->action(action)) {
+            originallyEnabledWebActions.setBit(action, a->isEnabled());
             a->setEnabled(false);
+        }
     }
 
     WebCore::Frame* focusedFrame = d->page->focusController()->focusedOrMainFrame();
@@ -1779,11 +1877,33 @@ void QWebPage::updatePositionDependentActions(const QPoint &pos)
     if (d->page->inspectorController()->enabled())
         menu.addInspectElementItem();
 
+    QBitArray visitedWebActions(QWebPage::WebActionCount);
+
+#ifndef QT_NO_CONTEXTMENU
     delete d->currentContextMenu;
-    // createContextMenu also enables actions if necessary
-    d->currentContextMenu = d->createContextMenu(&menu, menu.platformDescription());
+
+    // Then we let createContextMenu() enable the actions that are put into the menu
+    d->currentContextMenu = d->createContextMenu(&menu, menu.platformDescription(), &visitedWebActions);
+#endif // QT_NO_CONTEXTMENU
+
+    // Finally, we restore the original enablement for the actions that were not put into the menu.
+    originallyEnabledWebActions &= ~visitedWebActions; // Mask out visited actions (they're part of the menu)
+    for (int i = 0; i < QWebPage::WebActionCount; ++i) {
+        if (originallyEnabledWebActions.at(i)) {
+            if (QAction *a = this->action(QWebPage::WebAction(i))) {
+                a->setEnabled(true);
+            }
+        }
+    }
+
+    // This whole process ensures that any actions put into to the context menu has the right
+    // enablement, while also keeping the correct enablement for actions that were left out of
+    // the menu.
+
 }
 
+
+
 /*!
     \enum QWebPage::Extension
 
@@ -1950,6 +2070,8 @@ QNetworkAccessManager *QWebPage::networkAccessManager() const
     Sets the QWebPluginFactory \a factory responsible for creating plugins embedded into this
     QWebPage.
 
+    Note: The plugin factory is only used if the QWebSettings::PluginsEnabled attribute is enabled.
+
     \sa pluginFactory()
 */
 void QWebPage::setPluginFactory(QWebPluginFactory *factory)
