@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2007-2008 Trolltech ASA
+    Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -216,7 +216,7 @@ QWebSettings *QWebSettings::globalSettings()
     QWebSettings also configures global properties such as the web page memory
     cache and the web page icon database.
 
-    \sa QWebPage::settings(), QWebView::settings(), \l{Browser}
+    \sa QWebPage::settings(), QWebView::settings(), {Browser}
 */
 
 /*!
@@ -442,6 +442,8 @@ void QWebSettings::clearIconDatabase()
     If the web site does not specify an icon, or the icon is not in the
     database, a null QIcon is returned.
 
+    \note The returned icon's size is arbitrary.
+
     \sa setIconDatabasePath()
 */
 QIcon QWebSettings::iconForUrl(const QUrl &url)
