@@ -1,5 +1,6 @@
 /*
-    Copyright (C) 2007 Trolltech ASA
+    Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies)
+    Copyright (C) 2008 Holger Hans Peter Freyther
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -20,6 +21,9 @@
 #include "config.h"
 #include "qwebview.h"
 #include "qwebframe.h"
+#include "qwebpage_p.h"
+
+#include "qbitmap.h"
 #include "qevent.h"
 #include "qpainter.h"
 #include "qprinter.h"
@@ -27,7 +31,40 @@
 class QWebViewPrivate
 {
 public:
+    QWebViewPrivate(QWebView *view)
+        : view(view)
+        , page(0)
+#ifndef QT_NO_CURSOR
+        , cursorSetByWebCore(false)
+        , usesWebCoreCursor(true)
+#endif
+    {}
+
+    QWebView *view;
     QWebPage *page;
+
+
+#ifndef QT_NO_CURSOR
+    /*
+     * We keep track of if we have called setCursor and if the CursorChange
+     * event is sent due our setCursor call and if we currently use the WebCore
+     * Cursor and use it to decide if we can update to another WebCore Cursor.
+     */
+    bool cursorSetByWebCore;
+    bool usesWebCoreCursor;
+
+    void setCursor(const QCursor& newCursor)
+    {
+        webCoreCursor = newCursor;
+
+        if (usesWebCoreCursor) {
+            cursorSetByWebCore = true;
+            view->setCursor(webCoreCursor);
+        }
+    }
+
+    QCursor webCoreCursor;
+#endif
 };
 
 /*!
@@ -41,7 +78,7 @@ public:
     It can be used in various applications to display web content live from the
     Internet.
 
-    The image below shows QWebView previewed in \QD with the Trolltech website.
+    The image below shows QWebView previewed in \QD with the Nokia website.
 
     \image qwebview-url.png
 
@@ -103,7 +140,8 @@ public:
     \image qwebview-diagram.png
 
     \note It is possible to use QWebPage and QWebFrame, without using QWebView,
-    if you do not require QWidget attributes.
+    if you do not require QWidget attributes. Nevertheless, QtWebKit depends
+    on QtGui, so you should use a QApplication instead of QCoreApplication.
 
     \sa {Previewer Example}, {Browser}
 */
@@ -116,14 +154,15 @@ public:
 QWebView::QWebView(QWidget *parent)
     : QWidget(parent)
 {
-    d = new QWebViewPrivate;
-    d->page = 0;
+    d = new QWebViewPrivate(this);
 
     QPalette pal = palette();
     pal.setBrush(QPalette::Background, Qt::white);
 
     setAttribute(Qt::WA_OpaquePaintEvent);
+#if !defined(Q_WS_QWS)
     setAttribute(Qt::WA_InputMethodEnabled);
+#endif
 
     setPalette(pal);
     setAcceptDrops(true);
@@ -137,6 +176,9 @@ QWebView::QWebView(QWidget *parent)
 */
 QWebView::~QWebView()
 {
+    if (d->page)
+        d->page->d->view = 0;
+
     if (d->page && d->page->parent() == this)
         delete d->page;
     delete d;
@@ -283,7 +325,7 @@ void QWebView::setContent(const QByteArray &data, const QString &mimeType, const
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.3rdparty.webkit.WebKit.qt.Api.qwebview.cpp 0
+    \snippet doc/src/snippets/code/src_3rdparty_webkit_WebKit_qt_Api_qwebview.cpp 0
 */
 QWebHistory *QWebView::history() const
 {
@@ -295,7 +337,7 @@ QWebHistory *QWebView::history() const
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.3rdparty.webkit.WebKit.qt.Api.qwebview.cpp 1
+    \snippet doc/src/snippets/code/src_3rdparty_webkit_WebKit_qt_Api_qwebview.cpp 1
 
     \sa QWebSettings::globalSettings()
 */
@@ -308,6 +350,8 @@ QWebSettings *QWebView::settings() const
     \property QWebView::title
     \brief the title of the web page currently viewed
 
+    By default, this property contains an empty string.
+
     \sa titleChanged()
 */
 QString QWebView::title() const
@@ -321,7 +365,9 @@ QString QWebView::title() const
     \property QWebView::url
     \brief the url of the web page currently viewed
 
-    Setting this property clears the view and loads the url.
+    Setting this property clears the view and loads the URL.
+
+    By default, this property contains an empty, invalid URL.
 
     \sa load(), urlChanged()
 */
@@ -342,7 +388,9 @@ QUrl QWebView::url() const
     \property QWebView::icon
     \brief the icon associated with the web page currently viewed
 
-    \sa iconChanged()
+    By default, this property contains a null icon.
+
+    \sa iconChanged(), QWebSettings::iconForUrl()
 */
 QIcon QWebView::icon() const
 {
@@ -355,6 +403,8 @@ QIcon QWebView::icon() const
     \property QWebView::selectedText
     \brief the text currently selected
 
+    By default, this property contains an empty string.
+
     \sa findText(), selectionChanged()
 */
 QString QWebView::selectedText() const
@@ -379,7 +429,7 @@ QAction *QWebView::pageAction(QWebPage::WebAction action) const
     The following example triggers the copy action and therefore copies any
     selected text to the clipboard.
 
-    \snippet doc/src/snippets/code/src.3rdparty.webkit.WebKit.qt.Api.qwebview.cpp 2
+    \snippet doc/src/snippets/code/src_3rdparty_webkit_WebKit_qt_Api_qwebview.cpp 2
 
     \sa pageAction()
 */
@@ -394,6 +444,8 @@ void QWebView::triggerPageAction(QWebPage::WebAction action, bool checked)
 
     Parts of HTML documents can be editable for example through the
     \c{contenteditable} attribute on HTML elements.
+
+    By default, this property is false.
 */
 bool QWebView::isModified() const
 {
@@ -436,6 +488,8 @@ QSize QWebView::sizeHint() const
 /*!
   \property QWebView::textSizeMultiplier
   \brief the scaling factor for all text in the frame
+
+  By default, this property contains a value of 1.0.
 */
 
 void QWebView::setTextSizeMultiplier(qreal factor)
@@ -467,6 +521,7 @@ bool QWebView::findText(const QString &subString, QWebPage::FindFlags options)
 bool QWebView::event(QEvent *e)
 {
     if (d->page) {
+#ifndef QT_NO_CONTEXTMENU
         if (e->type() == QEvent::ContextMenu) {
             QContextMenuEvent *event = static_cast<QContextMenuEvent *>(e);
             if (d->page->swallowContextMenuEvent(event)) {
@@ -474,10 +529,31 @@ bool QWebView::event(QEvent *e)
                 return true;
             }
             d->page->updatePositionDependentActions(event->pos());
-        } else if (e->type() == QEvent::ShortcutOverride) {
+        } else
+#endif // QT_NO_CONTEXTMENU
+        if (e->type() == QEvent::ShortcutOverride) {
+            d->page->event(e);
+#ifndef QT_NO_CURSOR
+        } else if (e->type() == static_cast<QEvent::Type>(WebCore::SetCursorEvent::EventType)) {
+            d->setCursor(static_cast<WebCore::SetCursorEvent*>(e)->cursor());
+#if QT_VERSION >= 0x040400
+        } else if (e->type() == QEvent::CursorChange) {
+            // Okay we might use the WebCore Cursor now.
+            d->usesWebCoreCursor = d->cursorSetByWebCore;
+            d->cursorSetByWebCore = false;
+
+            // Go back to the WebCore Cursor. QWidget::unsetCursor is appromixated with this
+            if (!d->usesWebCoreCursor && cursor().shape() == Qt::ArrowCursor) {
+                d->usesWebCoreCursor = true;
+                d->setCursor(d->webCoreCursor);
+            }
+#endif
+#endif
+        } else if (e->type() == QEvent::Leave) {
             d->page->event(e);
         }
     }
+
     return QWidget::event(e);
 }
 
@@ -488,7 +564,9 @@ bool QWebView::event(QEvent *e)
 */
 void QWebView::print(QPrinter *printer) const
 {
+#ifndef QT_NO_PRINTER
     page()->mainFrame()->print(printer);
+#endif
 }
 
 /*!
@@ -496,7 +574,7 @@ void QWebView::print(QPrinter *printer) const
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.3rdparty.webkit.WebKit.qt.Api.qwebview.cpp 3
+    \snippet doc/src/snippets/code/src_3rdparty_webkit_WebKit_qt_Api_qwebview.cpp 3
 
     \sa reload(), pageAction(), loadFinished()
 */
@@ -512,7 +590,7 @@ void QWebView::stop()
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.3rdparty.webkit.WebKit.qt.Api.qwebview.cpp 4
+    \snippet doc/src/snippets/code/src_3rdparty_webkit_WebKit_qt_Api_qwebview.cpp 4
 
     \sa forward(), pageAction()
 */
@@ -528,7 +606,7 @@ void QWebView::back()
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.3rdparty.webkit.WebKit.qt.Api.qwebview.cpp 5
+    \snippet doc/src/snippets/code/src_3rdparty_webkit_WebKit_qt_Api_qwebview.cpp 5
 
     \sa back(), pageAction()
 */
@@ -623,6 +701,7 @@ void QWebView::mouseReleaseEvent(QMouseEvent* ev)
         d->page->event(ev);
 }
 
+#ifndef QT_NO_CONTEXTMENU
 /*! \reimp
 */
 void QWebView::contextMenuEvent(QContextMenuEvent* ev)
@@ -630,7 +709,9 @@ void QWebView::contextMenuEvent(QContextMenuEvent* ev)
     if (d->page)
         d->page->event(ev);
 }
+#endif // QT_NO_CONTEXTMENU
 
+#ifndef QT_NO_WHEELEVENT
 /*! \reimp
 */
 void QWebView::wheelEvent(QWheelEvent* ev)
@@ -641,6 +722,7 @@ void QWebView::wheelEvent(QWheelEvent* ev)
     if (!ev->isAccepted())
         return QWidget::wheelEvent(ev);
 }
+#endif // QT_NO_WHEELEVENT
 
 /*! \reimp
 */
