@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006 Zack Rusin <zack@kde.org>
  * Copyright (C) 2006 Apple Computer, Inc.  All rights reserved.
- * Copyright (C) 2007-2008 Trolltech ASA
+ * Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies)
  *
  * All rights reserved.
  *
@@ -480,6 +480,20 @@ void FrameLoaderClientQt::postProgressEstimateChangedNotification()
 
 void FrameLoaderClientQt::postProgressFinishedNotification()
 {
+    // send a mousemove event to
+    // (1) update the cursor to change according to whatever is underneath the mouse cursor right now
+    // (2) display the tool tip if the mouse hovers a node which has a tool tip
+    if (m_frame && m_frame->eventHandler() && m_webFrame->page()) {
+        QWidget* view = m_webFrame->page()->view();
+        if (view && view->hasFocus()) {
+            QPoint localPos = view->mapFromGlobal(QCursor::pos());
+            if (view->rect().contains(localPos)) {
+                QMouseEvent event(QEvent::MouseMove, localPos, Qt::NoButton, Qt::NoButton, Qt::NoModifier);
+                m_frame->eventHandler()->mouseMoved(PlatformMouseEvent(&event, 0));
+            }
+        }
+    }
+
     if (m_webFrame && m_frame->page())
         emit loadFinished(m_loadSucceeded);
 }
@@ -760,6 +774,8 @@ bool FrameLoaderClientQt::shouldFallBack(const WebCore::ResourceError&)
 WTF::PassRefPtr<WebCore::DocumentLoader> FrameLoaderClientQt::createDocumentLoader(const WebCore::ResourceRequest& request, const SubstituteData& substituteData)
 {
     RefPtr<DocumentLoader> loader = new DocumentLoader(request, substituteData);
+    if (substituteData.isValid())
+        loader->setDeferMainResourceDataLoad(false);
     return loader.release();
 }
 
@@ -880,34 +896,46 @@ void FrameLoaderClientQt::dispatchDecidePolicyForMIMEType(FramePolicyFunction fu
         slotCallPolicyFunction(PolicyDownload);
 }
 
-void FrameLoaderClientQt::dispatchDecidePolicyForNewWindowAction(FramePolicyFunction function, const WebCore::NavigationAction&, const WebCore::ResourceRequest&, const WebCore::String&)
+void FrameLoaderClientQt::dispatchDecidePolicyForNewWindowAction(FramePolicyFunction function, const WebCore::NavigationAction& action, const WebCore::ResourceRequest& request, const WebCore::String&)
 {
     Q_ASSERT(!m_policyFunction);
+    Q_ASSERT(m_webFrame);
     m_policyFunction = function;
+#if QT_VERSION < 0x040400
+    QWebNetworkRequest r(request);
+#else
+    QNetworkRequest r(request.toNetworkRequest());
+#endif
+    QWebPage* page = m_webFrame->page();
+
+    if (!page->d->acceptNavigationRequest(0, r, QWebPage::NavigationType(action.type()))) {
+        if (action.type() == NavigationTypeFormSubmitted || action.type() == NavigationTypeFormResubmitted)
+            m_frame->loader()->resetMultipleFormSubmissionProtection();
+        slotCallPolicyFunction(PolicyIgnore);
+        return;
+    }
     slotCallPolicyFunction(PolicyUse);
 }
 
 void FrameLoaderClientQt::dispatchDecidePolicyForNavigationAction(FramePolicyFunction function, const WebCore::NavigationAction& action, const WebCore::ResourceRequest& request)
 {
     Q_ASSERT(!m_policyFunction);
+    Q_ASSERT(m_webFrame);
     m_policyFunction = function;
-    if (m_webFrame) {
 #if QT_VERSION < 0x040400
-        QWebNetworkRequest r(request);
+    QWebNetworkRequest r(request);
 #else
-        QNetworkRequest r(request.toNetworkRequest());
+    QNetworkRequest r(request.toNetworkRequest());
 #endif
-        QWebPage *page = m_webFrame->page();
+    QWebPage*page = m_webFrame->page();
 
-        if (!page->d->acceptNavigationRequest(m_webFrame, r, QWebPage::NavigationType(action.type()))) {
-            if (action.type() == NavigationTypeFormSubmitted || action.type() == NavigationTypeFormResubmitted)
-                m_frame->loader()->resetMultipleFormSubmissionProtection();
-            slotCallPolicyFunction(PolicyIgnore);
-            return;
-        }
+    if (!page->d->acceptNavigationRequest(m_webFrame, r, QWebPage::NavigationType(action.type()))) {
+        if (action.type() == NavigationTypeFormSubmitted || action.type() == NavigationTypeFormResubmitted)
+            m_frame->loader()->resetMultipleFormSubmissionProtection();
+        slotCallPolicyFunction(PolicyIgnore);
+        return;
     }
     slotCallPolicyFunction(PolicyUse);
-    return;
 }
 
 void FrameLoaderClientQt::dispatchUnableToImplementPolicy(const WebCore::ResourceError&)
@@ -1035,6 +1063,7 @@ Widget* FrameLoaderClientQt::createPlugin(const IntSize&, Element* element, cons
 
     if (mimeType == "application/x-qt-plugin" || mimeType == "application/x-qt-styled-widget") {
         object = m_webFrame->page()->createPlugin(element->getAttribute("classid"), qurl, params, values);
+#ifndef QT_NO_STYLE_STYLESHEET
         QWidget *widget = qobject_cast<QWidget *>(object);
         if (widget && mimeType == "application/x-qt-styled-widget") {
             CSSComputedStyleDeclaration cssDecl(element);
@@ -1054,6 +1083,7 @@ Widget* FrameLoaderClientQt::createPlugin(const IntSize&, Element* element, cons
 
             widget->setStyleSheet(styleSheet);
         }
+#endif // QT_NO_STYLE_STYLESHEET
     }
 
     if (!object) {
