@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -784,13 +778,13 @@ static void setup()
     KOI8-R encoding, and want to convert it to Unicode. The simple way
     to do it is like this:
 
-    \snippet doc/src/snippets/code/src.corelib.codecs.qtextcodec.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_codecs_qtextcodec.cpp 0
 
     After this, \c string holds the text converted to Unicode.
     Converting a string from Unicode to the local encoding is just as
     easy:
 
-    \snippet doc/src/snippets/code/src.corelib.codecs.qtextcodec.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_codecs_qtextcodec.cpp 1
 
     To read or write files in various encodings, use QTextStream and
     its \l{QTextStream::setCodec()}{setCodec()} function. See the
@@ -807,7 +801,7 @@ static void setup()
     object for the codec and use this QTextDecoder for the whole
     decoding process, as shown below:
 
-    \snippet doc/src/snippets/code/src.corelib.codecs.qtextcodec.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_codecs_qtextcodec.cpp 2
 
     The QTextDecoder object maintains state between chunks and therefore
     works correctly even if a multi-byte character is split between
@@ -953,7 +947,7 @@ QTextCodec* QTextCodec::codecForMib(int mib)
 {
     setup();
 
-    // Qt 3 used 1000 (mib for UCS2) as it's identifier for the utf16 codec. Map
+    // Qt 3 used 1000 (mib for UCS2) as its identifier for the utf16 codec. Map
     // this correctly for compatibility.
     if (mib == 1000)
         mib = 1015;
@@ -1447,7 +1441,7 @@ QString QTextDecoder::toUnicode(const QByteArray &ba)
     might use eucKR for all the text in the program, in which case the
     main() function might look like this:
 
-    \snippet doc/src/snippets/code/src.corelib.codecs.qtextcodec.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_codecs_qtextcodec.cpp 3
 
     Note that this is not the way to select the encoding that the \e
     user has chosen. For example, to convert an application containing
@@ -1488,6 +1482,8 @@ QString QTextDecoder::toUnicode(const QByteArray &ba)
 */
 
 /*!
+    \since 4.4
+
     Tries to detect the encoding of the provided snippet of html in the given byte array, \a ba,
     and returns a QTextCodec instance that is capable of decoding the html to unicode.
     If the codec cannot be detected from the content provided, \a defaultCodec is returned.
