@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -26,6 +40,8 @@
 
 #ifndef QT_NO_TEXTCODECPLUGIN
 
+QT_BEGIN_NAMESPACE
+
 /*!
     \class QTextCodecPlugin
     \brief The QTextCodecPlugin class provides an abstract base for custom QTextCodec plugins.
@@ -72,22 +88,7 @@
 
     Example:
 
-    \code
-        QList<QByteArray> MyCodecPlugin::names() const
-        {
-            return QList<QByteArray> << "IBM01140" << "hp15-tw";
-        }
-
-        QTextCodec *MyCodecPlugin::createForName(const QByteArray &name)
-        {
-            if (name == "IBM01140") {
-                return new Ibm01140Codec;
-            } else if (name == "hp15-tw") {
-                return new Hp15TwCodec;
-            }
-            return 0;
-        }
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_codecs_qtextcodecplugin.cpp 0
 
     \sa names()
 */
@@ -151,4 +152,6 @@ QTextCodec *QTextCodecPlugin::create(const QString &name)
     return createForName(name.toLatin1());
 }
 
+QT_END_NAMESPACE
+
 #endif // QT_NO_TEXTCODECPLUGIN
