@@ -1,57 +1,45 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
 #include "qthreadpool.h"
+#include "qthreadpool_p.h"
 
 #ifndef QT_NO_THREAD
 
-#include <QMutex>
-#include <QQueue>
-#include <QSet>
-#include <QWaitCondition>
-
-#include <private/qobject_p.h>
-
 QT_BEGIN_NAMESPACE
 
 inline bool operator<(int priority, const QPair<QRunnable *, int> &p)
@@ -82,39 +70,7 @@ public:
 /*
     QThreadPool private class.
 */
-class QThreadPoolPrivate : public QObjectPrivate
-{
-    Q_DECLARE_PUBLIC(QThreadPool)
-    friend class QThreadPoolThread;
 
-public:
-    QThreadPoolPrivate();
-
-    bool tryStart(QRunnable *task);
-    void enqueueTask(QRunnable *task, int priority = 0);
-    int activeThreadCount() const;
-
-    void tryToStartMoreThreads();
-    bool tooManyThreadsActive() const;
-
-    void startThread(QRunnable *runnable = 0);
-    void reset();
-    void waitForDone();
-
-    mutable QMutex mutex;
-    QWaitCondition runnableReady;
-    QSet<QThreadPoolThread *> allThreads;
-    QQueue<QThreadPoolThread *> expiredThreads;
-    QList<QPair<QRunnable *, int> > queue;
-    QWaitCondition noActiveThreads;
-
-    bool isExiting;
-    int expiryTimeout;
-    int maxThreadCount;
-    int reservedThreads;
-    int waitingThreads;
-    int activeThreads;
-};
 
 /*!\internal
 
@@ -332,6 +288,31 @@ void QThreadPoolPrivate::waitForDone()
         noActiveThreads.wait(locker.mutex());
 }
 
+/*! \internal
+    Pulls a runnable from the front queue and runs it in the current thread. Blocks
+    until the runnable has completed. Returns true if a runnable was found.
+*/
+bool QThreadPoolPrivate::startFrontRunnable()
+{
+    QMutexLocker locker(&mutex);
+    if (queue.isEmpty())
+        return false;
+
+    QRunnable *runnable = queue.takeFirst().first;
+    const bool autoDelete = runnable->autoDelete();
+    bool del = autoDelete && !--runnable->ref;
+
+    locker.unlock();
+    runnable->run();
+    locker.relock();
+
+    if (del) {
+        delete runnable;
+    }
+
+    return true;
+}
+
 /*!
     \class QThreadPool
     \brief The QThreadPool class manages a collection of QThreads.
@@ -347,7 +328,7 @@ void QThreadPoolPrivate::waitForDone()
     the run() virtual function. Then create an object of that class and pass
     it to QThreadPool::start().
 
-    \snippet doc/src/snippets/code/src.corelib.concurrent.qthreadpool.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_concurrent_qthreadpool.cpp 0
 
     QThreadPool deletes the QRunnable automatically by default. Use 
     QRunnable::setAutoDelete() to change the auto-deletion flag.
@@ -582,6 +563,7 @@ void QThreadPool::waitForDone()
 {
     Q_D(QThreadPool);
     d->waitForDone();
+    d->reset();
 }
 
 QT_END_NAMESPACE
