@@ -1,49 +1,45 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
 #include "qbuffer.h"
 #include "private/qiodevice_p.h"
 
+QT_BEGIN_NAMESPACE
+
 /** QBufferPrivate **/
 class QBufferPrivate : public QIODevicePrivate
 {
@@ -94,10 +90,7 @@ void QBufferPrivate::_q_emitSignals()
     interface. The QByteArray is treated just as a standard random-accessed
     file. Example:
 
-    \quotefromfile snippets/buffer/buffer.cpp
-    \skipto main_snippet
-    \skipto QBuffer buffer
-    \printto /^\}/
+    \snippet doc/src/snippets/buffer/buffer.cpp 0
 
     By default, an internal QByteArray buffer is created for you when
     you create a QBuffer. You can access this buffer directly by
@@ -115,16 +108,12 @@ void QBufferPrivate::_q_emitSignals()
     The following code snippet shows how to write data to a
     QByteArray using QDataStream and QBuffer:
 
-    \skipto write_datastream_snippet
-    \skipto QByteArray
-    \printto /^\}/
+    \snippet doc/src/snippets/buffer/buffer.cpp 1
 
     Effectively, we convert the application's QPalette into a byte
     array. Here's how to read the data from the QByteArray:
 
-    \skipto read_datastream_snippet
-    \skipto QPalette
-    \printto /^\}/
+    \snippet doc/src/snippets/buffer/buffer.cpp 2
 
     QTextStream and QDataStream also provide convenience constructors
     that take a QByteArray and that create a QBuffer behind the
@@ -187,10 +176,7 @@ QBuffer::QBuffer(QObject *parent)
 
     Example:
 
-    \quotefromfile snippets/buffer/buffer.cpp
-    \skipto bytearray_ptr_ctor_snippet
-    \skipto QByteArray
-    \printto /^\}/
+    \snippet doc/src/snippets/buffer/buffer.cpp 3
 
     \sa open(), setBuffer(), setData()
 */
@@ -226,10 +212,7 @@ QBuffer::~QBuffer()
 
     Example:
 
-    \quotefromfile snippets/buffer/buffer.cpp
-    \skipto setBuffer_snippet
-    \skipto QByteArray
-    \printto /^\}/
+    \snippet doc/src/snippets/buffer/buffer.cpp 4
 
     If \a byteArray is 0, the buffer creates its own internal
     QByteArray to work on. This byte array is initially empty.
@@ -378,7 +361,17 @@ qint64 QBuffer::size() const
 bool QBuffer::seek(qint64 pos)
 {
     Q_D(QBuffer);
-    if (pos < 0 || pos >= d->buf->size() + 1) {
+    if (pos > d->buf->size() && isWritable()) {
+        if (seek(d->buf->size())) {
+            const qint64 gapSize = pos - d->buf->size();
+            if (write(QByteArray(gapSize, 0)) != gapSize) {
+                qWarning("QBuffer::seek: Unable to fill gap");
+                return false;
+            }
+        } else {
+            return false;
+        }
+    } else if (pos > d->buf->size() || pos < 0) {
         qWarning("QBuffer::seek: Invalid pos: %d", int(pos));
         return false;
     }
@@ -448,6 +441,9 @@ qint64 QBuffer::writeData(const char *data, qint64 len)
     return len;
 }
 
+QT_END_NAMESPACE
+
 #ifndef QT_NO_QOBJECT
 # include "moc_qbuffer.cpp"
 #endif
+
