@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -81,11 +75,11 @@ QT_BEGIN_NAMESPACE
 
     Example (write binary data to a stream):
 
-    \snippet doc/src/snippets/code/src.corelib.io.qdatastream.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 0
 
     Example (read binary data from a stream):
 
-    \snippet doc/src/snippets/code/src.corelib.io.qdatastream.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 1
 
     Each item written to the stream is written in a predefined binary
     format that varies depending on the item's type. Supported Qt
@@ -120,7 +114,7 @@ QT_BEGIN_NAMESPACE
     compatibility, you can hardcode the version number in the
     application:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qdatastream.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 2
 
     If you are producing a new binary data format, such as a file
     format for documents created by your application, you could use a
@@ -128,11 +122,11 @@ QT_BEGIN_NAMESPACE
     would write a brief header containing a magic string and a version
     number to give yourself room for future expansion. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qdatastream.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 3
 
     Then read it in with:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qdatastream.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 4
 
     You can select which byte order to use when serializing data. The
     default setting is big endian (MSB first). Changing it to little
@@ -513,6 +507,7 @@ void QDataStream::setByteOrder(ByteOrder bo)
 
     \table
     \header \i Qt Version       \i QDataStream Version
+    \row \i Qt 4.4                  \i 10
     \row \i Qt 4.3                  \i 9
     \row \i Qt 4.2                  \i 8
     \row \i Qt 4.0, 4.1            \i 7
@@ -527,7 +522,7 @@ void QDataStream::setByteOrder(ByteOrder bo)
     The \l Version enum provides symbolic constants for the different
     versions of Qt. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qdatastream.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 5
 
     \sa version(), Version
 */
