@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -261,6 +255,15 @@ QFilePrivate::setError(QFile::FileError err, int errNum)
     implementation detail means that QFile is not suitable for reading and
     writing certain types of files, such as device files on Unix platforms.
 
+    \section1 Platform Specific Issues
+
+    File permissions are handled differently on Linux/Mac OS X and
+    Windows.  In a non \l{QIODevice::isWritable()}{writable}
+    directory on Linux, files cannot be created. This is not always
+    the case on Windows, where, for instance, the 'My Documents'
+    directory usually is not writable, but it is still possible to
+    create files in it.
+
     \sa QTextStream, QDataStream, QFileInfo, QDir, {The Qt Resource System}
 */
 
@@ -414,7 +417,7 @@ QString QFile::fileName() const
     \e{at the time of the open()} call.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfile.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_io_qfile.cpp 0
 
     Note that the directory separator "/" works for all operating
     systems supported by Qt.
@@ -467,7 +470,7 @@ QFile::encodeName(const QString &fileName)
     This is a typedef for a pointer to a function with the following
     signature:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qfile.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_io_qfile.cpp 1
 
     \sa setEncodingFunction(), encodeName()
 */
@@ -509,7 +512,7 @@ QFile::setEncodingFunction(EncoderFn f)
     This is a typedef for a pointer to a function with the following
     signature:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qfile.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_io_qfile.cpp 2
 
     \sa setDecodingFunction()
 */
@@ -946,7 +949,7 @@ bool QFile::open(OpenMode mode)
         return false;
     }
     if (fileEngine()->open(mode)) {
-        setOpenMode(mode);
+        QIODevice::open(mode);
         if (mode & Append)
             seek(size());
         return true;
@@ -970,31 +973,37 @@ bool QFile::open(OpenMode mode)
     Returns true if successful; otherwise returns false.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfile.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_io_qfile.cpp 3
 
     When a QFile is opened using this function, close() does not actually
     close the file, but only flushes it.
 
-    \warning If \a fh is \c stdin, \c stdout, or \c stderr, you may not be
-    able to seek(). See QIODevice::isSequentialAccess() for more
-    information.
+    \bold{Warning:}
+    \list 1
+        \o If \a fh is \c stdin, \c stdout, or \c stderr, you may not be able
+           to seek(). See QIODevice::isSequentialAccess() for more information.
+        \o Since this function opens the file without specifying the file name,
+           you cannot use this QFile with a QFileInfo.
+    \endlist
 
-    \bold{Note:} On Windows, you need to enable support for console applications
-    in order to use the stdin, stdout and stderr streams at the console. To do
-    this, add the following declaration to your application's project file:
-
-    \snippet doc/src/snippets/code/src.corelib.io.qfile.cpp 4
-
-    \note On Windows, \a fh must be opened in binary mode (i.e., the mode
-    string must contain 'b', as in "rb" or "wb") when accessing files and
-    other random-access devices. Qt will translate the end-of-line characters
-    if you pass QIODevice::Text to \a mode. Sequential devices, such as stdin
-    and stdout, are unaffected by this limitation.
-
-    \warning For Windows CE you may not be able to call seek(), setSize(), 
-    fileTime(). Also, size() is set to \c 0.
+    \note For Windows CE you may not be able to call seek() and resize().
+    Also, size() is set to \c 0.
 
     \sa close(), {qmake Variable Reference#CONFIG}{qmake Variable Reference}
+
+    \bold{Note for the Windows Platform}
+
+    \a fh must be opened in binary mode (i.e., the mode string must contain
+    'b', as in "rb" or "wb") when accessing files and other random-access
+    devices. Qt will translate the end-of-line characters if you pass
+    QIODevice::Text to \a mode. Sequential devices, such as stdin and stdout,
+    are unaffected by this limitation.
+
+    You need to enable support for console applications in order to use the
+    stdin, stdout and stderr streams at the console. To do this, add the
+    following declaration to your application's project file:
+
+    \snippet doc/src/snippets/code/src_corelib_io_qfile.cpp 4
 */
 bool QFile::open(FILE *fh, OpenMode mode)
 {
@@ -1011,7 +1020,7 @@ bool QFile::open(FILE *fh, OpenMode mode)
         return false;
     }
     if(d->openExternalFile(mode, fh)) {
-        setOpenMode(mode);
+        QIODevice::open(mode);
         if (mode & Append) {
             seek(size());
         } else {
@@ -1050,6 +1059,9 @@ bool QFile::open(FILE *fh, OpenMode mode)
     \warning For Windows CE you may not be able to call seek(), setSize(), 
     fileTime(). size() is set to \c 0.
 
+    \warning Since this function opens the file without specifying the file name,
+             you cannot use this QFile with a QFileInfo.
+
     \sa close()
 */
 bool QFile::open(int fd, OpenMode mode)
@@ -1067,7 +1079,7 @@ bool QFile::open(int fd, OpenMode mode)
         return false;
     }
     if(d->openExternalFile(mode, fd)) {
-        setOpenMode(mode);
+        QIODevice::open(mode);
         if (mode & Append)
             seek(size());
         return true;
@@ -1103,6 +1115,7 @@ QFile::handle() const
 
 /*!
     \enum QFile::MemoryMapFlags
+    \since 4.4
 
     This enum describes special options that may be used by the map()
     function.
