@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -315,29 +309,30 @@ void QInotifyFileSystemWatcherEngine::readFromInotify()
     ioctl(inotifyFd, FIONREAD, &buffSize);
     QVarLengthArray<char, 4096> buffer(buffSize);
     buffSize = read(inotifyFd, buffer.data(), buffSize);
-    inotify_event *ev = reinterpret_cast<inotify_event *>(buffer.data());
-    inotify_event *end = reinterpret_cast<inotify_event *>(buffer.data() + buffSize);
-    while (ev < end) {
-        // qDebug() << "inotify event, wd" << ev->wd << "mask" << hex << ev->mask;
+    const char *at = buffer.data();
+    const char * const end = at + buffSize;
+    while (at < end) {
+        const inotify_event *event = reinterpret_cast<const inotify_event *>(at);
+        // qDebug() << "inotify event, wd" << event->wd << "mask" << hex << event->mask;
 
-        int id = ev->wd;
+        int id = event->wd;
         QString path = idToPath.value(id);
         if (path.isEmpty()) {
             // perhaps a directory?
             id = -id;
             path = idToPath.value(id);
             if (path.isEmpty()) {
-                ev += sizeof(inotify_event) + ev->len;
+                at += sizeof(inotify_event) + event->len;
                 continue;
             }
         }
 
         // qDebug() << "event for path" << path;
 
-        if ((ev->mask & (IN_DELETE_SELF | IN_UNMOUNT)) != 0) {
+        if ((event->mask & (IN_DELETE_SELF | IN_UNMOUNT)) != 0) {
             pathToID.remove(path);
             idToPath.remove(id);
-            inotify_rm_watch(inotifyFd, ev->wd);
+            inotify_rm_watch(inotifyFd, event->wd);
 
             if (id < 0)
                 emit directoryChanged(path, true);
@@ -350,7 +345,7 @@ void QInotifyFileSystemWatcherEngine::readFromInotify()
                 emit fileChanged(path, false);
         }
 
-        ev += sizeof(inotify_event) + ev->len;
+        at += sizeof(inotify_event) + event->len;
     }
 }
 
