@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -58,6 +52,7 @@
 #include <private/qprocess_p.h>
 #include <qtextcodec.h>
 #include <qthread.h>
+#include <qthreadpool.h>
 #include <qthreadstorage.h>
 #include <private/qthread_p.h>
 #include <qlibraryinfo.h>
@@ -439,6 +434,7 @@ void QCoreApplication::init()
 
 #ifdef Q_OS_UNIX
     setlocale(LC_ALL, "");                // use correct char set mapping
+    setlocale(LC_NUMERIC, "C");        // make sprintf()/scanf() work
 #endif
 
 #ifdef Q_WS_WIN
@@ -500,7 +496,11 @@ QCoreApplication::~QCoreApplication()
     QCoreApplicationPrivate::is_app_closing = true;
     QCoreApplicationPrivate::is_app_running = false;
 
-#ifndef QT_NO_THREAD
+#if !defined(QT_NO_THREAD)
+#if !defined(QT_NO_CONCURRENT)
+    // Synchronize and stop the global thread pool threads.
+    QThreadPool::globalInstance()->waitForDone();
+#endif
     QThread::cleanup();
 #endif
 
@@ -895,7 +895,7 @@ void QCoreApplication::exit(int returnCode)
     The event is \e not deleted when the event has been sent. The normal
     approach is to create the event on the stack, for example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 0
 
     \sa postEvent(), notify()
 */
@@ -1409,7 +1409,7 @@ bool QCoreApplication::event(QEvent *e)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 1
 
     \sa exit(), aboutToQuit(), QApplication::lastWindowClosed()
 */
@@ -1444,7 +1444,16 @@ void QCoreApplication::quit()
     the first installed translation file. The search stops as soon as
     a matching translation is found.
 
-  \sa removeTranslator() translate() QTranslator::load()
+    Installing or removing a QTranslator, or changing an installed QTranslator
+    generates a \l{QEvent::LanguageChange}{LanguageChange} event for the 
+    QCoreApplication instance. A QApplication instance will propagate the event 
+    to all toplevel windows, where a reimplementation of changeEvent can 
+    re-translate the user interface by passing user-visible strings via the
+    tr() function to the respective property setters. User-interface classes
+    generated by \l{Qt Designer} provide a \c retranslateUi() function that can be
+    called.
+
+  \sa removeTranslator() translate() QTranslator::load() {Dynamic Translation}
 */
 
 void QCoreApplication::installTranslator(QTranslator *translationFile)
@@ -1726,6 +1735,8 @@ QString QCoreApplication::applicationFilePath()
 }
 
 /*!
+    \since 4.4
+
     Returns the current process ID for the application.
 */
 qint64 QCoreApplication::applicationPid()
@@ -1952,7 +1963,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(QMutex, libraryPathMutex, (QMutex::Recursive))
     If you want to iterate over the list, you can use the \l foreach
     pseudo-keyword:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 2
 
     \sa setLibraryPaths(), addLibraryPath(), removeLibraryPath(), QLibrary,
         {How to Create Qt Plugins}
@@ -2006,11 +2017,13 @@ QStringList QCoreApplication::libraryPaths()
  */
 void QCoreApplication::setLibraryPaths(const QStringList &paths)
 {
+#if !defined(QT_NO_LIBRARY) && !defined(QT_NO_SETTINGS)
     QMutexLocker locker(libraryPathMutex());
     if (!coreappdata()->app_libpaths)
         coreappdata()->app_libpaths = new QStringList;
     *(coreappdata()->app_libpaths) = paths;
     QFactoryLoader::refreshAll();
+#endif
 }
 
 /*!
@@ -2026,6 +2039,7 @@ void QCoreApplication::setLibraryPaths(const QStringList &paths)
  */
 void QCoreApplication::addLibraryPath(const QString &path)
 {
+#if !defined(QT_NO_LIBRARY) && !defined(QT_NO_SETTINGS)
     if (path.isEmpty())
         return;
 
@@ -2040,6 +2054,7 @@ void QCoreApplication::addLibraryPath(const QString &path)
         coreappdata()->app_libpaths->prepend(canonicalPath);
         QFactoryLoader::refreshAll();
     }
+#endif
 }
 
 /*!
@@ -2050,6 +2065,7 @@ void QCoreApplication::addLibraryPath(const QString &path)
 */
 void QCoreApplication::removeLibraryPath(const QString &path)
 {
+#if !defined(QT_NO_LIBRARY) && !defined(QT_NO_SETTINGS)
     if (path.isEmpty())
         return;
 
@@ -2061,6 +2077,7 @@ void QCoreApplication::removeLibraryPath(const QString &path)
     QString canonicalPath = QDir(path).canonicalPath();
     coreappdata()->app_libpaths->removeAll(canonicalPath);
     QFactoryLoader::refreshAll();
+#endif
 }
 
 #endif //QT_NO_LIBRARY
@@ -2071,7 +2088,7 @@ void QCoreApplication::removeLibraryPath(const QString &path)
     A function with the following signature that can be used as an
     event filter:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 3
 
     \sa setEventFilter()
 */
@@ -2268,7 +2285,7 @@ int QCoreApplication::loopLevel()
     The function specified by \a ptr should take no arguments and should
     return nothing. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 4
 
     Note that for an application- or module-wide cleanup,
     qAddPostRoutine() is often not suitable. For example, if the
@@ -2282,7 +2299,7 @@ int QCoreApplication::loopLevel()
     parent-child mechanism to call a cleanup function at the right
     time:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 5
 
     By selecting the right parent object, this can often be made to
     clean up the module's data at the right moment.
@@ -2296,7 +2313,7 @@ int QCoreApplication::loopLevel()
     translation functions, \c tr() and \c trUtf8(), with these
     signatures:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 6
 
     This macro is useful if you want to use QObject::tr() or
     QObject::trUtf8() in classes that don't inherit from QObject.
@@ -2305,7 +2322,7 @@ int QCoreApplication::loopLevel()
     class definition (before the first \c{public:} or \c{protected:}).
     For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qcoreapplication.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_kernel_qcoreapplication.cpp 7
 
     The \a context parameter is normally the class name, but it can
     be any string.
