@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -42,15 +56,22 @@
 #include "private/qcrashhandler_p.h"
 #include "qbytearray.h" // for qvsnprintf()
 
+#ifndef QT_NO_CRASHHANDLER
+
 #include <stdio.h>
 #include <signal.h>
 #include <stdlib.h>
 
+QT_BEGIN_NAMESPACE
+
 QtCrashHandler QSegfaultHandler::callback = 0;
 
-#if defined(__GLIBC__) && (__GLIBC__ >= 2) && !defined(__UCLIBC__)
+#if defined(__GLIBC__) && (__GLIBC__ >= 2) && !defined(__UCLIBC__) && !defined(QT_LSB)
+QT_BEGIN_INCLUDE_NAMESPACE
 # include "qstring.h"
 # include <execinfo.h>
+QT_END_INCLUDE_NAMESPACE
+
 static void print_backtrace(FILE *outb)
 {
     void *stack[128];
@@ -70,8 +91,10 @@ static void print_backtrace(FILE *outb)
 static void init_backtrace(char **, int)
 {
 }
+
 #else /* Don't use the GLIBC callback */
 /* Code sourced from: */
+QT_BEGIN_INCLUDE_NAMESPACE
 #include <stdarg.h>
 #include <string.h>
 #include <errno.h>
@@ -80,6 +103,8 @@ static void init_backtrace(char **, int)
 #if defined(Q_OS_IRIX) && defined(USE_LIBEXC)
 # include <libexc.h>
 #endif
+QT_END_INCLUDE_NAMESPACE
+
 
 static char *globalProgName = NULL;
 static bool backtrace_command(FILE *outb, const char *format, ...)
@@ -385,3 +410,7 @@ QSegfaultHandler::initialize(char **argv, int argc)
     sigaction(SIGSEGV, &SignalAction, NULL);
     sigaction(SIGBUS, &SignalAction, NULL);
 }
+
+QT_END_NAMESPACE
+
+#endif // QT_NO_CRASHHANDLER
