@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -343,8 +337,14 @@ int QMetaObject::classInfoOffset() const
 }
 
 /*!
-    Returns the number of methods in this class. These include
-    signals and slots.
+    Returns the number of methods in this class, including the number of
+    properties provided by each base class. These include signals and slots
+    as well as normal member functions.
+
+    Use code like the following to obtain a QStringList containing the methods
+    specific to a given class:
+
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp methodCount
 
     \sa method(), methodOffset(), indexOfMethod()
 */
@@ -376,7 +376,13 @@ int QMetaObject::enumeratorCount() const
 }
 
 /*!
-    Returns the number of properties in this class.
+    Returns the number of properties in this class, including the number of
+    properties provided by each base class.
+
+    Use code like the following to obtain a QStringList containing the properties
+    specific to a given class:
+
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp propertyCount
 
     \sa property(), propertyOffset(), indexOfProperty()
 */
@@ -685,7 +691,7 @@ QMetaProperty QMetaObject::userProperty() const
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetaobject.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp 0
 
     \sa classInfoCount(), classInfoOffset(), indexOfClassInfo()
  */
@@ -773,7 +779,7 @@ static char *qNormalizeType(char *d, int &templdepth, QByteArray &result)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetaobject.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp 1
 
     \sa normalizedSignature()
  */
@@ -870,7 +876,7 @@ QByteArray QMetaObject::normalizedSignature(const char *method)
     \l{QPushButton::animateClick()}{animateClick()} slot on a
     QPushButton:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetaobject.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp 2
 
     With asynchronous method invocations, the parameters must be of
     types that are known to Qt's meta-object system, because Qt needs
@@ -878,7 +884,7 @@ QByteArray QMetaObject::normalizedSignature(const char *method)
     scenes. If you try to use a queued connection and get the error
     message
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetaobject.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp 3
 
     call qRegisterMetaType() to register the data type before you
     call invokeMethod().
@@ -886,7 +892,7 @@ QByteArray QMetaObject::normalizedSignature(const char *method)
     To synchronously invoke the \c compute(QString, int, double) slot on
     some arbitrary object \c obj retrieve its return value:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetaobject.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp 4
 
     If the "compute" slot does not take exactly one QString, one int
     and one double in the specified order, the call will fail.
@@ -2010,7 +2016,7 @@ bool QMetaProperty::isEditable(const QObject *object) const
     are specified using Q_CLASSINFO() in the source code. The
     information can be retrieved using name() and value(). For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetaobject.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetaobject.cpp 5
 
     This mechanism is free for you to use in your Qt applications. Qt
     doesn't use it for any of its classes.
