@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -92,16 +86,16 @@ QT_BEGIN_NAMESPACE
 
     This example shows a typical use case of Q_DECLARE_METATYPE():
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 0
 
     If \c MyStruct is in a namespace, the Q_DECLARE_METATYPE() macro
     has to be outside the namespace:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 1
 
     Since \c{MyStruct} is now known to QMetaType, it can be used in QVariant:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 2
 
     \sa qRegisterMetaType()
 */
@@ -206,7 +200,7 @@ QT_BEGIN_NAMESPACE
     The following code allocates and destructs an instance of
     \c{MyClass}:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 3
 
     If we want the stream operators \c operator<<() and \c
     operator>>() to work on QVariant objects that store custom types,
@@ -441,6 +435,8 @@ int QMetaType::registerType(const char *typeName, Destructor destructor,
 }
 
 /*! 
+    \since 4.4
+
     Unregisters a user type, with \a typeName. 
 
     \sa type(), typeName()
@@ -1247,7 +1243,7 @@ void QMetaType::destroy(int type, void *data)
 
     This example registers the class \c{MyClass}:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 4
 
     \sa qRegisterMetaTypeStreamOperators(), QMetaType::isRegistered(),
         Q_DECLARE_METATYPE()
@@ -1265,11 +1261,11 @@ void QMetaType::destroy(int type, void *data)
     QMetaType::save(). These functions are used when streaming a
     QVariant.
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 5
 
     The stream operators should have the following signatures:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 6
 
     \sa qRegisterMetaType(), QMetaType::isRegistered(), Q_DECLARE_METATYPE()
 */
@@ -1298,7 +1294,7 @@ void QMetaType::destroy(int type, void *data)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 7
 
     To use the type \c T in QVariant, using Q_DECLARE_METATYPE() is
     sufficient. To use the type \c T in queued signal and slot connections,
@@ -1324,7 +1320,7 @@ void QMetaType::destroy(int type, void *data)
 
     Typical usage:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 8
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 8
 
     QMetaType::type() returns the same ID as qMetaTypeId(), but does
     a lookup at runtime based on the name of the type.
