@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -113,13 +107,13 @@ QVariant QMimeDataPrivate::retrieveTypedData(const QString &format, QVariant::Ty
     // provide more conversion possiblities than just what QVariant provides
 
     // URLs can be lists as well...
-    if (type == QVariant::Url && data.type() == QVariant::List
-        || type == QVariant::List && data.type() == QVariant::Url)
+    if ((type == QVariant::Url && data.type() == QVariant::List)
+        || (type == QVariant::List && data.type() == QVariant::Url))
         return data;
 
     // images and pixmaps are interchangeable
-    if (type == QVariant::Pixmap && data.type() == QVariant::Image
-        || type == QVariant::Image && data.type() == QVariant::Pixmap)
+    if ((type == QVariant::Pixmap && data.type() == QVariant::Image)
+        || (type == QVariant::Image && data.type() == QVariant::Pixmap))
         return data;
 
     if (data.type() == QVariant::ByteArray) {
@@ -237,7 +231,7 @@ QVariant QMimeDataPrivate::retrieveTypedData(const QString &format, QVariant::Ty
     For example, if your write a widget that accepts URL drags, you
     would end up writing code like this:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 0
 
     There are three approaches for storing custom data in a QMimeData
     object:
@@ -246,7 +240,7 @@ QVariant QMimeDataPrivate::retrieveTypedData(const QString &format, QVariant::Ty
     \o  Custom data can be stored directly in a QMimeData object as a
         QByteArray using setData(). For example:
 
-        \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 1
+        \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 1
 
     \o  We can subclass QMimeData and reimplement hasFormat(),
         formats(), and retrieveData().
@@ -256,7 +250,7 @@ QVariant QMimeDataPrivate::retrieveTypedData(const QString &format, QVariant::Ty
         it, and use a qobject_cast() in the receiver's drop event
         handler. For example:
 
-        \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 2
+        \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 2
     \endlist
 
     \section1 Platform-Specific MIME Types
@@ -266,11 +260,11 @@ QVariant QMimeDataPrivate::retrieveTypedData(const QString &format, QVariant::Ty
     indicate that they represent data in non-standard formats.
     The formats will take the following form:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 3
 
     The following are examples of custom MIME types:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 4
 
     The \c value declaration of each format describes the way in which the
     data is encoded.
@@ -434,7 +428,7 @@ bool QMimeData::hasHtml() const
     library, whereas QImage belongs to \l QtGui. To convert the
     QVariant to a QImage, simply use qvariant_cast(). For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 5
 
     \sa hasImage()
 */
@@ -451,7 +445,7 @@ QVariant QMimeData::imageData() const
     library, whereas QImage belongs to \l QtGui. The conversion
     from QImage to QVariant is implicit. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 6
 
     \sa hasImage(), setData()
 */
@@ -481,7 +475,7 @@ bool QMimeData::hasImage() const
     library, whereas QColor belongs to \l QtGui. To convert the
     QVariant to a QColor, simply use qvariant_cast(). For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmimedata.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmimedata.cpp 7
 
     \sa hasColor(), setColorData(), data()
 */
@@ -535,7 +529,13 @@ QByteArray QMimeData::data(const QString &mimeType) const
     functions setText(), setHtml(), setUrls(), setImageData(), and
     setColorData() instead.
 
-    \sa hasFormat()
+    Note that if you want to use a custom data type in an item view drag and drop
+    operation, you must register it as a Qt \l{QMetaType}{meta type}, using the
+    Q_DECLARE_METATYPE() macro, and implement stream operators for it. The stream
+    operators must then be registered with the qRegisterMetaTypeStreamOperators()
+    function.
+
+    \sa hasFormat(), QMetaType, qRegisterMetaTypeStreamOperators()
 */
 void QMimeData::setData(const QString &mimeType, const QByteArray &data)
 {
@@ -610,6 +610,8 @@ void QMimeData::clear()
 }
 
 /*!
+    \since 4.4
+
     Removes the data entry for \a mimeType in the object.
 */
 void QMimeData::removeFormat(const QString &mimeType)
