@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -28,6 +42,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
 class QString;
@@ -41,7 +57,7 @@ class QByteArray;
 // The following macros are our "extensions" to C++
 // They are used, strictly speaking, only by the moc.
 
-#ifndef QT_MOC_CPP
+#ifndef Q_MOC_RUN
 # if defined(QT_NO_KEYWORDS)
 #  define QT_NO_EMIT
 # else
@@ -51,6 +67,7 @@ class QByteArray;
 # define Q_SLOTS
 # define Q_SIGNALS protected
 # define Q_PRIVATE_SLOT(d, signature)
+# define Q_EMIT
 #ifndef QT_NO_EMIT
 # define emit
 #endif
@@ -69,25 +86,63 @@ class QByteArray;
 #ifndef QT_NO_TRANSLATION
 # ifndef QT_NO_TEXTCODEC
 // full set of tr functions
+// ### Qt 5: merge overloads
 #  define QT_TR_FUNCTIONS \
     static inline QString tr(const char *s, const char *c = 0) \
         { return staticMetaObject.tr(s, c); } \
     static inline QString trUtf8(const char *s, const char *c = 0) \
-        { return staticMetaObject.trUtf8(s, c); }
+        { return staticMetaObject.trUtf8(s, c); } \
+    static inline QString tr(const char *s, const char *c, int n) \
+        { return staticMetaObject.tr(s, c, n); } \
+    static inline QString trUtf8(const char *s, const char *c, int n) \
+        { return staticMetaObject.trUtf8(s, c, n); }
 # else
 // no QTextCodec, no utf8
+// ### Qt 5: merge overloads
 #  define QT_TR_FUNCTIONS \
     static inline QString tr(const char *s, const char *c = 0) \
-        { return staticMetaObject.tr(s, c); }
+        { return staticMetaObject.tr(s, c); } \
+    static inline QString tr(const char *s, const char *c, int n) \
+        { return staticMetaObject.tr(s, c, n); }
 # endif
 #else
 // inherit the ones from QObject
 # define QT_TR_FUNCTIONS
 #endif
 
+#if defined(QT_NO_MEMBER_TEMPLATES) || defined(QT_NO_QOBJECT_CHECK)
+/* tmake ignore Q_OBJECT */
+#define Q_OBJECT_CHECK
+#else
+
+/* This is a compile time check that ensures that any class cast with qobject_cast
+   actually contains a Q_OBJECT macro. Note: qobject_cast will fail if a QObject
+   subclass doesn't contain Q_OBJECT.
+
+   In qt_check_for_QOBJECT_macro, we call a dummy templated function with two
+   parameters, the first being "this" and the other the target of the qobject
+   cast. If the types are not identical, we know that a Q_OBJECT macro is missing.
+
+   If you get a compiler error here, make sure that the class you are casting
+   to contains a Q_OBJECT macro.
+*/
+
+/* tmake ignore Q_OBJECT */
+#define Q_OBJECT_CHECK \
+    template <typename T> inline void qt_check_for_QOBJECT_macro(const T &_q_argument) const \
+    { int i = qYouForgotTheQ_OBJECT_Macro(this, &_q_argument); i = i; }
+
+template <typename T>
+inline int qYouForgotTheQ_OBJECT_Macro(T, T) { return 0; }
+
+template <typename T1, typename T2>
+inline void qYouForgotTheQ_OBJECT_Macro(T1, T2) {}
+#endif // QT_NO_MEMBER_TEMPLATES
+
 /* tmake ignore Q_OBJECT */
 #define Q_OBJECT \
 public: \
+    Q_OBJECT_CHECK \
     static const QMetaObject staticMetaObject; \
     virtual const QMetaObject *metaObject() const; \
     virtual void *qt_metacast(const char *); \
@@ -101,12 +156,13 @@ private:
 public: \
     static const QMetaObject staticMetaObject; \
 private:
-#else // QT_MOC_CPP
+#else // Q_MOC_RUN
 #define slots slots
 #define signals signals
 #define Q_SLOTS Q_SLOTS
 #define Q_SIGNALS Q_SIGNALS
 #define Q_CLASSINFO(name, value) Q_CLASSINFO(name, value)
+#define Q_INTERFACES(x) Q_INTERFACES(x)
 #define Q_PROPERTY(text) Q_PROPERTY(text)
 #define Q_OVERRIDE(text) Q_OVERRIDE(text)
 #define Q_ENUMS(x) Q_ENUMS(x)
@@ -122,7 +178,7 @@ private:
 #define Q_GADGET Q_GADGET
 #define Q_SCRIPTABLE Q_SCRIPTABLE
 #define Q_INVOKABLE Q_INVOKABLE
-#endif //QT_MOC_CPP
+#endif //Q_MOC_RUN
 
 // macro for onaming members
 #ifdef METHOD
@@ -149,8 +205,8 @@ private:
 #define QSLOT_CODE        1
 #define QSIGNAL_CODE        2
 
-#define Q_ARG(type, data) QArgument<type>(#type, data)
-#define Q_RETURN_ARG(type, data) QReturnArgument<type>(#type, data)
+#define Q_ARG(type, data) QArgument<type >(#type, data)
+#define Q_RETURN_ARG(type, data) QReturnArgument<type >(#type, data)
 
 class QObject;
 class QMetaMethod;
@@ -190,7 +246,7 @@ public:
 };
 
 
-template<class T>
+template <typename T>
 class QReturnArgument: public QGenericReturnArgument
 {
 public:
@@ -207,8 +263,11 @@ struct Q_CORE_EXPORT QMetaObject
     QObject *cast(QObject *obj) const;
 
 #ifndef QT_NO_TRANSLATION
+    // ### Qt 4: Merge overloads
     QString tr(const char *s, const char *c) const;
     QString trUtf8(const char *s, const char *c) const;
+    QString tr(const char *s, const char *c, int n) const;
+    QString trUtf8(const char *s, const char *c, int n) const;
 #endif // QT_NO_TRANSLATION
 
     int methodOffset() const;
@@ -232,9 +291,11 @@ struct Q_CORE_EXPORT QMetaObject
     QMetaEnum enumerator(int index) const;
     QMetaProperty property(int index) const;
     QMetaClassInfo classInfo(int index) const;
+    QMetaProperty userProperty() const;
 
     static bool checkConnectArgs(const char *signal, const char *method);
     static QByteArray normalizedSignature(const char *method);
+    static QByteArray normalizedType(const char *type);
 
     // internal index-based connect
     static bool connect(const QObject *sender, int signal_index,
@@ -356,6 +417,8 @@ inline const char *QMetaObject::superClassName() const
 { return d.superdata ? d.superdata->className() : 0; }
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QOBJECTDEFS_H
