@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -28,6 +42,10 @@
 #include "qabstracteventdispatcher.h"
 #include "qcoreapplication.h"
 
+#include "qobject_p.h"
+#include <private/qthread_p.h>
+
+QT_BEGIN_NAMESPACE
 
 /*!
     \class QSocketNotifier
@@ -36,13 +54,11 @@
 
     \ingroup io
 
-    The QSocketNotifier makes it possible to integrate Qt's event loop
-    with other event loops based on file descriptors. For example, the
-    \l
-    {http://www.trolltech.com/products/solutions/catalog/4/Utilities/qtcorba/}
-    {QtCorba Solution} uses it to process CORBA events.  File
-    descriptor action is detected in Qt's main event loop
-    (QCoreApplication::exec()).
+    The QSocketNotifier makes it possible to integrate Qt's event
+    loop with other event loops based on file descriptors. For
+    example, the \l{CORBA Framework} uses it to process CORBA
+    events.  File descriptor action is detected in Qt's main event
+    loop (QCoreApplication::exec()).
 
     \target write notifiers
 
@@ -76,8 +92,41 @@
     QTcpSocket and QUdpSocket provide notification through signals, so
     there is normally no need to use a QSocketNotifier on them.
 
-    \bold{Note for Windows users:} The socket passed to QSocketNotifier
-    will become non-blocking, even if it was created as a blocking socket.
+    \section1 Notes for Windows Users
+
+    The socket passed to QSocketNotifier will become non-blocking, even if
+    it was created as a blocking socket.
+    The activated() signal is sometimes triggered by high general activity
+    on the host, even if there is nothing to read. A subsequent read from
+    the socket can then fail, the error indicating that there is no data
+    available (e.g., \c{WSAEWOULDBLOCK}). This is an operating system
+    limitation, and not a bug in QSocketNotifier.
+
+    To ensure that the socket notifier handles read notifications correctly,
+    follow these steps when you receive a notification:
+
+    \list 1
+    \o Disable the notifier.
+    \o Read data from the socket.
+    \o Re-enable the notifier if you are interested in more data (such as after
+       having written a new command to a remote server).
+    \endlist
+
+    To ensure that the socket notifier handles write notifications correctly,
+    follow these steps when you receive a notification:
+
+    \list 1
+    \o Disable the notifier.
+    \o Write as much data as you can (before \c EWOULDBLOCK is returned).
+    \o Re-enable notifier if you have more data to write.
+    \endlist
+
+    \bold{Further information:}
+    On Windows, Qt always disables the notifier after getting a notification,
+    and only re-enables it if more data is expected. For example, if data is
+    read from the socket and it can be used to read more, or if reading or
+    writing is not possible because the socket would block, in which case
+    it is necessary to wait before attempting to read or write again.
 
     \sa QFile, QProcess, QTcpSocket, QUdpSocket
 */
@@ -127,11 +176,11 @@ QSocketNotifier::QSocketNotifier(int socket, Type type, QObject *parent)
     sntype = type;
     snenabled = true;
 
-    QAbstractEventDispatcher *eventDispatcher = QAbstractEventDispatcher::instance(thread());
-    if (!eventDispatcher) {
-        qWarning("QSocketNotifier can only be used with threads started with QThread");
+    Q_D(QObject);
+    if (!d->threadData->eventDispatcher) {
+        qWarning("QSocketNotifier: Can only be used with threads started with QThread");
     } else {
-        eventDispatcher->registerSocketNotifier(this);
+        d->threadData->eventDispatcher->registerSocketNotifier(this);
     }
 }
 
@@ -165,11 +214,11 @@ QSocketNotifier::QSocketNotifier(int socket, Type type, QObject *parent,
     sntype = type;
     snenabled = true;
 
-    QAbstractEventDispatcher *eventDispatcher = QAbstractEventDispatcher::instance(thread());
-    if (!eventDispatcher) {
-        qWarning("QSocketNotifier can only be used with threads started with QThread");
+    Q_D(QObject);
+    if (!d->threadData->eventDispatcher) {
+        qWarning("QSocketNotifier: Can only be used with threads started with QThread");
     } else {
-        eventDispatcher->registerSocketNotifier(this);
+        d->threadData->eventDispatcher->registerSocketNotifier(this);
     }
 }
 #endif
@@ -243,13 +292,13 @@ void QSocketNotifier::setEnabled(bool enable)
         return;
     snenabled = enable;
 
-    QAbstractEventDispatcher *eventDispatcher = QAbstractEventDispatcher::instance(thread());
-    if (!eventDispatcher) // perhaps application/thread is shutting down
+    Q_D(QObject);
+    if (!d->threadData->eventDispatcher) // perhaps application/thread is shutting down
         return;
     if (snenabled)
-        eventDispatcher->registerSocketNotifier(this);
+        d->threadData->eventDispatcher->registerSocketNotifier(this);
     else
-        eventDispatcher->unregisterSocketNotifier(this);
+        d->threadData->eventDispatcher->unregisterSocketNotifier(this);
 }
 
 
@@ -273,3 +322,5 @@ bool QSocketNotifier::event(QEvent *e)
     }
     return false;
 }
+
+QT_END_NAMESPACE
