@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -1151,7 +1145,7 @@ const QVariant::Handler *QVariant::handler = &qt_kernel_variant_handler;
 
     Here is some example code to demonstrate the use of QVariant:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 0
 
     You can even store QList<QVariant> and QMap<QString, QVariant>
     values in a variant, so you can easily construct arbitrarily
@@ -1162,7 +1156,7 @@ const QVariant::Handler *QVariant::handler = &qt_kernel_variant_handler;
     QVariant also supports the notion of null values, where you have
     a defined type with no value set.
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 1
 
     QVariant can be extended to support other types than those
     mentioned in the \l Type enum. See the \l QMetaType documentation
@@ -1176,13 +1170,13 @@ const QVariant::Handler *QVariant::handler = &qt_kernel_variant_handler;
     toColor() function. Instead, you can use the QVariant::value() or
     the qVariantValue() template function. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 2
 
     The inverse conversion (e.g., from QColor to QVariant) is
     automatic for all data types supported by QVariant, including
     GUI-related types:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 3
 
     \section1 Using canConvert() and convert() Consecutively
 
@@ -2493,7 +2487,7 @@ static const quint32 qCanConvertMatrix[QVariant::LastCoreType + 1] =
                          \l Font, \l Int, \l KeySequence, \l LongLong, \l StringList, \l Time, \l UInt,
                          \l ULongLong
     \row \o \l StringList \o \l List, \l String (if the list contains exactly one item)
-    \row \o \l Time \o \l DateTime, \l String
+    \row \o \l Time \o \l String
     \row \o \l UInt \o \l Bool, \l Char, \l Double, \l Int, \l LongLong, \l String, \l ULongLong
     \row \o \l ULongLong \o \l Bool, \l Char, \l Double, \l Int, \l LongLong, \l String, \l UInt
     \endtable
@@ -2615,8 +2609,8 @@ bool QVariant::convert(Type t)
     Compares this QVariant with \a v and returns true if they are
     equal; otherwise returns false.
 
-    \warning This function doesn't support custom types registered
-    with qRegisterMetaType().
+    In the case of custom types, their equalness operators are not called.
+    Instead the values' addresses are compared.
 */
 
 /*!
@@ -2866,7 +2860,7 @@ QDebug operator<<(QDebug dbg, const QVariant::Type p)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 4
 
     \warning This function is not available with MSVC 6. Use
     qVariantSetValue() instead if you need to support that version of
@@ -2887,7 +2881,7 @@ QDebug operator<<(QDebug dbg, const QVariant::Type p)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 5
 
     \warning This function is not available with MSVC 6. Use
     qVariantValue() or qvariant_cast() instead if you need to support
@@ -2903,7 +2897,7 @@ QDebug operator<<(QDebug dbg, const QVariant::Type p)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 6
 
     \warning This function is not available with MSVC 6. Use
     qVariantCanConvert() instead if you need to support that version
@@ -2919,7 +2913,10 @@ QDebug operator<<(QDebug dbg, const QVariant::Type p)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 7
+
+    \note If you are working with custom types, you should use
+    the Q_DECLARE_METATYPE() macro to register your custom type.
 
     \warning This function is not available with MSVC 6. Use
     qVariantFromValue() instead if you need to support that version
@@ -2942,7 +2939,7 @@ QDebug operator<<(QDebug dbg, const QVariant::Type p)
     For example, a QObject pointer can be stored in a variant with the
     following code:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qvariant.cpp 8
+    \snippet doc/src/snippets/code/src_corelib_kernel_qvariant.cpp 8
 
     \sa QVariant::fromValue()
 */
