@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -62,6 +56,7 @@
 #endif // NO_ERROR_H
 #include <qdebug.h>
 #include <qvector.h>
+#include <qdir.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -127,7 +122,7 @@ Q_GLOBAL_STATIC(QMutex, qt_library_mutex)
     symbol is not defined, the function pointer will be 0 and won't be
     called.
 
-    \snippet doc/src/snippets/code/src.corelib.plugin.qlibrary.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_plugin_qlibrary.cpp 0
 
     The symbol must be exported as a C function from the library for
     resolve() to work. This means that the function must be wrapped in
@@ -138,7 +133,7 @@ Q_GLOBAL_STATIC(QMutex, qt_library_mutex)
     use if you just want to call a function in a library without
     explicitly loading the library first:
 
-    \snippet doc/src/snippets/code/src.corelib.plugin.qlibrary.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_plugin_qlibrary.cpp 1
 
     \sa QPluginLoader
 */
@@ -167,6 +162,8 @@ Q_GLOBAL_STATIC(QMutex, qt_library_mutex)
     \sa loadHints
 */
 
+
+#ifndef QT_NO_PLUGIN_CHECK
 struct qt_token_info
 {
     qt_token_info(const char *f, const ulong fc)
@@ -285,8 +282,9 @@ static bool qt_parse_pattern(const char *s, uint *version, bool *debug, QByteArr
 
     return ret;
 }
+#endif // QT_NO_PLUGIN_CHECK
 
-#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC) && !defined(QT_NO_PLUGIN_CHECK)
 
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_LINUX)
 #  define USE_MMAP
@@ -411,7 +409,7 @@ static bool qt_unix_query(const QString &library, uint *version, bool *debug, QB
     return ret;
 }
 
-#endif // Q_OS_UNIX && !Q_OS_MAC
+#endif // Q_OS_UNIX && !Q_OS_MAC && !defined(QT_NO_PLUGIN_CHECK)
 
 typedef QMap<QString, QLibraryPrivate*> LibraryMap;
 Q_GLOBAL_STATIC(LibraryMap, libraryMap)
@@ -613,15 +611,36 @@ bool QLibraryPrivate::isPlugin(QSettings *settings)
 #endif
         {
             bool temporary_load = false;
-            if (!pHnd)
+#ifdef Q_OS_WIN
+            HMODULE hTempModule = 0;
+#endif
+            if (!pHnd) {
+#ifdef Q_OS_WIN
+                hTempModule = ::LoadLibraryExW((wchar_t*)QDir::toNativeSeparators(fileName).utf16(), 0, DONT_RESOLVE_DLL_REFERENCES);
+                //### optimization: for Win98, and WinMe we should call load_sys, 
+                //since they don't support the DONT_RESOLVE_DLL_REFERENCES flag.
+#else
                 temporary_load =  load_sys();
+#endif
+            }
 #  ifdef Q_CC_BOR
             typedef const char * __stdcall (*QtPluginQueryVerificationDataFunction)();
 #  else
             typedef const char * (*QtPluginQueryVerificationDataFunction)();
 #  endif
+#ifdef Q_OS_WIN
+            QtPluginQueryVerificationDataFunction qtPluginQueryVerificationDataFunction = hTempModule 
+                ? (QtPluginQueryVerificationDataFunction)
+#ifdef Q_OS_WINCE
+                    ::GetProcAddressW(hTempModule, L"qt_plugin_query_verification_data")
+#else
+                    ::GetProcAddress(hTempModule, "qt_plugin_query_verification_data")
+#endif
+                : (QtPluginQueryVerificationDataFunction) resolve("qt_plugin_query_verification_data");
+#else
             QtPluginQueryVerificationDataFunction qtPluginQueryVerificationDataFunction =
                 (QtPluginQueryVerificationDataFunction) resolve("qt_plugin_query_verification_data");
+#endif
 
             if (!qtPluginQueryVerificationDataFunction
                 || !qt_parse_pattern(qtPluginQueryVerificationDataFunction(), &qt_version, &debug, &key)) {
@@ -632,6 +651,15 @@ bool QLibraryPrivate::isPlugin(QSettings *settings)
             } else {
                 success = true;
             }
+#ifdef Q_OS_WIN
+            if (hTempModule) {
+                BOOL ok = ::FreeLibrary(hTempModule);
+                if (ok) {
+                    hTempModule = 0;
+                }
+
+            }
+#endif
         }
 
         QStringList queried;
@@ -700,6 +728,7 @@ bool QLibraryPrivate::isPlugin(QSettings *settings)
 
     return pluginState == IsAPlugin;
 #else
+    Q_UNUSED(settings);
     return pluginState == MightBeAPlugin;
 #endif
 }
@@ -894,6 +923,8 @@ void QLibrary::setFileNameAndVersion(const QString &fileName, int verNum)
 }
 
 /*!
+    \since 4.4
+
     Sets the fileName property and full version number to \a fileName
     and \a version respectively.
     The \a version parameter is ignored on Windows.
@@ -918,7 +949,7 @@ void QLibrary::setFileNameAndVersion(const QString &fileName, const QString &ver
     not be resolved or if the library could not be loaded.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.plugin.qlibrary.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_plugin_qlibrary.cpp 2
 
     The symbol must be exported as a C function from the library. This
     means that the function must be wrapped in an \c{extern "C"} if
@@ -926,11 +957,11 @@ void QLibrary::setFileNameAndVersion(const QString &fileName, const QString &ver
     also explicitly export the function from the DLL using the
     \c{__declspec(dllexport)} compiler directive, for example:
 
-    \snippet doc/src/snippets/code/src.corelib.plugin.qlibrary.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_plugin_qlibrary.cpp 3
 
     with \c MY_EXPORT defined as
 
-    \snippet doc/src/snippets/code/src.corelib.plugin.qlibrary.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_plugin_qlibrary.cpp 4
 
 */
 void *QLibrary::resolve(const char *symbol)
@@ -981,6 +1012,7 @@ void *QLibrary::resolve(const QString &fileName, int verNum, const char *symbol)
 
 /*!
     \overload
+    \since 4.4
 
     Loads the library \a fileName with full version number \a version and
     returns the address of the exported symbol \a symbol.
