@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -70,7 +64,7 @@
     functions allow you to implement your own implicitly shared
     classes.
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 0
 
     \section2 Memory ordering
 
@@ -106,7 +100,7 @@
     nothing and return false. This operation equates to the following
     code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 1
 
     There are 4 test-and-set functions: testAndSetRelaxed(),
     testAndSetAcquire(), testAndSetRelease(), and
@@ -119,7 +113,7 @@
     QAtomicInt and then assign a new value, returning the original
     value. This operation equates to the following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 2
 
     There are 4 fetch-and-store functions: fetchAndStoreRelaxed(),
     fetchAndStoreAcquire(), fetchAndStoreRelease(), and
@@ -133,7 +127,7 @@
     returning the original value. This operation equates to the
     following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 3
 
     There are 4 fetch-and-add functions: fetchAndAddRelaxed(),
     fetchAndAddAcquire(), fetchAndAddRelease(), and
@@ -674,7 +668,7 @@
     these functions do nothing and return false. This operation
     equates to the following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 4
 
     There are 4 test-and-set functions: testAndSetRelaxed(),
     testAndSetAcquire(), testAndSetRelease(), and
@@ -687,7 +681,7 @@
     QAtomicPointer and then assign a new value, returning the original
     value. This operation equates to the following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 5
 
     There are 4 fetch-and-store functions: fetchAndStoreRelaxed(),
     fetchAndStoreAcquire(), fetchAndStoreRelease(), and
@@ -701,7 +695,7 @@
     returning the original value. This operation equates to the
     following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qatomic.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_thread_qatomic.cpp 6
 
     There are 4 fetch-and-add functions: fetchAndAddRelaxed(),
     fetchAndAddAcquire(), fetchAndAddRelease(), and
