@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -74,7 +68,7 @@ QT_BEGIN_NAMESPACE
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qreadwritelock.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_thread_qreadwritelock.cpp 0
 
     To ensure that writers aren't blocked forever by readers, readers
     attempting to obtain a lock will not succeed if there is a blocked
@@ -95,7 +89,9 @@ QT_BEGIN_NAMESPACE
     \sa QReadLocker, QWriteLocker, QMutex, QSemaphore
 */
 
-/*! \enum QReadWriteLock::RecursionMode
+/*! 
+    \enum QReadWriteLock::RecursionMode
+    \since 4.4
 
     \value Recursive In this mode, a thread can lock the same
     QReadWriteLock multiple times and the mutex won't be unlocked
@@ -117,6 +113,8 @@ QReadWriteLock::QReadWriteLock()
 { }
 
 /*!
+    \since 4.4
+
     Constructs a QReadWriteLock object in the given \a recursionMode.
 
     \sa lockForRead(), lockForWrite(), RecursionMode
@@ -450,11 +448,11 @@ void QReadWriteLock::unlock()
     Here's an example that uses QReadLocker to lock and unlock a
     read-write lock for reading:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qreadwritelock.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_thread_qreadwritelock.cpp 1
 
     It is equivalent to the following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qreadwritelock.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_thread_qreadwritelock.cpp 2
 
     The QMutexLocker documentation shows examples where the use of a
     locker object greatly simplifies programming.
@@ -523,11 +521,11 @@ void QReadWriteLock::unlock()
     Here's an example that uses QWriteLocker to lock and unlock a
     read-write lock for writing:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qreadwritelock.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_thread_qreadwritelock.cpp 3
 
     It is equivalent to the following code:
 
-    \snippet doc/src/snippets/code/src.corelib.thread.qreadwritelock.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_thread_qreadwritelock.cpp 4
 
     The QMutexLocker documentation shows examples where the use of a
     locker object greatly simplifies programming.
