@@ -1,53 +1,46 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
 #include "qline.h"
 #include "qdebug.h"
 #include "qdatastream.h"
+#include "qmath.h"
 #include <private/qnumeric_p.h>
 
-#include <math.h>
-
 QT_BEGIN_NAMESPACE
 
 /*!
@@ -221,6 +214,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \fn void QLine::setP1(const QPoint &p1)
+    \since 4.4
 
     Sets the starting point of this line to \a p1.
 
@@ -230,6 +224,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \fn void QLine::setP2(const QPoint &p2)
+    \since 4.4
 
     Sets the end point of this line to \a p2.
 
@@ -239,6 +234,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \fn void QLine::setPoints(const QPoint &p1, const QPoint &p2)
+    \since 4.4
 
     Sets the start point of this line to \a p1 and the end point of this line to \a p2.
 
@@ -248,6 +244,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \fn void QLine::setLine(int x1, int y1, int x2, int y2)
+    \since 4.4
 
     Sets this line to the start in \a x1, \a y1 and end in \a x2, \a y2.
 
@@ -369,9 +366,12 @@ QDataStream &operator>>(QDataStream &stream, QLine &line)
     \value NoIntersection Indicates that the lines do not intersect;
     i.e. they are parallel.
 
-    \value UnboundedIntersection The two lines intersect,
-    but not within the range defined by their lengths. This will be
-    the case if the lines are not parallel.
+    \value UnboundedIntersection The two lines intersect, but not
+    within the range defined by their lengths. This will be the case
+    if the lines are not parallel. 
+
+    intersect() will also return this value if the intersect point is
+    within the start and end point of only one of the lines.
 
     \value BoundedIntersection The two lines intersect with each other
     within the start and end points of each line.
@@ -495,9 +495,11 @@ bool QLineF::isNull() const
 /*!
     \fn QLineF::setLength(qreal length)
 
-    Sets the length of the line to the given \a length. If the line is a
-    null line, the length will remain zero regardless of the length
-    specified.
+    Sets the length of the line to the given \a length. QLineF will
+    move the end point - p2() - of the line to give the line its new length.
+    
+    If the line is a null line, the length will remain zero regardless
+    of the length specified. 
 
     \sa length(), isNull()
 */
@@ -550,7 +552,7 @@ qreal QLineF::length() const
 {
     qreal x = pt2.x() - pt1.x();
     qreal y = pt2.y() - pt1.y();
-    return sqrt(x*x + y*y);
+    return qSqrt(x*x + y*y);
 }
 
 /*!
@@ -595,8 +597,8 @@ void QLineF::setAngle(qreal angle)
     const qreal angleR = angle * M_2PI / 360.0;
     const qreal l = length();
 
-    const qreal dx = cos(angleR) * l;
-    const qreal dy = -sin(angleR) * l;
+    const qreal dx = qCos(angleR) * l;
+    const qreal dy = -qSin(angleR) * l;
 
     pt2.rx() = pt1.x() + dx;
     pt2.ry() = pt1.y() + dy;
@@ -615,7 +617,7 @@ void QLineF::setAngle(qreal angle)
 QLineF QLineF::fromPolar(qreal length, qreal angle)
 {
     const qreal angleR = angle * M_2PI / 360.0;
-    return QLineF(0, 0, cos(angleR) * length, -sin(angleR) * length);
+    return QLineF(0, 0, qCos(angleR) * length, -qSin(angleR) * length);
 }
 
 /*!
@@ -629,7 +631,7 @@ QLineF QLineF::unitVector() const
     qreal x = pt2.x() - pt1.x();
     qreal y = pt2.y() - pt1.y();
 
-    qreal len = sqrt(x*x + y*y);
+    qreal len = qSqrt(x*x + y*y);
     QLineF f(p1(), QPointF(pt1.x() + x/len, pt1.y() + y/len));
 
 #ifndef QT_NO_DEBUG
@@ -752,6 +754,7 @@ QLineF::IntersectType QLineF::intersect(const QLineF &l, QPointF *intersectionPo
 
 /*!
     \fn void QLineF::setP1(const QPointF &p1)
+    \since 4.4
 
     Sets the starting point of this line to \a p1.
 
@@ -761,6 +764,7 @@ QLineF::IntersectType QLineF::intersect(const QLineF &l, QPointF *intersectionPo
 
 /*!
     \fn void QLineF::setP2(const QPointF &p2)
+    \since 4.4
 
     Sets the end point of this line to \a p2.
 
@@ -770,6 +774,7 @@ QLineF::IntersectType QLineF::intersect(const QLineF &l, QPointF *intersectionPo
 
 /*!
     \fn void QLineF::setPoints(const QPointF &p1, const QPointF &p2)
+    \since 4.4
 
     Sets the start point of this line to \a p1 and the end point of this line to \a p2.
 
@@ -779,6 +784,7 @@ QLineF::IntersectType QLineF::intersect(const QLineF &l, QPointF *intersectionPo
 
 /*!
     \fn void QLineF::setLine(qreal x1, qreal y1, qreal x2, qreal y2)
+    \since 4.4
 
     Sets this line to the start in \a x1, \a y1 and end in \a x2, \a y2.
 
