@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -187,7 +181,7 @@ void QSize::transpose()
     \endlist
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 0
 
     \sa setWidth(), setHeight()
 */
@@ -232,7 +226,7 @@ void QSize::scale(const QSize &s, Qt::AspectRatioMode mode)
     Using a reference makes it possible to manipulate the width
     directly. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 1
 
     \sa rheight(), setWidth()
 */
@@ -245,7 +239,7 @@ void QSize::scale(const QSize &s, Qt::AspectRatioMode mode)
     Using a reference makes it possible to manipulate the height
     directly. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 2
 
     \sa rwidth(), setHeight()
 */
@@ -256,7 +250,7 @@ void QSize::scale(const QSize &s, Qt::AspectRatioMode mode)
     Adds the given \a size to \e this size, and returns a reference to
     this size. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 3
 */
 
 /*!
@@ -265,7 +259,7 @@ void QSize::scale(const QSize &s, Qt::AspectRatioMode mode)
     Subtracts the given \a size from \e this size, and returns a
     reference to this size. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 4
 */
 
 /*!
@@ -589,7 +583,7 @@ void QSizeF::transpose()
     \endlist
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 5
 
     \sa setWidth(), setHeight()
 */
@@ -634,7 +628,7 @@ void QSizeF::scale(const QSizeF &s, Qt::AspectRatioMode mode)
     Using a reference makes it possible to manipulate the width
     directly. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 6
 
     \sa rheight(), setWidth()
 */
@@ -647,7 +641,7 @@ void QSizeF::scale(const QSizeF &s, Qt::AspectRatioMode mode)
     Using a reference makes it possible to manipulate the height
     directly. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 7
 
     \sa rwidth(), setHeight()
 */
@@ -658,7 +652,7 @@ void QSizeF::scale(const QSizeF &s, Qt::AspectRatioMode mode)
     Adds the given \a size to this size and returns a reference to
     this size. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 8
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 8
 */
 
 /*!
@@ -667,7 +661,7 @@ void QSizeF::scale(const QSizeF &s, Qt::AspectRatioMode mode)
     Subtracts the given \a size from this size and returns a reference
     to this size. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qsize.cpp 9
+    \snippet doc/src/snippets/code/src_corelib_tools_qsize.cpp 9
 */
 
 /*!
