@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -199,7 +193,7 @@ void QTimeLinePrivate::setCurrentTime(int msecs)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.tools.qtimeline.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_tools_qtimeline.cpp 0
 
     You can also use QTimeLine with the
     \l{Graphics View}{Graphics View framework} for
@@ -358,6 +352,8 @@ QTimeLine::State QTimeLine::state() const
     \brief the number of times the timeline should loop before it's finished.
 
     A loop count of of 0 means that the timeline will loop forever.
+
+    By default, this property contains a value of 1.
 */
 int QTimeLine::loopCount() const
 {
@@ -378,6 +374,8 @@ void QTimeLine::setLoopCount(int count)
     This direction indicates whether the time moves from 0 towards the
     timeline duration, or from the value of the duration and towards 0 after
     start() has been called.
+
+    By default, this property is set to \l Forward.
 */
 QTimeLine::Direction QTimeLine::direction() const
 {
@@ -512,6 +510,8 @@ void QTimeLine::setUpdateInterval(int interval)
 
     If you have reimplemented valueForTime(), this value is ignored.
 
+    By default, this property is set to \l EaseInOutCurve.
+
     \sa valueForTime()
 */
 QTimeLine::CurveShape QTimeLine::curveShape() const
@@ -533,6 +533,8 @@ void QTimeLine::setCurveShape(CurveShape shape)
     a function of the duration and direction of the timeline. Otherwise, it is
     value that was current when stop() was called last, or the value set by
     setCurrentTime().
+
+    By default, this property contains a value of 0.
 */
 int QTimeLine::currentTime() const
 {
