@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtDBus module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -172,10 +166,10 @@ bool QDBusArgumentPrivate::checkReadAndDetach(QDBusArgumentPrivate *&d)
     \inmodule QtDBus
     \since 4.2
 
-    \brief The QDBusArgument class is used to marshall and demarshall D-BUS arguments.
+    \brief The QDBusArgument class is used to marshall and demarshall D-Bus arguments.
 
-    The class is used to send arguments over D-BUS to remote
-    applications and to receive them back. D-BUS offers an extensible
+    The class is used to send arguments over D-Bus to remote
+    applications and to receive them back. D-Bus offers an extensible
     type system, based on a few primitive types and associations of
     them. See the \l {qdbustypesystem.html}{QtDBus type system} page
     for more information on the type system.
@@ -190,13 +184,13 @@ bool QDBusArgumentPrivate::checkReadAndDetach(QDBusArgumentPrivate *&d)
     integer and a string can be constructed using the \l
     {qdbustypesystem.html}{QtDBus type system}:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 0
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 0
 
     The type has to be registered with qDBusRegisterMetaType() before
     it can be used with QDBusArgument. Therefore, somewhere in your
     program, you should add the following code:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 1
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 1
 
     Once registered, a type can be used in outgoing method calls
     (placed with QDBusAbstractInterface::call()), signal emissions
@@ -213,7 +207,7 @@ bool QDBusArgumentPrivate::checkReadAndDetach(QDBusArgumentPrivate *&d)
     in context of a class that may contain invalid data:
 
     \badcode
-        // Wrongly marshall the MyTime data into a D-BUS argument
+        // Wrongly marshall the MyTime data into a D-Bus argument
         QDBusArgument &operator<<(QDBusArgument &argument, const MyTime &mytime)
         {
             argument.beginStructure();
@@ -243,11 +237,11 @@ bool QDBusArgumentPrivate::checkReadAndDetach(QDBusArgumentPrivate *&d)
     Attempts to demarshall the contents of \a argument into the type
     \c{T}. For example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 2
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 2
 
     Note that it is equivalent to the following:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 3
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 3
 */
 
 /*!
@@ -317,7 +311,7 @@ QDBusArgument::~QDBusArgument()
 }
 
 /*!
-    Appends the primitive value \a arg of type \c{BYTE} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{BYTE} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(uchar arg)
 {
@@ -328,7 +322,7 @@ QDBusArgument &QDBusArgument::operator<<(uchar arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{BOOLEAN} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{BOOLEAN} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(bool arg)
 {
@@ -339,7 +333,7 @@ QDBusArgument &QDBusArgument::operator<<(bool arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{INT16} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{INT16} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(short arg)
 {
@@ -350,7 +344,7 @@ QDBusArgument &QDBusArgument::operator<<(short arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{UINT16} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{UINT16} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(ushort arg)
 {
@@ -361,7 +355,7 @@ QDBusArgument &QDBusArgument::operator<<(ushort arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{INT32} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{INT32} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(int arg)
 {
@@ -372,7 +366,7 @@ QDBusArgument &QDBusArgument::operator<<(int arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{UINT32} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{UINT32} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(uint arg)
 {
@@ -383,7 +377,7 @@ QDBusArgument &QDBusArgument::operator<<(uint arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{INT64} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{INT64} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(qlonglong arg)
 {
@@ -394,7 +388,7 @@ QDBusArgument &QDBusArgument::operator<<(qlonglong arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{UINT64} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{UINT64} to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(qulonglong arg)
 {
@@ -406,7 +400,7 @@ QDBusArgument &QDBusArgument::operator<<(qulonglong arg)
 /*!
     \overload
     Appends the primitive value \a arg of type \c{DOUBLE} (double-precision
-    floating-point) to the D-BUS stream.
+    floating-point) to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(double arg)
 {
@@ -418,7 +412,7 @@ QDBusArgument &QDBusArgument::operator<<(double arg)
 /*!
     \overload
     Appends the primitive value \a arg of type \c{STRING} (Unicode character
-    string) to the D-BUS stream.
+    string) to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(const QString &arg)
 {
@@ -430,8 +424,8 @@ QDBusArgument &QDBusArgument::operator<<(const QString &arg)
 /*!
     \overload
     \internal
-    Appends the primitive value \a arg of type \c{OBJECT_PATH} (path to a D-BUS
-    object) to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{OBJECT_PATH} (path to a D-Bus
+    object) to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(const QDBusObjectPath &arg)
 {
@@ -443,8 +437,8 @@ QDBusArgument &QDBusArgument::operator<<(const QDBusObjectPath &arg)
 /*!
     \overload
     \internal
-    Appends the primitive value \a arg of type \c{SIGNATURE} (D-BUS type
-    signature) to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{SIGNATURE} (D-Bus type
+    signature) to the D-Bus stream.
 */
 QDBusArgument &QDBusArgument::operator<<(const QDBusSignature &arg)
 {
@@ -455,9 +449,9 @@ QDBusArgument &QDBusArgument::operator<<(const QDBusSignature &arg)
 
 /*!
     \overload
-    Appends the primitive value \a arg of type \c{VARIANT} to the D-BUS stream.
+    Appends the primitive value \a arg of type \c{VARIANT} to the D-Bus stream.
 
-    A D-BUS variant type can contain any type, including other
+    A D-Bus variant type can contain any type, including other
     variants. It is similar to the Qt QVariant type.
 */
 QDBusArgument &QDBusArgument::operator<<(const QDBusVariant &arg)
@@ -470,7 +464,7 @@ QDBusArgument &QDBusArgument::operator<<(const QDBusVariant &arg)
 /*!
     \overload
     Appends the QStringList given by \a arg as \c{ARRAY of STRING}
-    to the D-BUS stream.
+    to the D-Bus stream.
 
     QStringList and QByteArray are the only two non-primitive types
     that are supported directly by QDBusArgument because of their
@@ -488,7 +482,7 @@ QDBusArgument &QDBusArgument::operator<<(const QStringList &arg)
 /*!
     \overload
     Appends the QByteArray given by \a arg as \c{ARRAY of BYTE}
-    to the D-BUS stream.
+    to the D-Bus stream.
 
     QStringList and QByteArray are the only two non-primitive types
     that are supported directly by QDBusArgument because of their
@@ -505,7 +499,7 @@ QDBusArgument &QDBusArgument::operator<<(const QByteArray &arg)
 
 /*!
     \internal
-    Returns the type signature of the D-BUS type this QDBusArgument
+    Returns the type signature of the D-Bus type this QDBusArgument
     object is currently pointing to.
 */
 QString QDBusArgument::currentSignature() const
@@ -519,8 +513,8 @@ QString QDBusArgument::currentSignature() const
 }
 
 /*!
-    Extracts one D-BUS primitive argument of type \c{BYTE} from the
-    D-BUS stream and puts it into \a arg.
+    Extracts one D-Bus primitive argument of type \c{BYTE} from the
+    D-Bus stream and puts it into \a arg.
 */
 const QDBusArgument &QDBusArgument::operator>>(uchar &arg) const
 {
@@ -531,8 +525,8 @@ const QDBusArgument &QDBusArgument::operator>>(uchar &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{BOOLEAN} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{BOOLEAN} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(bool &arg) const
 {
@@ -543,8 +537,8 @@ const QDBusArgument &QDBusArgument::operator>>(bool &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{UINT16} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{UINT16} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(ushort &arg) const
 {
@@ -555,8 +549,8 @@ const QDBusArgument &QDBusArgument::operator>>(ushort &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{INT16} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{INT16} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(short &arg) const
 {
@@ -567,8 +561,8 @@ const QDBusArgument &QDBusArgument::operator>>(short &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{INT32} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{INT32} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(int &arg) const
 {
@@ -579,8 +573,8 @@ const QDBusArgument &QDBusArgument::operator>>(int &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{UINT32} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{UINT32} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(uint &arg) const
 {
@@ -591,8 +585,8 @@ const QDBusArgument &QDBusArgument::operator>>(uint &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{INT64} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{INT64} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(qlonglong &arg) const
 {
@@ -603,8 +597,8 @@ const QDBusArgument &QDBusArgument::operator>>(qlonglong &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{UINT64} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{UINT64} from the
+    D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(qulonglong &arg) const
 {
@@ -615,8 +609,8 @@ const QDBusArgument &QDBusArgument::operator>>(qulonglong &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{DOUBLE}
-    (double-precision floating pount) from the D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{DOUBLE}
+    (double-precision floating pount) from the D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(double &arg) const
 {
@@ -627,8 +621,8 @@ const QDBusArgument &QDBusArgument::operator>>(double &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{STRING} (Unicode
-    character string) from the D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{STRING} (Unicode
+    character string) from the D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(QString &arg) const
 {
@@ -640,8 +634,8 @@ const QDBusArgument &QDBusArgument::operator>>(QString &arg) const
 /*!
     \overload
     \internal
-    Extracts one D-BUS primitive argument of type \c{OBJECT_PATH}
-    (D-BUS path to an object) from the D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{OBJECT_PATH}
+    (D-Bus path to an object) from the D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(QDBusObjectPath &arg) const
 {
@@ -653,8 +647,8 @@ const QDBusArgument &QDBusArgument::operator>>(QDBusObjectPath &arg) const
 /*!
     \overload
     \internal
-    Extracts one D-BUS primitive argument of type \c{SIGNATURE} (D-BUS
-    type signature) from the D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{SIGNATURE} (D-Bus
+    type signature) from the D-Bus stream.
 */
 const QDBusArgument &QDBusArgument::operator>>(QDBusSignature &arg) const
 {
@@ -665,10 +659,10 @@ const QDBusArgument &QDBusArgument::operator>>(QDBusSignature &arg) const
 
 /*!
     \overload
-    Extracts one D-BUS primitive argument of type \c{VARIANT} from the
-    D-BUS stream.
+    Extracts one D-Bus primitive argument of type \c{VARIANT} from the
+    D-Bus stream.
 
-    A D-BUS variant type can contain any type, including other
+    A D-Bus variant type can contain any type, including other
     variants. It is similar to the Qt QVariant type.
 
     In case the variant contains a type not directly supported by
@@ -685,7 +679,7 @@ const QDBusArgument &QDBusArgument::operator>>(QDBusVariant &arg) const
 
 /*!
     \overload
-    Extracts an array of strings from the D-BUS stream and return it
+    Extracts an array of strings from the D-Bus stream and return it
     as a QStringList.
 
     QStringList and QByteArray are the only two non-primitive types
@@ -703,7 +697,7 @@ const QDBusArgument &QDBusArgument::operator>>(QStringList &arg) const
 
 /*!
     \overload
-    Extracts an array of bytes from the D-BUS stream and return it
+    Extracts an array of bytes from the D-Bus stream and return it
     as a QByteArray.
 
     QStringList and QByteArray are the only two non-primitive types
@@ -720,17 +714,17 @@ const QDBusArgument &QDBusArgument::operator>>(QByteArray &arg) const
 }
 
 /*!
-    Opens a new D-BUS structure suitable for appending new arguments.
+    Opens a new D-Bus structure suitable for appending new arguments.
 
     This function is used usually in \c{operator<<} streaming
     operators, as in the following example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 4
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 4
 
     Structures can contain other structures, so the following code is
     also valid:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 5
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 5
 
     \sa endStructure(), beginArray(), beginMap()
 */
@@ -741,7 +735,7 @@ void QDBusArgument::beginStructure()
 }
 
 /*!
-    Closes a D-BUS structure opened with beginStructure(). This function must be called
+    Closes a D-Bus structure opened with beginStructure(). This function must be called
     same number of times that beginStructure() is called.
 
     \sa beginStructure(), endArray(), endMap()
@@ -753,12 +747,12 @@ void QDBusArgument::endStructure()
 }
 
 /*!
-    Opens a new D-BUS array suitable for appending elements of meta-type \a id.
+    Opens a new D-Bus array suitable for appending elements of meta-type \a id.
 
     This function is used usually in \c{operator<<} streaming
     operators, as in the following example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 6
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 6
 
     If the type you want to marshall is a QList, QVector or any of the
     Qt's \l {Generic Containers} that take one template parameter,
@@ -776,7 +770,7 @@ void QDBusArgument::beginArray(int id)
 }
 
 /*!
-    Closes a D-BUS array opened with beginArray(). This function must be called
+    Closes a D-Bus array opened with beginArray(). This function must be called
     same number of times that beginArray() is called.
 
     \sa beginArray(), endStructure(), endMap()
@@ -788,7 +782,7 @@ void QDBusArgument::endArray()
 }
 
 /*!
-    Opens a new D-BUS map suitable for
+    Opens a new D-Bus map suitable for
     appending elements. Maps are containers that associate one entry
     (the key) to another (the value), such as Qt's QMap or QHash. The
     ids of the map's key and value meta types must be passed in \a kid
@@ -797,7 +791,7 @@ void QDBusArgument::endArray()
     This function is used usually in \c{operator<<} streaming
     operators, as in the following example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 7
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 7
 
     If the type you want to marshall is a QMap or QHash, you need not
     declare an \c{operator<<} function for it, since QtDBus provides
@@ -812,7 +806,7 @@ void QDBusArgument::beginMap(int kid, int vid)
 }
 
 /*!
-    Closes a D-BUS map opened with beginMap(). This function must be called
+    Closes a D-Bus map opened with beginMap(). This function must be called
     same number of times that beginMap() is called.
 
     \sa beginMap(), endStructure(), endArray()
@@ -824,7 +818,7 @@ void QDBusArgument::endMap()
 }
 
 /*!
-    Opens a D-BUS map entry suitable for
+    Opens a D-Bus map entry suitable for
     appending the key and value entries. This function is only valid
     when a map has been opened with beginMap().
 
@@ -839,7 +833,7 @@ void QDBusArgument::beginMapEntry()
 }
 
 /*!
-    Closes a D-BUS map entry opened with beginMapEntry(). This function must be called
+    Closes a D-Bus map entry opened with beginMapEntry(). This function must be called
     same number of times that beginMapEntry() is called.
 
     \sa beginMapEntry()
@@ -851,12 +845,12 @@ void QDBusArgument::endMapEntry()
 }
 
 /*!
-    Opens a D-BUS structure suitable for extracting elements.
+    Opens a D-Bus structure suitable for extracting elements.
 
     This function is used usually in \c{operator>>} streaming
     operators, as in the following example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 8
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 8
 
     \sa endStructure(), beginArray(), beginMap()
 */
@@ -867,7 +861,7 @@ void QDBusArgument::beginStructure() const
 }
 
 /*!
-    Closes the D-BUS structure and allow extracting of the next element
+    Closes the D-Bus structure and allow extracting of the next element
     after the structure.
 
     \sa beginStructure()
@@ -879,13 +873,13 @@ void QDBusArgument::endStructure() const
 }
 
 /*!
-    Recurses into the D-BUS array to allow extraction of
+    Recurses into the D-Bus array to allow extraction of
     the array elements.
 
     This function is used usually in \c{operator>>} streaming
     operators, as in the following example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 9
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 9
 
     If the type you want to demarshall is a QList, QVector or any of the
     Qt's \l {Generic Containers} that take one template parameter, you
@@ -903,7 +897,7 @@ void QDBusArgument::beginArray() const
 }
 
 /*!
-    Closes the D-BUS array and allow extracting of the next element
+    Closes the D-Bus array and allow extracting of the next element
     after the array.
 
     \sa beginArray()
@@ -915,13 +909,13 @@ void QDBusArgument::endArray() const
 }
 
 /*!
-    Recurses into the D-BUS map to allow extraction of
+    Recurses into the D-Bus map to allow extraction of
     the map's elements.
 
     This function is used usually in \c{operator>>} streaming
     operators, as in the following example:
 
-    \snippet doc/src/snippets/code/src.qdbus.qdbusargument.cpp 10
+    \snippet doc/src/snippets/code/src_qdbus_qdbusargument.cpp 10
 
     If the type you want to demarshall is a QMap or QHash, you need not
     declare an \c{operator>>} function for it, since QtDBus provides
@@ -936,7 +930,7 @@ void QDBusArgument::beginMap() const
 }
 
 /*!
-    Closes the D-BUS map and allow extracting of the next element
+    Closes the D-Bus map and allow extracting of the next element
     after the map.
 
     \sa beginMap()
@@ -948,7 +942,7 @@ void QDBusArgument::endMap() const
 }
 
 /*!
-    Recurses into the D-BUS map entry to allow extraction
+    Recurses into the D-Bus map entry to allow extraction
     of the key and value pair.
 
     See beginMap() for an example of how this function is usually used.
@@ -962,7 +956,7 @@ void QDBusArgument::beginMapEntry() const
 }
 
 /*!
-    Closes the D-BUS map entry and allow extracting of the next element
+    Closes the D-Bus map entry and allow extracting of the next element
     on the map.
 
     \sa beginMapEntry()
