@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -52,9 +46,13 @@
 #include "qtooltip.h"
 #include "qwhatsthis.h"
 #include "qwidget.h"
-#include "private/qmath_p.h"
+#include "qdebug.h"
+#include <qmath.h>
 #include <QRubberBand>
 #include <QtGui/QFocusFrame>
+#include <QtGui/QMenu>
+
+QT_BEGIN_NAMESPACE
 
 static QList<QWidget*> childWidgets(const QWidget *widget)
 {
@@ -62,7 +60,10 @@ static QList<QWidget*> childWidgets(const QWidget *widget)
     QList<QWidget*> widgets;
     for (int i = 0; i < list.size(); ++i) {
         QWidget *w = qobject_cast<QWidget *>(list.at(i));
-        if (w && !w->isWindow() && !qobject_cast<QFocusFrame*>(w))
+        if (w && !w->isWindow() 
+            && !qobject_cast<QFocusFrame*>(w)
+            && !qobject_cast<QMenu*>(w)
+            && w->objectName() != QLatin1String("qt_rubberband"))
             widgets.append(w);
     }
     return widgets;
@@ -266,7 +267,9 @@ QRect QAccessibleWidget::rect(int child) const
     return QRect(wpos.x(), wpos.y(), w->width(), w->height());
 }
 
+QT_BEGIN_INCLUDE_NAMESPACE
 #include <private/qobject_p.h>
+QT_END_INCLUDE_NAMESPACE
 
 class QACConnectionObject : public QObject
 {
@@ -788,7 +791,7 @@ int QAccessibleWidget::indexOfChild(const QAccessibleInterface *child) const
 }
 
 // from qwidget.cpp
-extern QString qt_setWindowTitle_helperHelper(const QString &, QWidget*);
+extern QString qt_setWindowTitle_helperHelper(const QString &, const QWidget*);
 
 /*! \reimp */
 QString QAccessibleWidget::text(Text t, int child) const
@@ -1027,4 +1030,6 @@ QVariant QAccessibleWidgetEx::invokeMethodEx(Method method, int child, const QVa
     }
 }
 
+QT_END_NAMESPACE
+
 #endif //QT_NO_ACCESSIBILITY
