@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -98,6 +92,8 @@ QT_BEGIN_NAMESPACE
     about the underlying files and directories related to items in the model.
     Directories can be created and removed using mkdir(), rmdir().
 
+    \note QFileSystemModel requires an instance of a GUI application.
+
     \sa {Model Classes}
 */
 
@@ -786,7 +782,7 @@ bool QFileSystemModel::setData(const QModelIndex &idx, const QVariant &value, in
 
     if (newName.isEmpty()
         || newName.contains(QDir::separator())
-        || !d->rootDir.rename(oldName, newName)) {
+        || !QDir(filePath(parent(idx))).rename(oldName, newName)) {
 #ifndef QT_NO_MESSAGEBOX
         QMessageBox::information(0, QFileSystemModel::tr("Invalid filename"),
                                 QFileSystemModel::tr("<b>The name \"%1\" can not be used.</b><p>Try using another name, with fewer characters or no punctuations marks.")
@@ -1391,6 +1387,8 @@ QDir::Filters QFileSystemModel::filter() const
     \brief Whether the directory model should resolve symbolic links
 
     This is only relevant on operating systems that support symbolic links.
+
+    By default, this property is false.
 */
 void QFileSystemModel::setResolveSymlinks(bool enable)
 {
@@ -1501,6 +1499,19 @@ QStringList QFileSystemModel::nameFilters() const
     return filters;
 }
 
+/*!
+    \reimp
+*/
+bool QFileSystemModel::event(QEvent *event)
+{
+    Q_D(QFileSystemModel);
+    if (event->type() == QEvent::LanguageChange) {
+        d->root.retranslateStrings(d->fileInfoGatherer.iconProvider(), QString());
+        return true;
+    }
+    return QAbstractItemModel::event(event);
+}
+
 /*!
      \internal
 
@@ -1517,10 +1528,10 @@ void QFileSystemModelPrivate::_q_directoryChanged(const QString &directory, cons
     // Ignore files we already have and cleanup filtered files that were removed.
     // non-filtered files will be removed in a fileSystemChanged()
     for (int i = parentNode->children.count() - 1;  i >= 0; --i) {
-        QStringList::const_iterator iterator;
+        QStringList::iterator iterator;
         iterator = qBinaryFind(newFiles.begin(), newFiles.end(),
                        parentNode->children.at(i).fileName);
-        if (iterator == newFiles.constEnd()) {
+        if (iterator == newFiles.end()) {
            removeNode(parentNode, i);
         }
     }
@@ -1639,7 +1650,7 @@ void QFileSystemModelPrivate::addVisibleFiles(QFileSystemNode *parentNode, const
         QList<int> visibleLocation;
         do {
             vf.location = locations[i + visibleLocation.count()];
-            QList<int>::const_iterator iterator;
+            QList<int>::iterator iterator;
             iterator = qUpperBound(parentNode->visibleChildren.begin(),
                     parentNode->visibleChildren.end(),
                     newFiles.at(i + visibleLocation.count()), vf);
