@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -46,6 +60,8 @@
 #include <private/qdialog_p.h>
 #include <private/qfont_p.h>
 
+QT_BEGIN_NAMESPACE
+
 class QFontListView : public QListView
 {
     Q_OBJECT
@@ -89,30 +105,19 @@ QFontListView::QFontListView(QWidget *parent)
 /*!
   \class QFontDialog
   \ingroup dialogs
+  \ingroup text
   \mainclass
   \brief The QFontDialog class provides a dialog widget for selecting a font.
 
-  The usual way to use this class is to call one of the static convenience
-  functions, e.g. getFont().
+    A font dialog is created through one of the static getFont()
+    functions.
 
   Examples:
 
-  \code
-    bool ok;
-    QFont font = QFontDialog::getFont(
-                    &ok, QFont("Helvetica [Cronyx]", 10), this);
-    if (ok) {
-        // the user clicked OK and font is set to the font the user selected
-    } else {
-        // the user canceled the dialog; font is set to the initial
-        // value, in this case Helvetica [Cronyx], 10
-    }
-  \endcode
+  \snippet doc/src/snippets/code/src_gui_dialogs_qfontdialog.cpp 0
 
     The dialog can also be used to set a widget's font directly:
-  \code
-    myWidget.setFont(QFontDialog::getFont(0, myWidget.font()));
-  \endcode
+  \snippet doc/src/snippets/code/src_gui_dialogs_qfontdialog.cpp 1
   If the user clicks OK the font they chose will be used for myWidget,
   and if they click Cancel the original font is used.
 
@@ -138,6 +143,7 @@ public:
     void _q_styleHighlighted(int);
     void _q_sizeHighlighted(int);
     void _q_updateSample();
+    void retranslateStrings();
 
     QLabel * familyAccel;
     QLineEdit * familyEdit;
@@ -202,7 +208,7 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
     d->familyList = new QFontListView(this);
     d->familyEdit->setFocusProxy(d->familyList);
 
-    d->familyAccel = new QLabel(tr("&Font"), this);
+    d->familyAccel = new QLabel(this);
 #ifndef QT_NO_SHORTCUT
     d->familyAccel->setBuddy(d->familyList);
 #endif
@@ -213,7 +219,7 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
     d->styleList = new QFontListView(this);
     d->styleEdit->setFocusProxy(d->styleList);
 
-    d->styleAccel = new QLabel(tr("Font st&yle"), this);
+    d->styleAccel = new QLabel(this);
 #ifndef QT_NO_SHORTCUT
     d->styleAccel->setBuddy(d->styleList);
 #endif
@@ -225,23 +231,21 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
     d->sizeEdit->setValidator(validator);
     d->sizeList = new QFontListView(this);
 
-    d->sizeAccel = new QLabel(tr("&Size"), this);
+    d->sizeAccel = new QLabel(this);
 #ifndef QT_NO_SHORTCUT
     d->sizeAccel->setBuddy(d->sizeEdit);
 #endif
     d->sizeAccel->setIndent(2);
 
     // effects box
-    d->effects = new QGroupBox(tr("Effects"), this);
+    d->effects = new QGroupBox(this);
     QVBoxLayout *vbox = new QVBoxLayout(d->effects);
     d->strikeout = new QCheckBox(d->effects);
-    d->strikeout->setText(tr("Stri&keout"));
     vbox->addWidget(d->strikeout);
     d->underline = new QCheckBox(d->effects);
-    d->underline->setText(tr("&Underline"));
     vbox->addWidget(d->underline);
 
-    d->sample = new QGroupBox(tr("Sample"), this);
+    d->sample = new QGroupBox(this);
     QHBoxLayout *hbox = new QHBoxLayout(d->sample);
     d->sampleEdit = new QLineEdit(d->sample);
     d->sampleEdit->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
@@ -253,7 +257,7 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
 
     d->writingSystemCombo = new QComboBox(this);
 
-    d->writingSystemAccel = new QLabel(tr("Wr&iting System"), this);
+    d->writingSystemAccel = new QLabel(this);
 #ifndef QT_NO_SHORTCUT
     d->writingSystemAccel->setBuddy(d->writingSystemCombo);
 #endif
@@ -291,10 +295,22 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
         d->familyList->setCurrentItem(0);
 
     // grid layout
-    QGridLayout * mainGrid = new QGridLayout(this);
-    int margin = mainGrid->margin();
+    QGridLayout *mainGrid = new QGridLayout(this);
+
     int spacing = mainGrid->spacing();
-    mainGrid->setSpacing(0);
+    if (spacing >= 0) {     // uniform spacing
+       mainGrid->setSpacing(0);
+
+       mainGrid->setColumnMinimumWidth(1, spacing);
+       mainGrid->setColumnMinimumWidth(3, spacing);
+
+       int margin = 0;
+       mainGrid->getContentsMargins(0, 0, 0, &margin);
+
+       mainGrid->setRowMinimumHeight(3, margin);
+       mainGrid->setRowMinimumHeight(6, 2);
+       mainGrid->setRowMinimumHeight(8, margin);
+    }
 
     mainGrid->addWidget(d->familyAccel, 0, 0);
     mainGrid->addWidget(d->familyEdit, 1, 0);
@@ -312,21 +328,13 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
     mainGrid->setColumnStretch(2, 24);
     mainGrid->setColumnStretch(4, 10);
 
-    mainGrid->setColumnMinimumWidth(1, spacing);
-    mainGrid->setColumnMinimumWidth(3, spacing);
-
-    mainGrid->setRowMinimumHeight(3, margin);
-
     mainGrid->addWidget(d->effects, 4, 0);
 
     mainGrid->addWidget(d->sample, 4, 2, 4, 3);
 
     mainGrid->addWidget(d->writingSystemAccel, 5, 0);
-    mainGrid->setRowMinimumHeight(6, 2);
     mainGrid->addWidget(d->writingSystemCombo, 7, 0);
 
-    mainGrid->setRowMinimumHeight(8, margin);
-
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
     mainGrid->addWidget(buttonBox, 9, 0, 1, 5);
 
@@ -340,7 +348,11 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
     buttonBox->addButton(modal ? QDialogButtonBox::Cancel : QDialogButtonBox::Close);
     connect(buttonBox, SIGNAL(rejected()), SLOT(reject()));
 
+#if defined(Q_OS_WINCE)
+    resize(180, 120);
+#else
     resize(500, 360);
+#endif //Q_OS_WINCE
 
     d->sizeEdit->installEventFilter(this);
     d->familyList->installEventFilter(this);
@@ -348,6 +360,7 @@ QFontDialog::QFontDialog(QWidget *parent, bool modal, Qt::WindowFlags f)
     d->sizeList->installEventFilter(this);
 
     d->familyList->setFocus();
+    d->retranslateStrings();
 }
 
 /*!
@@ -362,34 +375,20 @@ QFontDialog::~QFontDialog()
 /*!
   Executes a modal font dialog and returns a font.
 
-  If the user clicks OK, the selected font is returned. If the user
-  clicks Cancel, the \a initial font is returned.
+  If the user clicks \gui OK, the selected font is returned. If the user
+  clicks \gui Cancel, the \a initial font is returned.
 
-  The dialog is constructed with the given \a parent.  \a caption is
+  The dialog is constructed with the given \a parent. \a caption is
   shown as the window title of the dialog and  \a initial is the
-  initially selected font. If the \a ok parameter is not-null, \e *\a
-  ok is set to true if the user clicked OK, and set to false if the
-  user clicked Cancel.
-
-  This static function is less flexible than the full QFontDialog
-  object, but is convenient and easy to use.
+  initially selected font. If the \a ok parameter is not-null, the
+  value it refers to is set to true if the user clicks \gui OK, and
+  set to false if the user clicks \gui Cancel.
 
   Examples:
-  \code
-    bool ok;
-    QFont font = QFontDialog::getFont(&ok, QFont("Times", 12), this);
-    if (ok) {
-        // font is set to the font the user selected
-    } else {
-        // the user canceled the dialog; font is set to the initial
-        // value, in this case Times, 12.
-    }
-  \endcode
+  \snippet doc/src/snippets/code/src_gui_dialogs_qfontdialog.cpp 2
 
     The dialog can also be used to set a widget's font directly:
-  \code
-    myWidget.setFont(QFontDialog::getFont(0, myWidget.font()));
-  \endcode
+  \snippet doc/src/snippets/code/src_gui_dialogs_qfontdialog.cpp 3
   In this example, if the user clicks OK the font they chose will be
   used, and if they click Cancel the original font is used.
 */
@@ -413,27 +412,16 @@ QFont QFontDialog::getFont(bool *ok, const QFont &initial,
 
   Executes a modal font dialog and returns a font.
 
-  If the user clicks OK, the selected font is returned. If the user
-  clicks Cancel, the Qt default font is returned.
+  If the user clicks \gui OK, the selected font is returned. If the user
+  clicks \gui Cancel, the Qt default font is returned.
 
   The dialog is constructed with the given \a parent.
-  If the \a ok parameter is not-null, \e *\a ok is set to true if the
-  user clicked OK, and false if the user clicked Cancel.
-
-  This static function is less functional than the full QFontDialog
-  object, but is convenient and easy to use.
+  If the \a ok parameter is not-null, the value it refers to is set
+  to true if the user clicks \gui OK, and false if the user clicks
+  \gui Cancel.
 
   Example:
-  \code
-    bool ok;
-    QFont font = QFontDialog::getFont(&ok, this);
-    if (ok) {
-        // font is set to the font the user selected
-    } else {
-        // the user canceled the dialog; font is set to the default
-        // application font, QApplication::font()
-    }
-  \endcode
+  \snippet doc/src/snippets/code/src_gui_dialogs_qfontdialog.cpp 4
 
 */
 QFont QFontDialog::getFont(bool *ok, QWidget *parent)
@@ -786,6 +774,31 @@ void QFontDialogPrivate::_q_sizeChanged(const QString &s)
     _q_updateSample();
 }
 
+void QFontDialogPrivate::retranslateStrings()
+{
+    familyAccel->setText(QFontDialog::tr("&Font"));
+    styleAccel->setText(QFontDialog::tr("Font st&yle"));
+    sizeAccel->setText(QFontDialog::tr("&Size"));
+    effects->setTitle(QFontDialog::tr("Effects"));
+    strikeout->setText(QFontDialog::tr("Stri&keout"));
+    underline->setText(QFontDialog::tr("&Underline"));
+    sample->setTitle(QFontDialog::tr("Sample"));
+    writingSystemAccel->setText(QFontDialog::tr("Wr&iting System"));
+}
+
+
+/*!
+    \reimp
+*/
+void QFontDialog::changeEvent(QEvent *e)
+{
+    Q_D(QFontDialog);
+    if (e->type() == QEvent::LanguageChange) {
+        d->retranslateStrings();
+    }
+    QDialog::changeEvent(e);
+}
+
 /*!
   \internal
   Sets the font highlighted in the QFontDialog to font \a f.
@@ -843,7 +856,9 @@ QFont QFontDialog::font() const
     The \a name parameter is ignored.
 */
 
+QT_END_NAMESPACE
+
 #include "qfontdialog.moc"
 #include "moc_qfontdialog.cpp"
 
-#endif
+#endif // QT_NO_FONTDIALOG
