@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -574,7 +568,6 @@ void QPrintPreviewDialogPrivate::_q_pageSetup()
     Q_Q(QPrintPreviewDialog);
 
     QPageSetupDialog pageSetup(printer, q);
-    pageSetup.setWindowTitle(QCoreApplication::translate("QPrintPreviewDialog", "Page Setup"));
     if (pageSetup.exec() == QDialog::Accepted) {
         // update possible orientation changes
         if (preview->orientation() == QPrinter::Portrait) {
@@ -631,8 +624,10 @@ void QPrintPreviewDialogPrivate::_q_zoomFactorChanged()
     When the dialog needs to generate a set of preview pages, the
     paintRequested() signal will be emitted. You can use the exact
     same code for the actual printing as for having the preview
-    generated. Connect a slot to the paintRequested() signal, where
-    you draw onto the QPrinter object that is passed into the slot.
+    generated, including calling QPrinter::newPage() to start a new
+    page in the preview. Connect a slot to the paintRequested()
+    signal, where you draw onto the QPrinter object that is passed
+    into the slot.
 
     \o Call exec().
 
@@ -659,6 +654,7 @@ QPrintPreviewDialog::QPrintPreviewDialog(QPrinter* printer, QWidget *parent, Qt:
 
 /*!
     \overload
+    \fn QPrintPreviewDialog::QPrintPreviewDialog(QWidget *parent, Qt::WindowFlags flags)
 
     This will create an internal QPrinter object, which will use the
     system default printer.
@@ -698,9 +694,12 @@ void QPrintPreviewDialog::setVisible(bool visible)
 /*!
     \fn void QPrintPreviewDialog::paintRequested(QPrinter *printer)
 
-    When the the QPrintPreviewDialog needs to generate a set of
-    preview pages, this signal is emitted with the \a printer
-    you should draw onto.
+    This signal is emitted when the QPrintPreviewDialog needs to generate
+    a set of preview pages.
+
+    The \a printer instance supplied is the paint device onto which you should
+    paint the contents of each page, using the QPrinter instance in the same way
+    as you would when printing directly.
 */
 
 
