@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -70,6 +64,7 @@ QT_BEGIN_NAMESPACE
     items in a QGraphicsScene.
     \since 4.4
     \ingroup multimedia
+    \ingroup graphicsview-api
 
     QGraphicsWidget is an extended base item that provides extra functionality
     over QGraphicsItem. It is similar to QWidget in many ways:
@@ -111,9 +106,9 @@ QT_BEGIN_NAMESPACE
                 \o All widget attributes are supported.
     \row      \o A top-level item's style defaults to QGraphicsScene::style
                 \o A top-level widget's style defaults to QApplication::style
-    \row      \o Graphics View provides a custom DnD framework, different
+    \row      \o Graphics View provides a custom drag and drop framework, different
                     from QWidget.
-                \o Standard DnD framework.
+                \o Standard drag and drop framework.
     \row      \o Widget items do not support modality.
                 \o Full modality support.
     \endtable
@@ -162,6 +157,8 @@ QT_BEGIN_NAMESPACE
 
     This property is declared in QGraphicsItem.
 
+    By default, this property is true.
+
     \sa QGraphicsItem::isEnabled(), QGraphicsItem::setEnabled()
 */
 
@@ -171,6 +168,8 @@ QT_BEGIN_NAMESPACE
 
     This property is declared in QGraphicsItem.
 
+    By default, this property is true.
+
     \sa QGraphicsItem::isVisible(), QGraphicsItem::setVisible(), show(),
     hide()
 */
@@ -213,9 +212,9 @@ QGraphicsWidget::~QGraphicsWidget()
     d->focusNext = this;
     d->focusPrev = this;
 
-    delete d->layout;
-
     clearFocus();
+
+    delete d->layout;
 }
 
 /*!
@@ -234,9 +233,11 @@ QGraphicsWidget::~QGraphicsWidget()
     update any child widgets's geometry.
 
     This property does not affect any layout of the parent widget. If the
-    widget itself is managed by a parent layout, e.g., it has a parent widget
+    widget itself is managed by a parent layout; e.g., it has a parent widget
     with a layout assigned, that layout will not activate.
 
+    By default, this property contains a size with zero width and height.
+
     \sa setGeometry(), QGraphicsSceneResizeEvent, QGraphicsLayout
 */
 QSizeF QGraphicsWidget::size() const
@@ -511,7 +512,7 @@ QRectF QGraphicsWidget::windowFrameRect() const
 
     For example:
 
-    \snippet doc/src/snippets/code/src.gui.graphicsview.qgraphicswidget.cpp 0
+    \snippet doc/src/snippets/code/src_gui_graphicsview_qgraphicswidget.cpp 0
 
     \sa QStyleOption::initFrom()
 */
@@ -803,6 +804,8 @@ void QGraphicsWidget::setStyle(QStyle *style)
     \l{QEvent::FontChange}{FontChange} event and notifies all its
     descendants so that they can resolve their fonts as well.
 
+    By default, this property contains the application's default font.
+
     \sa QApplication::font(), QGraphicsScene::font, QFont::resolve()
 */
 QFont QGraphicsWidget::font() const
@@ -819,7 +822,7 @@ void QGraphicsWidget::setFont(const QFont &font)
 
 /*!
     \property QGraphicsWidget::palette
-    \brief the widgets' palette
+    \brief the widget's palette
 
     This property provides the widget's palette. The palette provides colors
     and brushes for color groups (e.g., QPalette::Button) and states (e.g.,
@@ -835,9 +838,11 @@ void QGraphicsWidget::setFont(const QFont &font)
     When a widget's palette changes, it resolves its entries against its
     parent widget, or if it doesn't have a parent widget, it resolves against
     the scene. It then sends itself a \l{QEvent::PaletteChange}{PaletteChange}
-    event, and notifies all its descendents so they can resolve their palettes
+    event, and notifies all its descendants so they can resolve their palettes
     as well.
 
+    By default, this property contains the application's default palette.
+
     \sa QApplication::palette(), QGraphicsScene::palette, QPalette::resolve()
 */
 QPalette QGraphicsWidget::palette() const
@@ -848,6 +853,9 @@ QPalette QGraphicsWidget::palette() const
 void QGraphicsWidget::setPalette(const QPalette &palette)
 {
     Q_D(QGraphicsWidget);
+    // ### Qt 4.5: Add this attribute and fix the d->resolvePalette() function
+    // to respect it.
+    // setAttribute(Qt::WA_SetPalette, palette.resolve() != 0);
     d->palette = palette;
     d->resolvePalette();
 }
@@ -1045,6 +1053,8 @@ bool QGraphicsWidget::windowFrameEvent(QEvent *event)
 }
 
 /*!
+    \since 4.4
+
     Returns the window frame section at position \a pos, or
     Qt::NoWindowFrameSection if there is no window frame section at this
     position.
@@ -1242,6 +1252,9 @@ bool QGraphicsWidget::event(QEvent *event)
 void QGraphicsWidget::changeEvent(QEvent *event)
 {
     switch (event->type()) {
+    case QEvent::StyleChange:
+        // ### Don't unset if the margins are explicitly set.
+        unsetWindowFrameMargins();
     case QEvent::FontChange:
         update();
         updateGeometry();
@@ -1484,11 +1497,13 @@ Qt::WindowType QGraphicsWidget::windowType() const
 
 /*!
     \property QGraphicsWidget::windowFlags
-    \brief This propery holds the widget's window flags.
+    \brief the widget's window flags
 
-    Window flags are a combination a window type (e.g. Qt::Dialog) and several
-    flags giving hints on the behaviour of the window. The behaviour is
-    platform dependent.
+    Window flags are a combination of a window type (e.g., Qt::Dialog) and
+    several flags giving hints on the behavior of the window. The behavior
+    is platform-dependent.
+
+    By default, this property contains no window flags.
 */
 Qt::WindowFlags QGraphicsWidget::windowFlags() const
 {
@@ -1517,26 +1532,31 @@ void QGraphicsWidget::setWindowFlags(Qt::WindowFlags wFlags)
 }
 
 /*!
-    Returns true if this widget's window is the active window.
+    Returns true if this widget's window is in the active window, or if the
+    widget does not have a window but is in an active scene (i.e., a scene
+    that currently has focus).
 
     The active window is the window that either contains a child widget that
     currently has input focus, or that itself has input focus.
+
+    \sa QGraphicsScene::activeWindow(), QGraphicsScene::setActiveWindow()
 */
 bool QGraphicsWidget::isActiveWindow() const
 {
     Q_D(const QGraphicsWidget);
     if (!d->scene)
         return false;
-    const QGraphicsWidget *w = isWindow() ? this : window();
-    return w && d->scene->activeWindow() == w;
+    const QGraphicsWidget *w = window();
+    return (!w && d->scene->d_func()->activationRefCount) || (w && d->scene->activeWindow() == w);
 }
 
 /*!
     \property QGraphicsWidget::windowTitle
     \brief This property holds the window title (caption).
 
-    This property is only used for windows. If no title has been set, the
-    title is an empty string.
+    This property is only used for windows.
+
+    By default, if no title has been set, this property contains an empty string.
 */
 void QGraphicsWidget::setWindowTitle(const QString &title)
 {
@@ -1586,9 +1606,9 @@ void QGraphicsWidget::setFocusPolicy(Qt::FocusPolicy policy)
 }
 
 /*!
-    If this widget, a child or descendent of this widget currently has input
+    If this widget, a child or descendant of this widget currently has input
     focus, this function will return a pointer to that widget. If
-    no descendent has input focus, 0 is returned.
+    no descendant has input focus, 0 is returned.
 
     \sa QWidget::focusWidget()
 */
@@ -1606,11 +1626,11 @@ QGraphicsWidget *QGraphicsWidget::focusWidget() const
     Note that since the tab order of the \a second widget is changed, you
     should order a chain like this:
 
-    \snippet doc/src/snippets/code/src.gui.graphicsview.qgraphicswidget.cpp 1
+    \snippet doc/src/snippets/code/src_gui_graphicsview_qgraphicswidget.cpp 1
 
     \e not like this:
 
-    \snippet doc/src/snippets/code/src.gui.graphicsview.qgraphicswidget.cpp 2
+    \snippet doc/src/snippets/code/src_gui_graphicsview_qgraphicswidget.cpp 2
 
     If \a first is 0, this indicates that \a second should be the first widget
     to receive input focus should the scene gain Tab focus (i.e., the user
