@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -587,7 +581,7 @@ QImageReader::~QImageReader()
     Sets the format QImageReader will use when reading images, to \a
     format. \a format is a case insensitive text string. Example:
 
-    \snippet doc/src/snippets/code/src.gui.image.qimagereader.cpp 0
+    \snippet doc/src/snippets/code/src_gui_image_qimagereader.cpp 0
 
     You can call supportedImageFormats() for the full list of formats
     QImageReader supports.
@@ -605,7 +599,7 @@ void QImageReader::setFormat(const QByteArray &format)
     You can call this function after assigning a device to the
     reader to determine the format of the device. For example:
 
-    \snippet doc/src/snippets/code/src.gui.image.qimagereader.cpp 1
+    \snippet doc/src/snippets/code/src_gui_image_qimagereader.cpp 1
 
     If the reader cannot read any image from the device (e.g., there is no
     image there, or the image has already been read), or if the format is
@@ -952,7 +946,7 @@ QImage QImageReader::read()
     which always constructs a new image; especially when reading several
     images with the same format and size.
 
-    \snippet doc/src/snippets/code/src.gui.image.qimagereader.cpp 2
+    \snippet doc/src/snippets/code/src_gui_image_qimagereader.cpp 2
 
     For image formats that support animation, calling read() repeatedly will
     return the next frame. When all frames have been read, a null image will
@@ -1189,7 +1183,7 @@ QString QImageReader::errorString() const
     (see text()), and the BMP format allows you to determine the image's size
     without loading the whole image into memory (see size()).
 
-    \snippet doc/src/snippets/code/src.gui.image.qimagereader.cpp 3
+    \snippet doc/src/snippets/code/src_gui_image_qimagereader.cpp 3
 
     \sa QImageWriter::supportsOption()
 */
