@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -76,9 +70,7 @@
 # include <private/qpixmap_x11_p.h>
 #endif
 
-#if defined(Q_OS_WIN) && !defined(QT_NO_DIRECT3D)
-# include "qpixmap_raster_p.h"
-#endif
+#include "qpixmap_raster_p.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -154,10 +146,13 @@ QPixmap::QPixmap()
 /*!
     \fn QPixmap::QPixmap(int width, int height)
 
-    Constructs a pixmap with the given \a width and \a height.
+    Constructs a pixmap with the given \a width and \a height. If
+    either \a width or \a height is zero, a null pixmap is
+    constructed.
 
-    The content of the pixmap is uninitialized.  If either \a width or
-    \a height is zero, a null pixmap is constructed.
+    \warning This will create a QPixmap with uninitialized data. Call
+    fill() to fill the pixmap with an appropriate color before drawing
+    onto it with QPainter.
 
     \sa isNull()
 */
@@ -175,6 +170,10 @@ QPixmap::QPixmap(int w, int h)
     \overload
 
     Constructs a pixmap of the given \a size.
+
+    \warning This will create a QPixmap with uninitialized data. Call
+    fill() to fill the pixmap with an appropriate color before drawing
+    onto it with QPainter.
 */
 
 QPixmap::QPixmap(const QSize &size)
@@ -287,7 +286,7 @@ QPixmap::QPixmap(const QPixmap &pixmap)
     Note that it's possible to squeeze the XPM variable a little bit
     by using an unusual declaration:
 
-    \snippet doc/src/snippets/code/src.gui.image.qpixmap.cpp 0
+    \snippet doc/src/snippets/code/src_gui_image_qpixmap.cpp 0
 
     The extra \c const makes the entire definition read-only, which is
     slightly more efficient (for example, when the code is in a shared
@@ -574,9 +573,8 @@ void QPixmap::resize_helper(const QSize &s)
     if (size() == s)
         return;
 
-    int d = data->depth();
     // Create new pixmap
-    QPixmap pm(QSize(w, h), d == 1 ? QPixmapData::BitmapType : QPixmapData::PixmapType);
+    QPixmap pm(QSize(w, h), data->type);
     bool uninit = false;
 #if defined(Q_WS_X11)
     QX11PixmapData *x11Data = static_cast<QX11PixmapData*>(data);
@@ -693,7 +691,7 @@ void QPixmap::setMask(const QBitmap &mask)
     The mask may not be perfect but it should be reasonable, so you
     can do things such as the following:
 
-    \snippet doc/src/snippets/code/src.gui.image.qpixmap.cpp 1
+    \snippet doc/src/snippets/code/src_gui_image_qpixmap.cpp 1
 
     This function is slow because it involves converting to/from a
     QImage, and non-trivial computations.
@@ -1661,7 +1659,7 @@ QPixmap QPixmap::transformed(const QMatrix &matrix, Qt::TransformationMode mode)
 */
 bool QPixmap::hasAlpha() const
 {
-    return (!data->mask().isNull() || data->hasAlphaChannel());
+    return (data->hasAlphaChannel() || !data->mask().isNull());
 }
 
 /*!
@@ -1808,12 +1806,16 @@ extern _qt_pixmap_cleanup_hook_64 qt_pixmap_cleanup_hook_64;
 */
 void QPixmap::detach()
 {
+    if (data->classId() == QPixmapData::RasterClass) {
+        QRasterPixmapData *rasterData = static_cast<QRasterPixmapData*>(data);
+        rasterData->image.detach();
 #if defined(Q_WS_WIN) && !defined(QT_NO_DIRECT3D)
-    QRasterPixmapData *rasterData = static_cast<QRasterPixmapData*>(data);
-    if (rasterData->texture)
-        rasterData->texture->Release();
-    rasterData->texture = 0;
+        if (rasterData->texture) {
+            rasterData->texture->Release();
+            rasterData->texture = 0;
+        }
 #endif
+    }
 
     if (qt_pixmap_cleanup_hook_64 && data->ref == 1)
         qt_pixmap_cleanup_hook_64(cacheKey());
