@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -230,7 +224,7 @@ static int lowest_bit(uint v)
     int i;
     ulong lb;
     lb = 1;
-    for (i=0; ((v & lb) == 0) && i<32;  i++, lb<<=1);
+    for (i=0; ((v & lb) == 0) && i<32;  i++, lb<<=1) {}
     return i==32 ? -1 : i;
 }
 
@@ -350,7 +344,19 @@ void QX11PixmapData::fromImage(const QImage &img,
 
     w = img.width();
     h = img.height();
-    d = (pixelType() == BitmapType ? 1 : img.depth());
+    d = img.depth();
+
+    if (defaultScreen >= 0 && defaultScreen != xinfo.screen()) {
+        QX11InfoData* xd = xinfo.getX11Data(true);
+        xd->screen = defaultScreen;
+        xd->depth = QX11Info::appDepth(xd->screen);
+        xd->cells = QX11Info::appCells(xd->screen);
+        xd->colormap = QX11Info::appColormap(xd->screen);
+        xd->defaultColormap = QX11Info::appDefaultColormap(xd->screen);
+        xd->visual = (Visual *)QX11Info::appVisual(xd->screen);
+        xd->defaultVisual = QX11Info::appDefaultVisual(xd->screen);
+        xinfo.setX11Data(xd);
+    }
 
     if (pixelType() == BitmapType) {
         bitmapFromImage(img);
@@ -362,7 +368,9 @@ void QX11PixmapData::fromImage(const QImage &img,
         return;
     }
 
-    const int dd = X11->use_xrender && img.hasAlphaChannel() ? 32 : xinfo.depth();
+    int dd = X11->use_xrender && img.hasAlphaChannel() ? 32 : xinfo.depth();
+    if (qt_x11_preferred_pixmap_depth)
+        dd = qt_x11_preferred_pixmap_depth;
 
     QImage image = img;
 
@@ -400,7 +408,7 @@ void QX11PixmapData::fromImage(const QImage &img,
 
     if (d == 1 || d == 16 || d == 24) {
         image = image.convertToFormat(QImage::Format_RGB32, flags);
-        fromImage(image, flags);
+        fromImage(image, Qt::AutoColor);
         return;
     }
 
@@ -1143,6 +1151,9 @@ QX11PixmapData::~QX11PixmapData()
 
 void QX11PixmapData::release()
 {
+    delete pengine;
+    pengine = 0;
+
     if (!qApp)
         return;
 
@@ -1171,8 +1182,6 @@ void QX11PixmapData::release()
         XFreePixmap(xinfo.display(), hd);
         hd = 0;
     }
-
-    delete pengine;
 }
 
 QPixmap QX11PixmapData::alphaChannel() const
@@ -1673,6 +1682,11 @@ QImage QX11PixmapData::toImage() const
 QPixmap QX11PixmapData::transformed(const QTransform &transform,
                                     Qt::TransformationMode mode ) const
 {
+    if (mode == Qt::SmoothTransformation || transform.type() >= QTransform::TxProject) {
+        QImage image = toImage();
+        return QPixmap::fromImage(image.transformed(transform, mode));
+    }
+
     uint   w = 0;
     uint   h = 0;                               // size of target pixmap
     uint   ws, hs;                              // size of source pixmap
@@ -1694,24 +1708,23 @@ QPixmap QX11PixmapData::transformed(const QTransform &transform,
     qreal scaledWidth;
     qreal scaledHeight;
 
-    if (mat.m12() == 0.0F && mat.m21() == 0.0F) {
+    if (mat.type() <= QTransform::TxScale) {
         scaledHeight = qAbs(mat.m22()) * hs + 0.9999;
         scaledWidth = qAbs(mat.m11()) * ws + 0.9999;
         h = qAbs(int(scaledHeight));
         w = qAbs(int(scaledWidth));
     } else {                                        // rotation or shearing
-        QPolygonF a(QRectF(0, 0, ws+1, hs+1));
+        QPolygonF a(QRectF(0, 0, ws, hs));
         a = mat.map(a);
-        QRectF r = a.boundingRect().normalized();
-        w = int(r.width() + 0.9999);
-        h = int(r.height() + 0.9999);
+        QRect r = a.boundingRect().toAlignedRect();
+        w = r.width();
+        h = r.height();
         scaledWidth = w;
         scaledHeight = h;
         complex_xform = true;
     }
     mat = QPixmap::trueMatrix(mat, ws, hs); // true matrix
 
-
     bool invertible;
     mat = mat.inverted(&invertible);  // invert matrix
 
@@ -1720,11 +1733,6 @@ QPixmap QX11PixmapData::transformed(const QTransform &transform,
 	// error, return null pixmap
         return QPixmap();
 
-    if (mode == Qt::SmoothTransformation) {
-        QImage image = toImage();
-        return QPixmap::fromImage(image.transformed(transform, mode));
-    }
-
 #if defined(QT_MITSHM)
     static bool try_once = true;
     if (try_once) {
@@ -1906,7 +1914,7 @@ void QPixmap::x11SetScreen(int screen)
         return;
     }
 #if 0
-    qDebug("QPixmap::x11SetScreen for %p from %d to %d. Size is %d/%d", data, data->xinfo.screen(), screen, width(), height());
+    qDebug("QPixmap::x11SetScreen for %p from %d to %d. Size is %d/%d", x11Data, x11Data->xinfo.screen(), screen, width(), height());
 #endif
 
     QImage img = toImage();
