@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -33,13 +47,130 @@
 #include <qvector.h>
 
 #include <png.h>
+#include <pngconf.h>
 
-#ifdef Q_OS_TEMP
+#ifdef Q_OS_WINCE
 #define CALLBACK_CALL_TYPE        __cdecl
 #else
 #define CALLBACK_CALL_TYPE
 #endif
 
+QT_BEGIN_NAMESPACE
+
+#if defined(Q_OS_WINCE) && defined(STANDARDSHELL_UI_MODEL)
+#  define Q_INTERNAL_WIN_NO_THROW __declspec(nothrow)
+#else
+#  define Q_INTERNAL_WIN_NO_THROW
+#endif
+
+#ifdef QT_LSB
+
+// LSB doesn't standardize png_info_struct and png_struct_def
+// These structs are documented to not change, so fork as much as
+// we need. In the future, we should use the propper accessors, though.
+
+QT_BEGIN_INCLUDE_NAMESPACE
+#include <setjmp.h>
+QT_END_INCLUDE_NAMESPACE
+
+struct png_info_struct
+{
+   /* the following are necessary for every PNG file */
+   png_uint_32 width;       /* width of image in pixels (from IHDR) */
+   png_uint_32 height;      /* height of image in pixels (from IHDR) */
+   png_uint_32 valid;       /* valid chunk data (see PNG_INFO_ below) */
+   png_uint_32 rowbytes;    /* bytes needed to hold an untransformed row */
+   png_colorp palette;      /* array of color values (valid & PNG_INFO_PLTE) */
+   png_uint_16 num_palette; /* number of color entries in "palette" (PLTE) */
+   png_uint_16 num_trans;   /* number of transparent palette color (tRNS) */
+   png_byte bit_depth;      /* 1, 2, 4, 8, or 16 bits/channel (from IHDR) */
+   png_byte color_type;     /* see PNG_COLOR_TYPE_ below (from IHDR) */
+   /* The following three should have been named *_method not *_type */
+   png_byte compression_type; /* must be PNG_COMPRESSION_TYPE_BASE (IHDR) */
+   png_byte filter_type;    /* must be PNG_FILTER_TYPE_BASE (from IHDR) */
+   png_byte interlace_type; /* One of PNG_INTERLACE_NONE, PNG_INTERLACE_ADAM7 */
+
+   /* The following is informational only on read, and not used on writes. */
+   png_byte channels;       /* number of data channels per pixel (1, 2, 3, 4) */
+   png_byte pixel_depth;    /* number of bits per pixel */
+   png_byte spare_byte;     /* to align the data, and for future use */
+   png_byte signature[8];   /* magic bytes read by libpng from start of file */
+
+   /* The rest of the data is optional.  If you are reading, check the
+    * valid field to see if the information in these are valid.  If you
+    * are writing, set the valid field to those chunks you want written,
+    * and initialize the appropriate fields below.
+    */
+
+#if defined(PNG_gAMA_SUPPORTED) && defined(PNG_FLOATING_POINT_SUPPORTED)
+   /* The gAMA chunk describes the gamma characteristics of the system
+    * on which the image was created, normally in the range [1.0, 2.5].
+    * Data is valid if (valid & PNG_INFO_gAMA) is non-zero.
+    */
+   float gamma; /* gamma value of image, if (valid & PNG_INFO_gAMA) */
+#endif
+
+#if defined(PNG_sRGB_SUPPORTED)
+    /* GR-P, 0.96a */
+    /* Data valid if (valid & PNG_INFO_sRGB) non-zero. */
+   png_byte srgb_intent; /* sRGB rendering intent [0, 1, 2, or 3] */
+#endif
+
+#if defined(PNG_TEXT_SUPPORTED)
+   /* The tEXt, and zTXt chunks contain human-readable textual data in
+    * uncompressed, compressed, and optionally compressed forms, respectively.
+    * The data in "text" is an array of pointers to uncompressed,
+    * null-terminated C strings. Each chunk has a keyword that describes the
+    * textual data contained in that chunk.  Keywords are not required to be
+    * unique, and the text string may be empty.  Any number of text chunks may
+    * be in an image.
+    */
+   int num_text; /* number of comments read/to write */
+   int max_text; /* current size of text array */
+   png_textp text; /* array of comments read/to write */
+#endif /* PNG_TEXT_SUPPORTED */
+
+#if defined(PNG_tIME_SUPPORTED)
+   /* The tIME chunk holds the last time the displayed image data was
+    * modified.  See the png_time struct for the contents of this struct.
+    */
+   png_time mod_time;
+#endif
+
+#if defined(PNG_sBIT_SUPPORTED)
+   /* The sBIT chunk specifies the number of significant high-order bits
+    * in the pixel data.  Values are in the range [1, bit_depth], and are
+    * only specified for the channels in the pixel data.  The contents of
+    * the low-order bits is not specified.  Data is valid if
+    * (valid & PNG_INFO_sBIT) is non-zero.
+    */
+   png_color_8 sig_bit; /* significant bits in color channels */
+#endif
+
+#if defined(PNG_tRNS_SUPPORTED) || defined(PNG_READ_EXPAND_SUPPORTED) || \
+defined(PNG_READ_BACKGROUND_SUPPORTED)
+   /* The tRNS chunk supplies transparency data for paletted images and
+    * other image types that don't need a full alpha channel.  There are
+    * "num_trans" transparency values for a paletted image, stored in the
+    * same order as the palette colors, starting from index 0.  Values
+    * for the data are in the range [0, 255], ranging from fully transparent
+    * to fully opaque, respectively.  For non-paletted images, there is a
+    * single color specified that should be treated as fully transparent.
+    * Data is valid if (valid & PNG_INFO_tRNS) is non-zero.
+    */
+   png_bytep trans; /* transparent values for paletted image */
+   png_color_16 trans_values; /* transparent color for non-palette image */
+#endif
+};
+
+struct png_struct_def
+{
+#ifdef PNG_SETJMP_SUPPORTED
+       jmp_buf jmpbuf;            /* used in png_error */
+#endif
+};
+
+#endif // QT_LSB
 
 /*
   All PNG files load to the minimal QImage equivalent.
@@ -140,9 +271,11 @@ void setup_qt(QImage& image, png_structp png_ptr, png_infop info_ptr, float scre
         if (bit_depth == 1 && info_ptr->channels == 1) {
             png_set_invert_mono(png_ptr);
             png_read_update_info(png_ptr, info_ptr);
-            image = QImage(width, height, QImage::Format_Mono);
-            if (image.isNull())
-                return;
+            if (image.size() != QSize(width, height) || image.format() != QImage::Format_Mono) {
+                image = QImage(width, height, QImage::Format_Mono);
+                if (image.isNull())
+                    return;
+            }
             image.setNumColors(2);
             image.setColor(1, qRgb(0,0,0));
             image.setColor(0, qRgb(255,255,255));
@@ -150,9 +283,11 @@ void setup_qt(QImage& image, png_structp png_ptr, png_infop info_ptr, float scre
             png_set_expand(png_ptr);
             png_set_strip_16(png_ptr);
             png_set_gray_to_rgb(png_ptr);
-            image = QImage(width, height, QImage::Format_ARGB32);
-            if (image.isNull())
-                return;
+            if (image.size() != QSize(width, height) || image.format() != QImage::Format_ARGB32) {
+                image = QImage(width, height, QImage::Format_ARGB32);
+                if (image.isNull())
+                    return;
+            }
             if (QSysInfo::ByteOrder == QSysInfo::BigEndian)
                 png_set_swap_alpha(png_ptr);
 
@@ -164,9 +299,11 @@ void setup_qt(QImage& image, png_structp png_ptr, png_infop info_ptr, float scre
                 png_set_packing(png_ptr);
             int ncols = bit_depth < 8 ? 1 << bit_depth : 256;
             png_read_update_info(png_ptr, info_ptr);
-            image = QImage(width, height, QImage::Format_Indexed8);
-            if (image.isNull())
-                return;
+            if (image.size() != QSize(width, height) || image.format() != QImage::Format_Indexed8) {
+                image = QImage(width, height, QImage::Format_Indexed8);
+                if (image.isNull())
+                    return;
+            }
             image.setNumColors(ncols);
             for (int i=0; i<ncols; i++) {
                 int c = i*255/(ncols-1);
@@ -188,9 +325,12 @@ void setup_qt(QImage& image, png_structp png_ptr, png_infop info_ptr, float scre
             png_set_packing(png_ptr);
         png_read_update_info(png_ptr, info_ptr);
         png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, 0, 0, 0);
-        image = QImage(width, height, bit_depth == 1 ? QImage::Format_Mono : QImage::Format_Indexed8);
-        if (image.isNull())
-            return;
+        QImage::Format format = bit_depth == 1 ? QImage::Format_Mono : QImage::Format_Indexed8;
+        if (image.size() != QSize(width, height) || image.format() != format) {
+            image = QImage(width, height, format);
+            if (image.isNull())
+                return;
+        }
         image.setNumColors(info_ptr->num_palette);
         int i = 0;
         if (png_get_valid(png_ptr, info_ptr, PNG_INFO_tRNS)) {
@@ -234,9 +374,11 @@ void setup_qt(QImage& image, png_structp png_ptr, png_infop info_ptr, float scre
             // We want 4 bytes, but it isn't an alpha channel
             format = QImage::Format_RGB32;
         }
-        image = QImage(width, height, format);
-        if (image.isNull())
-            return;
+        if (image.size() != QSize(width, height) || image.format() != format) {
+            image = QImage(width, height, format);
+            if (image.isNull())
+                return;
+        }
 
         if (QSysInfo::ByteOrder == QSysInfo::BigEndian)
             png_set_swap_alpha(png_ptr);
@@ -297,7 +439,7 @@ public:
 /*!
     \internal
 */
-bool QPngHandlerPrivate::readPngHeader()
+bool Q_INTERNAL_WIN_NO_THROW QPngHandlerPrivate::readPngHeader()
 {
     state = Error;
     png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING,0,0,0);
@@ -320,7 +462,7 @@ bool QPngHandlerPrivate::readPngHeader()
         return false;
     }
 
-    if (setjmp(png_ptr->jmpbuf)) {
+    if (setjmp(png_jmpbuf(png_ptr))) {
         png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
         png_ptr = 0;
         return false;
@@ -338,19 +480,19 @@ bool QPngHandlerPrivate::readPngHeader()
         QString key, value;
 #if defined(PNG_iTXt_SUPPORTED)
         if (text_ptr->lang) {
-            QTextCodec *textCodec = QTextCodec::codecForName(text_ptr->lang);
-            if (textCodec) {
+            QTextCodec *codec = QTextCodec::codecForName(text_ptr->lang);
+            if (codec) {
                 key = codec->toUnicode(text_ptr->lang_key);
                 value = codec->toUnicode(QByteArray(text_ptr->text, text_ptr->itxt_length));
             } else {
                 key = QString::fromLatin1(text_ptr->key);
-                value = QString::fromLatin1(QByteArray(text_ptr->text, text_ptr->text_length));
+                value = QString::fromLatin1(QByteArray(text_ptr->text, int(text_ptr->text_length)));
             }
         } else
 #endif
         {
             key = QString::fromLatin1(text_ptr->key);
-            value = QString::fromLatin1(QByteArray(text_ptr->text, text_ptr->text_length));
+            value = QString::fromLatin1(QByteArray(text_ptr->text, int(text_ptr->text_length)));
         }
         if (!description.isEmpty())
             description += QLatin1String("\n\n");
@@ -366,7 +508,7 @@ bool QPngHandlerPrivate::readPngHeader()
 /*!
     \internal
 */
-bool QPngHandlerPrivate::readPngImage(QImage *outImage)
+bool Q_INTERNAL_WIN_NO_THROW QPngHandlerPrivate::readPngImage(QImage *outImage)
 {
     if (state == Error)
         return false;
@@ -376,18 +518,20 @@ bool QPngHandlerPrivate::readPngImage(QImage *outImage)
         return false;
     }
 
-    if (setjmp(png_ptr->jmpbuf)) {
+    row_pointers = 0;
+    if (setjmp(png_jmpbuf(png_ptr))) {
         png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
+        delete [] row_pointers;
         png_ptr = 0;
         state = Error;
         return false;
     }
 
-    QImage image;
-    setup_qt(image, png_ptr, info_ptr, gamma);
+    setup_qt(*outImage, png_ptr, info_ptr, gamma);
 
-    if (image.isNull()) {
+    if (outImage->isNull()) {
         png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
+        delete [] row_pointers;
         png_ptr = 0;
         state = Error;
         return false;
@@ -400,9 +544,9 @@ bool QPngHandlerPrivate::readPngImage(QImage *outImage)
     png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth, &color_type,
                  0, 0, 0);
 
-    uchar *data = image.bits();
-    int bpl = image.bytesPerLine();
-    row_pointers=new png_bytep[height];
+    uchar *data = outImage->bits();
+    int bpl = outImage->bytesPerLine();
+    row_pointers = new png_bytep[height];
 
     for (uint y = 0; y < height; y++)
         row_pointers[y] = data + y * bpl;
@@ -411,7 +555,7 @@ bool QPngHandlerPrivate::readPngImage(QImage *outImage)
 
 #if 0 // libpng takes care of this.
     png_get_valid(png_ptr, info_ptr, PNG_INFO_tRNS)
-        if (image.depth()==32 && png_get_valid(png_ptr, info_ptr, PNG_INFO_tRNS)) {
+        if (outImage->depth()==32 && png_get_valid(png_ptr, info_ptr, PNG_INFO_tRNS)) {
             QRgb trans = 0xFF000000 | qRgb(
                 (info_ptr->trans_values.red << 8 >> bit_depth)&0xff,
                 (info_ptr->trans_values.green << 8 >> bit_depth)&0xff,
@@ -427,38 +571,50 @@ bool QPngHandlerPrivate::readPngImage(QImage *outImage)
         }
 #endif
 
-    image.setDotsPerMeterX(png_get_x_pixels_per_meter(png_ptr,info_ptr));
-    image.setDotsPerMeterY(png_get_y_pixels_per_meter(png_ptr,info_ptr));
+    outImage->setDotsPerMeterX(png_get_x_pixels_per_meter(png_ptr,info_ptr));
+    outImage->setDotsPerMeterY(png_get_y_pixels_per_meter(png_ptr,info_ptr));
 
 #ifndef QT_NO_IMAGE_TEXT
     png_textp text_ptr;
     int num_text=0;
     png_get_text(png_ptr,info_ptr,&text_ptr,&num_text);
     while (num_text--) {
-        image.setText(text_ptr->key,0,text_ptr->text);
+        outImage->setText(text_ptr->key,0,QString::fromAscii(text_ptr->text));
         text_ptr++;
     }
 
-    foreach (QString pair, description.split("\n\n")) {
-        int index = pair.indexOf(":");
-        if (index >= 0 && pair.indexOf(" ") < index) {
-            image.setText("Description", pair.simplified());
+    foreach (QString pair, description.split(QLatin1String("\n\n"))) {
+        int index = pair.indexOf(QLatin1Char(':'));
+        if (index >= 0 && pair.indexOf(QLatin1Char(' ')) < index) {
+            outImage->setText(QLatin1String("Description"), pair.simplified());
         } else {
             QString key = pair.left(index);
-            image.setText(key, pair.mid(index + 2).simplified());
+            outImage->setText(key, pair.mid(index + 2).simplified());
         }
     }
 #endif
 
-    delete [] row_pointers;
-
-    *outImage = image;
-
     png_read_end(png_ptr, end_info);
     png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
+    delete [] row_pointers;
     png_ptr = 0;
     state = Ready;
 
+    // sanity check palette entries
+    if (color_type == PNG_COLOR_TYPE_PALETTE
+        && outImage->format() == QImage::Format_Indexed8) {
+        int color_table_size = outImage->numColors();
+        for (int y=0; y<(int)height; ++y) {
+            uchar *p = outImage->scanLine(y);
+            uchar *end = p + width;
+            while (p < end) {
+                if (*p >= color_table_size)
+                    *p = 0;
+                ++p;
+            }
+        }
+    }
+
     return true;
 }
 
@@ -507,11 +663,11 @@ static void set_text(const QImage &image, png_structp png_ptr, png_infop info_pt
             text.insert(key, image.text(key));
     }
     foreach (QString pair, description.split(QLatin1String("\n\n"))) {
-        int index = pair.indexOf(":");
-        if (index >= 0 && pair.indexOf(" ") < index) {
+        int index = pair.indexOf(QLatin1Char(':'));
+        if (index >= 0 && pair.indexOf(QLatin1Char(' ')) < index) {
             QString s = pair.simplified();
             if (!s.isEmpty())
-                text.insert("Description", s);
+                text.insert(QLatin1String("Description"), s);
         } else {
             QString key = pair.left(index);
             if (!key.simplified().isEmpty())
@@ -567,20 +723,33 @@ bool QPNGImageWriter::writeImage(const QImage& image, int off_x, int off_y)
     return writeImage(image, -1, QString(), off_x, off_y);
 }
 
-bool QPNGImageWriter::writeImage(const QImage& image_in, int quality_in, const QString &description,
+bool Q_INTERNAL_WIN_NO_THROW QPNGImageWriter::writeImage(const QImage& image_in, int quality_in, const QString &description,
                                  int off_x_in, int off_y_in)
 {
 #ifdef QT_NO_IMAGE_TEXT
     Q_UNUSED(description);
 #endif
 
-    QImage image = image_in;
-    if(image.format() == QImage::Format_ARGB32_Premultiplied)
-        image = image.convertToFormat(QImage::Format_ARGB32);
-#ifdef Q_WS_QWS
-    else if (image.format() == QImage::Format_RGB16)
-        image = image.convertToFormat(QImage::Format_RGB32);
-#endif
+    QImage image;
+    switch (image_in.format()) {
+    case QImage::Format_ARGB32_Premultiplied:
+    case QImage::Format_ARGB4444_Premultiplied:
+    case QImage::Format_ARGB8555_Premultiplied:
+    case QImage::Format_ARGB8565_Premultiplied:
+    case QImage::Format_ARGB6666_Premultiplied:
+        image = image_in.convertToFormat(QImage::Format_ARGB32);
+        break;
+    case QImage::Format_RGB16:
+    case QImage::Format_RGB444:
+    case QImage::Format_RGB555:
+    case QImage::Format_RGB666:
+    case QImage::Format_RGB888:
+        image = image_in.convertToFormat(QImage::Format_RGB32);
+        break;
+    default:
+        image = image_in;
+        break;
+    }
 
     QPoint offset = image.offset();
     int off_x = off_x_in + offset.x();
@@ -603,7 +772,7 @@ bool QPNGImageWriter::writeImage(const QImage& image_in, int quality_in, const Q
         return false;
     }
 
-    if (setjmp(png_ptr->jmpbuf)) {
+    if (setjmp(png_jmpbuf(png_ptr))) {
         png_destroy_write_struct(&png_ptr, &info_ptr);
         return false;
     }
@@ -858,4 +1027,6 @@ QByteArray QPngHandler::name() const
     return "png";
 }
 
+QT_END_NAMESPACE
+
 #endif // QT_NO_IMAGEFORMAT_PNG
