@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -185,50 +179,52 @@ void QDirModelPrivate::invalidate()
 }
 
 /*!
-  \class QDirModel qdirmodel.h
+    \class QDirModel qdirmodel.h
 
-  \brief The QDirModel class provides a data model for the local filesystem.
+    \brief The QDirModel class provides a data model for the local filesystem.
 
-  \ingroup model-view
+    \ingroup model-view
 
-  This class provides access to the local filesystem, providing functions
-  for renaming and removing files and directories, and for creating new
-  directories. In the simplest case, it can be used with a suitable display
-  widget as part of a browser or filer.
+    This class provides access to the local filesystem, providing functions
+    for renaming and removing files and directories, and for creating new
+    directories. In the simplest case, it can be used with a suitable display
+    widget as part of a browser or filer.
 
-  QDirModel keeps a cache with file information. The cache needs to be
-  updated with refresh().
+    QDirModel keeps a cache with file information. The cache needs to be
+    updated with refresh().
 
-  A directory model that displays the contents of a default directory
-  is usually constructed with a parent object:
+    A directory model that displays the contents of a default directory
+    is usually constructed with a parent object:
 
-  \snippet doc/src/snippets/shareddirmodel/main.cpp 2
+    \snippet doc/src/snippets/shareddirmodel/main.cpp 2
 
-  A tree view can be used to display the contents of the model
+    A tree view can be used to display the contents of the model
 
-  \snippet doc/src/snippets/shareddirmodel/main.cpp 4
+    \snippet doc/src/snippets/shareddirmodel/main.cpp 4
 
-  and the contents of a particular directory can be displayed by
-  setting the tree view's root index:
+    and the contents of a particular directory can be displayed by
+    setting the tree view's root index:
 
-  \snippet doc/src/snippets/shareddirmodel/main.cpp 7
+    \snippet doc/src/snippets/shareddirmodel/main.cpp 7
 
-  The view's root index can be used to control how much of a
-  hierarchical model is displayed. QDirModel provides a convenience
-  function that returns a suitable model index for a path to a
-  directory within the model.
+    The view's root index can be used to control how much of a
+    hierarchical model is displayed. QDirModel provides a convenience
+    function that returns a suitable model index for a path to a
+    directory within the model.
 
-  QDirModel can be accessed using the standard interface provided by
-  QAbstractItemModel, but it also provides some convenience functions
-  that are specific to a directory model. The fileInfo() and isDir()
-  functions provide information about the underlying files and directories
-  related to items in the model.
-  
-  Directories can be created and removed using mkdir(), rmdir(), and the
-  model will be automatically updated to take the changes into account.
+    QDirModel can be accessed using the standard interface provided by
+    QAbstractItemModel, but it also provides some convenience functions
+    that are specific to a directory model. The fileInfo() and isDir()
+    functions provide information about the underlying files and directories
+    related to items in the model.
 
-  \sa nameFilters(), setFilter(), filter(), QListView, QTreeView,
-      {Dir View Example}, {Model Classes}
+    Directories can be created and removed using mkdir(), rmdir(), and the
+    model will be automatically updated to take the changes into account.
+
+    \note QDirModel requires an instance of a GUI application.
+
+    \sa nameFilters(), setFilter(), filter(), QListView, QTreeView,
+    {Dir View Example}, {Model Classes}
 */
 
 /*!
@@ -592,6 +588,7 @@ bool QDirModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
 
     bool success = true;
     QString to = filePath(parent) + QDir::separator();
+    QModelIndex _parent = parent;
 
     QList<QUrl> urls = data->urls();
     QList<QUrl>::const_iterator it = urls.constBegin();
@@ -615,8 +612,11 @@ bool QDirModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
             if(QFile::copy(path, to + QFileInfo(path).fileName())
                && QFile::remove(path)) {
                 QModelIndex idx=index(QFileInfo(path).path());
-                if(idx.isValid())
+                if(idx.isValid()) {
                     refresh(idx);
+                    //the previous call to refresh may invalidate the _parent. so recreate a new QModelIndex
+                    _parent = index(to);
+                }
             } else {
                 success = false;
             }
@@ -627,7 +627,7 @@ bool QDirModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
     }
 
     if (success)
-        refresh(parent);
+        refresh(_parent);
 
     return success;
 }
