@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -85,9 +79,9 @@ public:
     \enum QTreeWidgetItem::ChildIndicatorPolicy
     \since 4.3
 
-    \value ShowIndicator
-    \value DontShowIndicator
-    \value DontShowIndicatorWhenChildless
+    \value ShowIndicator     The controls for expanding and collapsing will be shown for this item even if there are no children.
+    \value DontShowIndicator   The controls for expanding and collapsing will never be shown even if there are children.  If the node is forced open the user will not be able to expand or collapse the item.
+    \value DontShowIndicatorWhenChildless  The controls for expanding and collapsing will be shown if the item contains children.
 */
 
 /*!
@@ -755,7 +749,6 @@ bool QTreeModel::executePendingSort() const
         Qt::SortOrder order = view()->header()->sortIndicatorOrder();
         QTreeModel *that = const_cast<QTreeModel*>(this);
         that->sort(column, order);
-        emit that->itemsSorted();
         return true;
     }
     return false;
@@ -950,11 +943,14 @@ void QTreeModel::sortItems(QList<QTreeWidgetItem*> *items, int column, Qt::SortO
 */
 
 /*!
-  \fn void QTreeWidgetItem::sortChildren(int column, Qt::SortOrder order)
-  \since 4.2
+    \fn void QTreeWidgetItem::sortChildren(int column, Qt::SortOrder order)
+    \since 4.2
 
-  Sorts the children of the item using the given \a order,
-  by the values in the given \a column.
+    Sorts the children of the item using the given \a order,
+    by the values in the given \a column.
+
+    \note This function does nothing if the item is not associated with a
+    QTreeWidget.
 */
 
 /*!
@@ -2170,7 +2166,6 @@ public:
     void _q_emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &index);
     void _q_sort();
     void _q_dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
-    void _q_itemsSorted();
     void _q_selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
 };
 
@@ -2245,6 +2240,7 @@ void QTreeWidgetPrivate::_q_sort()
 
 void QTreeWidgetPrivate::_q_selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
+    Q_Q(QTreeWidget);
     QModelIndexList indices = selected.indexes();
     int i;
     QTreeModel *m = model();
@@ -2259,6 +2255,7 @@ void QTreeWidgetPrivate::_q_selectionChanged(const QItemSelection &selected, con
         item->d->selected = false;
     }
 
+    emit q->itemSelectionChanged();
 }
 
 void QTreeWidgetPrivate::_q_dataChanged(const QModelIndex &topLeft,
@@ -2276,12 +2273,6 @@ void QTreeWidgetPrivate::_q_dataChanged(const QModelIndex &topLeft,
     }
 }
 
-void QTreeWidgetPrivate::_q_itemsSorted()
-{
-    Q_Q(QTreeWidget);
-    q->doItemsLayout();
-}
-
 /*!
   \class QTreeWidget
 
@@ -2304,7 +2295,7 @@ void QTreeWidgetPrivate::_q_itemsSorted()
 
   In its simplest form, a tree widget can be constructed in the following way:
 
-  \snippet doc/src/snippets/code/src.gui.itemviews.qtreewidget.cpp 0
+  \snippet doc/src/snippets/code/src_gui_itemviews_qtreewidget.cpp 0
 
   Before items can be added to the tree widget, the number of columns must
   be set with setColumnCount(). This allows each item to have one or more
@@ -2340,6 +2331,8 @@ void QTreeWidgetPrivate::_q_itemsSorted()
 /*!
     \property QTreeWidget::columnCount
     \brief the number of columns displayed in the tree widget
+
+    By default, this property has a value of 1.
 */
 
 /*!
@@ -2371,9 +2364,9 @@ void QTreeWidgetPrivate::_q_itemsSorted()
 
     This signal is emitted when the user clicks inside the widget.
 
-    The specified \a item is the item that was clicked, or 0 if no
-    item was clicked. The \a column is the item's column that was
-    clicked, or -1 if no item was clicked.
+    The specified \a item is the item that was clicked. The \a column is the
+    item's column that was clicked. If no item was clicked, no signal will be
+    emitted.
 */
 
 /*!
@@ -2384,7 +2377,7 @@ void QTreeWidgetPrivate::_q_itemsSorted()
 
     The specified \a item is the item that was clicked, or 0 if no
     item was clicked. The \a column is the item's column that was
-    clicked, or -1 if no item was clicked.
+    clicked. If no item was double clicked, no signal will be emitted.
 */
 
 /*!
@@ -2393,6 +2386,9 @@ void QTreeWidgetPrivate::_q_itemsSorted()
     This signal is emitted when the specified \a item is expanded so that
     all of its children are displayed.
 
+    \note This signal will not be emitted if an item changes its state when
+    expandAll() is invoked.
+
     \sa isItemExpanded(), itemCollapsed(), expandItem()
 */
 
@@ -2402,6 +2398,9 @@ void QTreeWidgetPrivate::_q_itemsSorted()
     This signal is emitted when the specified \a item is collapsed so that
     none of its children are displayed.
 
+    \note This signal will not be emitted if an item changes its state when
+    collapseAll() is invoked.
+
     \sa isItemExpanded(), itemExpanded(), collapseItem()
 */
 
@@ -2468,19 +2467,14 @@ QTreeWidget::QTreeWidget(QWidget *parent)
             SLOT(_q_emitItemCollapsed(QModelIndex)));
     connect(selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
             this, SLOT(_q_emitCurrentItemChanged(QModelIndex,QModelIndex)));
-    connect(selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SIGNAL(itemSelectionChanged()));
     connect(model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
             this, SLOT(_q_emitItemChanged(QModelIndex)));
     connect(model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
             this, SLOT(_q_dataChanged(QModelIndex,QModelIndex)));
     connect(model(), SIGNAL(columnsRemoved(QModelIndex,int,int)),
             this, SLOT(_q_sort()));
-    connect(model(), SIGNAL(itemsSorted()), this, SLOT(_q_itemsSorted()));
-
     connect(selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this, SLOT(_q_selectionChanged(QItemSelection,QItemSelection)));
-
     header()->setClickable(false);
 }
 
@@ -2547,9 +2541,12 @@ QTreeWidgetItem *QTreeWidget::topLevelItem(int index) const
     return d->model()->rootItem->child(index);
 }
 
-/*!\property QTreeWidget::topLevelItemCount
+/*!
+    \property QTreeWidget::topLevelItemCount
     \brief the number of top-level items
 
+    By default, this property has a value of 0.
+
     \sa columnCount(), currentItem()
 */
 
@@ -2889,9 +2886,12 @@ void QTreeWidget::closePersistentEditor(QTreeWidgetItem *item, int column)
 }
 
 /*!
-  \since 4.1
+    \since 4.1
+
+    Returns the widget displayed in the cell specified by \a item and the given \a column.
+
+    \note The tree takes ownership of the widget.
 
-  Returns the widget displayed in the cell specified by \a item and the given \a column.
 */
 QWidget *QTreeWidget::itemWidget(QTreeWidgetItem *item, int column) const
 {
@@ -2900,22 +2900,24 @@ QWidget *QTreeWidget::itemWidget(QTreeWidgetItem *item, int column) const
 }
 
 /*!
-  \since 4.1
+    \since 4.1
 
-  Sets the given \a widget to be displayed in the cell specified by
-  the given \a item and \a column.
+    Sets the given \a widget to be displayed in the cell specified by
+    the given \a item and \a column.
 
-  Note that the given \a widget's \l {QWidget}{autoFillBackground}
-  property must be set to true, otherwise the widget's background will
-  be transparent, showing both the model data and the tree widget
-  item.
+    Note that the given \a widget's \l {QWidget}{autoFillBackground}
+    property must be set to true, otherwise the widget's background will
+    be transparent, showing both the model data and the tree widget
+    item.
 
-  This function should only be used to display static content in the
-  place of a tree widget item. If you want to display custom dynamic
-  content or implement a custom editor widget, use QTreeView and
-  subclass QItemDelegate instead.
+    This function should only be used to display static content in the
+    place of a tree widget item. If you want to display custom dynamic
+    content or implement a custom editor widget, use QTreeView and
+    subclass QItemDelegate instead.
 
-  \sa {Delegate Classes}
+    \note The tree takes ownership of the widget.
+
+    \sa {Delegate Classes}
 */
 void QTreeWidget::setItemWidget(QTreeWidgetItem *item, int column, QWidget *widget)
 {
