@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -504,6 +498,8 @@ bool QAction::autoRepeat() const
     QAction. The font will can be considered a hint as it will not be
     consulted in all cases based upon application and style.
 
+    By default, this property contains the application's default font.
+
     \sa QAction::setText() QStyle
 */
 void QAction::setFont(const QFont &font)
@@ -765,7 +761,7 @@ QString QAction::text() const
     If the icon text is not explicitly set, the action's normal text will be
     used for the icon text.
 
-    There is no default icon text.
+    By default, this property contains an empty string.
 
     \sa setToolTip(), setStatusTip()
 */
@@ -794,6 +790,8 @@ QString QAction::iconText() const
     This text is used for the tooltip. If no tooltip is specified,
     the action's text is used.
 
+    By default, this property contains the action's text.
+
     \sa setStatusTip() setShortcut()
 */
 void QAction::setToolTip(const QString &tooltip)
@@ -824,6 +822,8 @@ QString QAction::toolTip() const
     The status tip is displayed on all status bars provided by the
     action's top-level parent widget.
 
+    By default, this property contains an empty string.
+
     \sa setToolTip() showStatusText()
 */
 void QAction::setStatusTip(const QString &statustip)
@@ -962,8 +962,12 @@ bool QAction::isChecked() const
     which indicates that they are unavailable. For example, they might
     be displayed using only shades of gray.
 
-    What's this? help on disabled actions is still available, provided
+    \gui{What's This?} help on disabled actions is still available, provided
     that the QAction::whatsThis property is set.
+
+    By default, this property is true (actions are enabled).
+
+    \sa text
 */
 void QAction::setEnabled(bool b)
 {
@@ -997,6 +1001,8 @@ bool QAction::isEnabled() const
 
     Actions which are not visible are \e not grayed out; they do not
     appear at all.
+
+    By default, this property is true (actions are visible).
 */
 void QAction::setVisible(bool b)
 {
@@ -1320,7 +1326,7 @@ QAction::MenuRole QAction::menuRole() const
     the presence (or abscence) of the attribute.
 
     For example:
-    \snippet doc/src/snippets/code/src.gui.kernel.qaction.cpp 0
+    \snippet doc/src/snippets/code/src_gui_kernel_qaction.cpp 0
 
     \sa QAction::icon QApplication::setAttribute()
 */
