@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -28,12 +42,20 @@
 #include <qcursor.h>
 #include <X11/cursorfont.h>
 
+#include <qlibrary.h>
+
 #ifndef QT_NO_XCURSOR
 #  include <X11/Xcursor/Xcursor.h>
 #endif // QT_NO_XCURSOR
 
+#ifndef QT_NO_XFIXES
+#  include <X11/extensions/Xfixes.h>
+#endif // QT_NO_XFIXES
+
 #include "qx11info_x11.h"
 
+QT_BEGIN_NAMESPACE
+
 // Define QT_USE_APPROXIMATE_CURSORS when compiling if you REALLY want to
 // use the ugly X11 cursors.
 
@@ -51,7 +73,7 @@ QCursorData::QCursorData(Qt::CursorShape s)
 
 QCursorData::~QCursorData()
 {
-    Display *dpy = X11->display;
+    Display *dpy = X11 ? X11->display : (Display*)0;
 
     // Add in checking for the display too as on HP-UX
     // we seem to get a core dump as the cursor data is
@@ -98,8 +120,6 @@ QCursorData *QCursorData::setBitmap(const QBitmap &bitmap, const QBitmap &mask,
     d->bg.red   = 0xffff;
     d->bg.green = 0xffff;
     d->bg.blue  = 0xffff;
-    d->update(); // Xcursor's backward compatibility hack needs the cursor to be created
-                 // right after the bitmaps are created and filled with data
     return d;
 }
 
@@ -114,15 +134,6 @@ Qt::HANDLE QCursor::handle() const
     return d->hcurs;
 }
 
-/*!
-    Returns the position of the cursor (hot spot) in global screen
-    coordinates.
-
-    You can call QWidget::mapFromGlobal() to translate it to widget
-    coordinates.
-
-    \sa setPos(), QWidget::mapFromGlobal(), QWidget::mapToGlobal()
-*/
 QPoint QCursor::pos()
 {
     Window root;
@@ -156,16 +167,6 @@ int QCursor::x11Screen()
     return -1;
 }
 
-/*!
-    Moves the cursor (hot spot) to the global screen position (\a x,
-    \a y).
-
-    You can call QWidget::mapToGlobal() to translate widget
-    coordinates to global screen coordinates.
-
-    \sa pos(), QWidget::mapFromGlobal(), QWidget::mapToGlobal()
-*/
-
 void QCursor::setPos(int x, int y)
 {
     QPoint current, target(x, y);
@@ -199,15 +200,6 @@ void QCursor::setPos(int x, int y)
     XWarpPointer(X11->display, XNone, QX11Info::appRootWindow(screen), 0, 0, 0, 0, x, y);
 }
 
-/*!
-    \fn void QCursor::setPos (const QPoint &p)
-
-    \overload
-
-    Moves the cursor (hot spot) to the global screen position at point
-    \a p.
-*/
-
 
 /*!
     \internal
@@ -237,7 +229,6 @@ void QCursorData::update()
         return;
     }
 
-#ifndef QT_NO_XCURSOR
     static const char *cursorNames[] = {
         "left_ptr",
         "up_arrow",
@@ -255,10 +246,14 @@ void QCursorData::update()
         "pointing_hand",
         "forbidden",
         "whats_this",
-        "left_ptr_watch"
+        "left_ptr_watch",
+        "openhand",
+        "closedhand"
     };
 
-    hcurs = XcursorLibraryLoadCursor(dpy, cursorNames[cshape]);
+#ifndef QT_NO_XCURSOR
+    if (X11->ptrXcursorLibraryLoadCursor)
+        hcurs = X11->ptrXcursorLibraryLoadCursor(dpy, cursorNames[cshape]);
     if (hcurs)
         return;
 #endif // QT_NO_XCURSOR
@@ -422,12 +417,29 @@ void QCursorData::update()
         0x0f,0x1f,0x0f,0x0f,0x3e,0x0f,0x1f,0xfc,0x0f,0x1e,0xf8,0x07,0x3e,0xf0,0x07,
         0xfc,0xe0,0x03,0xf8,0xff,0x01,0xf0,0xff,0x00,0xe0,0x7f,0x00,0x80,0x1f,0x00};
 
+    static const char openhand_bits[] = {
+        0x80,0x01,0x58,0x0e,0x64,0x12,0x64,0x52,0x48,0xb2,0x48,0x92,
+        0x16,0x90,0x19,0x80,0x11,0x40,0x02,0x40,0x04,0x40,0x04,0x20,
+        0x08,0x20,0x10,0x10,0x20,0x10,0x00,0x00};
+    static const char openhandm_bits[] = {
+       0x80,0x01,0xd8,0x0f,0xfc,0x1f,0xfc,0x5f,0xf8,0xff,0xf8,0xff,
+       0xf6,0xff,0xff,0xff,0xff,0x7f,0xfe,0x7f,0xfc,0x7f,0xfc,0x3f,
+       0xf8,0x3f,0xf0,0x1f,0xe0,0x1f,0x00,0x00};
+    static const char closedhand_bits[] = {
+        0x00,0x00,0x00,0x00,0x00,0x00,0xb0,0x0d,0x48,0x32,0x08,0x50,
+        0x10,0x40,0x18,0x40,0x04,0x40,0x04,0x20,0x08,0x20,0x10,0x10,
+        0x20,0x10,0x20,0x10,0x00,0x00,0x00,0x00};
+    static const char closedhandm_bits[] = {
+        0x00,0x00,0x00,0x00,0x00,0x00,0xb0,0x0d,0xf8,0x3f,0xf8,0x7f,
+        0xf0,0x7f,0xf8,0x7f,0xfc,0x7f,0xfc,0x3f,0xf8,0x3f,0xf0,0x1f,
+        0xe0,0x1f,0xe0,0x1f,0x00,0x00,0x00,0x00};
+
     static const char * const cursor_bits20[] = {
         forbidden_bits, forbiddenm_bits
     };
 
-    if (cshape >= Qt::SizeVerCursor && cshape < Qt::SizeAllCursor
-            || cshape == Qt::BlankCursor) {
+    if ((cshape >= Qt::SizeVerCursor && cshape < Qt::SizeAllCursor)
+        || cshape == Qt::BlankCursor) {
         XColor bg, fg;
         bg.red   = 255 << 8;
         bg.green = 255 << 8;
@@ -439,10 +451,8 @@ void QCursorData::update()
         pm  = XCreateBitmapFromData(dpy, rootwin, cursor_bits16[i], 16, 16);
         pmm = XCreateBitmapFromData(dpy, rootwin, cursor_bits16[i + 1], 16, 16);
         hcurs = XCreatePixmapCursor(dpy, pm, pmm, &fg, &bg, 8, 8);
-        return;
-    }
-    if ((cshape >= Qt::SplitVCursor && cshape <= Qt::SplitHCursor)
-            || cshape == Qt::WhatsThisCursor || cshape == Qt::BusyCursor) {
+    } else if ((cshape >= Qt::SplitVCursor && cshape <= Qt::SplitHCursor)
+               || cshape == Qt::WhatsThisCursor || cshape == Qt::BusyCursor) {
         XColor bg, fg;
         bg.red   = 255 << 8;
         bg.green = 255 << 8;
@@ -456,9 +466,7 @@ void QCursorData::update()
         int hs = (cshape == Qt::PointingHandCursor || cshape == Qt::WhatsThisCursor
                   || cshape == Qt::BusyCursor) ? 0 : 16;
         hcurs = XCreatePixmapCursor(dpy, pm, pmm, &fg, &bg, hs, hs);
-        return;
-    }
-    if (cshape == Qt::ForbiddenCursor) {
+    } else if (cshape == Qt::ForbiddenCursor) {
         XColor bg, fg;
         bg.red   = 255 << 8;
         bg.green = 255 << 8;
@@ -470,8 +478,29 @@ void QCursorData::update()
         pm  = XCreateBitmapFromData(dpy, rootwin, cursor_bits20[i], 20, 20);
         pmm = XCreateBitmapFromData(dpy, rootwin, cursor_bits20[i + 1], 20, 20);
         hcurs = XCreatePixmapCursor(dpy, pm, pmm, &fg, &bg, 10, 10);
+    } else if (cshape == Qt::OpenHandCursor || cshape == Qt::ClosedHandCursor) {
+        XColor bg, fg;
+        bg.red   = 255 << 8;
+        bg.green = 255 << 8;
+        bg.blue  = 255 << 8;
+        fg.red   = 0;
+        fg.green = 0;
+        fg.blue  = 0;
+        bool open = cshape == Qt::OpenHandCursor;
+        pm  = XCreateBitmapFromData(dpy, rootwin, open ? openhand_bits : closedhand_bits, 16, 16);
+        pmm = XCreateBitmapFromData(dpy, rootwin, open ? openhandm_bits : closedhandm_bits, 16, 16);
+        hcurs = XCreatePixmapCursor(dpy, pm, pmm, &fg, &bg, 8, 8);
+    }
+
+    if (hcurs)
+    {
+#ifndef QT_NO_XFIXES
+        if (X11->use_xfixes)
+            X11->ptrXFixesSetCursorName(dpy, hcurs, cursorNames[cshape]);
+#endif /* ! QT_NO_XFIXES */
         return;
     }
+
 #endif /* ! QT_USE_APPROXIMATE_CURSORS */
 
     uint sh;
@@ -540,4 +569,11 @@ void QCursorData::update()
         return;
     }
     hcurs = XCreateFontCursor(dpy, sh);
+
+#ifndef QT_NO_XFIXES
+    if (X11->use_xfixes)
+        X11->ptrXFixesSetCursorName(dpy, hcurs, cursorNames[cshape]);
+#endif /* ! QT_NO_XFIXES */
 }
+
+QT_END_NAMESPACE
