@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -842,7 +836,7 @@ static void handle_xdnd_position(QWidget *w, const XEvent * xe, bool passive)
     if (!passive && checkEmbedded(c, xe))
         return;
 
-    if (!c || !c->acceptDrops() && (c->windowType() == Qt::Desktop))
+    if (!c || (!c->acceptDrops() && (c->windowType() == Qt::Desktop)))
         return;
 
     if (l[0] != qt_xdnd_dragsource_xid) {
@@ -850,9 +844,14 @@ static void handle_xdnd_position(QWidget *w, const XEvent * xe, bool passive)
         return;
     }
 
+    // timestamp from the source
     if (l[3] != 0) {
-        // timestamp from the source
-        qt_xdnd_target_current_time = X11->userTime = l[3];
+        // Some X server/client combination swallow the first 32 bit and
+        // interpret a set bit 31 as negative sign.
+        qt_xdnd_target_current_time = X11->userTime =
+            ((sizeof(Time) == 8 && xe->xclient.data.l[3] < 0)
+             ? uint(l[3])
+             : l[3]);
     }
 
     QDragManager *manager = QDragManager::self();
@@ -1129,9 +1128,14 @@ void QX11Data::xdndHandleDrop(QWidget *, const XEvent * xe, bool passive)
         return;
     }
 
+    // update the "user time" from the timestamp in the event.
     if (l[2] != 0) {
-        // update the "user time" from the timestamp in the event.
-        qt_xdnd_target_current_time = X11->userTime = l[2];
+        // Some X server/client combination swallow the first 32 bit and
+        // interpret a set bit 31 as negative sign.
+        qt_xdnd_target_current_time = X11->userTime =
+            ((sizeof(Time) == 8 && xe->xclient.data.l[2] < 0)
+             ? uint(l[2])
+             :  l[2]);
     }
 
     if (!passive) {
@@ -1700,21 +1704,22 @@ void QDragManager::drop()
 
 bool QX11Data::xdndHandleBadwindow()
 {
-    QDragManager *manager = QDragManager::self();
-    if (manager->object && qt_xdnd_current_target) {
-        qt_xdnd_current_target = 0;
-        qt_xdnd_current_proxy_target = 0;
-        manager->object->deleteLater();
-        manager->object = 0;
-        delete xdnd_data.deco;
-        xdnd_data.deco = 0;
-        return true;
+    if (qt_xdnd_current_target) {
+        QDragManager *manager = QDragManager::self();
+        if (manager->object) {
+            qt_xdnd_current_target = 0;
+            qt_xdnd_current_proxy_target = 0;
+            manager->object->deleteLater();
+            manager->object = 0;
+            delete xdnd_data.deco;
+            xdnd_data.deco = 0;
+            return true;
+        }
     }
     if (qt_xdnd_dragsource_xid) {
         qt_xdnd_dragsource_xid = 0;
         if (qt_xdnd_current_widget) {
-            QDragLeaveEvent e;
-            QApplication::sendEvent(qt_xdnd_current_widget, &e);
+            QApplication::postEvent(qt_xdnd_current_widget, new QDragLeaveEvent);
             qt_xdnd_current_widget = 0;
         }
         return true;
