@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -49,6 +43,8 @@
 
 #ifndef QT_NO_DRAGANDDROP
 
+QT_BEGIN_NAMESPACE
+
 /*!
     \class QDrag
     \brief The QDrag class provides support for MIME-based drag and drop data
@@ -63,13 +59,10 @@
     QMimeData object. This is specified with the setMimeData() function in the
     following way:
 
-    \quotefromfile snippets/dragging/mainwindow.cpp
-    \skipto mousePressEvent
-    \skipto QDrag
-    \printuntil setMimeData
+    \snippet doc/src/snippets/dragging/mainwindow.cpp 1
 
     Note that setMimeData() assigns ownership of the QMimeData object to the
-    QDrag object. The QDrag must be constructed on the heap with a parent QObject
+    QDrag object. The QDrag must be constructed on the heap with a parent QWidget
     to ensure that Qt can clean up after the drag and drop operation has been
     completed.
 
@@ -82,11 +75,9 @@
     following code positions the pixmap so that the cursor's hot spot points to
     the center of its bottom edge:
 
-    \quotefromfile snippets/separations/finalwidget.cpp
-    \skipto setHotSpot
-    \printuntil ;
+    \snippet doc/src/snippets/separations/finalwidget.cpp 2
 
-    \bold{Note:} on X11, the pixmap may not be able to keep up with the mouse
+    \note On X11, the pixmap may not be able to keep up with the mouse
     movements if the hot spot causes the pixmap to be displayed
     directly under the cursor.
 
@@ -354,4 +345,6 @@ void QDrag::setDragCursor(const QPixmap &cursor, Qt::DropAction action)
     \sa target(), actionChanged()
 */
 
+QT_END_NAMESPACE
+
 #endif // QT_NO_DRAGANDDROP
