@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -83,10 +77,11 @@ QT_BEGIN_NAMESPACE
     an action on a given shortcut. On X11 the ampersand will not be
     shown and the character will be underlined. On Windows, shortcuts
     are normally not displayed until the user presses the \gui Alt
-    key, but this is a setting the user can change. On Mac such
-    shortcuts do not exists, unless you explicitly call the global
-    qt_set_sequence_auto_mnemonic() function; then they will appear as
-    they do on X11.
+    key, but this is a setting the user can change. On Mac, shortcuts
+    are disabled by default. Call qt_set_sequence_auto_mnemonic() to
+    enable them. However, because mnemonic shortcuts do not fit in
+    with Aqua's guidelines, Qt will not show the shortcut character
+    underlined.
 
     For applications that use menus, it may be more convenient to
     use the convenience functions provided in the QMenu class to
@@ -97,7 +92,7 @@ QT_BEGIN_NAMESPACE
     The simplest way to create a shortcut for a particular widget is
     to construct the shortcut with a key sequence. For example:
 
-    \snippet doc/src/snippets/code/src.gui.kernel.qshortcut.cpp 0
+    \snippet doc/src/snippets/code/src_gui_kernel_qshortcut.cpp 0
 
     When the user types the \l{QKeySequence}{key sequence}
     for a given shortcut, the shortcut's activated() signal is
@@ -234,7 +229,9 @@ QShortcut::~QShortcut()
     This is a key sequence with an optional combination of Shift, Ctrl,
     and Alt. The key sequence may be supplied in a number of ways:
 
-    \snippet doc/src/snippets/code/src.gui.kernel.qshortcut.cpp 1
+    \snippet doc/src/snippets/code/src_gui_kernel_qshortcut.cpp 1
+
+    By default, this property contains an empty key sequence.
 */
 void QShortcut::setKey(const QKeySequence &key)
 {
@@ -263,6 +260,8 @@ QKeySequence QShortcut::key() const
     If the application is in \c WhatsThis mode the shortcut will not emit
     the signals, but will show the "What's This?" text instead.
 
+    By default, this property is true.
+
     \sa whatsThis
 */
 void QShortcut::setEnabled(bool enable)
@@ -290,6 +289,8 @@ bool QShortcut::isEnabled() const
     which allows the shortcut to trigger if the parent (the widget
     containing the shortcut) is a subwidget of the active top-level
     window.
+
+    By default, this property is set to Qt::WindowShortcut.
 */
 void QShortcut::setContext(Qt::ShortcutContext context)
 {
@@ -317,6 +318,8 @@ Qt::ShortcutContext QShortcut::context()
     To set "What's This?" help on a menu item (with or without a
     shortcut key), set the help on the item's action.
 
+    By default, this property contains an empty string.
+
     \sa QWhatsThis::inWhatsThisMode(), QAction::setWhatsThis()
 */
 void QShortcut::setWhatsThis(const QString &text)
