@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 #include <qglobal.h>
@@ -499,10 +493,8 @@ void QWidgetPrivate::moveRect(const QRect &rect, int dx, int dy)
         wbs->dirtyOnScreen += destRect.translated(toplevelOffset);
 #else
         if (!q->internalWinId()) {
-            QWidget *nativeParent = q->nativeParentWidget();
-            const QPoint nativeParentOffset = pw->mapTo(nativeParent, QPoint(0, 0));
-            nativeParent->d_func()->dirtyOnScreen += sourceRect.translated(nativeParentOffset);
-            nativeParent->d_func()->dirtyOnScreen += destRect.translated(nativeParentOffset);
+            tlw->d_func()->dirtyOnScreen += sourceRect.translated(toplevelOffset);
+            tlw->d_func()->dirtyOnScreen += destRect.translated(toplevelOffset);
         }
 #endif
     }
@@ -781,7 +773,13 @@ void QWidgetBackingStore::cleanRegion(const QRegion &rgn, QWidget *widget, bool
             windowSurface->setGeometry(QRect());
             // the old window surface is deleted in setWindowSurface, which is
             // called from QWindowSurface constructor
-            windowSurface = qt_default_window_surface(tlw);
+            windowSurface = qt_default_window_surface(currWidget);
+
+            // qt_default_window_surface() will set topdata->windowSurface on the 
+            // widget to zero. However, if this is a sub-surface, it should point
+            // to the widget's sub windowSurface, so we set that here:
+            if (!currWidget->isWindow())
+                currWidget->d_func()->topData()->windowSurface = windowSurface;
         }
 #endif
         if (windowSurface->geometry() != tlwRect) {
@@ -918,7 +916,8 @@ void QWidgetBackingStore::cleanRegion(const QRegion &rgn, QWidget *widget, bool
     QTLWExtra *tlwExtra = tlw->d_func()->extra->topextra;
 #ifdef Q_WS_X11
     // Delay the sync until we get the Expose event.
-    if (tlwExtra->waitingForMapNotify)
+    // However, we must repaint immediately regardless of the state if someone calls repaint().
+    if (tlwExtra->waitingForMapNotify && !tlwExtra->inRepaint)
         return;
 #endif
 
@@ -1130,13 +1129,16 @@ void QWidget::repaint(const QRegion& rgn)
     Q_ASSERT(testAttribute(Qt::WA_WState_Created));
 //    qDebug() << "repaint" << this << rgn;
     if (!d->paintOnScreen()) {
-        if (QWidgetBackingStore *bs = d->maybeBackingStore()) {
+        QTLWExtra *tlwExtra = window()->d_func()->maybeTopData();
+        if (tlwExtra && tlwExtra->backingStore) {
+            tlwExtra->inRepaint = true;
             QRegion wrgn(rgn);
             d->subtractOpaqueSiblings(wrgn, QPoint());
             d->subtractOpaqueChildren(wrgn, rect(), QPoint());
             // Update immediately, i.e. use QApplication::sendEvent instead of
             // QApplication::postEvent in QWidgetPrivate::dirtyWidget_sys.
-            bs->dirtyRegion(wrgn, this, true);
+            tlwExtra->backingStore->dirtyRegion(wrgn, this, true);
+            tlwExtra->inRepaint = false;
         }
     }
 #ifndef Q_WS_QWS
