@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -117,7 +111,7 @@ struct DrawHelper {
 
 extern DrawHelper qDrawHelper[QImage::NImageFormats];
 void qBlendTexture(int count, const QSpan *spans, void *userData);
-#ifdef Q_WS_QWS
+#if defined(Q_WS_QWS) && !defined(QT_NO_RASTERCALLBACKS)
 extern DrawHelper qDrawHelperCallback[QImage::NImageFormats];
 void qBlendTextureCallback(int count, const QSpan *spans, void *userData);
 #endif
@@ -227,7 +221,7 @@ struct QSpanData
     BitmapBlitFunc bitmapBlit;
     AlphamapBlitFunc alphamapBlit;
     RectFillFunc fillRect;
-    qreal m11, m12, m13, m21, m22, m23, dx, dy;   // inverse xform matrix
+    qreal m11, m12, m13, m21, m22, m23, m33, dx, dy;   // inverse xform matrix
     enum Type {
         None,
         Solid,
@@ -1384,7 +1378,7 @@ template <typename SRC>
 static inline quint32 qt_convertToRgb(SRC color);
 
 template <>
-static inline quint32 qt_convertToRgb(quint32 color)
+inline quint32 qt_convertToRgb(quint32 color)
 {
     const int r = qRed(color) >> (8 - qrgb::len_red);
     const int g = qGreen(color) >> (8 - qrgb::len_green);
@@ -1399,7 +1393,7 @@ static inline quint32 qt_convertToRgb(quint32 color)
 }
 
 template <>
-static inline quint32 qt_convertToRgb(quint16 color)
+inline quint32 qt_convertToRgb(quint16 color)
 {
     return qt_convertToRgb(qt_colorConvert<quint32, quint16>(color, 0));
 }
@@ -1427,14 +1421,14 @@ private:
 } Q_PACKED;
 
 template <>
-static inline qrgb_generic16 qt_colorConvert(quint32 color, qrgb_generic16 dummy)
+inline qrgb_generic16 qt_colorConvert(quint32 color, qrgb_generic16 dummy)
 {
     Q_UNUSED(dummy);
     return qrgb_generic16(color);
 }
 
 template <>
-static inline qrgb_generic16 qt_colorConvert(quint16 color, qrgb_generic16 dummy)
+inline qrgb_generic16 qt_colorConvert(quint16 color, qrgb_generic16 dummy)
 {
     Q_UNUSED(dummy);
     return qrgb_generic16(qt_colorConvert<quint32, quint16>(color, 0));
