@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -157,6 +151,7 @@ static void qt_debug_path(const QPainterPath &path)
 /*!
     \class QPainterPath
     \ingroup multimedia
+    \ingroup shared
 
     \brief The QPainterPath class provides a container for painting operations,
     enabling graphical shapes to be constructed and reused.
@@ -220,7 +215,7 @@ static void qt_debug_path(const QPainterPath &path)
     \row
     \o \inlineimage qpainterpath-construction.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 0
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 0
     \endtable
 
     The painter path is initially empty when constructed. We first add
@@ -714,7 +709,7 @@ void QPainterPath::lineTo(const QPointF &p)
     \row
     \o \inlineimage qpainterpath-cubicto.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 1
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 1
     \endtable
 
     \sa quadTo(), {QPainterPath#Composing a QPainterPath}{Composing
@@ -833,7 +828,7 @@ void QPainterPath::quadTo(const QPointF &c, const QPointF &e)
     \row
     \o \inlineimage qpainterpath-arcto.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 2
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 2
     \endtable
 
     \sa arcMoveTo(), addEllipse(), QPainter::drawArc(), QPainter::drawPie(),
@@ -941,7 +936,7 @@ QPointF QPainterPath::currentPosition() const
     \row
     \o \inlineimage qpainterpath-addrectangle.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 3
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 3
     \endtable
 
     \sa addRegion(), lineTo(), {QPainterPath#Composing a
@@ -982,7 +977,7 @@ void QPainterPath::addRect(const QRectF &r)
     \row
     \o \inlineimage qpainterpath-addpolygon.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 4
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 4
     \endtable
 
     \sa lineTo(), {QPainterPath#Composing a QPainterPath}{Composing
@@ -1018,7 +1013,7 @@ void QPainterPath::addPolygon(const QPolygonF &polygon)
     \row
     \o \inlineimage qpainterpath-addellipse.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 5
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 5
     \endtable
 
     \sa arcTo(), QPainter::drawEllipse(), {QPainterPath#Composing a
@@ -1064,7 +1059,7 @@ void QPainterPath::addEllipse(const QRectF &boundingRect)
     \row
     \o \inlineimage qpainterpath-addtext.png
     \o
-    \snippet doc/src/snippets/code/src.gui.painting.qpainterpath.cpp 6
+    \snippet doc/src/snippets/code/src_gui_painting_qpainterpath.cpp 6
     \endtable
 
     \sa QPainter::drawText(), {QPainterPath#Composing a
@@ -2104,7 +2099,7 @@ bool QPainterPath::operator==(const QPainterPath &path) const
     else if (d->elements.size() != path.d_func()->elements.size())
         return false;
 
-    const qreal qt_epsilon = sizeof(qreal) == sizeof(double) ? 1e-12 : 1e-5;
+    const qreal qt_epsilon = sizeof(qreal) == sizeof(double) ? 1e-12 : qreal(1e-5);
 
     QSizeF epsilon = boundingRect().size();
     epsilon.rwidth() *= qt_epsilon;
