@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -437,8 +431,8 @@ void QPrinterPrivate::addToManualSetList(QPrintEngine::PrintEnginePropertyKey ke
   */
 
 /*!
-
   \enum QPrinter::PaperSize
+  \since 4.4
 
   This enum type specifies what paper size QPrinter should use.
   QPrinter does not check that the paper size is available; it just
@@ -539,7 +533,8 @@ void QPrinterPrivate::addToManualSetList(QPrintEngine::PrintEnginePropertyKey ke
 */
 
 /*!
- \enum QPrinter::Unit
+  \enum QPrinter::Unit
+  \since 4.4
 
   This enum type is used to specify the measurement unit for page and
   paper sizes.
@@ -602,6 +597,8 @@ QPrinter::QPrinter(PrinterMode mode)
 }
 
 /*!
+    \since 4.4
+
     Creates a new printer object with the given \a printer and \a mode.
 */
 QPrinter::QPrinter(const QPrinterInfo& printer, PrinterMode mode)
@@ -804,10 +801,13 @@ void QPrinter::setPrinterName(const QString &name)
 
 
 /*!
+  \since 4.4
+
   Returns true if the printer currently selected is a valid printer
-  in the system, or a pdf/ps printer; otherwise returns false.
+  in the system, or a pure PDF/PostScript printer; otherwise returns false.
 
   To detect other failures check the output of QPainter::begin() or QPainter::nextPage().
+
   \snippet doc/src/snippets/printing-qprinter/errors.cpp 0
 
   \sa setPrinterName()
@@ -849,6 +849,8 @@ bool QPrinter::isValid() const
   Returns the name of the output file. By default, this is an empty string
   (indicating that the printer shouldn't print to file).
 
+  \sa QPrintEngine::PrintEnginePropertyKey
+
 */
 
 QString QPrinter::outputFileName() const
@@ -858,19 +860,23 @@ QString QPrinter::outputFileName() const
 }
 
 /*!
-  Sets the name of the output file to \a fileName.
+    Sets the name of the output file to \a fileName.
 
-  Setting a null or empty name (0 or "") disables printing to a file. Setting a
-  non-empty name enables printing to a file.
+    Setting a null or empty name (0 or "") disables printing to a file.
+    Setting a non-empty name enables printing to a file.
 
-  This can change the value of outputFormat().  If the file name has the suffix
-  ".ps" then PostScript is automatically selected as output format. If the file
-  name has the ".pdf" suffix PDF is generated.  QPrinter will use Qt's
-  cross-platform PostScript or PDF print engines respectively. If you can
-  produce this format natively, for example Mac OS X can generate PDF's from
-  its print engine, set the output format back to NativeFormat.
+    This can change the value of outputFormat().  If the file name has the
+    suffix ".ps" then PostScript is automatically selected as output format.
+    If the file name has the ".pdf" suffix PDF is generated. If the file name
+    has a suffix other than ".ps" and ".pdf", the output format used is the
+    one set with setOutputFormat().
 
-  \sa outputFileName() setOutputToFile() setOutputFormat()
+    QPrinter uses Qt's cross-platform PostScript or PDF print engines
+    respectively. If you can produce this format natively, for example
+    Mac OS X can generate PDF's from its print engine, set the output format
+    back to NativeFormat.
+
+    \sa outputFileName() setOutputToFile() setOutputFormat()
 */
 
 void QPrinter::setOutputFileName(const QString &fileName)
@@ -930,7 +936,7 @@ void QPrinter::setPrintProgram(const QString &printProg)
 /*!
   Returns the document name.
 
-  \sa setDocName()
+  \sa setDocName(), QPrintEngine::PrintEnginePropertyKey
 */
 QString QPrinter::docName() const
 {
@@ -942,8 +948,12 @@ QString QPrinter::docName() const
 /*!
   Sets the document name to \a name.
 
-  On X11, the document name is for example used as the
-  default output filename in QPrintDialog.
+  On X11, the document name is for example used as the default
+  output filename in QPrintDialog. Note that the document name does
+  not affect the file name if the printer is printing to a file.
+  Use the setOutputFile() function for this.
+
+  \sa docName(), QPrintEngine::PrintEnginePropertyKey
 */
 void QPrinter::setDocName(const QString &name)
 {
@@ -1409,11 +1419,20 @@ bool QPrinter::fontEmbeddingEnabled() const
 
 /*!
     \enum QPrinter::DuplexMode
+    \since 4.4
 
-    \value DuplexNone       no duplex printing, single sided only.
-    \value DuplexAuto
-    \value DuplexLongSide
-    \value DuplexShortSide
+    This enum is used to indicate whether printing will occur on one or both sides
+    of each sheet of paper (simplex or duplex printing).
+
+    \value DuplexNone       Single sided (simplex) printing only.
+    \value DuplexAuto       The printer's default setting is used to determine whether
+                            duplex printing is used.
+    \value DuplexLongSide   Both sides of each sheet of paper are used for printing.
+                            The paper is turned over its longest edge before the second
+                            side is printed 
+    \value DuplexShortSide  Both sides of each sheet of paper are used for printing.
+                            The paper is turned over its shortest edge before the second
+                            side is printed 
 */
 
 /*!
