@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -60,20 +54,6 @@
 
 QT_BEGIN_NAMESPACE
 
-/*!
-    \class QPrinterInfo
-
-    \brief The QPrinterInfo class gives access to information about
-    existing printers.
-
-    Use the static functions to generate a list of QPrinterInfo
-    objects. Each QPrinterInfo object in the list represents a single
-    printer and can be queried for name, supported paper sizes, and
-    whether or not it is the default printer.
-
-    \since 4.4
-*/
-
 #ifndef QT_NO_PRINTER
 
 class QPrinterInfoPrivate
@@ -824,9 +804,6 @@ int qt_getLprPrinters(QList<QPrinterDescription>& printers)
 /////////////////////////////////////////////////////////////////////////////
 /////////////////////////////////////////////////////////////////////////////
 
-/*!
-    Returns a list of available printers on the system.
-*/
 QList<QPrinterInfo> QPrinterInfo::availablePrinters()
 {
     QList<QPrinterInfo> list;
@@ -872,14 +849,6 @@ QList<QPrinterInfo> QPrinterInfo::availablePrinters()
     return list;
 }
 
-/*!
-    Returns the default printer on the system.
-
-    The return value should be checked using isNull() before being
-    used, in case there is no default printer.
-
-    \sa isNull()
-*/
 QPrinterInfo QPrinterInfo::defaultPrinter()
 {
     QList<QPrinterInfo> prnList = availablePrinters();
@@ -890,28 +859,17 @@ QPrinterInfo QPrinterInfo::defaultPrinter()
     return (prnList.size() > 0) ? prnList[0] : QPrinterInfo();
 }
 
-/*!
-    Constructs an empty QPrinterInfo object.
-
-    \sa isNull()
-*/
 QPrinterInfo::QPrinterInfo()
 {
     d_ptr = &nullQPrinterInfoPrivate;
 }
 
-/*!
-    Constructs a copy of \a src.
-*/
 QPrinterInfo::QPrinterInfo(const QPrinterInfo& src)
 {
     d_ptr = &nullQPrinterInfoPrivate;
     *this = src;
 }
 
-/*!
-    Constructs a QPrinterInfo object from \a printer.
-*/
 QPrinterInfo::QPrinterInfo(const QPrinter& printer)
 {
     d_ptr = new QPrinterInfoPrivate(printer.printerName());
@@ -971,19 +929,12 @@ QPrinterInfo::QPrinterInfo(const QString& name)
     d_ptr->q_ptr = this;
 }
 
-/*!
-    Destroys the QPrinterInfo object. References to the values in the
-    object become invalid.
-*/
 QPrinterInfo::~QPrinterInfo()
 {
     if (d_ptr != &nullQPrinterInfoPrivate)
         delete d_ptr;
 }
 
-/*!
-    Sets the QPrinterInfo object to be equal to \a src.
-*/
 QPrinterInfo& QPrinterInfo::operator=(const QPrinterInfo& src)
 {
     Q_ASSERT(d_ptr);
@@ -994,43 +945,24 @@ QPrinterInfo& QPrinterInfo::operator=(const QPrinterInfo& src)
     return *this;
 }
 
-/*!
-    Returns the name of the printer.
-
-    \sa QPrinter::setPrinterName()
-*/
 QString QPrinterInfo::printerName() const
 {
     const Q_D(QPrinterInfo);
     return d->m_name;
 }
 
-/*!
-    Returns whether this QPrinterInfo object holds a printer definition.
-
-    An empty QPrinterInfo object could result for example from calling
-    defaultPrinter() when there are no printers on the system.
-*/
 bool QPrinterInfo::isNull() const
 {
     const Q_D(QPrinterInfo);
     return d->m_isNull;
 }
 
-/*!
-    Returns whether this printer is the default printer.
-*/
 bool QPrinterInfo::isDefault() const
 {
     const Q_D(QPrinterInfo);
     return d->m_default;
 }
 
-/*!
-    Returns a list of supported paper sizes by the printer.
-
-    Not all printer drivers support this query, so the list may be empty.
-*/
 QList< QPrinter::PaperSize> QPrinterInfo::supportedPaperSizes() const
 {
     const Q_D(QPrinterInfo);
