@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -417,7 +411,9 @@ QFontEngineData::~QFontEngineData()
     Use QFontMetrics to get measurements, e.g. the pixel length of a
     string using QFontMetrics::width().
 
-    Use QApplication::setFont() to set the application's default font.
+    Note that a QApplication instance must exist before a QFont can be
+    used. You can set the application's default font with
+    QApplication::setFont().
 
     If a chosen font does not include all the characters that
     need to be displayed, QFont will try to find the characters in the
@@ -427,7 +423,7 @@ QFontEngineData::~QFontEngineData()
 
     Create QFonts like this:
 
-    \snippet doc/src/snippets/code/src.gui.text.qfont.cpp 0
+    \snippet doc/src/snippets/code/src_gui_text_qfont.cpp 0
 
     The attributes set in the constructor can also be set later, e.g.
     setFamily(), setPointSize(), setPointSizeFloat(), setWeight() and
@@ -524,11 +520,11 @@ QFontEngineData::~QFontEngineData()
 
     Examples:
 
-    \snippet doc/src/snippets/code/src.gui.text.qfont.cpp 1
+    \snippet doc/src/snippets/code/src_gui_text_qfont.cpp 1
     If you had both an Adobe and a Cronyx Helvetica, you might get
     either.
 
-    \snippet doc/src/snippets/code/src.gui.text.qfont.cpp 2
+    \snippet doc/src/snippets/code/src_gui_text_qfont.cpp 2
 
     You can specify the foundry you want in the family name. The font f
     in the above example will be set to "Helvetica
@@ -537,11 +533,11 @@ QFontEngineData::~QFontEngineData()
     To determine the attributes of the font actually used in the window
     system, use a QFontInfo object, e.g.
 
-    \snippet doc/src/snippets/code/src.gui.text.qfont.cpp 3
+    \snippet doc/src/snippets/code/src_gui_text_qfont.cpp 3
 
     To find out font metrics use a QFontMetrics object, e.g.
 
-    \snippet doc/src/snippets/code/src.gui.text.qfont.cpp 4
+    \snippet doc/src/snippets/code/src_gui_text_qfont.cpp 4
 
     For more general information on fonts, see the
     \link http://nwalsh.com/comp.fonts/FAQ/ comp.fonts FAQ.\endlink
@@ -592,6 +588,105 @@ QFontEngineData::~QFontEngineData()
     \sa Weight
 */
 
+/*!
+    \fn Qt::HANDLE QFont::handle() const
+
+    Returns the window system handle to the font, for low-level
+    access. Using this function is \e not portable.
+*/
+
+/*!
+    \fn FT_Face QFont::freetypeFace() const
+
+    Returns the handle to the primary FreeType face of the font. If font merging is not disabled a
+    QFont can contain several physical fonts.
+
+    Returns 0 if the font does not contain a FreeType face.
+
+    \note This function is only available on platforms that provide the FreeType library;
+    i.e., X11 and some Embedded Linux platforms.
+*/
+
+/*!
+    \fn QString QFont::rawName() const
+
+    Returns the name of the font within the underlying window system.
+
+    Only on X11 when Qt was built without FontConfig support the XLFD (X Logical Font Description)
+    is returned; otherwise an empty string.
+
+    Using the return value of this function is usually \e not \e
+    portable.
+
+    \sa setRawName()
+*/
+
+/*!
+    \fn void QFont::setRawName(const QString &name)
+
+    Sets a font by its system specific name. The function is
+    particularly useful under X, where system font settings (for
+    example X resources) are usually available in XLFD (X Logical Font
+    Description) form only. You can pass an XLFD as \a name to this
+    function.
+
+    A font set with setRawName() is still a full-featured QFont. It can
+    be queried (for example with italic()) or modified (for example with
+    setItalic()) and is therefore also suitable for rendering rich text.
+
+    If Qt's internal font database cannot resolve the raw name, the
+    font becomes a raw font with \a name as its family.
+
+    Note that the present implementation does not handle wildcards in
+    XLFDs well, and that font aliases (file \c fonts.alias in the font
+    directory on X11) are not supported.
+
+    \sa rawName(), setRawMode(), setFamily()
+*/
+
+/*!
+    \fn QString QFont::lastResortFamily() const
+
+    Returns the "last resort" font family name.
+
+    The current implementation tries a wide variety of common fonts,
+    returning the first one it finds. Is is possible that no family is
+    found in which case an empty string is returned.
+
+    \sa lastResortFont()
+*/
+
+/*!
+    \fn QString QFont::defaultFamily() const
+
+    Returns the family name that corresponds to the current style
+    hint.
+
+    \sa StyleHint styleHint() setStyleHint()
+*/
+
+/*!
+    \fn QString QFont::lastResortFont() const
+
+    Returns a "last resort" font name for the font matching algorithm.
+    This is used if the last resort family is not available. It will
+    always return a name, if necessary returning something like
+    "fixed" or "system".
+
+    The current implementation tries a wide variety of common fonts,
+    returning the first one it finds. The implementation may change
+    at any time, but this function will always return a string
+    containing something.
+
+    It is theoretically possible that there really isn't a
+    lastResortFont() in which case Qt will abort with an error
+    message. We have not been able to identify a case where this
+    happens. Please \link bughowto.html report it as a bug\endlink if
+    it does, preferably with a list of the fonts you have installed.
+
+    \sa lastResortFamily() rawName()
+*/
+
 /*!
   Constructs a font from \a font for use on the paint device \a pd.
 */
