@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -127,6 +121,11 @@ QTextCursorPrivate::AdjustResult QTextCursorPrivate::adjustPosition(int position
 
 void QTextCursorPrivate::setX()
 {
+    if (priv && priv->isInEditBlock()) {
+        x = -1; // mark dirty
+        return;
+    }
+
     QTextBlock block = this->block();
     const QTextLayout *layout = blockLayout(block);
     int pos = position - block.position();
@@ -284,6 +283,67 @@ void QTextCursorPrivate::adjustCursor(QTextCursor::MoveOperation m)
     currentCharFormat = -1;
 }
 
+void QTextCursorPrivate::aboutToRemoveCell(int from, int to)
+{
+    Q_ASSERT(from <= to);
+    if (position == anchor)
+        return;
+
+    QTextTable *t = qobject_cast<QTextTable *>(priv->frameAt(position));
+    if (!t)
+        return;
+    QTextTableCell removedCellFrom = t->cellAt(from);
+    QTextTableCell removedCellEnd = t->cellAt(to);
+    if (! removedCellFrom.isValid() || !removedCellEnd.isValid())
+        return;
+
+    int curFrom = position;
+    int curTo = adjusted_anchor;
+    if (curTo < curFrom)
+        qSwap(curFrom, curTo);
+
+    QTextTableCell cellStart = t->cellAt(curFrom);
+    QTextTableCell cellEnd = t->cellAt(curTo);
+
+    if (cellStart.row() >= removedCellFrom.row() && cellEnd.row() <= removedCellEnd.row()
+            && cellStart.column() >= removedCellFrom.column()
+              && cellEnd.column() <= removedCellEnd.column()) { // selection is completely removed
+        // find a new position, as close as possible to where we were.
+        QTextTableCell cell;
+        if (removedCellFrom.row() == 0 && removedCellEnd.row() == t->rows()-1) // removed n columns
+            cell = t->cellAt(cellStart.row(), removedCellEnd.column()+1);
+        else if (removedCellFrom.column() == 0 && removedCellEnd.column() == t->columns()-1) // removed n rows
+            cell = t->cellAt(removedCellEnd.row() + 1, cellStart.column());
+
+        int newPosition;
+        if (cell.isValid())
+            newPosition = cell.firstPosition();
+        else
+            newPosition = t->lastPosition()+1;
+
+        setPosition(newPosition);
+        anchor = newPosition;
+        adjusted_anchor = newPosition;
+        x = 0;
+    }
+    else if (cellStart.row() >= removedCellFrom.row() && cellStart.row() <= removedCellEnd.row()
+        && cellEnd.row() > removedCellEnd.row()) {
+        int newPosition = t->cellAt(removedCellEnd.row() + 1, cellStart.column()).firstPosition();
+        if (position < anchor)
+            position = newPosition;
+        else
+            anchor = adjusted_anchor = newPosition;
+    }
+    else if (cellStart.column() >= removedCellFrom.column() && cellStart.column() <= removedCellEnd.column()
+        && cellEnd.column() > removedCellEnd.column()) {
+        int newPosition = t->cellAt(cellStart.row(), removedCellEnd.column()+1).firstPosition();
+        if (position < anchor)
+            position = newPosition;
+        else
+            anchor = adjusted_anchor = newPosition;
+    }
+}
+
 bool QTextCursorPrivate::movePosition(QTextCursor::MoveOperation op, QTextCursor::MoveMode mode)
 {
     currentCharFormat = -1;
@@ -323,10 +383,9 @@ bool QTextCursorPrivate::movePosition(QTextCursor::MoveOperation op, QTextCursor
         newPosition = 0;
         break;
     case QTextCursor::StartOfLine: {
-
-        if (!line.isValid())
-            break;
-        newPosition = blockIt.position() + line.textStart();
+        newPosition = blockIt.position();
+        if (line.isValid())
+            newPosition += line.textStart();
 
         break;
     }
@@ -405,8 +464,12 @@ bool QTextCursorPrivate::movePosition(QTextCursor::MoveOperation op, QTextCursor
         newPosition = priv->length() - 1;
         break;
     case QTextCursor::EndOfLine: {
-        if (!line.isValid() || line.textLength() == 0)
+        if (!line.isValid() || line.textLength() == 0) {
+            if (blockIt.length() >= 1)
+                // position right before the block separator
+                newPosition = blockIt.position() + blockIt.length() - 1;
             break;
+        }
         newPosition = blockIt.position() + line.textStart() + line.textLength();
         if (line.lineNumber() < layout->lineCount() - 1) {
             const QString text = blockIt.text();
@@ -1101,7 +1164,7 @@ bool QTextCursor::movePosition(MoveOperation op, MoveMode mode, int n)
   Visual navigation means skipping over hidden text pragraphs. The
   default is false.
 
-  /sa setVisualNavigation(), movePosition()
+  \sa setVisualNavigation(), movePosition()
  */
 bool QTextCursor::visualNavigation() const
 {
@@ -1130,7 +1193,7 @@ void QTextCursor::setVisualNavigation(bool b)
 
     If there is a selection, the selection is deleted and replaced by
     \a text, for example:
-    \snippet doc/src/snippets/code/src.gui.text.qtextcursor.cpp 0
+    \snippet doc/src/snippets/code/src_gui_text_qtextcursor.cpp 0
     This clears any existing selection, selects the word at the cursor
     (i.e. from position() forward), and replaces the selection with
     the phrase "Hello World".
@@ -1201,8 +1264,7 @@ void QTextCursor::insertText(const QString &text, const QTextCharFormat &_format
             d->priv->insert(d->position, QString(text.unicode() + textStart, text.length() - textStart), formatIdx);
     }
     d->priv->endEditBlock();
-    if (!d->priv->isInEditBlock())
-        d->setX();
+    d->setX();
 }
 
 /*!
@@ -1764,8 +1826,7 @@ void QTextCursor::insertBlock(const QTextBlockFormat &format, const QTextCharFor
     d->remove();
     d->insertBlock(format, charFormat);
     d->priv->endEditBlock();
-    if (!d->priv->isInEditBlock())
-        d->setX();
+    d->setX();
 }
 
 /*!
@@ -2025,7 +2086,7 @@ void QTextCursor::insertImage(const QTextImageFormat &format)
     Convenience method for inserting the image with the given \a name at the
     current position().
 
-    \snippet doc/src/snippets/code/src.gui.text.qtextcursor.cpp 1
+    \snippet doc/src/snippets/code/src_gui_text_qtextcursor.cpp 1
 */
 void QTextCursor::insertImage(const QString &name)
 {
@@ -2147,7 +2208,7 @@ bool QTextCursor::operator>(const QTextCursor &rhs) const
 
     For example:
 
-    \snippet doc/src/snippets/code/src.gui.text.qtextcursor.cpp 2
+    \snippet doc/src/snippets/code/src_gui_text_qtextcursor.cpp 2
 
     The call to undo() will cause both insertions to be undone,
     causing both "World" and "Hello" to be removed.
@@ -2173,7 +2234,7 @@ void QTextCursor::beginEditBlock()
 
     For example:
 
-    \snippet doc/src/snippets/code/src.gui.text.qtextcursor.cpp 3
+    \snippet doc/src/snippets/code/src_gui_text_qtextcursor.cpp 3
 
     The call to undo() will cause all three insertions to be undone.
 
