@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -53,6 +47,8 @@
 #include <qdatastream.h>
 #include <qdatetime.h>
 
+QT_BEGIN_NAMESPACE
+
 QTextCopyHelper::QTextCopyHelper(const QTextCursor &_source, const QTextCursor &_destination, bool forceCharFormat, const QTextCharFormat &fmt)
     : formatCollection(*_destination.d->priv->formatCollection()), originalText(_source.d->priv->buffer())
 {
@@ -224,6 +220,9 @@ QTextDocumentFragmentPrivate::QTextDocumentFragmentPrivate(const QTextCursor &_c
     QTextCursor destCursor(doc);
     QTextCopyHelper(_cursor, destCursor).copy();
     doc->docHandle()->endEditBlock();
+
+    if (_cursor.d)
+        doc->docHandle()->mergeCachedResources(_cursor.d->priv);
 }
 
 void QTextDocumentFragmentPrivate::insert(QTextCursor &_cursor) const
@@ -243,6 +242,8 @@ void QTextDocumentFragmentPrivate::insert(QTextCursor &_cursor) const
 
 /*!
     \class QTextDocumentFragment
+    \reentrant
+
     \brief The QTextDocumentFragment class represents a piece of formatted text
     from a QTextDocument.
 
@@ -321,12 +322,11 @@ QTextDocumentFragment::QTextDocumentFragment(const QTextDocumentFragment &rhs)
 */
 QTextDocumentFragment &QTextDocumentFragment::operator=(const QTextDocumentFragment &rhs)
 {
-    QTextDocumentFragmentPrivate *x = rhs.d;
-    if (x)
-        x->ref.ref();
-    x = qAtomicSetPtr(&d, x);
-    if (x && !x->ref.deref())
-        delete x;
+    if (rhs.d)
+        rhs.d->ref.ref();
+    if (d && !d->ref.deref())
+        delete d;
+    d = rhs.d;
     return *this;
 }
 
@@ -365,6 +365,9 @@ QString QTextDocumentFragment::toPlainText() const
 /*!
     \overload
 */
+
+#ifndef QT_NO_TEXTHTMLPARSER
+
 QString QTextDocumentFragment::toHtml() const
 {
     return toHtml(QByteArray());
@@ -386,6 +389,8 @@ QString QTextDocumentFragment::toHtml(const QByteArray &encoding) const
     return QTextHtmlExporter(d->doc).toHtml(encoding, QTextHtmlExporter::ExportFragment);
 }
 
+#endif // QT_NO_TEXTHTMLPARSER
+
 /*!
     Returns a document fragment that contains the given \a plainText.
 
@@ -403,11 +408,21 @@ QTextDocumentFragment QTextDocumentFragment::fromPlainText(const QString &plainT
     return res;
 }
 
+static QTextListFormat::Style nextListStyle(QTextListFormat::Style style)
+{
+    if (style == QTextListFormat::ListDisc)
+        return QTextListFormat::ListCircle;
+    else if (style == QTextListFormat::ListCircle)
+        return QTextListFormat::ListSquare;
+    return style;
+}
+
+#ifndef QT_NO_TEXTHTMLPARSER
+
 QTextHtmlImporter::QTextHtmlImporter(QTextDocument *_doc, const QString &_html, ImportMode mode, const QTextDocument *resourceProvider)
-    : indent(0), doc(_doc), importMode(mode)
+    : indent(0), compressNextWhitespace(PreserveWhiteSpace), doc(_doc), importMode(mode)
 {
     cursor = QTextCursor(doc);
-    compressNextWhitespace = false;
     wsm = QTextHtmlParserNode::WhiteSpaceNormal;
 
     QString html = _html;
@@ -426,21 +441,12 @@ QTextHtmlImporter::QTextHtmlImporter(QTextDocument *_doc, const QString &_html,
 //    dumpHtml();
 }
 
-static QTextListFormat::Style nextListStyle(QTextListFormat::Style style)
-{
-    if (style == QTextListFormat::ListDisc)
-        return QTextListFormat::ListCircle;
-    else if (style == QTextListFormat::ListCircle)
-        return QTextListFormat::ListSquare;
-    return style;
-}
-
 void QTextHtmlImporter::import()
 {
     cursor.beginEditBlock();
     hasBlock = true;
     forceBlockMerging = false;
-    compressNextWhitespace = !textEditMode;
+    compressNextWhitespace = RemoveWhiteSpace;
     blockTagClosed = false;
     for (currentNodeIdx = 0; currentNodeIdx < count(); ++currentNodeIdx) {
         currentNode = &at(currentNodeIdx);
@@ -473,7 +479,27 @@ void QTextHtmlImporter::import()
             if (blockTagClosed
                 && !currentNode->isBlock()
                 && currentNode->id != Html_unknown)
+            {
                 hasBlock = false;
+            } else if (hasBlock) {
+                // when collapsing subsequent block tags we need to clear the block format
+                QTextBlockFormat blockFormat = currentNode->blockFormat;
+                blockFormat.setIndent(indent);
+
+                QTextBlockFormat oldFormat = cursor.blockFormat();
+                if (oldFormat.hasProperty(QTextFormat::PageBreakPolicy)) {
+                    QTextFormat::PageBreakFlags pageBreak = oldFormat.pageBreakPolicy();
+                    if (pageBreak == QTextFormat::PageBreak_AlwaysAfter)
+                        /* We remove an empty paragrah that requested a page break after.
+                           moving that request to the next paragraph means we also need to make
+                            that a pagebreak before to keep the same visual appearance.
+                        */
+                        pageBreak = QTextFormat::PageBreak_AlwaysBefore;
+                    blockFormat.setPageBreakPolicy(pageBreak);
+                }
+
+                cursor.setBlockFormat(blockFormat);
+            }
         }
 
         if (currentNode->displayMode == QTextHtmlElement::DisplayNone) {
@@ -518,20 +544,13 @@ void QTextHtmlImporter::import()
     cursor.endEditBlock();
 }
 
-static bool isPreservingWhitespaceMode(QTextHtmlParserNode::WhiteSpaceMode mode)
-{
-    return mode == QTextHtmlParserNode::WhiteSpacePre
-           || mode == QTextHtmlParserNode::WhiteSpacePreWrap
-           ;
-}
-
 bool QTextHtmlImporter::appendNodeText()
 {
     const int initialCursorPosition = cursor.position();
     QTextCharFormat format = currentNode->charFormat;
 
-    if (isPreservingWhitespaceMode(wsm))
-        compressNextWhitespace = false;
+    if(wsm == QTextHtmlParserNode::WhiteSpacePre || wsm == QTextHtmlParserNode::WhiteSpacePreWrap)
+        compressNextWhitespace = PreserveWhiteSpace;
 
     QString text = currentNode->text;
 
@@ -545,7 +564,9 @@ bool QTextHtmlImporter::appendNodeText()
             && ch != QChar::Nbsp
             && ch != QChar::ParagraphSeparator) {
 
-            if (compressNextWhitespace)
+            if (compressNextWhitespace == CollapseWhiteSpace)
+                compressNextWhitespace = RemoveWhiteSpace; // allow this one, and remove the ones coming next.
+            else if(compressNextWhitespace == RemoveWhiteSpace)
                 continue;
 
             if (wsm == QTextHtmlParserNode::WhiteSpacePre
@@ -558,14 +579,14 @@ bool QTextHtmlImporter::appendNodeText()
                     continue;
                 }
             } else if (wsm != QTextHtmlParserNode::WhiteSpacePreWrap) {
-                compressNextWhitespace = true;
+                compressNextWhitespace = RemoveWhiteSpace;
                 if (wsm == QTextHtmlParserNode::WhiteSpaceNoWrap)
                     ch = QChar::Nbsp;
                 else
                     ch = QLatin1Char(' ');
             }
         } else {
-            compressNextWhitespace = false;
+            compressNextWhitespace = PreserveWhiteSpace;
         }
 
         if (ch == QLatin1Char('\n')
@@ -622,6 +643,7 @@ QTextHtmlImporter::ProcessNodeResult QTextHtmlImporter::processSpecialNodes()
                 doc->rootFrame()->setFrameFormat(fmt);
                 const_cast<QTextHtmlParserNode *>(currentNode)->charFormat.clearProperty(QTextFormat::BackgroundBrush);
             }
+            compressNextWhitespace = RemoveWhiteSpace;
             break;
 
         case Html_ol:
@@ -654,7 +676,7 @@ QTextHtmlImporter::ProcessNodeResult QTextHtmlImporter::processSpecialNodes()
             l.format = listFmt;
             l.listNode = currentNodeIdx;
             lists.append(l);
-            compressNextWhitespace = true;
+            compressNextWhitespace = RemoveWhiteSpace;
 
             // broken html: <ul>Text here<li>Foo
             const QString simpl = currentNode->text.simplified();
@@ -667,6 +689,7 @@ QTextHtmlImporter::ProcessNodeResult QTextHtmlImporter::processSpecialNodes()
             Table t = scanTable(currentNodeIdx);
             tables.append(t);
             hasBlock = false;
+            compressNextWhitespace = RemoveWhiteSpace;
             return ContinueWithNextNode;
         }
 
@@ -689,6 +712,7 @@ QTextHtmlImporter::ProcessNodeResult QTextHtmlImporter::processSpecialNodes()
             cursor.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor);
             cursor.mergeCharFormat(currentNode->charFormat);
             cursor.movePosition(QTextCursor::Right);
+            compressNextWhitespace = CollapseWhiteSpace;
 
             hasBlock = false;
             return ContinueWithNextNode;
@@ -704,6 +728,7 @@ QTextHtmlImporter::ProcessNodeResult QTextHtmlImporter::processSpecialNodes()
             else
                 appendBlock(blockFormat);
             hasBlock = false;
+            compressNextWhitespace = RemoveWhiteSpace;
             return ContinueWithNextNode;
         }
 
@@ -760,7 +785,7 @@ bool QTextHtmlImporter::closeTag()
                 // claim to have closed one for the creation of a new one
                 // in import()
                 blockTagClosed = false;
-                compressNextWhitespace = true;
+                compressNextWhitespace = RemoveWhiteSpace;
                 break;
 
             case Html_th:
@@ -768,7 +793,7 @@ bool QTextHtmlImporter::closeTag()
                 if (t && !t->isTextFrame)
                     ++t->currentCell;
                 blockTagClosed = true;
-                compressNextWhitespace = true;
+                compressNextWhitespace = RemoveWhiteSpace;
                 break;
 
             case Html_ol:
@@ -781,7 +806,7 @@ bool QTextHtmlImporter::closeTag()
                 break;
 
             case Html_br:
-                compressNextWhitespace = true;
+                compressNextWhitespace = RemoveWhiteSpace;
                 break;
 
             case Html_div:
@@ -864,8 +889,12 @@ QTextHtmlImporter::Table QTextHtmlImporter::scanTable(int tableNodeIdx)
                 columnWidths.resize(qMax(columnWidths.count(), colsInRow));
                 rowColSpanForColumn.resize(columnWidths.size());
                 for (int i = currentColumn; i < currentColumn + c.tableCellColSpan; ++i) {
-                    if (columnWidths.at(i).type() == QTextLength::VariableLength)
-                        columnWidths[i] = c.width;
+                    if (columnWidths.at(i).type() == QTextLength::VariableLength) {
+                        QTextLength w = c.width;
+                        if (c.tableCellColSpan > 1 && w.type() != QTextLength::VariableLength)
+                            w = QTextLength(w.type(), w.value(100.) / c.tableCellColSpan);
+                        columnWidths[i] = w;
+                    }
                     rowColSpanForColumn[i] = spanInfo;
                 }
             }
@@ -958,12 +987,24 @@ QTextHtmlImporter::ProcessNodeResult QTextHtmlImporter::processBlockNode()
     if (currentNode->isTableCell() && !tables.isEmpty()) {
         Table &t = tables.last();
         if (!t.isTextFrame && !t.currentCell.atEnd()) {
-            const QTextTableCell cell = t.currentCell.cell();
-            if (cell.isValid())
+            QTextTableCell cell = t.currentCell.cell();
+            if (cell.isValid()) {
+                QTextTableCellFormat fmt = cell.format().toTableCellFormat();
+                if (topPadding(currentNodeIdx) >= 0)
+                    fmt.setTopPadding(topPadding(currentNodeIdx));
+                if (bottomPadding(currentNodeIdx) >= 0)
+                    fmt.setBottomPadding(bottomPadding(currentNodeIdx));
+                if (leftPadding(currentNodeIdx) >= 0)
+                    fmt.setLeftPadding(leftPadding(currentNodeIdx));
+                if (rightPadding(currentNodeIdx) >= 0)
+                    fmt.setRightPadding(rightPadding(currentNodeIdx));
+                cell.setFormat(fmt);
+
                 cursor.setPosition(cell.firstPosition());
+            }
         }
         hasBlock = true;
-        compressNextWhitespace = true;
+        compressNextWhitespace = RemoveWhiteSpace;
 
         if (currentNode->charFormat.background().style() != Qt::NoBrush) {
             charFmt.setBackground(currentNode->charFormat.background());
@@ -1113,10 +1154,12 @@ void QTextHtmlImporter::appendBlock(const QTextBlockFormat &format, QTextCharFor
 
     cursor.insertBlock(format, charFmt);
 
-    if (!isPreservingWhitespaceMode(wsm))
-        compressNextWhitespace = true;
+    if (wsm != QTextHtmlParserNode::WhiteSpacePre && wsm != QTextHtmlParserNode::WhiteSpacePreWrap)
+        compressNextWhitespace = RemoveWhiteSpace;
 }
 
+#endif // QT_NO_TEXTHTMLPARSER
+
 /*!
     \fn QTextDocumentFragment QTextDocumentFragment::fromHtml(const QString &text)
 
@@ -1125,6 +1168,9 @@ void QTextHtmlImporter::appendBlock(const QTextBlockFormat &format, QTextCharFor
     possible; for example, "<b>bold</b>" will become a document
     fragment with the text "bold" with a bold character format.
 */
+
+#ifndef QT_NO_TEXTHTMLPARSER
+
 QTextDocumentFragment QTextDocumentFragment::fromHtml(const QString &html)
 {
     return fromHtml(html, 0);
@@ -1142,6 +1188,7 @@ QTextDocumentFragment QTextDocumentFragment::fromHtml(const QString &html)
     If the provided HTML contains references to external resources such as imported style sheets, then
     they will be loaded through the \a resourceProvider.
 */
+
 QTextDocumentFragment QTextDocumentFragment::fromHtml(const QString &html, const QTextDocument *resourceProvider)
 {
     QTextDocumentFragment res;
@@ -1151,3 +1198,6 @@ QTextDocumentFragment QTextDocumentFragment::fromHtml(const QString &html, const
     importer.import();
     return res;
 }
+
+QT_END_NAMESPACE
+#endif // QT_NO_TEXTHTMLPARSER
