@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -306,10 +300,10 @@ Qt::LayoutDirection QTextInlineObject::textDirection() const
     device.
 
     Here's some pseudo code that presents the layout phase:
-    \snippet doc/src/snippets/code/src.gui.text.qtextlayout.cpp 0
+    \snippet doc/src/snippets/code/src_gui_text_qtextlayout.cpp 0
 
     The text can be drawn by calling the layout's draw() function:
-    \snippet doc/src/snippets/code/src.gui.text.qtextlayout.cpp 1
+    \snippet doc/src/snippets/code/src_gui_text_qtextlayout.cpp 1
 
     The text layout's text is set in the constructor or with
     setText(). The layout can be seen as a sequence of QTextLine
@@ -629,8 +623,10 @@ void QTextLayout::endLayout()
         d->freeMemory();
 }
 
-/*!  Clears the line information in the layout. After having called
-  this function, lineCount() returns 0.
+/*!  \since 4.4
+
+Clears the line information in the layout. After having called
+this function, lineCount() returns 0.
  */
 void QTextLayout::clearLayout()
 {
@@ -1162,6 +1158,7 @@ void QTextLayout::draw(QPainter *p, const QPointF &pos, const QVector<FormatRang
             if (selection.format.boolProperty(QTextFormat::FullWidthSelection)) {
                 QRectF fullLineRect(tl.rect());
                 fullLineRect.translate(position);
+                fullLineRect.setRight(QFIXED_MAX);
                 if (!selectionEndInLine)
                     region.addRect(QRectF(lineRect.topRight(), fullLineRect.bottomRight()));
                 if (!selectionStartInLine)
@@ -1527,17 +1524,17 @@ static inline bool checkFullOtherwiseExtend(QScriptLine &line, QScriptLine &tmpD
 static inline void addNextCluster(int &pos, int end, QScriptLine &line, int &glyphCount,
                                   const QScriptItem &current, const unsigned short *logClusters, const QGlyphLayout *glyphs)
 {
-    int gp = logClusters[pos];
-    do {
+    int glyphPosition = logClusters[pos];
+    do { // got to the first next cluster
         ++pos;
         ++line.length;
-    } while (pos < end && logClusters[pos] == gp);
-    do {
-        line.textWidth += glyphs[gp].advance.x * !glyphs[gp].attributes.dontPrint;
-        ++gp;
-    } while (gp < current.num_glyphs && !glyphs[gp].attributes.clusterStart);
+    } while (pos < end && logClusters[pos] == glyphPosition);
+    do { // calculate the textWidth for the rest of the current cluster.
+        line.textWidth += glyphs[glyphPosition].advance.x * !glyphs[glyphPosition].attributes.dontPrint;
+        ++glyphPosition;
+    } while (glyphPosition < current.num_glyphs && !glyphs[glyphPosition].attributes.clusterStart);
 
-    Q_ASSERT((pos == end && gp == current.num_glyphs) || logClusters[pos] == gp);
+    Q_ASSERT((pos == end && glyphPosition == current.num_glyphs) || logClusters[pos] == glyphPosition);
 
     ++glyphCount;
 }
