@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -64,7 +58,7 @@ QT_BEGIN_NAMESPACE
     a change to the document with redo() and undo the change with undo(). The
     implementations for these functions must be provided in a derived class.
 
-    \snippet doc/src/snippets/code/src.gui.util.qundostack.cpp 0
+    \snippet doc/src/snippets/code/src_gui_util_qundostack.cpp 0
 
     A QUndoCommand has an associated text(). This is a short string
     describing what the command does. It is used to update the text
@@ -74,7 +68,7 @@ QT_BEGIN_NAMESPACE
     QUndoCommand objects are owned by the stack they were pushed on.
     QUndoStack deletes a command if it has been undone and a new command is pushed. For example:
 
-\snippet doc/src/snippets/code/src.gui.util.qundostack.cpp 1
+\snippet doc/src/snippets/code/src_gui_util_qundostack.cpp 1
 
     In effect, when a command is pushed, it becomes the top-most command
     on the stack.
@@ -94,7 +88,7 @@ QT_BEGIN_NAMESPACE
     redo() on all its children. The parent should, however, have a meaningful
     text().
 
-    \snippet doc/src/snippets/code/src.gui.util.qundostack.cpp 2
+    \snippet doc/src/snippets/code/src_gui_util_qundostack.cpp 2
 
     Another way to create macros is to use the convenience functions
     QUndoStack::beginMacro() and QUndoStack::endMacro().
@@ -183,7 +177,7 @@ int QUndoCommand::id() const
 
     The default implementation returns false.
 
-    \snippet doc/src/snippets/code/src.gui.util.qundostack.cpp 3
+    \snippet doc/src/snippets/code/src_gui_util_qundostack.cpp 3
 
     \sa id() QUndoStack::push()
 */
@@ -259,6 +253,8 @@ void QUndoCommand::setText(const QString &text)
 }
 
 /*!
+    \since 4.4
+
     Returns the number of child commands in this command.
 
     \sa child()
@@ -270,6 +266,8 @@ int QUndoCommand::childCount() const
 }
 
 /*!
+    \since 4.4
+
     Returns the child command at \a index.
 
     \sa childCount(), QUndoStack::command()
@@ -891,11 +889,11 @@ QAction *QUndoStack::createRedoAction(QObject *parent, const QString &prefix) co
     The stack becomes enabled and appropriate signals are emitted when endMacro()
     is called for the outermost macro.
 
-    \snippet doc/src/snippets/code/src.gui.util.qundostack.cpp 4
+    \snippet doc/src/snippets/code/src_gui_util_qundostack.cpp 4
 
     This code is equivalent to:
 
-    \snippet doc/src/snippets/code/src.gui.util.qundostack.cpp 5
+    \snippet doc/src/snippets/code/src_gui_util_qundostack.cpp 5
 
     \sa endMacro()
 */
@@ -951,6 +949,8 @@ void QUndoStack::endMacro()
 }
 
 /*!
+  \since 4.4
+
   Returns a const pointer to the command at \a index.
 
   This function returns a const pointer, because modifying a command,
