@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -74,7 +68,7 @@ QT_BEGIN_NAMESPACE
     QAbstractScrollArea is a low-level abstraction of a scrolling
     area. The area provides a central widget called the viewport, in
     which the contents of the area is to be scrolled (i.e, the
-    visible parts of the contents are rendered in the viewport). 
+    visible parts of the contents are rendered in the viewport).
 
     Next to the viewport is a vertical scroll bar, and below is a
     horizontal scroll bar. When all of the area contents fits in the
@@ -113,14 +107,14 @@ QT_BEGIN_NAMESPACE
     receives a resize event or the size of the contents changes.
     The viewport also needs to be updated when the scroll bars
     values change. The initial values of the scroll bars are often
-    set when the area receives new contents. 
+    set when the area receives new contents.
 
     We give a simple example, in which we have implemented a scroll area
     that can scroll any QWidget. We make the widget a child of the
     viewport; this way, we do not have to calculate which part of
     the widget to draw but can simply move the widget with
     QWidget::move(). When the area contents or the viewport size
-    changes, we do the following: 
+    changes, we do the following:
 
     \snippet doc/src/snippets/myscrollarea.cpp 1
 
@@ -265,6 +259,10 @@ void QAbstractScrollAreaPrivate::replaceScrollBar(QScrollBar *scrollBar,
 void QAbstractScrollAreaPrivate::init()
 {
     Q_Q(QAbstractScrollArea);
+    viewport = new QWidget(q);
+    viewport->setObjectName(QLatin1String("qt_scrollarea_viewport"));
+    viewport->setBackgroundRole(QPalette::Base);
+    viewport->setAutoFillBackground(true);
     scrollBarContainers[Qt::Horizontal] = new QAbstractScrollAreaScrollBarContainer(Qt::Horizontal, q);
     scrollBarContainers[Qt::Horizontal]->setObjectName(QLatin1String("qt_scrollarea_hcontainer"));
     hbar = scrollBarContainers[Qt::Horizontal]->scrollBar;
@@ -280,10 +278,6 @@ void QAbstractScrollAreaPrivate::init()
     QObject::connect(vbar, SIGNAL(valueChanged(int)), q, SLOT(_q_vslide(int)));
     QObject::connect(vbar, SIGNAL(rangeChanged(int,int)), q, SLOT(_q_showOrHideScrollBars()), Qt::QueuedConnection);
     viewportFilter = new QAbstractScrollAreaFilter(this);
-    viewport = new QWidget(q);
-    viewport->setObjectName(QLatin1String("qt_scrollarea_viewport"));
-    viewport->setBackgroundRole(QPalette::Base);
-    viewport->setAutoFillBackground(true);
     viewport->installEventFilter(viewportFilter);
     viewport->setFocusProxy(q);
     q->setFocusPolicy(Qt::WheelFocus);
@@ -369,9 +363,9 @@ void QAbstractScrollAreaPrivate::layoutChildren()
         QRect frameRect = widgetRect;
         frameRect.adjust(0, 0, -cornerOffset.x() - cornerExtra.x(), -cornerOffset.y() - cornerExtra.y());
         q->setFrameRect(QStyle::visualRect(opt.direction, opt.rect, frameRect));
-        // The frame rect needs to be in logical coords, however we need to flip 
+        // The frame rect needs to be in logical coords, however we need to flip
         // the contentsRect back before passing it on to the viewportRect
-        // since the viewportRect has it's logical coords calculated later.
+        // since the viewportRect has its logical coords calculated later.
         viewportRect = QStyle::visualRect(opt.direction, opt.rect, q->contentsRect());
     } else {
         q->setFrameRect(QStyle::visualRect(opt.direction, opt.rect, widgetRect));
@@ -814,7 +808,7 @@ QWidgetList QAbstractScrollArea::scrollBarWidgets(Qt::Alignment alignment)
     Note that this function is frequently called by QTreeView and
     QTableView, so margins must be implemented by QAbstractScrollArea
     subclasses. Also, if the subclasses are to be used in item views,
-    they should not call this function. 
+    they should not call this function.
 
     By default all margins are zero.
 
@@ -846,7 +840,13 @@ bool QAbstractScrollArea::event(QEvent *e)
     Q_D(QAbstractScrollArea);
     switch (e->type()) {
     case QEvent::AcceptDropsChange:
-        d->viewport->setAcceptDrops(acceptDrops());
+        // There was a chance that with accessibility client we get an
+        // event before the viewport was created.
+        // Also, in some cases we might get here from QWidget::event() virtual function which is (indirectly) called
+        // from the viewport constructor at the time when the d->viewport is not yet initialized even without any
+        // accessibility client. See qabstractscrollarea autotest for a test case.
+        if (d->viewport)
+            d->viewport->setAcceptDrops(acceptDrops());
         break;
     case QEvent::MouseTrackingChange:
         d->viewport->setMouseTracking(hasMouseTracking());
@@ -871,11 +871,13 @@ bool QAbstractScrollArea::event(QEvent *e)
 #endif
         QFrame::paintEvent((QPaintEvent*)e);
         break;
+#ifndef QT_NO_CONTEXTMENU
     case QEvent::ContextMenu:
         if (static_cast<QContextMenuEvent *>(e)->reason() == QContextMenuEvent::Keyboard)
            return QFrame::event(e);
         e->ignore();
         break;
+#endif // QT_NO_CONTEXTMENU
     case QEvent::MouseButtonPress:
     case QEvent::MouseButtonRelease:
     case QEvent::MouseButtonDblClick:
@@ -1044,6 +1046,7 @@ void QAbstractScrollArea::wheelEvent(QWheelEvent *e)
 }
 #endif
 
+#ifndef QT_NO_CONTEXTMENU
 /*!
     This event handler can be reimplemented in a subclass to receive
     context menu events for the viewport() widget. The event is passed
@@ -1055,6 +1058,7 @@ void QAbstractScrollArea::contextMenuEvent(QContextMenuEvent *e)
 {
     e->ignore();
 }
+#endif // QT_NO_CONTEXTMENU
 
 /*!
     This function is called with key event \a e when key presses
