@@ -1,43 +1,37 @@
 /****************************************************************************)
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -85,7 +79,7 @@ QT_BEGIN_NAMESPACE
   QDateTimeEdit box. Dates and times appear in accordance with the
   format set; see setDisplayFormat().
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 0
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 0
 
   Here we've created a new QDateTimeEdit object initialized with
   today's date, and restricted the valid date range to today plus or
@@ -96,6 +90,14 @@ QT_BEGIN_NAMESPACE
   setMinimumDate(), setMaximumDate(),  setMinimumTime(),
   and setMaximumTime().
 
+  \section1 Using a Pop-up Calendar Widget
+  
+  QDateTimeEdit can be configured to allow a QCalendarWidget to be used
+  to select dates. This is enabled by setting the calendarPopup property.
+  Additionally, you can supply a custom calendar widget for use as the
+  calendar pop-up by calling the setCalendarWidget() function. The existing
+  calendar widget can be retrieved with calendarWidget().
+  
   \table 100%
   \row \o \inlineimage windowsxp-datetimeedit.png Screenshot of a Windows XP style date time editing widget
        \o A date time editing widget shown in the \l{Windows XP Style Widget Gallery}{Windows XP widget style}.
@@ -214,6 +216,9 @@ QDateTimeEdit::QDateTimeEdit(const QVariant &var, QVariant::Type parserType, QWi
   \property QDateTimeEdit::dateTime
   \brief the QDateTime that is set in the QDateTimeEdit
 
+  By default, this property contains a date that refers to January 1,
+  2000 and a time of 00:00:00 and 0 milliseconds.
+
   \sa date, time
 */
 
@@ -238,6 +243,8 @@ void QDateTimeEdit::setDateTime(const QDateTime &datetime)
   \property QDateTimeEdit::date
   \brief the QDate that is set in the QDateTimeEdit
 
+  By default, this property contains a date that refers to January 1, 2000.
+
   \sa time, dateTime
 */
 
@@ -267,6 +274,8 @@ void QDateTimeEdit::setDate(const QDate &date)
   \property QDateTimeEdit::time
   \brief the QTime that is set in the QDateTimeEdit
 
+  By default, this property contains a time of 00:00:00 and 0 milliseconds.
+
   \sa date, dateTime
 */
 
@@ -302,6 +311,9 @@ void QDateTimeEdit::setTime(const QTime &time)
   The default minimumDateTime can be restored with
   clearMinimumDateTime()
 
+  By default, this property contains a date that refers to September 14,
+  1752 and a time of 00:00:00 and 0 milliseconds.
+
   \sa maximumDateTime(), minimumTime(), maximumTime(), minimumDate(),
   maximumDate(), setDateTimeRange(), setDateRange(), setTimeRange(),
   clearMaximumDateTime(), clearMinimumDate(),
@@ -342,6 +354,9 @@ void QDateTimeEdit::setMinimumDateTime(const QDateTime &dt)
   The default maximumDateTime can be restored with
   clearMaximumDateTime().
 
+  By default, this property contains a date that refers to 31 December,
+  7999 and a time of 23:59:59 and 999 milliseconds.
+
   \sa minimumDateTime(), minimumTime(), maximumTime(), minimumDate(),
   maximumDate(), setDateTimeRange(), setDateRange(), setTimeRange(),
   clearMinimumDateTime(), clearMinimumDate(),
@@ -375,11 +390,11 @@ void QDateTimeEdit::setMaximumDateTime(const QDateTime &dt)
   function call.
   \since 4.4
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 1
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 1
 
   is analogous to:
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 2
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 2
 
   If either \a min or \a max are not valid, this function does
   nothing.
@@ -408,6 +423,8 @@ void QDateTimeEdit::setDateTimeRange(const QDateTime &min, const QDateTime &max)
   necessary, to ensure that the range remains valid. If the date is
   not a valid QDate object, this function does nothing.
 
+  By default, this property contains a date that refers to September 14, 1752.
+
   \sa minimumTime(), maximumTime(), setDateRange()
 */
 
@@ -439,6 +456,8 @@ void QDateTimeEdit::clearMinimumDate()
   necessary to ensure that the range remains valid. If the date is
   not a valid QDate object, this function does nothing.
 
+  By default, this property contains a date that refers to December 31, 7999.
+
   \sa minimumDate, minimumTime, maximumTime, setDateRange()
 */
 
@@ -470,6 +489,8 @@ void QDateTimeEdit::clearMaximumDate()
   necessary, to ensure that the range remains valid. If the time is
   not a valid QTime object, this function does nothing.
 
+  By default, this property contains a time of 00:00:00 and 0 milliseconds.
+
   \sa maximumTime, minimumDate, maximumDate, setTimeRange()
 */
 
@@ -502,6 +523,8 @@ void QDateTimeEdit::clearMinimumTime()
   necessary to ensure that the range remains valid. If the time is
   not a valid QTime object, this function does nothing.
 
+  By default, this property contains a time of 23:59:59 and 999 milliseconds.
+
   \sa minimumTime, minimumDate, maximumDate, setTimeRange()
 */
 QTime QDateTimeEdit::maximumTime() const
@@ -528,11 +551,11 @@ void QDateTimeEdit::clearMaximumTime()
   Convenience function to set minimum and maximum date with one
   function call.
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 3
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 3
 
   is analogous to:
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 4
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 4
 
   If either \a min or \a max are not valid, this function does
   nothing.
@@ -555,11 +578,11 @@ void QDateTimeEdit::setDateRange(const QDate &min, const QDate &max)
   Convenience function to set minimum and maximum time with one
   function call.
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 5
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 5
 
   is analogous to:
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qdatetimeedit.cpp 6
+  \snippet doc/src/snippets/code/src_gui_widgets_qdatetimeedit.cpp 6
 
   If either \a min or \a max are not valid, this function does
   nothing.
@@ -698,7 +721,7 @@ void QDateTimeEdit::setCurrentSectionIndex(int index)
 /*!
   \since 4.4
 
-  \brief Returns the calendar widget for the edit if calendarPopup is
+  \brief Returns the calendar widget for the editor if calendarPopup is
   set to true and (sections() & DateSections_Mask) != 0.
 
   This function creates and returns a calendar widget if none has been set.
@@ -716,6 +739,14 @@ QCalendarWidget *QDateTimeEdit::calendarWidget() const
     return d->monthCalendar->calendarWidget();
 }
 
+/*!
+  \since 4.4
+
+  Sets the given \a calendarWidget as the widget to be used for the calendar
+  pop-up. The editor does not automatically take ownership of the calendar widget.
+
+  \sa calendarPopup
+*/
 void QDateTimeEdit::setCalendarWidget(QCalendarWidget *calendarWidget)
 {
     Q_D(QDateTimeEdit);
@@ -803,6 +834,10 @@ QString QDateTimeEdit::sectionText(Section section) const
   \row \i MMMM d yy \i July 2 69
   \endtable
 
+  Note that if you specify a two digit year, it will be interpreted
+  to be in the century in which the date time edit was initialized.
+  The default century is the 21 (2000-2099).
+
   If you specify an invalid format the format will not be set.
 
   \sa QDateTime::toString(), displayedSections()
@@ -860,10 +895,10 @@ void QDateTimeEdit::setDisplayFormat(const QString &format)
 
 /*!
     \property QDateTimeEdit::calendarPopup
-    \brief the current calender popup showing mode.
+    \brief the current calender pop-up showing mode.
     \since 4.2
 
-    The calendar popup will be shown upon clicking the arrow button.
+    The calendar pop-up will be shown upon clicking the arrow button.
     This property is valid only if there is a valid date display format.
 
     \sa setDisplayFormat()
@@ -1304,8 +1339,7 @@ void QDateTimeEdit::stepBy(int steps)
   This virtual function is used by the date time edit whenever it
   needs to display \a dateTime.
 
-  If you reimplement this, you may also need to reimplement
-  valueFromText() and validate().
+  If you reimplement this, you may also need to reimplement validate().
 
   \sa dateTimeFromText(), validate()
 */
@@ -1508,6 +1542,14 @@ QTimeEdit::QTimeEdit(const QTime &time, QWidget *parent)
 {
 }
 
+/*!
+    \property QTimeEdit::time
+    \brief the QTime that is shown in the widget
+
+    By default, this property contains a time of 00:00:00 and 0 milliseconds.
+*/
+
+
 /*!
   \class QDateEdit
   \brief The QDateEdit class provides a widget for editing dates based on
@@ -1561,6 +1603,13 @@ QDateEdit::QDateEdit(const QDate &date, QWidget *parent)
 {
 }
 
+/*!
+    \property QDateEdit::date
+    \brief the QDate that is shown in the widget
+
+    By default, this property contains a date referring to January 1, 2000.
+*/
+
 
 // --- QDateTimeEditPrivate ---
 
@@ -1881,6 +1930,9 @@ QString QDateTimeEditPrivate::textFromValue(const QVariant &f) const
 /*!
   \internal
   \reimp
+
+  This function's name is slightly confusing; it is not to be confused
+  with QAbstractSpinBox::valueFromText().
 */
 
 QVariant QDateTimeEditPrivate::valueFromText(const QString &f) const
