@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -169,7 +163,7 @@ void QMainWindowPrivate::init()
 
     \note Creating a main window without a central widget is not supported.
     You must have a central widget even if it is just a placeholder.
-    
+
     \section1 Creating Main Window Components
 
     A central widget will typically be a standard Qt widget such
@@ -428,6 +422,15 @@ void QMainWindow::setToolButtonStyle(Qt::ToolButtonStyle toolButtonStyle)
     Returns the menu bar for the main window. This function creates
     and returns an empty menu bar if the menu bar does not exist.
 
+    If you want all windows in a Mac application to share one menu
+    bar, don't use this function to create it, because the menu bar
+    created here will have this QMainWindow as its parent.  Instead,
+    you must create a menu bar that does not have a parent, which you
+    can then share among all the Mac windows. Create a parent-less
+    menu bar this way:
+
+    \snippet doc/src/snippets/code/src_gui_widgets_qmenubar.cpp 1
+
     \sa setMenuBar()
 */
 QMenuBar *QMainWindow::menuBar() const
@@ -465,7 +468,8 @@ void QMainWindow::setMenuBar(QMenuBar *menuBar)
             if (cornerWidget)
                 menuBar->setCornerWidget(cornerWidget, Qt::TopRightCorner);
         }
-        delete oldMenuBar;
+        oldMenuBar->hide();
+        oldMenuBar->deleteLater();
     }
     d->layout->setMenuBar(menuBar);
 }
@@ -493,8 +497,10 @@ QWidget *QMainWindow::menuWidget() const
 void QMainWindow::setMenuWidget(QWidget *menuBar)
 {
     Q_D(QMainWindow);
-    if (d->layout->menuBar() && d->layout->menuBar() != menuBar)
-        delete d->layout->menuBar();
+    if (d->layout->menuBar() && d->layout->menuBar() != menuBar) {
+        d->layout->menuBar()->hide();
+        d->layout->menuBar()->deleteLater();
+    }
     d->layout->setMenuBar(menuBar);
 }
 #endif // QT_NO_MENUBAR
@@ -530,8 +536,10 @@ QStatusBar *QMainWindow::statusBar() const
 void QMainWindow::setStatusBar(QStatusBar *statusbar)
 {
     Q_D(QMainWindow);
-    if (d->layout->statusBar() && d->layout->statusBar() != statusbar)
-        delete d->layout->statusBar();
+    if (d->layout->statusBar() && d->layout->statusBar() != statusbar) {
+        d->layout->statusBar()->hide();
+        d->layout->statusBar()->deleteLater();
+    }
     d->layout->setStatusBar(statusbar);
 }
 #endif // QT_NO_STATUSBAR
@@ -556,8 +564,10 @@ QWidget *QMainWindow::centralWidget() const
 void QMainWindow::setCentralWidget(QWidget *widget)
 {
     Q_D(QMainWindow);
-    if (d->layout->centralWidget() && d->layout->centralWidget() != widget)
-        delete d->layout->centralWidget();
+    if (d->layout->centralWidget() && d->layout->centralWidget() != widget) {
+        d->layout->centralWidget()->hide();
+        d->layout->centralWidget()->deleteLater();
+    }
     d->layout->setCentralWidget(widget);
 }
 
@@ -930,6 +940,12 @@ void QMainWindow::addDockWidget(Qt::DockWidgetArea area, QDockWidget *dockwidget
 #endif
 }
 
+/*!
+    Restores the state of \a dockwidget if it is created after the call
+    to restoreState(). Returns true if the state was restored; otherwise
+    returns false.
+*/
+
 bool QMainWindow::restoreDockWidget(QDockWidget *dockwidget)
 {
     return d_func()->layout->restoreDockWidget(dockwidget);
@@ -1094,7 +1110,7 @@ void QMainWindowPrivate::adjustCursor(const QPoint &pos)
         if (!hoverSeparator.isEmpty())
             q->update(layout->layoutState.dockAreaLayout.separatorRect(hoverSeparator));
         hoverSeparator.clear();
-        
+
         if (cursorAdjusted) {
             cursorAdjusted = false;
             if (hasOldCursor)
@@ -1243,7 +1259,7 @@ bool QMainWindow::event(QEvent *event)
                d->hasOldCursor = testAttribute(Qt::WA_SetCursor);
            }
            break;
-#endif           
+#endif
 
         default:
             break;
@@ -1267,15 +1283,15 @@ bool QMainWindow::event(QEvent *event)
     means a couple of things.
 
     \list
-    \i QToolBars in this toolbar area are not movable and you cannot drag other toolbars to it
+    \i QToolBars in this toolbar area are not movable and you cannot drag other
+        toolbars to it
     \i Toolbar breaks are not respected or preserved
-    \i Any custom widgets in the toolbar will not be shown if the toolbar becomes too small
-      (only actions will be shown)
+    \i Any custom widgets in the toolbar will not be shown if the toolbar
+        becomes too small (only actions will be shown)
     \i If you call showFullScreen() on the main window, the QToolbar will
-       disappear since it is considered to be part of the title bar. You can work
-       around this by doing the following by turning off the unified toolbar
-       before you call showFullScrenn() and restore the value after you call
-       showNormal().
+        disappear since it is considered to be part of the title bar. You can
+        work around this by turning off the unified toolbar before you call
+        showFullScreen() and restoring it after you call showNormal().
     \endlist
 
     Setting this back to false will remove these restrictions.
@@ -1324,6 +1340,7 @@ bool QMainWindow::isSeparator(const QPoint &pos) const
 #endif
 }
 
+#ifndef QT_NO_CONTEXTMENU
 /*!
     \reimp
 */
@@ -1374,6 +1391,7 @@ void QMainWindow::contextMenuEvent(QContextMenuEvent *event)
     delete popup;
 #endif
 }
+#endif // QT_NO_CONTEXTMENU
 
 #ifndef QT_NO_MENU
 /*!
