@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -68,6 +62,7 @@
 
 #include <qdebug.h>
 
+#include <private/qapplication_p.h>
 #include <private/qlayoutengine_p.h>
 #ifdef Q_WS_MAC
 #   include <private/qcore_mac_p.h>
@@ -570,7 +565,9 @@ QLayoutItem *QMainWindowLayoutState::unplug(QList<int> path, QMainWindowLayoutSt
 {
     int i = path.takeFirst();
 
-#ifndef QT_NO_TOOLBAR
+#ifdef QT_NO_TOOLBAR
+    Q_UNUSED(other);
+#else
     if (i == 0)
         return toolBarAreaLayout.unplug(path, other ? &other->toolBarAreaLayout : 0);
 #endif
@@ -611,6 +608,9 @@ static QList<T> findChildrenHelper(const QObject *o)
 //pre4.3 tests the format that was used before 4.3
 bool QMainWindowLayoutState::checkFormat(QDataStream &stream, bool pre43)
 {
+#ifdef QT_NO_TOOLBAR
+    Q_UNUSED(pre43);
+#endif
     while (!stream.atEnd()) {
         uchar marker;
         stream >> marker;
@@ -621,7 +621,7 @@ bool QMainWindowLayoutState::checkFormat(QDataStream &stream, bool pre43)
             case QToolBarAreaLayout::ToolBarStateMarkerEx:
                 {
                     QList<QToolBar *> toolBars = findChildrenHelper<QToolBar*>(mainWindow);
-                    if (!toolBarAreaLayout.restoreState(stream, toolBars, marker, 
+                    if (!toolBarAreaLayout.restoreState(stream, toolBars, marker,
                         pre43 /*testing 4.3 format*/, true /*testing*/)) {
                             return false;
                     }
@@ -1020,6 +1020,8 @@ static const EventTypeSpec kToolbarEvents[] = {
 
 OSStatus QMainWindowLayout::qtmacToolbarDelegate(EventHandlerCallRef, EventRef event, void *data)
 {
+    QScopedLoopLevelCounter loopLevelCounter(QApplicationPrivate::instance()->threadData);
+
     QMainWindowLayout *mainWindowLayout = static_cast<QMainWindowLayout *>(data);
     OSStatus            result = eventNotHandledErr;
     CFMutableArrayRef   array;
@@ -1861,9 +1863,10 @@ void QMainWindowLayout::animationFinished(QWidget *widget)
 #ifndef QT_NO_DOCKWIDGET
 #ifndef QT_NO_TABBAR
     if (qobject_cast<QDockWidget*>(widget) != 0) {
-        QDockAreaLayoutInfo *info = layoutState.dockAreaLayout.info(widget);
-        Q_ASSERT(info != 0);
-        info->setCurrentTab(widget);
+        // info() might return null if the widget is destroyed while
+        // animating but before the animationFinished signal is received.
+        if (QDockAreaLayoutInfo *info = layoutState.dockAreaLayout.info(widget))
+            info->setCurrentTab(widget);
     }
 #endif
 #endif
@@ -1901,6 +1904,9 @@ QMainWindowLayout::QMainWindowLayout(QMainWindow *mainwindow)
 
 #ifndef QT_NO_RUBBERBAND
     gapIndicator = new QRubberBand(QRubberBand::Rectangle, mainwindow);
+    // For accessibility to identify this special widget.
+    gapIndicator->setObjectName(QLatin1String("qt_rubberband"));
+
     gapIndicator->hide();
 #endif
     pluggingWidget = 0;
@@ -2000,7 +2006,7 @@ QLayoutItem *QMainWindowLayout::unplug(QWidget *widget)
     }
 #endif
 
-    
+
     layoutState.unplug(path ,&savedState);
     savedState.fitLayout();
     currentGapPos = path;
