@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -83,17 +77,20 @@
     subwindows. This information could be used in a popup menu
     containing a list of windows, for example.
 
-    \omit
-        // does this still hold?
-        This feature is also
-        available as part of the \l{Window Menu} Solution.
-    \endomit
+    The subwindows are sorted by the the current
+    \l{QMdiArea::}{WindowOrder}. This is used for the subWindowList()
+    and for activateNextSubWindow() and acivatePreviousSubWindow().
+    Also, it is used when cascading or tiling the windows with
+    cascadeSubWindows() and tileSubWindows().
 
     QMdiArea provides two built-in layout strategies for
     subwindows: cascadeSubWindows() and tileSubWindows(). Both are
     slots and are easily connected to menu entries.
 
-    \img qmdiarea-arrange.png
+    \table
+    \row \o \inlineimage mdi-cascade.png
+         \o \inlineimage mdi-tile.png
+    \endtable
 
     \note The default scroll bar property for QMdiArea is Qt::ScrollBarAlwaysOff.
 
@@ -278,7 +275,14 @@ static inline QString tabTextFor(QMdiSubWindow *subWindow)
     if (!subWindow)
         return QString();
 
-    const QString title = subWindow->windowTitle();
+    QString title = subWindow->windowTitle();
+    if (subWindow->isWindowModified()) {
+        title.replace(QLatin1String("[*]"), QLatin1String("*"));
+    } else {
+        extern QString qt_setWindowTitle_helperHelper(const QString&, const QWidget*);
+        title = qt_setWindowTitle_helperHelper(title, subWindow);
+    }
+
     return title.isEmpty() ? QMdiArea::tr("(Untitled)") : title;
 }
 
@@ -550,9 +554,6 @@ QPoint MinOverlapPlacer::place(const QSize &size, const QList<QRect> &rects,
 
 
 #ifndef QT_NO_TABBAR
-/*!
-    \internal
-*/
 class QMdiAreaTabBar : public QTabBar
 {
 public:
@@ -560,7 +561,9 @@ public:
 
 protected:
     void mousePressEvent(QMouseEvent *event);
+#ifndef QT_NO_CONTEXTMENU
     void contextMenuEvent(QContextMenuEvent *event);
+#endif
 
 private:
     QMdiSubWindow *subWindowFromIndex(int index) const;
@@ -585,6 +588,7 @@ void QMdiAreaTabBar::mousePressEvent(QMouseEvent *event)
     subWindow->close();
 }
 
+#ifndef QT_NO_CONTEXTMENU
 /*!
     \internal
 */
@@ -626,6 +630,7 @@ void QMdiAreaTabBar::contextMenuEvent(QContextMenuEvent *event)
     subWindowPrivate->updateActions();
 #endif // QT_NO_MENU
 }
+#endif // QT_NO_CONTEXTMENU
 
 /*!
     \internal
@@ -893,7 +898,7 @@ void QMdiAreaPrivate::rearrange(Rearranger *rearranger)
 
     QList<QWidget *> widgets;
     const bool reverseList = rearranger->type() == Rearranger::RegularTiler;
-    const QList<QMdiSubWindow *> subWindows = subWindowList(QMdiArea::StackingOrder, reverseList);
+    const QList<QMdiSubWindow *> subWindows = subWindowList(activationOrder, reverseList);
     QSize minSubWindowSize;
     foreach (QMdiSubWindow *child, subWindows) {
         if (!sanityCheck(child, "QMdiArea::rearrange") || !child->isVisible())
@@ -979,7 +984,7 @@ void QMdiAreaPrivate::activateCurrentWindow()
     QMdiSubWindow *current = q_func()->currentSubWindow();
     if (current && !isExplicitlyDeactivated(current)) {
         current->d_func()->activationEnabled = true;
-        current->d_func()->setActive(true);
+        current->d_func()->setActive(true, /*changeFocus=*/false);
     }
 }
 
@@ -1380,6 +1385,19 @@ QMdiAreaPrivate::subWindowList(QMdiArea::WindowOrder order, bool reversed) const
     return list;
 }
 
+/*!
+    \internal
+*/
+void QMdiAreaPrivate::disconnectSubWindow(QObject *subWindow)
+{
+    if (!subWindow)
+        return;
+
+    Q_Q(QMdiArea);
+    QObject::disconnect(subWindow, 0, q, 0);
+    subWindow->removeEventFilter(q);
+}
+
 /*!
     \internal
 */
@@ -1461,6 +1479,8 @@ void QMdiAreaPrivate::highlightNextSubWindow(int increaseFactor)
 #ifndef QT_NO_RUBBERBAND
     if (!rubberBand) {
         rubberBand = new QRubberBand(QRubberBand::Rectangle, viewport);
+        // For accessibility to identify this special widget.
+        rubberBand->setObjectName(QLatin1String("qt_rubberband"));
         rubberBand->setWindowFlags(rubberBand->windowFlags() | Qt::WindowStaysOnTopHint);
     }
 #endif
@@ -1477,6 +1497,7 @@ void QMdiAreaPrivate::highlightNextSubWindow(int increaseFactor)
 
 /*!
     \internal
+    \since 4.4
 */
 void QMdiAreaPrivate::setViewMode(QMdiArea::ViewMode mode)
 {
@@ -1895,8 +1916,6 @@ QMdiSubWindow *QMdiArea::addSubWindow(QWidget *widget, Qt::WindowFlags windowFla
     QWidget *childFocus = widget->focusWidget();
     QMdiSubWindow *child = qobject_cast<QMdiSubWindow *>(widget);
 
-    const bool wasNativeViewport = d->viewport->internalWinId() != 0;
-
     // Widget is already a QMdiSubWindow
     if (child) {
         if (d->childWindows.indexOf(child) != -1) {
@@ -1912,15 +1931,6 @@ QMdiSubWindow *QMdiArea::addSubWindow(QWidget *widget, Qt::WindowFlags windowFla
         Q_ASSERT(child->testAttribute(Qt::WA_DeleteOnClose));
     }
 
-    // Enforce native sub-window if other sub-windows are native.
-    if (wasNativeViewport) {
-        child->setAttribute(Qt::WA_NativeWindow);
-    // We just added a native sub-window, which means all other sub-windows must be native.
-    } else if (d->viewport->internalWinId() || widget->testAttribute(Qt::WA_NativeWindow)) {
-        foreach (QMdiSubWindow *subWindow, d->childWindows)
-            subWindow->setAttribute(Qt::WA_NativeWindow);
-    }
-
     if (childFocus)
         childFocus->setFocus();
     d->appendChild(child);
@@ -1952,6 +1962,7 @@ void QMdiArea::removeSubWindow(QWidget *widget)
             qWarning("QMdiArea::removeSubWindow: window is not inside workspace");
             return;
         }
+        d->disconnectSubWindow(child);
         d->childWindows.removeAll(child);
         d->indicesToActivatedChildren.removeAll(index);
         d->updateActiveWindow(index, d->active == child);
@@ -2274,6 +2285,7 @@ bool QMdiArea::viewportEvent(QEvent *event)
                     if (mdiChild && mdiChild->isMaximized())
                         d->showActiveWindowMaximized = true;
                 }
+                d->disconnectSubWindow(child);
                 const bool activeRemoved = i == d->indicesToActivatedChildren.at(0);
                 d->childWindows.removeAt(i);
                 d->indicesToActivatedChildren.removeAll(i);
@@ -2381,7 +2393,7 @@ bool QMdiArea::event(QEvent *event)
         }
         break;
     case QEvent::Hide:
-        d->setActive(d->active, false);
+        d->setActive(d->active, false, false);
         d->setChildActivationEnabled(false);
         break;
 #ifndef QT_NO_TABBAR
@@ -2462,7 +2474,7 @@ bool QMdiArea::eventFilter(QObject *object, QEvent *event)
             && isVisible() && !window()->isMinimized()) {
             d->activateCurrentWindow();
         } else if (event->type() == QEvent::ApplicationDeactivate && d->active) {
-            d->setActive(d->active, false);
+            d->setActive(d->active, false, false);
         }
         return QAbstractScrollArea::eventFilter(object, event);
     }
@@ -2497,6 +2509,7 @@ bool QMdiArea::eventFilter(QObject *object, QEvent *event)
 #endif
 #ifndef QT_NO_TABBAR
     case QEvent::WindowTitleChange:
+    case QEvent::ModifiedChange:
         if (d->tabBar)
             d->tabBar->setTabText(d->childWindows.indexOf(subWindow), tabTextFor(subWindow));
         break;
