@@ -1,38 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -58,6 +57,8 @@
 #include "QtCore/qbasictimer.h"
 #include "private/qwidget_p.h"
 
+QT_BEGIN_NAMESPACE
+
 #ifndef QT_NO_MENU
 
 class QTornOffMenu;
@@ -73,15 +74,31 @@ struct QMacMenuAction {
 };
 #endif
 
+#ifdef Q_OS_WINCE
+struct QWceMenuAction {
+    uint command;    
+    QPointer<QAction> action;
+    HMENU menuHandle;
+    QWceMenuAction() : menuHandle(0), command(0) {}
+};
+#endif
+
 class QMenuPrivate : public QWidgetPrivate
 {
     Q_DECLARE_PUBLIC(QMenu)
 public:
-    QMenuPrivate() : itemsDirty(0), maxIconWidth(0), tabWidth(0), ncols(0), collapsibleSeparators(true), hasHadMouse(0), motions(0),
+    QMenuPrivate() : itemsDirty(0), maxIconWidth(0), tabWidth(0), ncols(0),
+                      collapsibleSeparators(true), hasHadMouse(0), aboutToHide(0), motions(0),
                       currentAction(0), scroll(0), eventLoop(0), tearoff(0), tornoff(0), tearoffHighlighted(0),
                       hasCheckableItems(0), sloppyAction(0)
 #ifdef Q_WS_MAC
                       ,mac_menu(0)
+#endif
+#if defined(Q_OS_WINCE) && !defined(QT_NO_MENUBAR)
+                      ,wce_menu(0)
+#endif
+#ifdef QT3_SUPPORT
+                      ,emitHighlighted(false)
 #endif
     { }
     ~QMenuPrivate()
@@ -89,6 +106,9 @@ public:
         delete scroll;
 #ifdef Q_WS_MAC
         delete mac_menu;
+#endif
+#if defined(Q_OS_WINCE) && !defined(QT_NO_MENUBAR)
+        delete wce_menu;
 #endif
     }
     void init();
@@ -111,6 +131,7 @@ public:
     static QPointer<QMenu> mouseDown;
     QPoint mousePopupPos;
     uint hasHadMouse : 1;
+    uint aboutToHide : 1;
     int motions;
     QAction *currentAction;
     static QBasicTimer menuDelayTimer;
@@ -159,6 +180,7 @@ public:
     virtual QList<QPointer<QWidget> > calcCausedStack() const;
     QMenuCaused causedPopup;
     void hideUpToMenuBar();
+    void hideMenu(QMenu *menu);
 
     //index mappings
     inline QAction *actionAt(int i) const { return q_func()->actions().at(i); }
@@ -223,9 +245,42 @@ public:
     void setMacMenuEnabled(bool enable = true);
 #endif
 
+    QPointer<QAction> actionAboutToTrigger;
+#ifdef QT3_SUPPORT
+    bool emitHighlighted;
+#endif
+
+#if defined(Q_OS_WINCE) && !defined(QT_NO_MENUBAR)
+    struct QWceMenuPrivate {
+        QList<QWceMenuAction*> actionItems;
+        HMENU menuHandle;
+        QWceMenuPrivate();
+        ~QWceMenuPrivate();        
+        void addAction(QAction *, QWceMenuAction* =0);
+        void addAction(QWceMenuAction *, QWceMenuAction* =0);
+        void syncAction(QWceMenuAction *);
+        inline void syncAction(QAction *a) { syncAction(findAction(a)); }
+        void removeAction(QWceMenuAction *);
+        void rebuild(bool reCreate = false);
+        inline void removeAction(QAction *a) { removeAction(findAction(a)); }
+        inline QWceMenuAction *findAction(QAction *a) {
+            for(int i = 0; i < actionItems.size(); i++) {
+                QWceMenuAction *act = actionItems[i];
+                if(a == act->action)
+                    return act;
+            }
+            return 0;
+        }
+    } *wce_menu;
+    HMENU wceMenu(bool create = false);
+    QAction* wceCommands(uint command);
+#endif
+
     QPointer<QWidget> noReplayFor;
 };
 
 #endif // QT_NO_MENU
 
+QT_END_NAMESPACE
+
 #endif // QMENU_P_H
