@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -183,7 +177,7 @@ QSizeF QPlainTextDocumentLayout::documentSize() const
 QRectF QPlainTextDocumentLayout::frameBoundingRect(QTextFrame *) const
 {
     Q_D(const QPlainTextDocumentLayout);
-    return QRectF(0, 0, d->width, INT_MAX);
+    return QRectF(0, 0, d->width, qreal(INT_MAX));
 }
 
 /*!
@@ -679,7 +673,10 @@ void QPlainTextEditPrivate::setTopBlock(int newTopBlock, int newTopLine)
 
     if (doc->blockCount() < SMALL_DOCUMENT_BLOCK_COUNT) {
         int lineNumber = lineCount(newTopBlock) + newTopLine;
-        vbar->setValue(lineNumber);
+        if (vbar->value() == lineNumber)
+            q->QPlainTextEdit::scrollContentsBy(0, 0);
+        else
+            vbar->setValue(lineNumber);
         return;
     }
 
@@ -973,7 +970,6 @@ void QPlainTextEditPrivate::_q_adjustScrollbars()
     int vmax = (blockCount < SMALL_DOCUMENT_BLOCK_COUNT ? lineCount() : blockCount) - 1;
     lastTopLineInMaximumBlock = -1;
 
-
     if (!centerOnScroll) {
         QTextBlock block = doc->lastBlock();
         QRect visible = viewport->rect();
@@ -1196,9 +1192,9 @@ void QPlainTextEditPrivate::ensureViewportLayouted()
    different and simplified text layout called
    QPlainTextDocumentLayout on the text document (see
    QTextDocument::setDocumentLayout()). The plain text document layout
-   does not support tables nor embedded frames, and replaces a
+   does not support tables nor embedded frames, and \e{replaces a
    pixel-exact height calculation with a line-by-line respectively
-   paragraph-by-paragraph scrolling approach. This makes it possible
+   paragraph-by-paragraph scrolling approach}. This makes it possible
    to handle significantly larger documents, and still resize the
    editor with line wrap enabled in real time. It also makes for a
    fast log viewer (see setMaximumBlockCount()).
@@ -1212,9 +1208,10 @@ void QPlainTextEditPrivate::ensureViewportLayouted()
 /*!
     \property QPlainTextEdit::plainText
 
-    This property gets and sets the plain text edit's
-    contents. Previous contents are removed and undo/redo history is
-    reset when the property is set.
+    This property gets and sets the plain text editor's contents. The previous
+    contents are removed and undo/redo history is reset when this property is set.
+
+    By default, for an editor with no contents, this property contains an empty string.
 */
 
 /*!
@@ -1223,6 +1220,8 @@ void QPlainTextEditPrivate::ensureViewportLayouted()
 
     Users are only able to undo or redo actions if this property is
     true, and if there is an action that can be undone (or redone).
+
+    By default, this property is true.
 */
 
 /*!
@@ -1459,6 +1458,7 @@ bool QPlainTextEdit::event(QEvent *e)
 {
     Q_D(QPlainTextEdit);
 
+#ifndef QT_NO_CONTEXTMENU
     if (e->type() == QEvent::ContextMenu
         && static_cast<QContextMenuEvent *>(e)->reason() == QContextMenuEvent::Keyboard) {
         ensureCursorVisible();
@@ -1468,7 +1468,9 @@ bool QPlainTextEdit::event(QEvent *e)
         const bool result = QAbstractScrollArea::event(&ce);
         e->setAccepted(ce.isAccepted());
         return result;
-    } else if (e->type() == QEvent::ShortcutOverride
+    }
+#endif // QT_NO_CONTEXTMENU
+    if (e->type() == QEvent::ShortcutOverride
                || e->type() == QEvent::ToolTip) {
         d->sendControlEvent(e);
     }
@@ -1969,6 +1971,7 @@ bool QPlainTextEdit::focusNextPrevChild(bool next)
     return QAbstractScrollArea::focusNextPrevChild(next);
 }
 
+#ifndef QT_NO_CONTEXTMENU
 /*!
   \fn void QPlainTextEdit::contextMenuEvent(QContextMenuEvent *event)
 
@@ -1982,13 +1985,14 @@ bool QPlainTextEdit::focusNextPrevChild(bool next)
 
   Information about the event is passed in the \a event object.
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qplaintextedit.cpp 0
+  \snippet doc/src/snippets/code/src_gui_widgets_qplaintextedit.cpp 0
 */
 void QPlainTextEdit::contextMenuEvent(QContextMenuEvent *e)
 {
     Q_D(QPlainTextEdit);
     d->sendControlEvent(e);
 }
+#endif // QT_NO_CONTEXTMENU
 
 #ifndef QT_NO_DRAGANDDROP
 /*! \reimp
@@ -2219,6 +2223,16 @@ QRect QPlainTextEdit::cursorRect() const
 
 /*!
    \property QPlainTextEdit::overwriteMode
+   \brief whether text entered by the user will overwrite existing text
+
+   As with many text editors, the plain text editor widget can be configured
+   to insert or overwrite existing text with new text entered by the user.
+
+   If this property is true, existing text is overwritten, character-for-character
+   by new text; otherwise, text is inserted at the cursor position, displacing
+   existing text.
+
+   By default, this property is false (new text does not overwrite existing text).
 */
 
 bool QPlainTextEdit::overwriteMode() const
@@ -2236,6 +2250,8 @@ void QPlainTextEdit::setOverwriteMode(bool overwrite)
 /*!
     \property QPlainTextEdit::tabStopWidth
     \brief the tab stop width in pixels
+
+    By default, this property contains a value of 80.
 */
 
 int QPlainTextEdit::tabStopWidth() const
@@ -2434,7 +2450,7 @@ QTextCharFormat QPlainTextEdit::currentCharFormat() const
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qplaintextedit.cpp 1
+    \snippet doc/src/snippets/code/src_gui_widgets_qplaintextedit.cpp 1
  */
 void QPlainTextEdit::insertPlainText(const QString &text)
 {
@@ -2506,6 +2522,8 @@ void QPlainTextEdit::setTabChangesFocus(bool b)
 /*!
     \property QPlainTextEdit::documentTitle
     \brief the title of the document parsed from the text.
+
+    By default, this property contains an empty string.
 */
 
 /*!
@@ -2544,6 +2562,8 @@ void QPlainTextEdit::setLineWrapMode(LineWrapMode wrap)
     \property QPlainTextEdit::wordWrapMode
     \brief the mode QPlainTextEdit will use when wrapping text by words
 
+    By default, this property is set to QTextOption::WrapAtWordBoundaryOrAnywhere.
+
     \sa QTextOption::WrapMode
 */
 
@@ -2568,9 +2588,9 @@ void QPlainTextEdit::setWordWrapMode(QTextOption::WrapMode mode)
 
     If set to true, the plain text edit paints the palette background
     on the viewport area not covered by the text document. Otherwise,
-    if set to false, it won't. The feature makes it possible for 
-    the user to visually distinguish between the area of the document,   
-    painted with the base color of the palette, and the empty 
+    if set to false, it won't. The feature makes it possible for
+    the user to visually distinguish between the area of the document,
+    painted with the base color of the palette, and the empty
     area not covered by any document.
 
     The default is false.
@@ -2715,7 +2735,7 @@ void QPlainTextEditPrivate::append(const QString &text, Qt::TextFormat format)
         document->setMaximumBlockCount(0);
 
     int voffset = verticalOffset();
-    const bool atBottom =  control->blockBoundingRect(document->lastBlock()).bottom() + voffset - MARGIN - 1
+    const bool atBottom =  control->blockBoundingRect(document->lastBlock()).bottom() - voffset
                            <= viewport->rect().bottom();
 
     QSizeF documentSize = documentLayout->documentSize();
@@ -2749,12 +2769,11 @@ void QPlainTextEditPrivate::append(const QString &text, Qt::TextFormat format)
     }
 
     documentLayout->priv()->blockDocumentSizeChanged = documentSizeChangedBlocked;
-    if (documentSize != documentLayout->documentSize())
-        _q_adjustScrollbars();
+    _q_adjustScrollbars();
 
     if (atBottom) {
         QTextBlock lastBlock = document->lastBlock();
-        ensureVisible(lastBlock.position() + lastBlock.length() - 1, false);
+        ensureVisible(lastBlock.position() + lastBlock.length() - 1, centerOnScroll);
     }
 }
 
@@ -2880,6 +2899,8 @@ QRectF QPlainTextEdit::blockBoundingRect(const QTextBlock &block) const
 /*!
     \property QPlainTextEdit::blockCount
     \brief the number of text blocks in the document.
+
+    By default, in an empty document, this property contains a value of 1.
 */
 int QPlainTextEdit::blockCount() const
 {
