@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -252,12 +246,12 @@ void QValidator::fixup(QString &) const
 
     Example of use:
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qvalidator.cpp 0
+    \snippet doc/src/snippets/code/src_gui_widgets_qvalidator.cpp 0
 
     Below we present some examples of validators. In practice they would
     normally be associated with a widget as in the example above.
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qvalidator.cpp 1
+    \snippet doc/src/snippets/code/src_gui_widgets_qvalidator.cpp 1
 
     The minimum and maximum values are set in one call with setRange(),
     or individually with setBottom() and setTop().
@@ -355,7 +349,7 @@ QIntValidator::~QIntValidator()
     the user might be just about to type the minus (especially for right-to-left
     languages).
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qvalidator.cpp 2
+    \snippet doc/src/snippets/code/src_gui_widgets_qvalidator.cpp 2
 
     By default, the \a pos parameter is not used by this validator.
 */
@@ -429,6 +423,9 @@ void QIntValidator::setRange(int bottom, int top)
     \property QIntValidator::bottom
     \brief the validator's lowest acceptable value
 
+    By default, this property's value is derived from the lowest signed
+    integer available (typically -2147483647).
+
     \sa setRange()
 */
 void QIntValidator::setBottom(int bottom)
@@ -440,6 +437,9 @@ void QIntValidator::setBottom(int bottom)
     \property QIntValidator::top
     \brief the validator's highest acceptable value
 
+    By default, this property's value is derived from the highest signed
+    integer available (typically 2147483647).
+
     \sa setRange()
 */
 void QIntValidator::setTop(int top)
@@ -690,6 +690,8 @@ void QDoubleValidator::setRange(double minimum, double maximum, int decimals)
     \property QDoubleValidator::bottom
     \brief the validator's minimum acceptable value
 
+    By default, this property contains a value of -infinity.
+
     \sa setRange()
 */
 
@@ -703,6 +705,8 @@ void QDoubleValidator::setBottom(double bottom)
     \property QDoubleValidator::top
     \brief the validator's maximum acceptable value
 
+    By default, this property contains a value of infinity.
+
     \sa setRange()
 */
 
@@ -715,6 +719,8 @@ void QDoubleValidator::setTop(double top)
     \property QDoubleValidator::decimals
     \brief the validator's maximum number of digits after the decimal point
 
+    By default, this property contains a value of 1000.
+
     \sa setRange()
 */
 
@@ -728,6 +734,8 @@ void QDoubleValidator::setDecimals(int decimals)
     \since 4.3
     \brief the notation of how a string can describe a number
 
+    By default, this property is set to ScientificNotation.
+
     \sa Notation
 */
 
@@ -768,12 +776,12 @@ QDoubleValidator::Notation QDoubleValidator::notation() const
     For a brief introduction to Qt's regexp engine, see \l QRegExp.
 
     Example of use:
-    \snippet doc/src/snippets/code/src.gui.widgets.qvalidator.cpp 3
+    \snippet doc/src/snippets/code/src_gui_widgets_qvalidator.cpp 3
 
     Below we present some examples of validators. In practice they would
     normally be associated with a widget as in the example above.
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qvalidator.cpp 4
+    \snippet doc/src/snippets/code/src_gui_widgets_qvalidator.cpp 4
 
     \sa QRegExp, QIntValidator, QDoubleValidator, {Settings Editor Example}
 */
@@ -873,6 +881,9 @@ QValidator::State QRegExpValidator::validate(QString &input, int& pos) const
 /*!
     \property QRegExpValidator::regExp
     \brief the regular expression used for validation
+
+    By default, this property contains a regular expression with the pattern \c{.*}
+    that matches any string.
 */
 
 void QRegExpValidator::setRegExp(const QRegExp& rx)
