@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -278,8 +272,8 @@ QByteArray QHttpNetworkRequestPrivate::header(const QHttpNetworkRequest &request
     ba += " HTTP/" + majorVersion.toLatin1() + "." + minorVersion.toLatin1() + "\r\n";
 
     QList<QPair<QByteArray, QByteArray> > fields = request.header();
-    QList<QPair<QByteArray, QByteArray> >::const_iterator it = fields.begin();
-    for (; it != fields.end(); ++it)
+    QList<QPair<QByteArray, QByteArray> >::const_iterator it = fields.constBegin();
+    for (; it != fields.constEnd(); ++it)
         ba += it->first + ": " + it->second + "\r\n";
     if (request.d->operation == QHttpNetworkRequest::Post) {
         // add content type, if not set in the request
@@ -505,10 +499,10 @@ bool QHttpNetworkReplyPrivate::gzipCheckHeader(QByteArray &content, int &pos)
             return ret;
     }
     if ((flags & ORIG_NAME) != 0) { // skip the original file name
-        while(++pos <= maxPos && body[pos]);
+        while(++pos <= maxPos && body[pos]) {}
     }
     if ((flags & COMMENT) != 0) {   // skip the .gz file comment
-        while(++pos <= maxPos && body[pos]);
+        while(++pos <= maxPos && body[pos]) {}
     }
     if ((flags & HEAD_CRC) != 0) {  // skip the header crc
         pos += 2;
@@ -633,8 +627,8 @@ qint64 QHttpNetworkReplyPrivate::readHeader(QAbstractSocket *socket)
     while (!allHeaders && socket->bytesAvailable()) {
         if (socket->peek(&c, 1) == 1 && c == '\n') {
             // check for possible header endings. As per HTTP rfc, 
-            // the header endings will be marked by CFLFCRLF. But 
-            // we will allow CFLFLF, LFLF & CRLFLF
+            // the header endings will be marked by CRLFCRLF. But 
+            // we will allow CRLFLF, LFLF & CRLFCRLF
             if (fragment.endsWith("\n\r") || fragment.endsWith('\n')) 
                 allHeaders = true;
         }
@@ -1154,7 +1148,7 @@ bool QHttpNetworkConnectionPrivate::ensureConnection(QAbstractSocket *socket)
 
 #ifndef QT_NO_NETWORKPROXY
         // HTTPS always use transparent proxy.
-        if (networkProxy.type() == QNetworkProxy::HttpCachingProxy && !encrypt) {
+        if (networkProxy.type() != QNetworkProxy::NoProxy && !encrypt) {
             connectHost = networkProxy.hostName();
             connectPort = networkProxy.port();
         }
@@ -1218,7 +1212,7 @@ bool QHttpNetworkConnectionPrivate::sendRequest(QAbstractSocket *socket)
         createAuthorization(socket, channels[i].request);
 #ifndef QT_NO_NETWORKPROXY
         QByteArray header = QHttpNetworkRequestPrivate::header(channels[i].request,
-            (networkProxy.type() == QNetworkProxy::HttpCachingProxy));
+            (networkProxy.type() != QNetworkProxy::NoProxy));
 #else
         QByteArray header = QHttpNetworkRequestPrivate::header(channels[i].request,
             false);
@@ -1405,6 +1399,10 @@ void QHttpNetworkConnectionPrivate::receiveReply(QAbstractSocket *socket, QHttpN
                 } else {
                     reply->d_func()->autoDecompress = false;
                 }
+                if (reply && reply->d_func()->statusCode == 100) {
+                    reply->d_func()->state = QHttpNetworkReplyPrivate::ReadingStatusState;
+                    break; // ignore
+                }
                 if (emitSignals(reply))
                     emit reply->headerChanged();
                 if (!expectContent(reply)) {
@@ -1458,7 +1456,7 @@ void QHttpNetworkConnectionPrivate::allDone(QAbstractSocket *socket, QHttpNetwor
 {
 #ifndef QT_NO_COMPRESS
     // expand the whole data.
-    if (reply->d_func()->autoDecompress && !reply->d_func()->streamEnd)
+    if (expectContent(reply) && reply->d_func()->autoDecompress && !reply->d_func()->streamEnd)
         expand(socket, reply, true); // ### if expand returns false, its an error
 #endif
     // while handling 401 & 407, we might reset the status code, so save this.
@@ -1537,8 +1535,8 @@ bool QHttpNetworkConnectionPrivate::handleAuthenticateChallenge(QAbstractSocket
     //create the response header to be used with QAuthenticatorPrivate.
     QHttpResponseHeader responseHeader;
     QList<QPair<QByteArray, QByteArray> > fields = reply->header();
-    QList<QPair<QByteArray, QByteArray> >::const_iterator it = fields.begin();
-    while (it != fields.end()) {
+    QList<QPair<QByteArray, QByteArray> >::const_iterator it = fields.constBegin();
+    while (it != fields.constEnd()) {
         responseHeader.addValue(QString::fromLatin1(it->first), QString::fromUtf8(it->second));
         it++;
     }
