@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -64,7 +58,7 @@ enum {
 static QByteArray makeCacheKey(const QUrl &url)
 {
     QUrl copy = url;
-    bool isEncrypted = url.scheme() == QLatin1String("https");
+    bool isEncrypted = url.scheme().toLower() == QLatin1String("https");
     copy.setPort(url.port(isEncrypted ? DefaultHttpsPort : DefaultHttpPort));
     return "http-connection:" + copy.toEncoded(QUrl::RemovePassword | QUrl::RemovePath |
                                                QUrl::RemoveQuery | QUrl::RemoveFragment);
@@ -88,13 +82,14 @@ QNetworkAccessHttpBackendFactory::create(QNetworkAccessManager::Operation op,
     }
 
     QUrl url = request.url();
-    if (url.scheme() == QLatin1String("http") || url.scheme() == QLatin1String("https"))
+    QString scheme = url.scheme().toLower();
+    if (scheme == QLatin1String("http") || scheme == QLatin1String("https"))
         return new QNetworkAccessHttpBackend;
 
     return 0;
 }
 
-static QNetworkReply::NetworkError statusCodeFromHttp(int httpStatusCode)
+static QNetworkReply::NetworkError statusCodeFromHttp(int httpStatusCode, const QUrl &url)
 {
     QNetworkReply::NetworkError code;
     // we've got an error
@@ -119,12 +114,12 @@ static QNetworkReply::NetworkError statusCodeFromHttp(int httpStatusCode)
         if (httpStatusCode > 500) {
             // some kind of server error
             code = QNetworkReply::ProtocolUnknownError;
-        } else if (httpStatusCode > 400) {
+        } else if (httpStatusCode >= 400) {
             // content error we did not handle above
             code = QNetworkReply::UnknownContentError;
         } else {
-            qWarning("QNetworkAccess: got HTTP status code %d which is not expected",
-                     httpStatusCode);
+            qWarning("QNetworkAccess: got HTTP status code %d which is not expected from url: \"%s\"",
+                     httpStatusCode, qPrintable(url.toString()));
             code = QNetworkReply::ProtocolFailure;
         }
     }
@@ -309,7 +304,7 @@ void QNetworkAccessHttpBackend::postRequest()
 void QNetworkAccessHttpBackend::open()
 {
     QUrl url = request().url();
-    bool encrypt = url.scheme() == QLatin1String("https");
+    bool encrypt = url.scheme().toLower() == QLatin1String("https");
     setAttribute(QNetworkRequest::ConnectionEncryptedAttribute, encrypt);
 
     // set the port number in the reply if it wasn't set
@@ -324,10 +319,14 @@ void QNetworkAccessHttpBackend::open()
 
 #ifndef QT_NO_NETWORKPROXY
         QNetworkProxy networkProxy = proxy();
-        if (encrypt || networkProxy.type() == QNetworkProxy::HttpProxy)
-            http->setTransparentProxy(networkProxy);
-        else
+        if (!encrypt && (networkProxy.type() == QNetworkProxy::HttpCachingProxy
+                         || networkProxy.type() == QNetworkProxy::HttpProxy)) {
             http->setCacheProxy(networkProxy);
+            http->setTransparentProxy(QNetworkProxy::NoProxy);
+        } else {
+            http->setTransparentProxy(networkProxy);
+            http->setCacheProxy(QNetworkProxy::NoProxy);
+        }
 #endif
 
         cache->addEntry(cacheKey, http);
@@ -560,7 +559,7 @@ void QNetworkAccessHttpBackend::replyFinished()
         QString msg = QLatin1String(QT_TRANSLATE_NOOP("QNetworkReply",
                                                       "Error downloading %1 - server replied: %2"));
         msg = msg.arg(url().toString(), httpReply->reasonPhrase());
-        error(statusCodeFromHttp(httpReply->statusCode()), msg);
+        error(statusCodeFromHttp(httpReply->statusCode(), httpReply->url()), msg);
     }
     finished();
 }
@@ -593,7 +592,11 @@ void QNetworkAccessHttpBackend::replyHeaderChanged()
         // What do we do about the caching of the HTML note?
         // The response to a 303 MUST NOT be cached, while the response to
         // all of the others is cacheable if the headers indicate it to be
-        redirectionRequested(QUrl::fromEncoded(rawHeader("location")));
+        QByteArray header = rawHeader("location");
+        QUrl url = QUrl::fromEncoded(header);
+        if (!url.isValid())
+            url = QUrl(QLatin1String(header));
+        redirectionRequested(url);
     }
 
     metaDataChanged();
