@@ -1,49 +1,45 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
 #include "qlocalsocket.h"
 #include "qlocalsocket_p.h"
 
+#ifndef QT_NO_LOCALSOCKET
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -213,18 +209,6 @@ void QLocalSocketPrivate::errorOccurred(QLocalSocket::LocalSocketError error, co
         q->emit stateChanged(state);
 }
 
-/*!
-    Attempts to make a connection to \a name.
-
-    The socket is opened in the given \a openMode and first enters ConnectingState.
-    It then attempts to connect to the address or addresses returned by the lookup.
-    Finally, if a connection is established, QLocalSocket enters ConnectedState
-    and emits connected().
-
-    At any point, the socket can emit error() to signal that an error occurred.
-
-    See also state(), serverName(), and waitForConnected().
-  */
 void QLocalSocket::connectToServer(const QString &name, OpenMode openMode)
 {
     Q_D(QLocalSocket);
@@ -287,7 +271,7 @@ void QLocalSocketPrivate::_q_connectToSocket()
 
     struct sockaddr_un name;
     name.sun_family = PF_UNIX;
-    if (sizeof(sockaddr_un) < (uint)connectingPathName.toLatin1().size()) {
+    if (sizeof(name.sun_path) < (uint)connectingPathName.toLatin1().size() + 1) {
         QString function = QLatin1String("QLocalSocket::connectToServer");
         errorOccurred(QLocalSocket::ServerNotFoundError, function);
         return;
@@ -343,7 +327,7 @@ void QLocalSocketPrivate::_q_connectToSocket()
     fullServerName = connectingPathName;
     if (unixSocket.setSocketDescriptor(connectingSocket,
         QAbstractSocket::ConnectedState, connectingOpenMode)) {
-        q->setOpenMode(connectingOpenMode);
+        q->QIODevice::open(connectingOpenMode);
         q->emit connected();
     } else {
         QString function = QLatin1String("QLocalSocket::connectToServer");
@@ -354,18 +338,6 @@ void QLocalSocketPrivate::_q_connectToSocket()
     connectingOpenMode = 0;
 }
 
-/*!
-    Initializes QLocalSocket with the native socket descriptor
-    \a socketDescriptor. Returns true if socketDescriptor is accepted
-    as a valid socket descriptor; otherwise returns false. The socket is
-    opened in the mode specified by \a openMode, and enters the socket state
-    specified by \a socketState.
-
-    Note: It is not possible to initialize two local sockets with the same
-    native socket descriptor.
-
-    \sa socketDescriptor(), state(), openMode()
- */
 bool QLocalSocket::setSocketDescriptor(quintptr socketDescriptor,
         LocalSocketState socketState, OpenMode openMode)
 {
@@ -385,7 +357,7 @@ bool QLocalSocket::setSocketDescriptor(quintptr socketDescriptor,
         newSocketState = QAbstractSocket::UnconnectedState;
         break;
     }
-    setOpenMode(openMode);
+    QIODevice::open(openMode);
     d->state = socketState;
     return d->unixSocket.setSocketDescriptor(socketDescriptor,
                                              newSocketState, openMode);
@@ -397,82 +369,48 @@ void QLocalSocketPrivate::_q_abortConnectionAttempt()
     q->close();
 }
 
-/*!
-    Returns the native socket descriptor of the QLocalSocket object if
-    this is available; otherwise returns -1.
-
-    The socket descriptor is not available when QLocalSocket
-    is in UnconnectedState.
-
-    \sa setSocketDescriptor()
- */
 quintptr QLocalSocket::socketDescriptor() const
 {
     Q_D(const QLocalSocket);
     return d->unixSocket.socketDescriptor();
 }
 
-/*!
-    \reimp
- */
 qint64 QLocalSocket::readData(char *data, qint64 c)
 {
     Q_D(QLocalSocket);
     return d->unixSocket.readData(data, c);
 }
 
-/*!
-    \reimp
- */
 qint64 QLocalSocket::writeData(const char *data, qint64 c)
 {
     Q_D(QLocalSocket);
     return d->unixSocket.writeData(data, c);
 }
 
-/*!
-    Aborts the current connection and resets the socket.
-    Unlike disconnectFromServer(), this function immediately closes the socket,
-    clearing any pending data in the write buffer.
-
-    \sa disconnectFromServer(), close()
- */
 void QLocalSocket::abort()
 {
     Q_D(QLocalSocket);
     d->unixSocket.abort();
 }
 
-/*!
-    \reimp
- */
 qint64 QLocalSocket::bytesAvailable() const
 {
     Q_D(const QLocalSocket);
     return QIODevice::bytesAvailable() + d->unixSocket.bytesAvailable();
 }
 
-/*!
-    \reimp
- */
 qint64 QLocalSocket::bytesToWrite() const
 {
     Q_D(const QLocalSocket);
     return d->unixSocket.bytesToWrite();
 }
 
-/*!
-    \reimp
- */
 bool QLocalSocket::canReadLine() const
 {
     Q_D(const QLocalSocket);
     return QIODevice::canReadLine() || d->unixSocket.canReadLine();
 }
 
-/*!
-    \reimp
- */
 void QLocalSocket::close()
 {
     Q_D(QLocalSocket);
@@ -495,54 +433,24 @@ void QLocalSocket::close()
     QIODevice::close();
 }
 
-/*!
-    \reimp
- */
 bool QLocalSocket::waitForBytesWritten(int msecs)
 {
     Q_D(QLocalSocket);
     return d->unixSocket.waitForBytesWritten(msecs);
 }
 
-/*!
-    This function writes as much as possible from the internal write buffer
-    to the socket, without blocking.  If any data was written, this function
-    returns true; otherwise false is returned.
-
-    Call this function if you need QLocalSocket to start sending buffered data
-    immediately. The number of bytes successfully written depends on the
-    operating system. In most cases, you do not need to call this function,
-    because QLocalSocket will start sending data automatically once control
-    goes back to the event loop. In the absence of an event loop, call
-    waitForBytesWritten() instead.
-
-    \sa write(), waitForBytesWritten()
- */
 bool QLocalSocket::flush()
 {
     Q_D(QLocalSocket);
     return d->unixSocket.flush();
 }
 
-/*!
-    Attempts to close the socket. If there is pending data waiting to be
-    written, QLocalSocket will enter ClosingState and wait until all data
-    has been written. Eventually, it will enter UnconnectedState and emit
-    the disconnectedFromServer() signal.
-
-    \sa connectToServer()
-*/
 void QLocalSocket::disconnectFromServer()
 {
     Q_D(QLocalSocket);
     d->unixSocket.disconnectFromHost();
 }
 
-/*!
-    Returns the type of error that last occurred.
-
-    \sa state(), errorString()
-*/
 QLocalSocket::LocalSocketError QLocalSocket::error() const
 {
     Q_D(const QLocalSocket);
@@ -576,71 +484,24 @@ QLocalSocket::LocalSocketError QLocalSocket::error() const
     return UnknownSocketError;
 }
 
-/*!
-    Returns true if the socket is valid and ready for use; otherwise
-    returns false.
-
-    Note: The socket's state must be ConnectedState before reading
-    and writing can occur.
-
-    \sa state()
- */
 bool QLocalSocket::isValid() const
 {
     Q_D(const QLocalSocket);
     return d->unixSocket.isValid();
 }
 
-/*!
-    Returns the size of the internal read buffer. This limits the amount of
-    data that the client can receive before you call read() or readAll().
-    A read buffer size of 0 (the default) means that the buffer has no size
-    limit, ensuring that no data is lost.
-
-    \sa setReadBufferSize(), read()
- */
 qint64 QLocalSocket::readBufferSize() const
 {
     Q_D(const QLocalSocket);
     return d->unixSocket.readBufferSize();
 }
 
-/*!
-    Sets the size of QLocalSocket's internal read buffer to be \a size bytes.
-
-    If the buffer size is limited to a certain size, QLocalSocket won't
-    buffer more than this size of data. Exceptionally, a buffer size of 0
-    means that the read buffer is unlimited and all incoming data is buffered.
-    This is the default.
-
-    This option is useful if you only read the data at certain points in
-    time (e.g., in a real-time streaming application) or if you want to
-    protect your socket against receiving too much data, which may eventually
-    cause your application to run out of memory.
-
-    \sa readBufferSize(), read()
- */
 void QLocalSocket::setReadBufferSize(qint64 size)
 {
     Q_D(QLocalSocket);
     d->unixSocket.setReadBufferSize(size);
 }
 
-/*!
-    Waits until the socket is connected, up to \a msec milliseconds. If the
-    connection has been established, this function returns true; otherwise
-    it returns false. In the case where it returns false, you can call
-    error() to determine the cause of the error.
-
-    The following example waits up to one second for a connection
-    to be established:
-
-    \snippet doc/src/snippets/code/src.network.socket.qlocalsocket_unix.cpp 0
-
-    If msecs is -1, this function will not time out.
-
-    \sa connectToServer(), connected()
- */
 bool QLocalSocket::waitForConnected(int msec)
 {
     Q_D(QLocalSocket);
@@ -678,22 +539,6 @@ bool QLocalSocket::waitForConnected(int msec)
     return (state() == ConnectedState);
 }
 
-/*!
-    Waits until the socket has disconnected, up to \a msecs
-    milliseconds. If the connection has been disconnected, this
-    function returns true; otherwise it returns false. In the case
-    where it returns false, you can call error() to determine
-    the cause of the error.
-
-    The following example waits up to one second for a connection
-    to be closed:
-
-    \snippet doc/src/snippets/code/src.network.socket.qlocalsocket_unix.cpp 1
-
-    If msecs is -1, this function will not time out.
-
-    \sa disconnectFromServer(), close()
-*/
 bool QLocalSocket::waitForDisconnected(int msecs)
 {
     Q_D(QLocalSocket);
@@ -704,18 +549,6 @@ bool QLocalSocket::waitForDisconnected(int msecs)
     return (d->unixSocket.waitForDisconnected(msecs));
 }
 
-/*!
-    This function blocks until data is available for reading and the
-    \l{QIODevice::}{readyRead()} signal has been emitted. The function
-    will timeout after \a msecs milliseconds; the default timeout is
-    30000 milliseconds.
-
-    The function returns true if data is available for reading;
-    otherwise it returns false (if an error occurred or the
-    operation timed out).
-
-    \sa waitForBytesWritten()
-*/
 bool QLocalSocket::waitForReadyRead(int msecs)
 {
     Q_D(QLocalSocket);
@@ -725,3 +558,5 @@ bool QLocalSocket::waitForReadyRead(int msecs)
 }
 
 QT_END_NAMESPACE
+
+#endif
