@@ -1,55 +1,48 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech gives permission to
-** link the code of its release of Qt with the OpenSSL project's
-** "OpenSSL" library (or modified versions of it that use the same
-** license as the "OpenSSL" library), and distribute the linked
-** executables.  You must comply with the GNU General Public License
-** version 2 or the GNU General Public License version 3 in all
-** respects for all of the code used other than the "OpenSSL" code.
-** If you modify this file, you may extend this exception to your
-** version of the file, but you are not obligated to do so.  If you do
-** not wish to do so, delete this exception statement from your
-** version of this file.
+** In addition, as a special exception, Nokia gives permission to link
+** the code of its release of Qt with the OpenSSL project's "OpenSSL"
+** library (or modified versions of it that use the same license as the
+** "OpenSSL" library), and distribute the linked executables.  You must
+** comply with the GNU General Public License versions 2.0 or 3.0 in all
+** respects for all of the code used other than the "OpenSSL" code.  If
+** you modify this file, you may extend this exception to your version
+** of the file, but you are not obligated to do so.  If you do not wish
+** to do so, delete this exception statement from your version of this
+** file.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -64,6 +57,7 @@
 
     \reentrant
     \ingroup io
+    \ingroup ssl
     \module network
 
     QSslSocket establishes a secure, encrypted TCP connection you can
@@ -84,7 +78,7 @@
     This method starts an immediate SSL handshake once the connection
     has been established.
 
-    \snippet doc/src/snippets/code/src.network.ssl.qsslsocket.cpp 0
+    \snippet doc/src/snippets/code/src_network_ssl_qsslsocket.cpp 0
 
     As with a plain QTcpSocket, QSslSocket enters the HostLookupState,
     ConnectingState, and finally the ConnectedState, if the connection
@@ -107,7 +101,7 @@
     the existing one passed in. It then initiates the SSL handshake
     by calling startServerEncryption().
 
-    \snippet doc/src/snippets/code/src.network.ssl.qsslsocket.cpp 1
+    \snippet doc/src/snippets/code/src_network_ssl_qsslsocket.cpp 1
 
     If an error occurs, QSslSocket emits the sslErrors() signal. In this
     case, if no action is taken to ignore the error(s), the connection
@@ -135,7 +129,7 @@
     waitForEncrypted(), which will block the calling thread until an
     encrypted connection has been established.
 
-    \snippet doc/src/snippets/code/src.network.ssl.qsslsocket.cpp 2
+    \snippet doc/src/snippets/code/src_network_ssl_qsslsocket.cpp 2
 
     QSslSocket provides an extensive, easy-to-use API for handling
     cryptographic ciphers, private keys, and local, peer, and
@@ -177,13 +171,14 @@
     It is either alreayd encrypted, or it is in the SSL handshake
     phase (see QSslSocket::isEncrypted()).
 
-    \value SslServerMode The socket is a client-side SSL socket.
+    \value SslServerMode The socket is a server-side SSL socket.
     It is either already encrypted, or it is in the SSL handshake
     phase (see QSslSocket::isEncrypted()).
 */
 
 /*!
     \enum QSslSocket::PeerVerifyMode
+    \since 4.4
 
     Describes the peer verification modes for QSslSocket. The default mode is
     AutoVerifyPeer, which selects an appropriate mode depending on the
@@ -233,6 +228,7 @@
 
 /*!
     \fn QSslSocket::encryptedBytesWritten(qint64 written)
+    \since 4.4
 
     This signal is emitted when QSslSocket writes its encrypted data to the
     network. The \a written parameter contains the number of bytes that were
@@ -243,7 +239,8 @@
 
 /*!
     \fn void QSslSocket::peerVerifyError(const QSslError &error)
-    
+    \since 4.4
+
     QSslSocket can emit this signal several times during the SSL handshake,
     before encryption has been established, to indicate that an error has
     occurred while establishing the identity of the peer. The \a error is
@@ -278,6 +275,8 @@
     
     Note: You cannot use Qt::QueuedConnection when connecting to this signal,
     or calling QSslSocket::ignoreSslErrors() will have no effect.
+
+    \sa peerVerifyError()
 */
 
 #include "qsslcipher.h"
@@ -375,7 +374,7 @@ QSslSocket::~QSslSocket()
 
     If the SSL handshake is successful, QSslSocket emits encrypted().
 
-    \snippet doc/src/snippets/code/src.network.ssl.qsslsocket.cpp 3
+    \snippet doc/src/snippets/code/src_network_ssl_qsslsocket.cpp 3
 
     \bold{Note:} The example above shows that text can be written to
     the socket immediately after requesting the encrypted connection,
@@ -503,6 +502,8 @@ void QSslSocket::setProtocol(QSsl::SslProtocol protocol)
 }
 
 /*!
+    \since 4.4
+
     Returns the socket's verify mode. This mode mode decides whether
     QSslSocket should request a certificate from the peer (i.e., the client
     requests a certificate from the server, or a server requesting a
@@ -521,6 +522,8 @@ QSslSocket::PeerVerifyMode QSslSocket::peerVerifyMode() const
 }
 
 /*!
+    \since 4.4
+
     Sets the socket's verify mode to \a mode. This mode decides whether
     QSslSocket should request a certificate from the peer (i.e., the client
     requests a certificate from the server, or a server requesting a
@@ -542,6 +545,8 @@ void QSslSocket::setPeerVerifyMode(QSslSocket::PeerVerifyMode mode)
 }
 
 /*!
+    \since 4.4
+
     Returns the maximum number of certificates in the peer's certificate chain
     to be checked during the SSL handshake phase, or 0 (the default) if no
     maximum depth has been set, indicating that the whole certificate chain
@@ -559,6 +564,8 @@ int QSslSocket::peerVerifyDepth() const
 }
 
 /*!
+    \since 4.4
+
     Sets the maximum number of certificates in the peer's certificate chain to
     be checked during the SSL handshake phase, to \a depth. Setting a depth of
     0 means that no maximum depth is set, indicating that the whole
@@ -608,6 +615,8 @@ qint64 QSslSocket::bytesToWrite() const
 }
 
 /*!
+    \since 4.4
+
     Returns the number of encrypted bytes that are awaiting decryption.
     Normally, this function will return 0 because QSslSocket decrypts its
     incoming data as soon as it can.
@@ -621,6 +630,8 @@ qint64 QSslSocket::encryptedBytesAvailable() const
 }
 
 /*!
+    \since 4.4
+
     Returns the number of encrypted bytes that are waiting to be written to
     the network.
 */
@@ -697,6 +708,8 @@ bool QSslSocket::flush()
 }
 
 /*!
+    \since 4.4
+
     Sets the size of QSslSocket's internal read buffer to be \a size bytes. 
 */
 void QSslSocket::setReadBufferSize(qint64 size)
@@ -732,6 +745,8 @@ void QSslSocket::abort()
 }
 
 /*!
+    \since 4.4
+
     Returns the socket's SSL configuration state. The default SSL
     configuration of a socket is to use the default ciphers,
     default CA certificates, no local private key or certificate.
@@ -755,6 +770,8 @@ QSslConfiguration QSslSocket::sslConfiguration() const
 }
 
 /*!
+    \since 4.4
+
     Sets the socket's SSL configuration to be the contents of \a configuration.
     This function sets the local certificate, the ciphers, the private key and the CA
     certificates to those stored in \a configuration.
@@ -1011,7 +1028,7 @@ void QSslSocket::setCiphers(const QList<QSslCipher> &ciphers)
     is a colon-separated list of cipher suite names. The ciphers are listed in
     order of preference, starting with the most preferred cipher. For example:
 
-    \snippet doc/src/snippets/code/src.network.ssl.qsslsocket.cpp 4
+    \snippet doc/src/snippets/code/src_network_ssl_qsslsocket.cpp 4
 
     Each cipher name in \a ciphers must be the name of a cipher in the
     list returned by supportedCiphers().  Restricting the cipher suite
@@ -1296,7 +1313,7 @@ bool QSslSocket::waitForConnected(int msecs)
     The following example waits up to one second for the socket to be
     encrypted:
 
-    \snippet doc/src/snippets/code/src.network.ssl.qsslsocket.cpp 5
+    \snippet doc/src/snippets/code/src_network_ssl_qsslsocket.cpp 5
 
     If msecs is -1, this function will not time out.
 
@@ -1342,24 +1359,38 @@ bool QSslSocket::waitForReadyRead(int msecs)
     if (d->mode == UnencryptedMode && !d->autoStartHandshake)
         return d->plainSocket->waitForReadyRead(msecs);
 
-    int oldReadBufferSize = d->readBuffer.size();
-    
+    // This function must return true if and only if readyRead() *was* emitted.
+    // So we initialize "readyReadEmitted" to false and check if it was set to true.
+    // waitForReadyRead() could be called recursively, so we can't use the same variable
+    // (the inner waitForReadyRead() may fail, but the outer one still succeeded)
+    bool readyReadEmitted = false;
+    bool *previousReadyReadEmittedPointer = d->readyReadEmittedPointer;
+    d->readyReadEmittedPointer = &readyReadEmitted;
+
     QTime stopWatch;
     stopWatch.start();
 
     if (!d->connectionEncrypted) {
         // Wait until we've entered encrypted mode, or until a failure occurs.
-        if (!waitForEncrypted(msecs))
+        if (!waitForEncrypted(msecs)) {
+            d->readyReadEmittedPointer = previousReadyReadEmittedPointer;
             return false;
-    }
-
-    while (d->plainSocket->waitForReadyRead(qt_timeout_value(msecs, stopWatch.elapsed()))) {
-        if (d->readBuffer.size() != oldReadBufferSize) {
-            // If the read buffer has grown, readyRead() must have been emitted.
-            return true;
         }
     }
-    return false;
+
+    if (!d->writeBuffer.isEmpty()) {
+        // empty our cleartext write buffer first
+        d->transmit();
+    }
+
+    // test readyReadEmitted first because either operation above
+    // (waitForEncrypted or transmit) may have set it
+    while (!readyReadEmitted &&
+           d->plainSocket->waitForReadyRead(qt_timeout_value(msecs, stopWatch.elapsed()))) {
+    }
+
+    d->readyReadEmittedPointer = previousReadyReadEmittedPointer;
+    return readyReadEmitted;
 }
 
 /*!
@@ -1381,8 +1412,10 @@ bool QSslSocket::waitForBytesWritten(int msecs)
         if (!waitForEncrypted(msecs))
             return false;
     }
-    if (!d->writeBuffer.isEmpty())
+    if (!d->writeBuffer.isEmpty()) {
+        // empty our cleartext write buffer first
         d->transmit();
+    }
 
     return d->plainSocket->waitForBytesWritten(qt_timeout_value(msecs, stopWatch.elapsed()));
 }
@@ -1564,7 +1597,7 @@ void QSslSocket::connectToHostImplementation(const QString &hostName, quint16 po
         d->plainSocket->setProxy(proxy());
 #endif
     }
-    setOpenMode(openMode);
+    QIODevice::open(openMode);
     d->plainSocket->connectToHost(hostName, port, openMode);
     d->cachedSocketDescriptor = d->plainSocket->socketDescriptor();
 }
@@ -1657,7 +1690,7 @@ qint64 QSslSocket::writeData(const char *data, qint64 len)
     \internal
 */
 QSslSocketPrivate::QSslSocketPrivate()
-    : initialized(false), plainSocket(0)
+    : initialized(false), readyReadEmittedPointer(0), plainSocket(0)
 {
     QSslConfigurationPrivate::deepCopyDefaultConfiguration(&configuration);
 }
@@ -1854,8 +1887,10 @@ void QSslSocketPrivate::createPlainSocket(QIODevice::OpenMode openMode)
     q->connect(plainSocket, SIGNAL(bytesWritten(qint64)),
                q, SLOT(_q_bytesWrittenSlot(qint64)),
                Qt::DirectConnection);
+#ifndef QT_NO_NETWORKPROXY
     q->connect(plainSocket, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)),
                q, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)));
+#endif
 
     readBuffer.clear();
     writeBuffer.clear();
@@ -1962,6 +1997,8 @@ void QSslSocketPrivate::_q_readyReadSlot()
     qDebug() << "QSslSocket::_q_readyReadSlot() -" << plainSocket->bytesAvailable() << "bytes available";
 #endif
     if (mode == QSslSocket::UnencryptedMode) {
+        if (readyReadEmittedPointer)
+            *readyReadEmittedPointer = true;
         emit q->readyRead();
         return;
     }
