@@ -1,55 +1,48 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech gives permission to
-** link the code of its release of Qt with the OpenSSL project's
-** "OpenSSL" library (or modified versions of it that use the same
-** license as the "OpenSSL" library), and distribute the linked
-** executables.  You must comply with the GNU General Public License
-** version 2 or the GNU General Public License version 3 in all
-** respects for all of the code used other than the "OpenSSL" code.
-** If you modify this file, you may extend this exception to your
-** version of the file, but you are not obligated to do so.  If you do
-** not wish to do so, delete this exception statement from your
-** version of this file.
+** In addition, as a special exception, Nokia gives permission to link
+** the code of its release of Qt with the OpenSSL project's "OpenSSL"
+** library (or modified versions of it that use the same license as the
+** "OpenSSL" library), and distribute the linked executables.  You must
+** comply with the GNU General Public License versions 2.0 or 3.0 in all
+** respects for all of the code used other than the "OpenSSL" code.  If
+** you modify this file, you may extend this exception to your version
+** of the file, but you are not obligated to do so.  If you do not wish
+** to do so, delete this exception statement from your version of this
+** file.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -72,6 +65,12 @@
 #include <QtCore/qurl.h>
 #include <QtCore/qvarlengtharray.h>
 
+static void initNetworkResources()
+{
+    // Initialize resources
+    Q_INIT_RESOURCE(network);
+}
+
 QT_BEGIN_NAMESPACE
 
 // Useful defines
@@ -388,6 +387,9 @@ bool QSslSocketPrivate::ensureInitialized()
     if (!q_initialized) {
         q_initialized = true;
 
+        // Initialize resources
+        initNetworkResources();
+
         // Initialize OpenSSL.
         q_CRYPTO_set_id_callback(id_function);
         q_CRYPTO_set_locking_callback(locking_function);
@@ -644,6 +646,9 @@ void QSslSocketBackendPrivate::transmit()
 #endif
                 char *ptr = readBuffer.reserve(readBytes);
                 ::memcpy(ptr, data.data(), readBytes);
+
+                if (readyReadEmittedPointer)
+                    *readyReadEmittedPointer = true;
                 emit q->readyRead();
                 transmitting = true;
                 continue;
@@ -743,6 +748,10 @@ bool QSslSocketBackendPrivate::testConnection()
     errorList << lastErrors;
     _q_sslErrorList()->mutex.unlock();
 
+    // Connection aborted during handshake phase.
+    if (q->state() != QAbstractSocket::ConnectedState)
+        return false;
+
     // Check if we're encrypted or not.
     if (result <= 0) {
         switch (q_SSL_get_error(ssl, result)) {
@@ -797,14 +806,23 @@ bool QSslSocketBackendPrivate::testConnection()
             }
             if (!matched) {
                 // No matches in common names or alternate names.
-                errors << QSslError(QSslError::HostNameMismatch);
+                QSslError error(QSslError::HostNameMismatch);
+                errors << error;
+                emit q->peerVerifyError(error);
+                if (q->state() != QAbstractSocket::ConnectedState)
+                    return false;
             }
         }
     } else {
         // No peer certificate presented. Report as error if the socket
         // expected one.
-        if (!dontVerifyPeer)
-            errors << QSslError(QSslError::NoPeerCertificate);
+        if (!dontVerifyPeer) {
+            QSslError error(QSslError::NoPeerCertificate);
+            errors << error;
+            emit q->peerVerifyError(error);
+            if (q->state() != QAbstractSocket::ConnectedState)
+                return false;
+        }
     }
 
     // Translate errors from the error list into QSslErrors.
