@@ -1,55 +1,48 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech gives permission to
-** link the code of its release of Qt with the OpenSSL project's
-** "OpenSSL" library (or modified versions of it that use the same
-** license as the "OpenSSL" library), and distribute the linked
-** executables.  You must comply with the GNU General Public License
-** version 2 or the GNU General Public License version 3 in all
-** respects for all of the code used other than the "OpenSSL" code.
-** If you modify this file, you may extend this exception to your
-** version of the file, but you are not obligated to do so.  If you do
-** not wish to do so, delete this exception statement from your
-** version of this file.
+** In addition, as a special exception, Nokia gives permission to link
+** the code of its release of Qt with the OpenSSL project's "OpenSSL"
+** library (or modified versions of it that use the same license as the
+** "OpenSSL" library), and distribute the linked executables.  You must
+** comply with the GNU General Public License versions 2.0 or 3.0 in all
+** respects for all of the code used other than the "OpenSSL" code.  If
+** you modify this file, you may extend this exception to your version
+** of the file, but you are not obligated to do so.  If you do not wish
+** to do so, delete this exception statement from your version of this
+** file.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -59,9 +52,7 @@
 #include <QtCore/qlibrary.h>
 #include <QtCore/qmutex.h>
 #include <private/qmutexpool_p.h>
-#if defined(Q_OS_WINCE)
 #include <QtCore/qdatetime.h>
-#endif
 #if defined(Q_OS_UNIX)
 #include <QtCore/qdir.h>
 #endif
@@ -276,8 +267,8 @@ static bool libGreaterThan(const QString &lhs, const QString &rhs)
             // left hand side is shorter, so it's less than rhs
             return false;
 
-        bool ok;
-        int b;
+        bool ok = false;
+        int b = 0;
         int a = lhsparts.at(i).toInt(&ok);
         if (ok)
             b = rhsparts.at(i).toInt(&ok);
@@ -587,10 +578,8 @@ bool q_resolveOpenSslSymbols()
 // contributed by Jay Case of Sarvega, Inc.; http://sarvega.com/
 // Based on X509_cmp_time() for intitial buffer hacking.
 //==============================================================================
-time_t q_getTimeFromASN1(const ASN1_TIME *aTime)
+QDateTime q_getTimeFromASN1(const ASN1_TIME *aTime)
 {
-    time_t lResult = 0;
-
     char lBuffer[24];
     char *pBuffer = lBuffer;
 
@@ -599,14 +588,14 @@ time_t q_getTimeFromASN1(const ASN1_TIME *aTime)
 
     if (aTime->type == V_ASN1_UTCTIME) {
         if ((lTimeLength < 11) || (lTimeLength > 17))
-            return 0;
+            return QDateTime();
 
         memcpy(pBuffer, pString, 10);
         pBuffer += 10;
         pString += 10;
     } else {
         if (lTimeLength < 13)
-            return 0;
+            return QDateTime();
 
         memcpy(pBuffer, pString, 12);
         pBuffer += 12;
@@ -635,7 +624,7 @@ time_t q_getTimeFromASN1(const ASN1_TIME *aTime)
         lSecondsFromUCT = 0;
     } else {
         if ((*pString != '+') && (*pString != '-'))
-            return 0;
+            return QDateTime();
 
         lSecondsFromUCT = ((pString[1] - '0') * 10 + (pString[2] - '0')) * 60;
         lSecondsFromUCT += (pString[3] - '0') * 10 + (pString[4] - '0');
@@ -652,32 +641,12 @@ time_t q_getTimeFromASN1(const ASN1_TIME *aTime)
     lTime.tm_year = ((lBuffer[0] - '0') * 10) + (lBuffer[1] - '0');
     if (lTime.tm_year < 50)
         lTime.tm_year += 100; // RFC 2459
-    lTime.tm_wday = 0;
-    lTime.tm_yday = 0;
-    lTime.tm_isdst = 0;  // No DST adjustment requested
 
-#if !defined(Q_OS_WINCE)
-    lResult = mktime(&lTime);
-#else
-    QDate resDate(lTime.tm_yday, lTime.tm_mon, lTime.tm_mday);
+    QDate resDate(lTime.tm_year + 1900, lTime.tm_mon + 1, lTime.tm_mday);
     QTime resTime(lTime.tm_hour, lTime.tm_min, lTime.tm_sec);
-    int days = QDate(1970, 1, 1).daysTo(resDate);
-    int secs = QTime().secsTo(resTime);
-    const int secsPerDay = 86400;
-    lResult = (qlonglong(days) * secsPerDay) + secs;
-    if (lResult >= Q_INT64_C(0xFFFFFFFF))
-        lResult = uint(-1);
-#endif
-
-    if ((time_t)-1 != lResult) {
-        if (0 != lTime.tm_isdst)
-            lResult -= 3600;  // mktime may adjust for DST  (OS dependent)
-        lResult += lSecondsFromUCT;
-    } else {
-        lResult = 0;
-    }
-
-    return lResult;
+    QDateTime result(resDate, resTime, Qt::UTC);
+    result = result.addSecs(lSecondsFromUCT);
+    return result;
 }
 
 QT_END_NAMESPACE
