@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -1154,7 +1148,7 @@ void Q3DnsManager::transmitQuery( int i )
 	return;
     }
 
-    if ( q && !q->dns || q->dns->isEmpty() )
+    if ((q && !q->dns) || q->dns->isEmpty())
 	// no one currently wants the answer, so there's no point in
 	// retransmitting the query. we keep it, though. an answer may
 	// arrive for an earlier query transmission, and if it does we
@@ -1786,7 +1780,7 @@ void Q3Dns::setLabel( const QHostAddress & address )
 
     Note that if you want to iterate over the list, you should iterate
     over a copy, e.g.
-    \snippet doc/src/snippets/code/src.qt3support.network.q3dns.cpp 0
+    \snippet doc/src/snippets/code/src_qt3support_network_q3dns.cpp 0
 
 */
 
@@ -1980,7 +1974,7 @@ bool Q3Dns::isWorking() const
 
     Note that if you want to iterate over the list, you should iterate
     over a copy, e.g.
-    \snippet doc/src/snippets/code/src.qt3support.network.q3dns.cpp 1
+    \snippet doc/src/snippets/code/src_qt3support_network_q3dns.cpp 1
 
 */
 
@@ -2023,7 +2017,7 @@ Q3ValueList<QHostAddress> Q3Dns::addresses() const
 
     Note that if you want to iterate over the list, you should iterate
     over a copy, e.g.
-    \snippet doc/src/snippets/code/src.qt3support.network.q3dns.cpp 2
+    \snippet doc/src/snippets/code/src_qt3support_network_q3dns.cpp 2
 
 */
 Q3ValueList<Q3Dns::MailServer> Q3Dns::mailServers() const
@@ -2069,7 +2063,7 @@ Q3ValueList<Q3Dns::MailServer> Q3Dns::mailServers() const
 
     Note that if you want to iterate over the list, you should iterate
     over a copy, e.g.
-    \snippet doc/src/snippets/code/src.qt3support.network.q3dns.cpp 3
+    \snippet doc/src/snippets/code/src_qt3support_network_q3dns.cpp 3
 */
 Q3ValueList<Q3Dns::Server> Q3Dns::servers() const
 {
@@ -2100,7 +2094,7 @@ Q3ValueList<Q3Dns::Server> Q3Dns::servers() const
 
     Note that if you want to iterate over the list, you should iterate
     over a copy, e.g.
-    \snippet doc/src/snippets/code/src.qt3support.network.q3dns.cpp 4
+    \snippet doc/src/snippets/code/src_qt3support_network_q3dns.cpp 4
 
 */
 QStringList Q3Dns::hostNames() const
@@ -2132,7 +2126,7 @@ QStringList Q3Dns::hostNames() const
 
     Note that if you want to iterate over the list, you should iterate
     over a copy, e.g.
-    \snippet doc/src/snippets/code/src.qt3support.network.q3dns.cpp 5
+    \snippet doc/src/snippets/code/src_qt3support_network_q3dns.cpp 5
 */
 QStringList Q3Dns::texts() const
 {
