@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -40,6 +54,8 @@
 #include "q3url.h"
 #include "qhttp.h"
 
+QT_BEGIN_NAMESPACE
+
 //#define Q3HTTP_DEBUG
 
 class Q3HttpPrivate
@@ -252,7 +268,7 @@ public:
 
 void Q3HttpPGHRequest::start( Q3Http *http )
 {
-    header.setValue( "Host", http->d->hostname );
+    header.setValue( QLatin1String("Host"), http->d->hostname );
     Q3HttpNormalRequest::start( http );
 }
 
@@ -332,17 +348,12 @@ void Q3HttpCloseRequest::start( Q3Http *http )
     consists of a name followed by a colon, a single space, and the
     field value. (See RFC 1945.) Field names are case-insensitive. A
     typical header field looks like this:
-    \code
-    content-type: text/html
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 0
 
     In the API the header field name is called the "key" and the
     content is called the "value". You can get and set a header
     field's value by using its key with value() and setValue(), e.g.
-    \code
-    header.setValue( "content-type", "text/html" );
-    QString contentType = header.value( "content-type" );
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 1
 
     Some fields are so common that getters and setters are provided
     for them as a convenient alternative to using \l value() and
@@ -438,11 +449,11 @@ bool Q3HttpHeader::isValid() const
 bool Q3HttpHeader::parse( const QString& str )
 {
     QStringList lst;
-    int pos = str.find( '\n' );
-    if ( pos > 0 && str.at( pos - 1 ) == '\r' )
-	lst = QStringList::split( "\r\n", str.stripWhiteSpace(), false );
+    int pos = str.find( QLatin1Char('\n') );
+    if ( pos > 0 && str.at( pos - 1 ) == QLatin1Char('\r') )
+	lst = QStringList::split( QLatin1String("\r\n"), str.stripWhiteSpace(), false );
     else
-	lst = QStringList::split( "\n", str.stripWhiteSpace(), false );
+	lst = QStringList::split( QLatin1String("\n"), str.stripWhiteSpace(), false );
 
     if ( lst.isEmpty() )
 	return true;
@@ -453,7 +464,7 @@ bool Q3HttpHeader::parse( const QString& str )
 	if ( !(*it).isEmpty() ) {
 	    if ( (*it)[0].isSpace() ) {
 		if ( !lines.isEmpty() ) {
-		    lines.last() += " ";
+		    lines.last() += QLatin1String(" ");
 		    lines.last() += (*it).stripWhiteSpace();
 		}
 	    } else {
@@ -547,7 +558,7 @@ void Q3HttpHeader::removeValue( const QString& key )
 */
 bool Q3HttpHeader::parseLine( const QString& line, int )
 {
-    int i = line.find( ":" );
+    int i = line.find( QLatin1String(":") );
     if ( i == -1 )
 	return false;
 
@@ -566,13 +577,13 @@ bool Q3HttpHeader::parseLine( const QString& line, int )
 QString Q3HttpHeader::toString() const
 {
     if ( !isValid() )
-	return "";
+	return QLatin1String("");
 
-    QString ret = "";
+    QString ret = QLatin1String("");
 
     QMap<QString,QString>::ConstIterator it = values.begin();
     for( ; it != values.end(); ++it )
-	ret += it.key() + ": " + it.data() + "\r\n";
+	ret += it.key() + QLatin1String(": ") + it.data() + QLatin1String("\r\n");
 
     return ret;
 }
@@ -585,7 +596,7 @@ QString Q3HttpHeader::toString() const
 */
 bool Q3HttpHeader::hasContentLength() const
 {
-    return hasKey( "content-length" );
+    return hasKey( QLatin1String("content-length") );
 }
 
 /*!
@@ -596,7 +607,7 @@ bool Q3HttpHeader::hasContentLength() const
 */
 uint Q3HttpHeader::contentLength() const
 {
-    return values[ "content-length" ].toUInt();
+    return values[ QLatin1String("content-length") ].toUInt();
 }
 
 /*!
@@ -607,7 +618,7 @@ uint Q3HttpHeader::contentLength() const
 */
 void Q3HttpHeader::setContentLength( int len )
 {
-    values[ "content-length" ] = QString::number( len );
+    values[ QLatin1String("content-length") ] = QString::number( len );
 }
 
 /*!
@@ -618,7 +629,7 @@ void Q3HttpHeader::setContentLength( int len )
 */
 bool Q3HttpHeader::hasContentType() const
 {
-    return hasKey( "content-type" );
+    return hasKey( QLatin1String("content-type") );
 }
 
 /*!
@@ -628,11 +639,11 @@ bool Q3HttpHeader::hasContentType() const
 */
 QString Q3HttpHeader::contentType() const
 {
-    QString type = values[ "content-type" ];
+    QString type = values[ QLatin1String("content-type") ];
     if ( type.isEmpty() )
 	return QString();
 
-    int pos = type.find( ";" );
+    int pos = type.find( QLatin1String(";") );
     if ( pos == -1 )
 	return type;
 
@@ -647,7 +658,7 @@ QString Q3HttpHeader::contentType() const
 */
 void Q3HttpHeader::setContentType( const QString& type )
 {
-    values[ "content-type" ] = type;
+    values[ QLatin1String("content-type") ] = type;
 }
 
 /****************************************************
@@ -781,12 +792,12 @@ bool Q3HttpResponseHeader::parseLine( const QString& line, int number )
     if ( l.length() < 10 )
 	return false;
 
-    if ( l.left( 5 ) == "HTTP/" && l[5].isDigit() && l[6] == '.' &&
-	    l[7].isDigit() && l[8] == ' ' && l[9].isDigit() ) {
+    if ( l.left( 5 ) == QLatin1String("HTTP/") && l[5].isDigit() && l[6] == QLatin1Char('.') &&
+	    l[7].isDigit() && l[8] == QLatin1Char(' ') && l[9].isDigit() ) {
 	majVer = l[5].latin1() - '0';
 	minVer = l[7].latin1() - '0';
 
-	int pos = l.find( ' ', 9 );
+	int pos = l.find( QLatin1Char(' '), 9 );
 	if ( pos != -1 ) {
 	    reasonPhr = l.mid( pos + 1 );
 	    statCode = l.mid( 9, pos - 9 ).toInt();
@@ -805,7 +816,7 @@ bool Q3HttpResponseHeader::parseLine( const QString& line, int number )
 */
 QString Q3HttpResponseHeader::toString() const
 {
-    QString ret( "HTTP/%1.%2 %3 %4\r\n%5\r\n" );
+    QString ret( QLatin1String("HTTP/%1.%2 %3 %4\r\n%5\r\n") );
     return ret.arg( majVer ).arg ( minVer ).arg( statCode ).arg( reasonPhr ).arg( Q3HttpHeader::toString() );
 }
 
@@ -944,15 +955,15 @@ bool Q3HttpRequestHeader::parseLine( const QString& line, int number )
     if ( number != 0 )
 	return Q3HttpHeader::parseLine( line, number );
 
-    QStringList lst = QStringList::split( " ", line.simplifyWhiteSpace() );
+    QStringList lst = QStringList::split( QLatin1String(" "), line.simplifyWhiteSpace() );
     if ( lst.count() > 0 ) {
 	m = lst[0];
 	if ( lst.count() > 1 ) {
 	    p = lst[1];
 	    if ( lst.count() > 2 ) {
 		QString v = lst[2];
-		if ( v.length() >= 8 && v.left( 5 ) == "HTTP/" &&
-			v[5].isDigit() && v[6] == '.' && v[7].isDigit() ) {
+		if ( v.length() >= 8 && v.left( 5 ) == QLatin1String("HTTP/") &&
+			v[5].isDigit() && v[6] == QLatin1Char('.') && v[7].isDigit() ) {
 		    majVer = v[5].latin1() - '0';
 		    minVer = v[7].latin1() - '0';
 		    return true;
@@ -968,8 +979,8 @@ bool Q3HttpRequestHeader::parseLine( const QString& line, int number )
 */
 QString Q3HttpRequestHeader::toString() const
 {
-    QString first( "%1 %2");
-    QString last(" HTTP/%3.%4\r\n%5\r\n" );
+    QString first( QLatin1String("%1 %2"));
+    QString last(QLatin1String(" HTTP/%3.%4\r\n%5\r\n") );
     return first.arg( m ).arg( p ) +
 	last.arg( majVer ).arg( minVer ).arg( Q3HttpHeader::toString());
 }
@@ -999,10 +1010,7 @@ QString Q3HttpRequestHeader::toString() const
     do not use it directly, but rather through a QUrlOperator, for
     example:
 
-    \code
-    QUrlOperator op( "http://www.trolltech.com" );
-    op.get( "index.html" );
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 2
 
     This code will only work if the Q3Http class is registered; to
     register the class, you must call q3InitNetworkProtocols() before
@@ -1039,12 +1047,7 @@ QString Q3HttpRequestHeader::toString() const
     from the Trolltech home page (i.e. the URL
     http://www.trolltech.com/index.html):
 
-    \code
-    Q3HttpRequestHeader header( "GET", "/index.html" );
-    header.setValue( "Host", "www.trolltech.com" );
-    http->setHost( "www.trolltech.com" );
-    http->request( header );
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 3
 
     For the common HTTP requests \c GET, \c POST and \c HEAD, Q3Http
     provides the convenience functions get(), post() and head(). They
@@ -1052,40 +1055,16 @@ QString Q3HttpRequestHeader::toString() const
     special header fields, they are easier to use. The above example
     can also be written as:
 
-    \code
-    http->setHost( "www.trolltech.com" ); // id == 1
-    http->get( "/index.html" );           // id == 2
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 4
 
     For this example the following sequence of signals is emitted
     (with small variations, depending on network traffic, etc.):
 
-    \code
-    requestStarted( 1 )
-    requestFinished( 1, false )
-
-    requestStarted( 2 )
-    stateChanged( Connecting )
-    stateChanged( Sending )
-    dataSendProgress( 77, 77 )
-    stateChanged( Reading )
-    responseHeaderReceived( responseheader )
-    dataReadProgress( 5388, 0 )
-    readyRead( responseheader )
-    dataReadProgress( 18300, 0 )
-    readyRead( responseheader )
-    stateChanged( Connected )
-    requestFinished( 2, false )
-
-    done( false )
-
-    stateChanged( Closing )
-    stateChanged( Unconnected )
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 5
 
     The dataSendProgress() and dataReadProgress() signals in the above
     example are useful if you want to show a \link QProgressBar
-    progressbar\endlink to inform the user about the progress of the
+    progress bar\endlink to inform the user about the progress of the
     download. The second argument is the total size of data. In
     certain cases it is not possible to know the total amount in
     advance, in which case the second argument is 0. (If you connect
@@ -1106,28 +1085,13 @@ QString Q3HttpRequestHeader::toString() const
 
     For example, if you have the following sequence of reqeusts
 
-    \code
-    http->setHost( "www.foo.bar" );       // id == 1
-    http->get( "/index.html" );           // id == 2
-    http->post( "register.html", data );  // id == 3
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 6
 
     and the get() request fails because the host lookup fails, then
     the post() request is never executed and the signals would look
     like this:
 
-    \code
-    requestStarted( 1 )
-    requestFinished( 1, false )
-
-    requestStarted( 2 )
-    stateChanged( HostLookup )
-    requestFinished( 2, true )
-
-    done( true )
-
-    stateChanged( Unconnected )
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_network_q3http.cpp 7
 
     You can then get details about the error with the error() and
     errorString() functions. Note that only unexpected behaviour, like
@@ -1191,18 +1155,18 @@ void Q3Http::init()
     d = new Q3HttpPrivate;
     d->errorString = QHttp::tr( "Unknown error" );
 
-    connect( &d->socket, SIGNAL( connected() ),
-	    this, SLOT( slotConnected() ) );
-    connect( &d->socket, SIGNAL( connectionClosed() ),
-	    this, SLOT( slotClosed() ) );
-    connect( &d->socket, SIGNAL( delayedCloseFinished() ),
-	    this, SLOT( slotClosed() ) );
-    connect( &d->socket, SIGNAL( readyRead() ),
-	    this, SLOT( slotReadyRead() ) );
-    connect( &d->socket, SIGNAL( error(int) ),
-	    this, SLOT( slotError(int) ) );
-    connect( &d->socket, SIGNAL( bytesWritten(int) ),
-	    this, SLOT( slotBytesWritten(int) ) );
+    connect( &d->socket, SIGNAL(connected()),
+	    this, SLOT(slotConnected()) );
+    connect( &d->socket, SIGNAL(connectionClosed()),
+	    this, SLOT(slotClosed()) );
+    connect( &d->socket, SIGNAL(delayedCloseFinished()),
+	    this, SLOT(slotClosed()) );
+    connect( &d->socket, SIGNAL(readyRead()),
+	    this, SLOT(slotReadyRead()) );
+    connect( &d->socket, SIGNAL(error(int)),
+	    this, SLOT(slotError(int)) );
+    connect( &d->socket, SIGNAL(bytesWritten(int)),
+	    this, SLOT(slotBytesWritten(int)) );
 
     d->idleTimer = startTimer( 0 );
 }
@@ -1590,8 +1554,8 @@ int Q3Http::setHost(const QString &hostname, Q_UINT16 port )
 */
 int Q3Http::get( const QString& path, QIODevice* to )
 {
-    Q3HttpRequestHeader header( "GET", path );
-    header.setValue( "Connection", "Keep-Alive" );
+    Q3HttpRequestHeader header( QLatin1String("GET"), path );
+    header.setValue( QLatin1String("Connection"), QLatin1String("Keep-Alive") );
     return addRequest( new Q3HttpPGHRequest( header, (QIODevice*)0, to ) );
 }
 
@@ -1625,8 +1589,8 @@ int Q3Http::get( const QString& path, QIODevice* to )
 */
 int Q3Http::post( const QString& path, QIODevice* data, QIODevice* to  )
 {
-    Q3HttpRequestHeader header( "POST", path );
-    header.setValue( "Connection", "Keep-Alive" );
+    Q3HttpRequestHeader header( QLatin1String("POST"), path );
+    header.setValue( QLatin1String("Connection"), QLatin1String("Keep-Alive") );
     return addRequest( new Q3HttpPGHRequest( header, data, to ) );
 }
 
@@ -1637,8 +1601,8 @@ int Q3Http::post( const QString& path, QIODevice* data, QIODevice* to  )
 */
 int Q3Http::post( const QString& path, const QByteArray& data, QIODevice* to )
 {
-    Q3HttpRequestHeader header( "POST", path );
-    header.setValue( "Connection", "Keep-Alive" );
+    Q3HttpRequestHeader header( QLatin1String("POST"), path );
+    header.setValue( QLatin1String("Connection"), QLatin1String("Keep-Alive") );
     return addRequest( new Q3HttpPGHRequest( header, new QByteArray(data), to ) );
 }
 
@@ -1662,8 +1626,8 @@ int Q3Http::post( const QString& path, const QByteArray& data, QIODevice* to )
 */
 int Q3Http::head( const QString& path )
 {
-    Q3HttpRequestHeader header( "HEAD", path );
-    header.setValue( "Connection", "Keep-Alive" );
+    Q3HttpRequestHeader header( QLatin1String("HEAD"), path );
+    header.setValue( QLatin1String("Connection"), QLatin1String("Keep-Alive") );
     return addRequest( new Q3HttpPGHRequest( header, (QIODevice*)0, 0 ) );
 }
 
@@ -1820,7 +1784,7 @@ void Q3Http::slotClosed()
 	return;
 
     if ( d->state == Reading ) {
-	if ( d->response.hasKey( "content-length" ) ) {
+	if ( d->response.hasKey( QLatin1String("content-length") ) ) {
 	    // We got Content-Length, so did we get all bytes?
 	    if ( d->bytesDone+bytesAvailable() != d->response.contentLength() ) {
 		finishedWithError( QHttp::tr("Wrong content length"), WrongContentLength );
@@ -1911,7 +1875,7 @@ void Q3Http::slotReadyRead()
 	setState( Reading );
 	d->buffer = QByteArray();
 	d->readHeader = true;
-	d->headerStr = "";
+	d->headerStr = QLatin1String("");
 	d->bytesDone = 0;
 	d->chunkedSize = -1;
     }
@@ -1920,8 +1884,8 @@ void Q3Http::slotReadyRead()
 	bool end = false;
 	QString tmp;
 	while ( !end && d->socket.canReadLine() ) {
-	    tmp = d->socket.readLine();
-	    if ( tmp == "\r\n" || tmp == "\n" )
+	    tmp = QLatin1String(d->socket.readLine());
+	    if ( tmp == QLatin1String("\r\n") || tmp == QLatin1String("\n") )
 		end = true;
 	    else
 		d->headerStr += tmp;
@@ -1934,7 +1898,7 @@ void Q3Http::slotReadyRead()
 	qDebug( "Q3Http: read response header:\n---{\n%s}---", d->headerStr.latin1() );
 #endif
 	d->response = Q3HttpResponseHeader( d->headerStr );
-	d->headerStr = "";
+	d->headerStr = QLatin1String("");
 #if defined(Q3HTTP_DEBUG)
 	qDebug( "Q3Http: read response header:\n---{\n%s}---", d->response.toString().latin1() );
 #endif
@@ -1950,8 +1914,8 @@ void Q3Http::slotReadyRead()
 	// one chunk.
 	if (d->response.statusCode() != 100) {
 	    d->readHeader = false;
-	    if ( d->response.hasKey( "transfer-encoding" ) &&
-		 d->response.value( "transfer-encoding" ).lower().contains( "chunked" ) )
+	    if ( d->response.hasKey( QLatin1String("transfer-encoding") ) &&
+		 d->response.value( QLatin1String("transfer-encoding") ).lower().contains( QLatin1String("chunked") ) )
 		d->chunkedSize = 0;
 
 	    emit responseHeaderReceived( d->response );
@@ -1961,7 +1925,7 @@ void Q3Http::slotReadyRead()
     if ( !d->readHeader ) {
 	bool everythingRead = false;
 
-	if ( currentRequest().method() == "HEAD" ) {
+	if ( currentRequest().method() == QLatin1String("HEAD") ) {
 	    everythingRead = true;
 	} else {
 	    Q_ULONG n = d->socket.bytesAvailable();
@@ -1973,8 +1937,8 @@ void Q3Http::slotReadyRead()
 		    if ( d->chunkedSize == 0 ) {
 			if ( !d->socket.canReadLine() )
 			    break;
-			QString sizeString = d->socket.readLine();
-			int tPos = sizeString.find( ';' );
+			QString sizeString = QLatin1String(d->socket.readLine());
+			int tPos = sizeString.find( QLatin1Char(';') );
 			if ( tPos != -1 )
 			    sizeString.truncate( tPos );
 			bool ok;
@@ -1982,6 +1946,7 @@ void Q3Http::slotReadyRead()
 			if ( !ok ) {
 			    finishedWithError( QHttp::tr("Invalid HTTP chunked body"), WrongContentLength );
 			    close();
+                            delete arr;
 			    return;
 			}
 			if ( d->chunkedSize == 0 ) // last-chunk
@@ -1990,8 +1955,8 @@ void Q3Http::slotReadyRead()
 
 		    // read trailer
 		    while ( d->chunkedSize == -2 && d->socket.canReadLine() ) {
-			QString read = d->socket.readLine();
-			if ( read == "\r\n" || read == "\n" )
+			QString read = QLatin1String(d->socket.readLine());
+			if ( read == QLatin1String("\r\n") || read == QLatin1String("\n") )
 			    d->chunkedSize = -1;
 		    }
 		    if ( d->chunkedSize == -1 ) {
@@ -2028,6 +1993,7 @@ void Q3Http::slotReadyRead()
 			if ( tmp[0] != '\r' || tmp[1] != '\n' ) {
 			    finishedWithError( QHttp::tr("Invalid HTTP chunked body"), WrongContentLength );
 			    close();
+                            delete arr;
 			    return;
 			}
 		    }
@@ -2076,7 +2042,7 @@ void Q3Http::slotReadyRead()
 
 	if ( everythingRead ) {
 	    // Handle "Connection: close"
-	    if ( d->response.value("connection").lower() == "close" ) {
+	    if ( d->response.value(QLatin1String("connection")).lower() == QLatin1String("close") ) {
 		close();
 	    } else {
 		setState( Connected );
@@ -2197,8 +2163,8 @@ int Q3Http::supportedOperations() const
 */
 void Q3Http::operationGet( Q3NetworkOperation *op )
 {
-    connect( this, SIGNAL(readyRead(const Q3HttpResponseHeader&)),
-	    this, SLOT(clientReply(const Q3HttpResponseHeader&)) );
+    connect( this, SIGNAL(readyRead(Q3HttpResponseHeader)),
+	    this, SLOT(clientReply(Q3HttpResponseHeader)) );
     connect( this, SIGNAL(done(bool)),
 	    this, SLOT(clientDone(bool)) );
     connect( this, SIGNAL(stateChanged(int)),
@@ -2207,8 +2173,8 @@ void Q3Http::operationGet( Q3NetworkOperation *op )
     bytesRead = 0;
     op->setState( StInProgress );
     Q3Url u( operationInProgress()->arg( 0 ) );
-    Q3HttpRequestHeader header( "GET", u.encodedPathAndQuery(), 1, 0 );
-    header.setValue( "Host", u.host() );
+    Q3HttpRequestHeader header( QLatin1String("GET"), u.encodedPathAndQuery(), 1, 0 );
+    header.setValue( QLatin1String("Host"), u.host() );
     setHost( u.host(), u.port() != -1 ? u.port() : 80 );
     request( header );
 }
@@ -2217,8 +2183,8 @@ void Q3Http::operationGet( Q3NetworkOperation *op )
 */
 void Q3Http::operationPut( Q3NetworkOperation *op )
 {
-    connect( this, SIGNAL(readyRead(const Q3HttpResponseHeader&)),
-	    this, SLOT(clientReply(const Q3HttpResponseHeader&)) );
+    connect( this, SIGNAL(readyRead(Q3HttpResponseHeader)),
+	    this, SLOT(clientReply(Q3HttpResponseHeader)) );
     connect( this, SIGNAL(done(bool)),
 	    this, SLOT(clientDone(bool)) );
     connect( this, SIGNAL(stateChanged(int)),
@@ -2227,8 +2193,8 @@ void Q3Http::operationPut( Q3NetworkOperation *op )
     bytesRead = 0;
     op->setState( StInProgress );
     Q3Url u( operationInProgress()->arg( 0 ) );
-    Q3HttpRequestHeader header( "POST", u.encodedPathAndQuery(), 1, 0 );
-    header.setValue( "Host", u.host() );
+    Q3HttpRequestHeader header( QLatin1String("POST"), u.encodedPathAndQuery(), 1, 0 );
+    header.setValue( QLatin1String("Host"), u.host() );
     setHost( u.host(), u.port() != -1 ? u.port() : 80 );
     request( header, op->rawArg(1) );
 }
@@ -2240,7 +2206,7 @@ void Q3Http::clientReply( const Q3HttpResponseHeader &rep )
 	if ( rep.statusCode() >= 400 && rep.statusCode() < 600 ) {
 	    op->setState( StFailed );
 	    op->setProtocolDetail(
-		    QString("%1 %2").arg(rep.statusCode()).arg(rep.reasonPhrase())
+		    QString(QLatin1String("%1 %2")).arg(rep.statusCode()).arg(rep.reasonPhrase())
 						    );
 	    switch ( rep.statusCode() ) {
 		case 401:
@@ -2273,8 +2239,8 @@ void Q3Http::clientReply( const Q3HttpResponseHeader &rep )
 
 void Q3Http::clientDone( bool err )
 {
-    disconnect( this, SIGNAL(readyRead(const Q3HttpResponseHeader&)),
-	    this, SLOT(clientReply(const Q3HttpResponseHeader&)) );
+    disconnect( this, SIGNAL(readyRead(Q3HttpResponseHeader)),
+	    this, SLOT(clientReply(Q3HttpResponseHeader)) );
     disconnect( this, SIGNAL(done(bool)),
 	    this, SLOT(clientDone(bool)) );
     disconnect( this, SIGNAL(stateChanged(int)),
@@ -2347,4 +2313,6 @@ void Q3Http::clientStateChanged( int state )
     }
 }
 
+QT_END_NAMESPACE
+
 #endif
