@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -125,7 +119,7 @@ public:
 
     A Q3UrlOperator can be used like this, for example to download a
     file (and assuming that the FTP protocol is registered):
-    \snippet doc/src/snippets/code/src.qt3support.network.q3urloperator.cpp 0
+    \snippet doc/src/snippets/code/src_qt3support_network_q3urloperator.cpp 0
 
     If you want to be notified about success/failure, progress, etc.,
     you can connect to Q3UrlOperator's signals, e.g. to start(),
@@ -737,18 +731,18 @@ bool Q3UrlOperator::isDir( bool *ok )
 
     For example, to get a web page you might do something like this:
 
-    \snippet doc/src/snippets/code/src.qt3support.network.q3urloperator.cpp 1
+    \snippet doc/src/snippets/code/src_qt3support_network_q3urloperator.cpp 1
 
     For most other operations, the path of the Q3UrlOperator must point
     to a directory. If you want to download a file you could do the
     following:
 
-    \snippet doc/src/snippets/code/src.qt3support.network.q3urloperator.cpp 2
+    \snippet doc/src/snippets/code/src_qt3support_network_q3urloperator.cpp 2
 
     This will get the data of ftp://ftp.whatever.org/pub/a_file.txt.
 
     \e Never do anything like this:
-    \snippet doc/src/snippets/code/src.qt3support.network.q3urloperator.cpp 3
+    \snippet doc/src/snippets/code/src_qt3support_network_q3urloperator.cpp 3
 
     If \a location is not empty and relative it must not contain any
     queries or references, just the name of a child. So if you need to
@@ -796,13 +790,13 @@ const Q3NetworkOperation *Q3UrlOperator::get( const QString &location )
 
     For putting some data to a file you can do the following:
 
-    \snippet doc/src/snippets/code/src.qt3support.network.q3urloperator.cpp 4
+    \snippet doc/src/snippets/code/src_qt3support_network_q3urloperator.cpp 4
 
     For most other operations, the path of the Q3UrlOperator must point
     to a directory. If you want to upload data to a file you could do
     the following:
 
-    \snippet doc/src/snippets/code/src.qt3support.network.q3urloperator.cpp 5
+    \snippet doc/src/snippets/code/src_qt3support_network_q3urloperator.cpp 5
 
     This will upload the data to ftp://ftp.whatever.com/home/me/filename.dat.
 
