@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -61,6 +55,7 @@
 #include "q3cleanuphandler.h"
 #include "qregexp.h"
 #include "private/q3membuf_p.h"
+#include "private/qobject_p.h"
 
 #include <stdlib.h>
 #include <errno.h>
@@ -653,58 +648,11 @@ Q3Membuf* Q3Process::membufStderr()
     return &d->bufStderr;
 }
 
-/*!
-    Destroys the instance.
-
-    If the process is running, it is <b>not</b> terminated! The
-    standard input, standard output and standard error of the process
-    are closed.
-
-    You can connect the destroyed() signal to the kill() slot, if you
-    want the process to be terminated automatically when the instance
-    is destroyed.
-
-    \sa tryTerminate() kill()
-*/
 Q3Process::~Q3Process()
 {
     delete d;
 }
 
-/*!
-    Tries to run a process for the command and arguments that were
-    specified with setArguments(), addArgument() or that were
-    specified in the constructor. The command is searched for in the
-    path for executable programs; you can also use an absolute path in
-    the command itself.
-
-    If \a env is null, then the process is started with the same
-    environment as the starting process. If \a env is non-null, then
-    the values in the stringlist are interpreted as environment
-    setttings of the form \c {key=value} and the process is started in
-    these environment settings. For convenience, there is a small
-    exception to this rule: under Unix, if \a env does not contain any
-    settings for the environment variable \c LD_LIBRARY_PATH, then
-    this variable is inherited from the starting process; under
-    Windows the same applies for the environment variable \c PATH.
-
-    Returns true if the process could be started; otherwise returns
-    false.
-
-    You can write data to the process's standard input with
-    writeToStdin(). You can close standard input with closeStdin() and
-    you can terminate the process with tryTerminate(), or with kill().
-
-    You can call this function even if you've used this instance to
-    create a another process which is still running. In such cases,
-    Q3Process closes the old process's standard input and deletes
-    pending data, i.e., you lose all control over the old process, but
-    the old process is not terminated. This applies also if the
-    process could not be started. (On operating systems that have
-    zombie processes, Qt will also wait() on the old process.)
-
-    \sa launch() closeStdin()
-*/
 bool Q3Process::start( QStringList *env )
 {
 #if defined(QT_Q3PROCESS_DEBUG)
@@ -1001,56 +949,18 @@ error:
 }
 
 
-/*!
-    Asks the process to terminate. Processes can ignore this if they
-    wish. If you want to be certain that the process really
-    terminates, you can use kill() instead.
-
-    The slot returns immediately: it does not wait until the process
-    has finished. When the process terminates, the processExited()
-    signal is emitted.
-
-    \sa kill() processExited()
-*/
 void Q3Process::tryTerminate() const
 {
     if ( d->proc != 0 )
 	::kill( d->proc->pid, SIGTERM );
 }
 
-/*!
-    Terminates the process. This is not a safe way to end a process
-    since the process will not be able to do any cleanup.
-    tryTerminate() is safer, but processes can ignore a
-    tryTerminate().
-
-    The nice way to end a process and to be sure that it is finished,
-    is to do something like this:
-    \snippet doc/src/snippets/code/src.qt3support.other.q3process_unix.cpp 0
-
-    This tries to terminate the process the nice way. If the process
-    is still running after 5 seconds, it terminates the process the
-    hard way. The timeout should be chosen depending on the time the
-    process needs to do all its cleanup: use a higher value if the
-    process is likely to do a lot of computation or I/O on cleanup.
-
-    The slot returns immediately: it does not wait until the process
-    has finished. When the process terminates, the processExited()
-    signal is emitted.
-
-    \sa tryTerminate() processExited()
-*/
 void Q3Process::kill() const
 {
     if ( d->proc != 0 )
 	::kill( d->proc->pid, SIGKILL );
 }
 
-/*!
-    Returns true if the process is running; otherwise returns false.
-
-    \sa normalExit() exitStatus() processExited()
-*/
 bool Q3Process::isRunning() const
 {
     if ( d->exitValuesCalculated ) {
@@ -1095,12 +1005,6 @@ bool Q3Process::isRunning() const
     return true;
 }
 
-/*!
-    Returns true if it's possible to read an entire line of text from
-    standard output at this time; otherwise returns false.
-
-    \sa readLineStdout() canReadLineStderr()
-*/
 bool Q3Process::canReadLineStdout() const
 {
     if ( !d->proc || !d->proc->socketStdout )
@@ -1110,12 +1014,6 @@ bool Q3Process::canReadLineStdout() const
     return that->membufStdout()->scanNewline( 0 );
 }
 
-/*!
-    Returns true if it's possible to read an entire line of text from
-    standard error at this time; otherwise returns false.
-
-    \sa readLineStderr() canReadLineStdout()
-*/
 bool Q3Process::canReadLineStderr() const
 {
     if ( !d->proc || !d->proc->socketStderr )
@@ -1125,19 +1023,6 @@ bool Q3Process::canReadLineStderr() const
     return that->membufStderr()->scanNewline( 0 );
 }
 
-/*!
-    Writes the data \a buf to the process's standard input. The
-    process may or may not read this data.
-
-    This function returns immediately; the Q3Process class might write
-    the data at a later point (you must enter the event loop for this
-    to occur). When all the data is written to the process, the signal
-    wroteToStdin() is emitted. This does not mean that the process
-    actually read the data, since this class only detects when it was
-    able to write the data to the operating system.
-
-    \sa wroteToStdin() closeStdin() readStdout() readStderr()
-*/
 void Q3Process::writeToStdin( const QByteArray& buf )
 {
 #if defined(QT_Q3PROCESS_DEBUG)
@@ -1149,14 +1034,6 @@ void Q3Process::writeToStdin( const QByteArray& buf )
 }
 
 
-/*!
-    Closes the process's standard input.
-
-    This function also deletes any pending data that has not been
-    written to standard input.
-
-    \sa wroteToStdin()
-*/
 void Q3Process::closeStdin()
 {
     if ( d->proc == 0 )
@@ -1165,7 +1042,8 @@ void Q3Process::closeStdin()
 	while ( !d->stdinBuf.isEmpty() ) {
 	    delete d->stdinBuf.dequeue();
 	}
-	delete d->notifierStdin;
+	d->notifierStdin->setEnabled(false);
+	qDeleteInEventHandler(d->notifierStdin);
 	d->notifierStdin = 0;
 	if ( ::close( d->proc->socketStdin ) != 0 ) {
 	    qWarning( "Could not close stdin of child process" );
@@ -1231,7 +1109,7 @@ void Q3Process::socketRead( int fd )
 	    qDebug( "Q3Process::socketRead(): stdout (%d) closed", fd );
 #endif
 	    d->notifierStdout->setEnabled( false );
-	    delete d->notifierStdout;
+	    qDeleteInEventHandler(d->notifierStdout);
 	    d->notifierStdout = 0;
 	    ::close( d->proc->socketStdout );
 	    d->proc->socketStdout = 0;
@@ -1241,7 +1119,7 @@ void Q3Process::socketRead( int fd )
 	    qDebug( "Q3Process::socketRead(): stderr (%d) closed", fd );
 #endif
 	    d->notifierStderr->setEnabled( false );
-	    delete d->notifierStderr;
+	    qDeleteInEventHandler(d->notifierStderr);
 	    d->notifierStderr = 0;
 	    ::close( d->proc->socketStderr );
 	    d->proc->socketStderr = 0;
@@ -1388,18 +1266,6 @@ void Q3Process::setWroteStdinConnected( bool value )
     \internal
 */
 
-/*!
-    Returns platform dependent information about the process. This can
-    be used together with platform specific system calls.
-
-    Under Unix the return value is the PID of the process, or -1 if no
-    process belongs to this object.
-
-    Under Windows it is a pointer to the \c PROCESS_INFORMATION
-    struct, or 0 if no process is belongs to this object.
-
-    Use of this function's return value is likely to be non-portable.
-*/
 Q3Process::PID Q3Process::processIdentifier()
 {
     if ( d->proc == 0 )
