@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -32,6 +46,8 @@
 
 #ifndef QT_NO_SQL_EDIT_WIDGETS
 
+QT_BEGIN_NAMESPACE
+
 /*!
     \class Q3EditorFactory qeditorfactory.h
     \brief The Q3EditorFactory class is used to create editor widgets
@@ -119,8 +135,8 @@ QWidget * Q3EditorFactory::createEditor(QWidget * parent, const QVariant & v)
             break;
         case QVariant::Bool:
             w = new QComboBox(parent, "qt_editor_bool");
-            ((QComboBox *) w)->insertItem("False");
-            ((QComboBox *) w)->insertItem("True");
+            ((QComboBox *) w)->insertItem(QLatin1String("False"));
+            ((QComboBox *) w)->insertItem(QLatin1String("True"));
             break;
         case QVariant::UInt:
             w = new QSpinBox(0, 999999, 1, parent, "qt_editor_spinbox");
@@ -135,23 +151,23 @@ QWidget * Q3EditorFactory::createEditor(QWidget * parent, const QVariant & v)
             break;
         case QVariant::Date: {
             QDateTimeEdit *edit = new QDateTimeEdit(parent);
-            edit->setDisplayFormat("yyyy/MM/dd");
-            edit->setObjectName("qt_editor_date");
+            edit->setDisplayFormat(QLatin1String("yyyy/MM/dd"));
+            edit->setObjectName(QLatin1String("qt_editor_date"));
             w = edit; }
             break;
         case QVariant::Time: {
             QDateTimeEdit *edit = new QDateTimeEdit(parent);
-            edit->setDisplayFormat("hh:mm");
-            edit->setObjectName("qt_editor_time");
+            edit->setDisplayFormat(QLatin1String("hh:mm"));
+            edit->setObjectName(QLatin1String("qt_editor_time"));
             w = edit; }
             break;
         case QVariant::DateTime:
             w = new QDateTimeEdit(parent);
-            w->setObjectName("qt_editor_datetime");
+            w->setObjectName(QLatin1String("qt_editor_datetime"));
             break;
 #ifndef QT_NO_LABEL
         case QVariant::Pixmap:
-            w = new QLabel(parent, "qt_editor_pixmap");
+            w = new QLabel(parent, QLatin1String("qt_editor_pixmap"));
             break;
 #endif
         case QVariant::Palette:
@@ -176,4 +192,7 @@ QWidget * Q3EditorFactory::createEditor(QWidget * parent, const QVariant & v)
     }
     return w;
 }
+
+QT_END_NAMESPACE
+
 #endif // QT_NO_SQL
