@@ -1,38 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -43,6 +42,9 @@
 #elif defined(Q_WS_WIN)
     // needed for bsearch on some platforms
 #   include "qt_windows.h"
+#if defined(Q_OS_WINCE)
+#   include "qfunctions_wince.h"
+#endif
 #endif
 
 #define	 Q3GARRAY_CPP
@@ -54,6 +56,8 @@
 #  include "private/qmutexpool_p.h"
 #endif
 
+QT_BEGIN_NAMESPACE
+
 /*
   If USE_MALLOC isn't defined, we use new[] and delete[] to allocate
   memory. The documentation for QMemArray<T>::assign() explicitly
@@ -508,26 +512,10 @@ void Q3GArray::store(const char *d, uint len)
   allocating memory or copying data.
 
   Example of intended use:
-  \code
-    static uchar bindata[] = { 231, 1, 44, ... };
-    QByteArray	a;
-    a.setRawData(bindata, sizeof(bindata));	// a points to bindata
-    QDataStream s(a, IO_ReadOnly);		// open on a's data
-    s >> <something>;				// read raw bindata
-    s.close();
-    a.resetRawData(bindata, sizeof(bindata)); // finished
-  \endcode
+  \snippet doc/src/snippets/code/src_qt3support_tools_q3garray.cpp 0
 
   Example of misuse (do not do this):
-  \code
-    static uchar bindata[] = { 231, 1, 44, ... };
-    QByteArray	a, b;
-    a.setRawData(bindata, sizeof(bindata));	// a points to bindata
-    a.resize(8);				// will crash
-    b = a;					// will crash
-    a[2] = 123;					// might crash
-      // forget to resetRawData - will crash
-  \endcode
+  \snippet doc/src/snippets/code/src_qt3support_tools_q3garray.cpp 1
 
   \warning If you do not call resetRawData(), Q3GArray will attempt to
   deallocate or reallocate the raw data, which might not be too good.
@@ -683,7 +671,7 @@ static int cmp_item_size = 0;
 extern "C" {
 #endif
 
-#ifdef Q_OS_TEMP
+#ifdef Q_OS_WINCE
 static int __cdecl cmp_arr(const void *n1, const void *n2)
 #else
 static int cmp_arr(const void *n1, const void *n2)
@@ -801,3 +789,5 @@ void Q3GArray::deleteData(array_data *p)
 {
     delete p;
 }
+
+QT_END_NAMESPACE
