@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -64,6 +58,8 @@
 #include <qrubberband.h>
 #include <qdebug.h>
 
+QT_BEGIN_NAMESPACE
+
 #ifdef Q_WS_MAC
 static bool default_opaque = true;
 #else
@@ -790,10 +786,7 @@ void Q3DockWindowTitleBar::mouseDoubleClickEvent(QMouseEvent *)
     or a Q3MainWindow as its parent if you want it docked. Pass 0 for
     the parent if you want it floated.
 
-    \code
-    Q3ToolBar *fileTools = new Q3ToolBar(this, "File Actions");
-    moveDockWindow(fileTools, Left);
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3dockwindow.cpp 0
 
     In the example above we create a new Q3ToolBar in the constructor
     of a Q3MainWindow subclass (so that the \e this pointer points to
@@ -1355,7 +1348,7 @@ void Q3DockWindow::updateGui()
                 }
             }
         }
-#ifndef Q_OS_TEMP
+#ifndef Q_OS_WINCE
         if (moveEnabled)
             setLineWidth(1);
         else
@@ -1614,8 +1607,8 @@ void Q3DockWindow::setCloseMode(int m)
 
 bool Q3DockWindow::isCloseEnabled() const
 {
-    return  ((cMode & Docked) == Docked && place() == InDock ||
-              (cMode & Undocked) == Undocked && place() == OutsideDock);
+    return  (((cMode & Docked) == Docked && place() == InDock) ||
+              ((cMode & Undocked) == Undocked && place() == OutsideDock));
 }
 
 int Q3DockWindow::closeMode() const
@@ -2109,6 +2102,8 @@ void Q3DockWindow::contextMenuEvent(QContextMenuEvent *e)
         e->ignore();
 }
 
+QT_END_NAMESPACE
+
 #include "q3dockwindow.moc"
 
 #endif //QT_NO_MAINWINDOW
