@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -460,7 +454,7 @@ void QHideToolTip::maybeTip(const QPoint &pos)
     toolbar buttons then describe the facilities of Q3MainWindow
     itself.
 
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3mainwindow.cpp 0
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3mainwindow.cpp 0
 
     Q3MainWindows may be created in their own right as shown above.
     The central widget is set with setCentralWidget(). Popup menus can
@@ -561,7 +555,7 @@ void QHideToolTip::maybeTip(const QPoint &pos)
     widget inside its own movable dock window and restrict this dock
     window to only live within the \c Top or \c Bottom dock:
 
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3mainwindow.cpp 1
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3mainwindow.cpp 1
 
     An application with multiple dock windows can choose to save the
     current dock window layout in order to restore it later, e.g. in
@@ -570,12 +564,12 @@ void QHideToolTip::maybeTip(const QPoint &pos)
 
     To save the layout and positions of all the dock windows do this:
 
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3mainwindow.cpp 2
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3mainwindow.cpp 2
 
     To restore the dock window positions and sizes (normally when the
     application is next started), do the following:
 
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3mainwindow.cpp 3
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3mainwindow.cpp 3
 
     The QSettings class can be used in conjunction with the streaming
     operators to store the application's settings.
@@ -1431,7 +1425,7 @@ bool Q3MainWindow::eventFilter(QObject* o, QEvent *e)
             setUpLayout();
         d->tll->activate();
     } else if (e->type() == QEvent::ContextMenu && d->dockMenu &&
-                (qobject_cast<Q3DockArea*>(o) && dockMainWindow(o) || o == d->hideDock || o == d->mb)) {
+                ((qobject_cast<Q3DockArea*>(o) && dockMainWindow(o)) || o == d->hideDock || o == d->mb)) {
         if (showDockMenu(((QMouseEvent*)e)->globalPos())) {
             ((QContextMenuEvent*)e)->accept();
             return true;
@@ -1679,7 +1673,7 @@ void Q3MainWindow::triggerLayout(bool deleteLayout)
     implemented as a main window object's slot. This way it can easily
     be used for popup menus, for example:
 
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3mainwindow.cpp 4
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3mainwindow.cpp 4
 
     \sa Q3WhatsThis::enterWhatsThisMode()
 */
