@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -388,10 +382,10 @@ void Q3ScrollViewData::viewportResized(int w, int h)
     reliable size on X11 servers). In this usage, you just make one
     large child in the Q3ScrollView. The child should be a child of the
     viewport() of the scrollview and be added with addChild():
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3scrollview.cpp 0
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3scrollview.cpp 0
     You can go on to add arbitrary child widgets to the single child
     in the scrollview as you would with any widget:
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3scrollview.cpp 1
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3scrollview.cpp 1
 
     Here the Q3ScrollView has four children: the viewport(), the
     verticalScrollBar(), the horizontalScrollBar() and a small
@@ -412,7 +406,7 @@ void Q3ScrollViewData::viewportResized(int w, int h)
     add some widgets by making them children of the viewport() and
     adding them with addChild() (this is the same as the process for
     the single large widget in the previous example):
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3scrollview.cpp 2
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3scrollview.cpp 2
     Here, the Q3ScrollView has the same four children: the viewport(),
     the verticalScrollBar(), the horizontalScrollBar() and a small
     cornerWidget(). The viewport() has the three QLabel objects as
@@ -430,7 +424,7 @@ void Q3ScrollViewData::viewportResized(int w, int h)
     reimplement drawContents() to paint the contents. You then call
     enableClipper(true) and add widgets, again by making them children
     of the viewport(), and adding them with addChild():
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3scrollview.cpp 3
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3scrollview.cpp 3
 
     Here, the Q3ScrollView has four children:  the clipper() (not the
     viewport() this time), the verticalScrollBar(), the
@@ -1292,7 +1286,7 @@ void Q3ScrollView::setCornerWidget(QWidget* corner)
     if (oldcorner != corner) {
         if (oldcorner) oldcorner->hide();
         d->corner = corner;
-        corner->setParent(this);
+        if (corner) corner->setParent(this);
         updateScrollBars();
         if (corner) corner->show();
     }
@@ -2286,7 +2280,7 @@ void Q3ScrollView::repaintContents(bool erase)
 
     \sa updateContents()
 */
-void Q3ScrollView::repaintContents(int x, int y, int w, int h, bool erase)
+void Q3ScrollView::repaintContents(int x, int y, int w, int h, bool /*erase*/)
 {
     if (!isVisible() || !updatesEnabled())
         return;
@@ -2319,7 +2313,7 @@ void Q3ScrollView::repaintContents(int x, int y, int w, int h, bool erase)
         y -= d->clipped_viewport->y();
     }
 
-    vp->repaint(x, y, w, h, erase);
+    vp->update(x, y, w, h);
 }
 
 
@@ -2349,7 +2343,7 @@ void Q3ScrollView::drawContentsOffset(QPainter* p, int offsetx, int offsety, int
     rectangle is in the scrollview's coordinates.
 
     For example:
-    \snippet doc/src/snippets/code/src.qt3support.widgets.q3scrollview.cpp 4
+    \snippet doc/src/snippets/code/src_qt3support_widgets_q3scrollview.cpp 4
 
     The clip rectangle and translation of the painter \a p is already
     set appropriately.
