@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtScript module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -72,7 +66,7 @@ QT_BEGIN_NAMESPACE
   Use evaluate() to evaluate script code; this is the C++ equivalent
   of the built-in script function \c{eval()}.
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 0
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 0
 
   evaluate() returns a QScriptValue that holds the result of the
   evaluation. The QScriptValue class provides functions for converting
@@ -82,13 +76,13 @@ QT_BEGIN_NAMESPACE
   The following code snippet shows how a script function can be
   defined and then invoked from C++ using QScriptValue::call():
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 1
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 1
 
   As can be seen from the above snippets, a script is provided to the
   engine in the form of a string. One common way of loading scripts is
   by reading the contents of a file and passing it to evaluate():
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 2
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 2
 
   Here we pass the name of the file as the second argument to
   evaluate().  This does not affect evaluation in any way; the second
@@ -105,7 +99,7 @@ QT_BEGIN_NAMESPACE
   want to configure a script engine by adding one or more properties
   to the Global Object:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 3
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 3
 
   Adding custom properties to the scripting environment is one of the
   standard means of providing a scripting API that is specific to your
@@ -126,7 +120,7 @@ QT_BEGIN_NAMESPACE
   Calling clearExceptions() will cause any uncaught exceptions to be
   cleared.
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 4
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 4
 
   When handling possibly incomplete input, the canEvaluate() function
   can be used to determine whether code can usefully be passed to
@@ -151,7 +145,7 @@ QT_BEGIN_NAMESPACE
   properties of the proxy object. No binding code is needed because it
   is done dynamically using the Qt meta object system.
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 5
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 5
 
   Use qScriptConnect() to connect a C++ signal to a script function;
   this is the Qt Script equivalent of QObject::connect().  When a
@@ -212,17 +206,17 @@ QT_BEGIN_NAMESPACE
   argument to newFunction(). Here is an example of a function that
   returns the sum of its first two arguments:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 6
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 6
 
   To expose this function to script code, you can set it as a property
   of the Global Object:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 7
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 7
 
   Once this is done, script code can call your function in the exact
   same manner as a "normal" script function:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 8
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 8
 
   \section1 Long-running Scripts
 
@@ -394,12 +388,12 @@ QScriptValue QScriptEngine::undefinedValue()
   wrapping a custom type, by having registered the defaultPrototype()
   of that type. Example:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 9
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 9
 
   To wrap a custom type and provide a constructor for it, you'd typically
   do something like this:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 10
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 10
 */
 QScriptValue QScriptEngine::newFunction(QScriptEngine::FunctionSignature fun,
                                         const QScriptValue &prototype,
@@ -639,7 +633,7 @@ QScriptValue QScriptEngine::newActivationObject()
   functions (analogous to how properties work in \l{Qt's Property
   System}). Example:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 11
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 11
 
   When the property \c{foo} of the script object is subsequently
   accessed in script code, \c{getSetFoo()} will be invoked to handle
@@ -654,7 +648,7 @@ QScriptValue QScriptEngine::newActivationObject()
   (QScriptValue::PropertyGetter or QScriptValue::PropertySetter) when
   setting the property, e.g.:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 12
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 12
 
   \sa QScriptValue::call()
 */
@@ -670,6 +664,7 @@ QScriptValue QScriptEngine::newFunction(QScriptEngine::FunctionSignature fun, in
 
 /*!
   \internal
+  \since 4.4
 */
 QScriptValue QScriptEngine::newFunction(QScriptEngine::FunctionWithArgSignature fun, void *arg)
 {
@@ -746,7 +741,7 @@ QScriptValue QScriptEngine::newDate(const QDateTime &value)
 
   Example:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 27
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 27
 
   \sa newQObject(), scriptValueFromQMetaObject()
 */
@@ -767,7 +762,7 @@ QScriptValue QScriptEngine::newQMetaObject(
   This function is used in combination with one of the
   Q_SCRIPT_DECLARE_QMETAOBJECT() macro. Example:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 13
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 13
 
   \warning This function is not available with MSVC 6. Use
   qScriptValueFromQMetaObject() instead if you need to support that version
@@ -820,27 +815,27 @@ QScriptValue QScriptEngine::newQMetaObject(
   different results.)
 
   Given the input
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 14
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 14
   canEvaluate() will return true, since the program appears to be complete.
 
   Given the input
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 15
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 15
   canEvaluate() will return false, since the if-statement is not complete,
   but is syntactically correct so far.
 
   Given the input
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 16
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 16
   canEvaluate() will return true, but evaluate() will throw a
   SyntaxError given the same input.
 
   Given the input
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 17
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 17
   canEvaluate() will return true, even though the code is clearly not
   syntactically valid QtScript code. evaluate() will throw a
   SyntaxError when this code is evaluated.
 
   Given the input
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 18
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 18
   canEvaluate() will return true, but evaluate() will throw a
   ReferenceError if \c{foo} is not defined in the script
   environment.
@@ -916,7 +911,7 @@ QScriptContext *QScriptEngine::currentContext() const
   \l{QScriptContext::activationObject()}{activationObject}() to initialize
   local variables that will be available to scripts. Example:
 
-  \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 19
+  \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 19
 
   In the above example, the new variable "tmp" defined in the script
   will be local to the context; in other words, the script doesn't
@@ -1060,13 +1055,23 @@ void QScriptEngine::setDefaultPrototype(int metaTypeId, const QScriptValue &prot
 }
 
 /*!
-    \typedef QScriptEngine::FunctionSignature
-    \relates QScriptEngine
+  \typedef QScriptEngine::FunctionSignature
+  \relates QScriptEngine
 
-    The function signature \c{QScriptValue f(QScriptContext *, QScriptEngine *)}.
+  The function signature \c{QScriptValue f(QScriptContext *, QScriptEngine *)}.
 
-    A function with such a signature can be passed to QScriptEngine::newFunction()
-    to wrap the function.
+  A function with such a signature can be passed to
+  QScriptEngine::newFunction() to wrap the function.
+*/
+
+/*!
+  \typedef QScriptEngine::FunctionWithArgSignature
+  \relates QScriptEngine
+
+  The function signature \c{QScriptValue f(QScriptContext *, QScriptEngine *, void *)}.
+
+  A function with such a signature can be passed to
+  QScriptEngine::newFunction() to wrap the function.
 */
 
 /*!
@@ -1324,28 +1329,28 @@ QStringList QScriptEngine::importedExtensions() const
     specify custom conversion of our type \c{MyStruct}. Here's the C++
     type:
 
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 20
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 20
 
     We must declare it so that the type will be known to QMetaType:
 
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 21
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 21
 
     Next, the \c{MyStruct} conversion functions. We represent the
     \c{MyStruct} value as a script object and just copy the properties:
 
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 22
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 22
 
     Now we can register \c{MyStruct} with the engine:
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 23
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 23
 
     Working with \c{MyStruct} values is now easy:
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 24
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 24
 
     If you want to be able to construct values of your custom type
     from script code, you have to register a constructor function for
     the type. For example:
 
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 25
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 25
 
     \sa qScriptRegisterSequenceMetaType(), qRegisterMetaType()
 */
@@ -1385,7 +1390,7 @@ QStringList QScriptEngine::importedExtensions() const
     type, it must be declared using Q_DECLARE_METATYPE() as well.
     Example:
 
-    \snippet doc/src/snippets/code/src.script.qscriptengine.cpp 26
+    \snippet doc/src/snippets/code/src_script_qscriptengine.cpp 26
 
     \sa qScriptRegisterMetaType()
 */
