@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtScript module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -1524,6 +1518,8 @@ void QScript::QtFunction::execute(QScriptContextPrivate *context)
                 tid = argType.typeId();
                 v = QVariant(tid, (void *)0);
                 converted = eng_p->convert(actual, tid, v.data());
+                if (eng_p->hasUncaughtException())
+                    return;
             }
 
             if (!converted) {
@@ -1912,8 +1908,10 @@ public:
 
     virtual bool resolve(const QScriptValueImpl &object, QScriptNameIdImpl *nameId,
                          QScript::Member *member, QScriptValueImpl *base);
-    virtual bool get(const QScriptValueImpl &obj, const QScript::Member &member,
+    virtual bool get(const QScriptValueImpl &object, const QScript::Member &member,
                      QScriptValueImpl *result);
+    virtual bool put(QScriptValueImpl *object, const QScript::Member &member,
+                     const QScriptValueImpl &value);
     virtual void mark(const QScriptValueImpl &object, int generation);
 
 private:
@@ -1935,9 +1933,14 @@ bool ExtQMetaObjectData::resolve(const QScriptValueImpl &object,
     if (!meta)
         return false;
 
-    QScriptEngine *eng = object.engine();
+    QScriptEnginePrivate *eng_p = QScriptEnginePrivate::get(object.engine());
+    if (eng_p->idTable()->id_prototype == nameId) {
+        // prototype property is a proxy to constructor's prototype property
+        member->native(nameId, /*id=*/0, QScriptValue::Undeletable);
+        return true;
+    }
 
-    QByteArray name = QScriptEnginePrivate::get(eng)->toString(nameId).toLatin1();
+    QByteArray name = eng_p->toString(nameId).toLatin1();
 
     for (int i = 0; i < meta->enumeratorCount(); ++i) {
         QMetaEnum e = meta->enumerator(i);
@@ -1956,14 +1959,35 @@ bool ExtQMetaObjectData::resolve(const QScriptValueImpl &object,
     return false;
 }
 
-bool ExtQMetaObjectData::get(const QScriptValueImpl &obj,
+bool ExtQMetaObjectData::get(const QScriptValueImpl &object,
                              const QScript::Member &member,
                              QScriptValueImpl *result)
 {
     if (! member.isNativeProperty())
         return false;
 
-    *result = QScriptValueImpl(QScriptEnginePrivate::get(obj.engine()), member.id());
+    QScriptEnginePrivate *eng_p = QScriptEnginePrivate::get(object.engine());
+    if (eng_p->idTable()->id_prototype == member.nameId()) {
+        ExtQMetaObject::Instance *inst = ExtQMetaObject::Instance::get(object, m_classInfo);
+        *result = inst->ctor.property(eng_p->idTable()->id_prototype);
+    } else {
+        *result = QScriptValueImpl(eng_p, member.id());
+    }
+    return true;
+}
+
+bool ExtQMetaObjectData::put(QScriptValueImpl *object, const Member &member,
+                             const QScriptValueImpl &value)
+{
+    if (! member.isNativeProperty())
+        return false;
+
+    QScriptEnginePrivate *eng_p = QScriptEnginePrivate::get(object->engine());
+    if (eng_p->idTable()->id_prototype == member.nameId()) {
+        ExtQMetaObject::Instance *inst = ExtQMetaObject::Instance::get(*object, m_classInfo);
+        inst->ctor.setProperty(eng_p->idTable()->id_prototype, value);
+    }
+
     return true;
 }
 
