@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtScript module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -88,7 +82,7 @@ QT_BEGIN_NAMESPACE
   QScriptValues. Use setProperty() to set a property of an object, and
   call property() to retrieve the value of a property.
 
-  \snippet doc/src/snippets/code/src.script.qscriptvalue.cpp 0
+  \snippet doc/src/snippets/code/src_script_qscriptvalue.cpp 0
 
   Each property can have a set of attributes; these are specified as
   the third (optional) argument to setProperty(). The attributes of a
@@ -96,7 +90,7 @@ QT_BEGIN_NAMESPACE
   following code snippet creates a property that cannot be modified by
   script code:
 
-  \snippet doc/src/snippets/code/src.script.qscriptvalue.cpp 1
+  \snippet doc/src/snippets/code/src_script_qscriptvalue.cpp 1
 
   If you want to iterate over the properties of a script object, use
   the QScriptValueIterator class.
@@ -854,7 +848,7 @@ void QScriptValue::setProperty(const QString &name, const QScriptValue &value,
   occurred, property() returns the value that was thrown (typically
   an \c{Error} object).
 
-  \sa setProperty(), propertyFlags()
+  \sa setProperty(), propertyFlags(), QScriptValueIterator
 */
 QScriptValue QScriptValue::property(const QString &name,
                                     const ResolveFlags &mode) const
@@ -906,6 +900,8 @@ void QScriptValue::setProperty(quint32 arrayIndex, const QScriptValue &value,
 }
 
 /*! 
+  \since 4.4
+
   Returns the value of this QScriptValue's property with the given \a name,
   using the given \a mode to resolve the property.
 
@@ -925,6 +921,8 @@ QScriptValue QScriptValue::property(const QScriptString &name,
 }
 
 /*!
+  \since 4.4
+
   Sets the value of this QScriptValue's property with the given \a
   name to the given \a value. The given \a flags specify how this
   property may be accessed by script code.
@@ -964,6 +962,8 @@ QScriptValue::PropertyFlags QScriptValue::propertyFlags(const QString &name,
 }
 
 /*!
+  \since 4.4
+
   Returns the flags of the property with the given \a name, using the
   given \a mode to resolve the property.
 
@@ -997,7 +997,7 @@ QScriptValue::PropertyFlags QScriptValue::propertyFlags(const QScriptString &nam
   QScriptEngine::hasUncaughtException() to determine if an exception
   occurred.
 
-  \snippet doc/src/snippets/code/src.script.qscriptvalue.cpp 2
+  \snippet doc/src/snippets/code/src_script_qscriptvalue.cpp 2
 
   \sa construct()
 */
@@ -1033,7 +1033,7 @@ QScriptValue QScriptValue::call(const QScriptValue &thisObject,
   One common usage of this function is to forward native function
   calls to another function:
 
-  \snippet doc/src/snippets/code/src.script.qscriptvalue.cpp 3
+  \snippet doc/src/snippets/code/src_script_qscriptvalue.cpp 3
 
   \sa construct(), QScriptContext::argumentsObject()
 */
