@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtTest module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -100,7 +94,7 @@ QT_BEGIN_NAMESPACE
    by the test framework.
 
    Example:
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 0
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 0
 
    \sa QCOMPARE()
 */
@@ -114,7 +108,7 @@ QT_BEGIN_NAMESPACE
     C string.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 1
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 1
 
     \sa QVERIFY(), QCOMPARE()
 */
@@ -128,6 +122,10 @@ QT_BEGIN_NAMESPACE
    continues. If not, a failure is recorded in the test log and the test
    won't be executed further.
 
+   In the case of comparing floats and doubles, qFuzzyCompare() is used for
+   comparing. This means that comparing to 0 will likely fail. One solution
+   to this is to compare to 1, and add 1 to the produced output.
+
    QCOMPARE tries to output the contents of the values if the comparison fails,
    so it is visible from the test log why the comparison failed.
 
@@ -146,7 +144,7 @@ QT_BEGIN_NAMESPACE
    by the test framework.
 
    Example:
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 2
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 2
 
    \sa QVERIFY(), QTest::toString()
 */
@@ -161,12 +159,12 @@ QT_BEGIN_NAMESPACE
 
    Assuming a test has the following data:
 
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 3
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 3
 
    The test data has two elements, a QString called \c aString and an integer
    called \c expected. To fetch these values in the actual test:
 
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 4
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 4
 
    \c aString and \c expected are variables on the stack that are initialized with
    the current test data.
@@ -196,7 +194,7 @@ QT_BEGIN_NAMESPACE
 
    Example:
 
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 5
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 5
 */
 
 /*! \macro QTEST(actual, testElement)
@@ -211,11 +209,11 @@ QT_BEGIN_NAMESPACE
 
    Instead of writing:
 
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 6
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 6
 
    you can write:
 
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 7
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 7
 
    \sa QCOMPARE()
 */
@@ -234,7 +232,7 @@ QT_BEGIN_NAMESPACE
    by the test framework.
 
    Example:
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 8
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 8
 
    \sa QTest::SkipMode
 */
@@ -263,7 +261,7 @@ QT_BEGIN_NAMESPACE
    by the test framework.
 
    Example 1:
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 9
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 9
 
    In the example above, an expected fail will be written into the test output
    if the variable \c i is not 42. If the variable \c i is 42, an unexpected pass
@@ -271,7 +269,7 @@ QT_BEGIN_NAMESPACE
    statement in the example.
 
    Example 2:
-   \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 10
+   \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 10
 
    The above testfunction will not continue executing for the test data
    entry \c{data27}.
@@ -288,7 +286,7 @@ QT_BEGIN_NAMESPACE
     Use this macro to build stand-alone executables.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 11
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 11
 
     \sa QTEST_APPLESS_MAIN(), QTest::qExec()
 */
@@ -313,7 +311,7 @@ QT_BEGIN_NAMESPACE
     Use this macro to create a test that produces valid test output but just
     doesn't execute any test, for example in conditional compilations:
 
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 12
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 12
 
     \sa QTEST_MAIN()
 */
@@ -373,7 +371,7 @@ QT_BEGIN_NAMESPACE
     Simulates clicking of \a key with an optional \a modifier on a \a widget. If \a delay is larger than 0, the test will wait for \a delay milliseconds.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 13
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 13
 
     The example above simulates clicking \c a on \c myWidget without
     any keyboard modifiers and without delay of the test.
@@ -386,7 +384,7 @@ QT_BEGIN_NAMESPACE
     Simulates clicking of \a key with an optional \a modifier on a \a widget. If \a delay is larger than 0, the test will wait for \a delay milliseconds.
 
     Examples:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 14
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 14
 
     The first example above simulates clicking the \c escape key on \c
     myWidget without any keyboard modifiers and without delay. The
@@ -454,7 +452,7 @@ QT_BEGIN_NAMESPACE
     click.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 15
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 15
 
     The example above simulates clicking the sequence of keys
     representing "hello world" on \c myWidget without any keyboard
@@ -530,7 +528,7 @@ QT_BEGIN_NAMESPACE
 
     Example:
 
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 16
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 16
 
     The example above defines a toString() specialization for a class
     called \c MyPoint. Whenever a comparison of two instances of \c
@@ -615,6 +613,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \fn char *QTest::toString(const QUrl &url)
+    \since 4.4
     \overload
 
     Returns a textual representation of the given \a url.
@@ -647,7 +646,7 @@ QT_BEGIN_NAMESPACE
     your test will stay responsive to user interface events or network communication.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 17
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 17
 
     The code above will wait until the network server is responding for a
     maximum of about 12.5 seconds.
@@ -1112,7 +1111,7 @@ char *toHexRepresentation(const char *ba, int length)
     The following example will run all tests in \c MyFirstTestObject and
     \c{MySecondTestObject}:
 
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 18
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 18
 
     Note: This function is not reentrant, only one test can run at a time. A
     test that was executed with qExec() can't run another test via qExec() and
@@ -1232,6 +1231,7 @@ int QTest::qExec(QObject *testObject, int argc, char **argv)
 
 /*!
   \overload
+  \since 4.4
 
   Behaves identically to qExec(QObject *, int, char**) but takes a
   QStringList of \a arguments instead of a \c char** list.
@@ -1306,7 +1306,7 @@ void QTest::qWarn(const char *message)
     call ignoreMessage() twice, too.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 19
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 19
 
     The example above tests that QDir::mkdir() outputs the right warning when invoked
     with an invalid file name.
@@ -1362,7 +1362,7 @@ void QTest::addColumnInternal(int id, const char *name)
     that can be used to stream in data.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 20
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 20
 
     \bold {Note:} This macro can only be used in a test's data function
     that is invoked by the test framework.
@@ -1390,7 +1390,7 @@ QTestData &QTest::newRow(const char *dataTag)
     \l QFETCH() to fetch the data in the actual test.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 21
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 21
 
     To add custom types to the testdata, the type must be registered with
     QMetaType via \l Q_DECLARE_METATYPE().
@@ -1409,7 +1409,7 @@ QTestData &QTest::newRow(const char *dataTag)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 22
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 22
 */
 const char *QTest::currentTestFunction()
 {
@@ -1446,7 +1446,7 @@ bool QTest::currentTestFailed()
     qSleep() depends on the operating system.
 
     Example:
-    \snippet doc/src/snippets/code/src.qtestlib.qtestcase.cpp 23
+    \snippet doc/src/snippets/code/src_qtestlib_qtestcase.cpp 23
 
     \sa qWait()
 */
