@@ -1,38 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -41,6 +40,8 @@
 
 #include <QVariant>
 
+QT_BEGIN_NAMESPACE
+
 class QDomElement;
 class QDomDocument;
 class QDomNode;
@@ -64,7 +65,6 @@ struct Common
     inline void init()
     { kind = Kind_Unknown; }
 };
-Q_DECLARE_METATYPE(Common)
 
 struct Color
 {
@@ -82,7 +82,6 @@ struct Color
     inline bool operator == (const Color &other) const
     { return red == other.red && green == other.green && blue == other.blue; }
 };
-Q_DECLARE_METATYPE(Color)
 
 struct Point
 {
@@ -96,7 +95,6 @@ struct Point
         this->y = y;
     }
 };
-Q_DECLARE_METATYPE(Point)
 
 struct Size
 {
@@ -113,7 +111,6 @@ struct Size
         this->height = height;
     }
 };
-Q_DECLARE_METATYPE(Size)
 
 struct Rect
 {
@@ -130,7 +127,6 @@ struct Rect
         this->height = height;
     }
 };
-Q_DECLARE_METATYPE(Rect)
 
 struct Font
 {
@@ -153,7 +149,6 @@ struct Font
         strikeout = false;
     }
 };
-Q_DECLARE_METATYPE(Font)
 
 struct SizePolicy
 {
@@ -172,7 +167,6 @@ struct SizePolicy
         verstretch = 0;
     }
 };
-Q_DECLARE_METATYPE(SizePolicy)
 
 struct Cursor
 {
@@ -185,7 +179,6 @@ struct Cursor
         this->shape = shape;
     }
 };
-Q_DECLARE_METATYPE(Cursor)
 
 union Variant
 {
@@ -233,7 +226,6 @@ union Variant
     inline Variant &createCursor(int shape)
     { cursor.init(shape); return *this; }
 };
-Q_DECLARE_METATYPE(Variant)
 
 class DomTool
 {
@@ -253,6 +245,20 @@ public:
     static void fixAttribute(QDomNode&, double);
 };
 
+QT_END_NAMESPACE
+
+Q_DECLARE_METATYPE(Size)
+Q_DECLARE_METATYPE(Rect)
+Q_DECLARE_METATYPE(Font)
+Q_DECLARE_METATYPE(SizePolicy)
+Q_DECLARE_METATYPE(Cursor)
+Q_DECLARE_METATYPE(Color)
+Q_DECLARE_METATYPE(Point)
+Q_DECLARE_METATYPE(Common)
+Q_DECLARE_METATYPE(Variant)
+
+QT_BEGIN_NAMESPACE
+
 inline Variant asVariant(const QVariant &v)
 {
     Variant var;
@@ -260,4 +266,6 @@ inline Variant asVariant(const QVariant &v)
     return var;
 }
 
+QT_END_NAMESPACE
+
 #endif // DOMTOOL_H
