@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtXMLPatterns module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -94,7 +88,7 @@ QXmlSerializerPrivate::QXmlSerializerPrivate(const QXmlQuery &query,
 
 /*!
   \class QXmlSerializer
-  \brief The QXmlSerializer class receives an XQuery sequence and translates it into XML.
+  \brief The QXmlSerializer class is an implementation of QAbstractXmlReceiver for transforming XQuery output into unformatted XML.
 
   \reentrant
   \since 4.4
@@ -103,7 +97,7 @@ QXmlSerializerPrivate::QXmlSerializerPrivate(const QXmlQuery &query,
   QXmlSerializer translates an \l {XQuery Sequence} {XQuery sequence}, usually
   the output of an QXmlQuery, into XML. Consider the example:
 
-  \snippet doc/src/snippets/code/src.xmlpatterns.api.qxmlserializer.cpp 0
+  \snippet doc/src/snippets/code/src_xmlpatterns_api_qxmlserializer.cpp 0
 
   First it constructs a \l {QXmlQuery} {query} that gets the
   first paragraph from document \c index.html. Then it constructs
@@ -151,10 +145,9 @@ QXmlSerializerPrivate::QXmlSerializerPrivate(const QXmlQuery &query,
   write mode, otherwise behavior is undefined.
 
   \a outputDevice must not be opened with QIODevice::Text because it
-  will cause the output to be incorrect. This class will ensure line endings
-  are serialized as according with the XML specification.
-
- QXmlSerializer does not own \a outputDevice.
+  will cause the output to be incorrect. This class will ensure line
+  endings are serialized as according with the XML specification.
+  QXmlSerializer does not take ownership of \a outputDevice.
  */
 QXmlSerializer::QXmlSerializer(const QXmlQuery &query,
                                QIODevice *outputDevice) : QAbstractXmlReceiver(new QXmlSerializerPrivate(query, outputDevice))
@@ -179,7 +172,7 @@ bool QXmlSerializer::atDocumentRoot() const
 {
     Q_D(const QXmlSerializer);
     return d->state == BeforeDocumentElement ||
-           d->state == InsideDocumentElement && d->hasClosedElement.size() == 1;
+           (d->state == InsideDocumentElement && d->hasClosedElement.size() == 1);
 }
 
 /*!
@@ -374,7 +367,7 @@ void QXmlSerializer::attribute(const QXmlName &name,
     {
         Q_UNUSED(d);
         d->query.d->staticContext()->error(QtXmlPatterns::tr(
-           "Attribute element %1 can't be serialized because it appears at "
+           "Attribute %1 can't be serialized because it appears at "
            "the top level.").arg(formatKeyword(d->np, name)),
                                            ReportContext::SENR0001,
                                            d->query.d->expression().data());
@@ -589,10 +582,11 @@ void QXmlSerializer::endDocument()
 }
 
 /*!
- Returns a pointer to the output device. There is no corresponding
- function to \e set the output device, because the output device
- must be passed to the constructor. The serializer does not own
- the IO device returned.
+
+  Returns a pointer to the output device. There is no corresponding
+  function to \e set the output device, because the output device must
+  be passed to the constructor. The serializer does not take ownership
+  of its IO device.
  */
 QIODevice *QXmlSerializer::outputDevice() const
 {
@@ -603,9 +597,8 @@ QIODevice *QXmlSerializer::outputDevice() const
 /*!
   Sets the codec the serializer will use for encoding its XML output.
   The output codec is set to \a outputCodec. By default, the output
-  codec is set to the one for \c UTF-8.
-
-  The serializer does not take ownership of the codec.
+  codec is set to the one for \c UTF-8. The serializer does not take
+  ownership of the codec.
 
   \sa codec()
 
@@ -642,7 +635,8 @@ void QXmlSerializer::endOfSequence()
 {
     /* If this function is changed to flush or close or something like that,
      * take into consideration QXmlFormatter, especially
-     * QXmlFormatter::endOfSequence(). */
+     * QXmlFormatter::endOfSequence().
+     */
 }
 
 QT_END_NAMESPACE
