@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -497,7 +491,6 @@ void Reader::cleanupIndex(EntryTable &entryTable)
 QHelpSearchIndexReader::QHelpSearchIndexReader()
     : QThread()
     , m_cancel(false)
-    , m_collectionFile(QString())
 {
     // nothing todo
 }
@@ -519,7 +512,8 @@ void QHelpSearchIndexReader::cancelSearching()
     mutex.unlock();
 }
 
-void QHelpSearchIndexReader::search(const QString &collectionFile, 
+void QHelpSearchIndexReader::search(const QString &collectionFile,
+                                    const QString &indexFilesFolder,
                                     const QList<QHelpSearchQuery> &queryList)
 {
     QMutexLocker lock(&mutex);
@@ -528,6 +522,7 @@ void QHelpSearchIndexReader::search(const QString &collectionFile,
     this->m_cancel = false;
     this->m_query = queryList;
     this->m_collectionFile = collectionFile;
+    this->m_indexFilesFolder = indexFilesFolder;
 
     start(QThread::NormalPriority);
 }
@@ -554,6 +549,7 @@ void QHelpSearchIndexReader::run()
     const QList<QHelpSearchQuery> &queryList = this->m_query;
     const QLatin1String key("DefaultSearchNamespaces");
     const QString collectionFile(this->m_collectionFile);
+    const QString indexPath = m_indexFilesFolder;
     
     mutex.unlock();
 
@@ -571,13 +567,7 @@ void QHelpSearchIndexReader::run()
     QHelpEngineCore engine(collectionFile, 0);
     if (!engine.setupData())
         return;
-
-    QString indexPath = engine.customValue(QLatin1String("indexFilesFolder")).toString();
-    QDir dir(indexPath);
-    if (!dir.isAbsolute()) {
-        indexPath = QFileInfo(engine.collectionFile()).path() + dir.separator() + dir.path();
-    }
-
+    
     const QStringList registeredDocs = engine.registeredDocumentations();
     const QStringList indexedNamespaces = engine.customValue(key).toString().
         split(QLatin1String("|"), QString::SkipEmptyParts);
