@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -73,7 +67,7 @@
 QT_BEGIN_NAMESPACE
 
 namespace {
-    HelpViewer* helpViewerFromTabPosition(const QTabWidget *widget, const QPoint &point) 
+    HelpViewer* helpViewerFromTabPosition(const QTabWidget *widget, const QPoint &point)
     {
         QTabBar *tabBar = qFindChild<QTabBar*>(widget);
         for (int i = 0; i < tabBar->count(); ++i) {
@@ -97,7 +91,7 @@ FindWidget::FindWidget(QWidget *parent)
     hboxLayout->setMargin(0);
 #endif
 
-    toolClose = new QToolButton(this);    
+    toolClose = new QToolButton(this);
     toolClose->setIcon(QIcon(QString::fromUtf8(":/trolltech/assistant/images/%1/closetab.png").arg(system)));
     toolClose->setAutoRaise(true);
     hboxLayout->addWidget(toolClose);
@@ -135,10 +129,10 @@ FindWidget::FindWidget(QWidget *parent)
     labelWrapped->setMinimumSize(QSize(0, 20));
     labelWrapped->setMaximumSize(QSize(105, 20));
     labelWrapped->setTextFormat(Qt::RichText);
-    labelWrapped->setScaledContents(true);    
+    labelWrapped->setScaledContents(true);
     labelWrapped->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
     labelWrapped->setText(tr("<img src=\":/trolltech/assistant/images/wrap.png\">&nbsp;Search wrapped"));
-    hboxLayout->addWidget(labelWrapped);    
+    hboxLayout->addWidget(labelWrapped);
 
     QSpacerItem *spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
     hboxLayout->addItem(spacerItem);
@@ -175,10 +169,11 @@ CentralWidget::CentralWidget(QHelpEngine *engine, MainWindow *parent)
     lastTabPage = 0;
     globalActionList.clear();
     collectionFile = helpEngine->collectionFile();
-    
+    usesDefaultCollection = parent->usesDefaultCollection();
+
     QString system = QLatin1String("win");
     QVBoxLayout *vboxLayout = new QVBoxLayout(this);
-    
+
 #ifdef Q_OS_MAC
     system = QLatin1String("mac");
 #else
@@ -215,7 +210,7 @@ CentralWidget::CentralWidget(QHelpEngine *engine, MainWindow *parent)
     findBar->hide();
     findWidget->editFind->installEventFilter(this);
     connect(findWidget->toolClose, SIGNAL(clicked()), findBar, SLOT(hide()));
-    
+
     connect(findWidget->toolNext, SIGNAL(clicked()), this, SLOT(findNext()));
     connect(findWidget->editFind, SIGNAL(returnPressed()), this, SLOT(findNext()));
     connect(findWidget->editFind, SIGNAL(textChanged(const QString&)), this, SLOT(findCurrentText(const QString&)));
@@ -225,28 +220,47 @@ CentralWidget::CentralWidget(QHelpEngine *engine, MainWindow *parent)
     if (tabBar) {
         tabBar->installEventFilter(this);
         tabBar->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(tabBar, SIGNAL(customContextMenuRequested(const QPoint&)), 
+        connect(tabBar, SIGNAL(customContextMenuRequested(const QPoint&)),
                 this, SLOT(showTabBarContextMenu(const QPoint&)));
     }
 
     staticCentralWidget = this;
+    QPalette p = palette();
+    p.setColor(QPalette::Inactive, QPalette::Highlight,
+        p.color(QPalette::Active, QPalette::Highlight));
+    p.setColor(QPalette::Inactive, QPalette::HighlightedText,
+        p.color(QPalette::Active, QPalette::HighlightedText));
+    setPalette(p);    
 }
 
 CentralWidget::~CentralWidget()
 {
-    QDir dir;
-    QString currentPages;
     QHelpEngineCore engine(collectionFile, 0);
+    if (!engine.setupData())
+        return;
 
-    if (engine.setupData()) {
-        for (int i = 1; i < tabWidget->count(); ++i) {
-            HelpViewer *viewer = qobject_cast<HelpViewer*>(tabWidget->widget(i));
-            if (viewer && viewer->source().isValid())
-                currentPages.append(viewer->source().toString()).append(QLatin1Char('|'));
+    QString zoomCount;
+    QString currentPages;
+    QLatin1Char sep('|');
+    for (int i = 1; i < tabWidget->count(); ++i) {
+        HelpViewer *viewer = qobject_cast<HelpViewer*>(tabWidget->widget(i));
+        if (viewer && viewer->source().isValid()) {
+            currentPages.append(viewer->source().toString()).append(sep);
+#if defined(USE_WEBKIT)
+            zoomCount.append(QString::number(viewer->textSizeMultiplier())).
+                append(sep);
+#else
+            zoomCount.append(QString::number(viewer->zoom())).append(sep);
+#endif
         }
-        engine.setCustomValue(QLatin1String("LastTabPage"), lastTabPage);
-        engine.setCustomValue(QLatin1String("LastShownPages"), currentPages);
     }
+    engine.setCustomValue(QLatin1String("LastTabPage"), lastTabPage);
+    engine.setCustomValue(QLatin1String("LastShownPages"), currentPages);
+#if defined(USE_WEBKIT)
+    engine.setCustomValue(QLatin1String("LastPagesZoomWebView"), zoomCount);
+#else
+    engine.setCustomValue(QLatin1String("LastPagesZoomTextBrowser"), zoomCount);
+#endif
 }
 
 CentralWidget *CentralWidget::instance()
@@ -346,24 +360,38 @@ void CentralWidget::setSource(const QUrl &url)
     currentPageChanged(lastTabPage);
     viewer->setFocus(Qt::OtherFocusReason);
     tabWidget->setCurrentIndex(lastTabPage);
-    tabWidget->setTabText(lastTabPage, viewer->documentTitle());
+    tabWidget->setTabText(lastTabPage, quoteTabTitle(viewer->documentTitle()));
 }
 
 void CentralWidget::setLastShownPages()
 {
-    const QStringList lastShownPageList = helpEngine->customValue(QLatin1String("LastShownPages")).
-        toString().split(QLatin1Char('|'), QString::SkipEmptyParts);
+#if defined(USE_WEBKIT)
+    QLatin1String zoom("LastPagesZoomWebView");
+#else
+    QLatin1String zoom("LastPagesZoomTextBrowser");
+#endif
+
+    const QStringList lastShownPageList =
+        helpEngine->customValue(QLatin1String("LastShownPages")).toString().
+        split(QLatin1Char('|'), QString::SkipEmptyParts);
 
     if (!lastShownPageList.isEmpty()) {
-        foreach (const QString page, lastShownPageList)
-            setSourceInNewTab(page);
+        QVector<QString>zoomList = helpEngine->customValue(zoom).toString().
+            split(QLatin1Char('|'), QString::SkipEmptyParts).toVector();
+        if (zoomList.isEmpty())
+            zoomList.fill(QLatin1String("0.0"), lastShownPageList.size());
         
-        tabWidget->setCurrentIndex(helpEngine->customValue(QLatin1String("LastTabPage"), 1).toInt());
-    } else {
-        setSource(QUrl(QLatin1String("help")));
-    }
+        QVector<QString>::const_iterator zIt = zoomList.constBegin();
+        QStringList::const_iterator it = lastShownPageList.constBegin();
+        for (; it != lastShownPageList.constEnd(); ++it, ++zIt)
+            setSourceInNewTab((*it), (*zIt).toFloat());
 
-    updateBrowserFont();
+        tabWidget->setCurrentIndex(helpEngine->customValue(
+            QLatin1String("LastTabPage"), 1).toInt());
+    } else {
+        if (usesDefaultCollection)
+            setSource(QUrl(QLatin1String("help")));
+    }
 }
 
 bool CentralWidget::hasSelection() const
@@ -442,7 +470,7 @@ void CentralWidget::printPreview()
     initPrinter();
     QPrintPreviewDialog preview(printer, this);
     connect(&preview, SIGNAL(paintRequested(QPrinter *)), SLOT(printPreview(QPrinter *)));
-    preview.exec();    
+    preview.exec();
 #endif
 }
 
@@ -458,7 +486,7 @@ void CentralWidget::printPreview(QPrinter *p)
 void CentralWidget::pageSetup()
 {
 #ifndef QT_NO_PRINTER
-    initPrinter();    
+    initPrinter();
     QPageSetupDialog dlg(printer);
     dlg.exec();
 #endif
@@ -518,19 +546,29 @@ void CentralWidget::setGlobalActions(const QList<QAction*> &actions)
 {
     globalActionList = actions;
 }
-void CentralWidget::setSourceInNewTab(const QUrl &url)
+
+void CentralWidget::setSourceInNewTab(const QUrl &url, qreal zoom)
 {
     HelpViewer* viewer = new HelpViewer(helpEngine, this);
     viewer->installEventFilter(this);
     viewer->setSource(url);
     viewer->setFocus(Qt::OtherFocusReason);
-    tabWidget->setCurrentIndex(tabWidget->addTab(viewer, viewer->documentTitle()));
+    tabWidget->setCurrentIndex(tabWidget->addTab(viewer, quoteTabTitle(viewer->documentTitle())));
 
     QFont font = qApp->font();
-    if (helpEngine->customValue(QLatin1String("useBrowserFont")).toBool())
-        font = qVariantValue<QFont>(helpEngine->customValue(QLatin1String("browserFont")));
+    if (helpEngine->customValue(QLatin1String("useBrowserFont")).toBool()) {
+        font = qVariantValue<QFont>(helpEngine->customValue(
+            QLatin1String("browserFont")));
+    }
 
+#if defined(USE_WEBKIT)
     viewer->setFont(font);
+    viewer->setTextSizeMultiplier(zoom == 0.0 ? 1.0 : zoom);
+#else
+    font.setPointSize((int)(font.pointSize() + zoom));
+    viewer->setFont(font);
+    viewer->setZoom((int)zoom);
+#endif
 
     connectSignals();
 }
@@ -549,7 +587,7 @@ HelpViewer *CentralWidget::newEmptyTab()
     viewer->setDocumentTitle(tr("unknown"));
 #endif
     tabWidget->setCurrentIndex(tabWidget->addTab(viewer, tr("unknown")));
-    
+
     connectSignals();
     return viewer;
 }
@@ -570,7 +608,7 @@ void CentralWidget::connectSignals()
 
 HelpViewer *CentralWidget::currentHelpViewer() const
 {
-    return qobject_cast<HelpViewer*>(tabWidget->currentWidget());    
+    return qobject_cast<HelpViewer*>(tabWidget->currentWidget());
 }
 
 void CentralWidget::activateTab(bool onlyHelpViewer)
@@ -580,9 +618,9 @@ void CentralWidget::activateTab(bool onlyHelpViewer)
     } else {
         int idx = 0;
         if (onlyHelpViewer)
-            idx = lastTabPage;        
+            idx = lastTabPage;
         tabWidget->setCurrentIndex(idx);
-        tabWidget->currentWidget()->setFocus();        
+        tabWidget->currentWidget()->setFocus();
     }
 }
 
@@ -591,7 +629,7 @@ void CentralWidget::setTabTitle(const QUrl& url)
     Q_UNUSED(url)
     const HelpViewer* viewer = currentHelpViewer();
     if (viewer)
-        tabWidget->setTabText(lastTabPage, viewer->documentTitle().trimmed());
+        tabWidget->setTabText(lastTabPage, quoteTabTitle(viewer->documentTitle().trimmed()));
 }
 
 void CentralWidget::currentPageChanged(int index)
@@ -630,7 +668,7 @@ void CentralWidget::showTabBarContextMenu(const QPoint &point)
     QAction *newBookmark = menu.addAction(tr("Add Bookmark for this Page..."));
 
     if (tabBar->count() == 1) {
-        close_page->setEnabled(false); 
+        close_page->setEnabled(false);
         close_pages->setEnabled(false);
     } else if (m_searchWidget && tabBar->count() == 2) {
         close_pages->setEnabled(false);
@@ -700,7 +738,7 @@ bool CentralWidget::eventFilter(QObject *object, QEvent *e)
             findBar->hide();
             HelpViewer *hv = currentHelpViewer();
             if (hv)
-                hv->setFocus();            
+                hv->setFocus();
         }
     }
     return QWidget::eventFilter(object, e);
@@ -708,17 +746,18 @@ bool CentralWidget::eventFilter(QObject *object, QEvent *e)
 
 void CentralWidget::keyPressEvent(QKeyEvent *e)
 {
-    if (!findBar->isVisible()) {
-        QString text = e->text();
-        if (text.startsWith(QLatin1Char('/'))) {
-            findBar->show();
-            findWidget->editFind->clear();
-            findWidget->editFind->setFocus();
-            return;
-        }
-    }
-
-    QWidget::keyPressEvent(e);
+	QString text = e->text();
+	if (text.startsWith(QLatin1Char('/'))) {
+		if (!findBar->isVisible()) {
+			findBar->show();
+			findWidget->editFind->clear();
+		} else {
+			findWidget->editFind->selectAll();
+		}
+		findWidget->editFind->setFocus();
+		return;
+	}
+	QWidget::keyPressEvent(e);
 }
 
 void CentralWidget::find(QString ttf, bool forward, bool backward)
@@ -732,6 +771,10 @@ void CentralWidget::find(QString ttf, bool forward, bool backward)
     p.setColor(QPalette::Active, QPalette::Base, Qt::white);
 
 #if defined(USE_WEBKIT)
+    Q_UNUSED(backward)
+    Q_UNUSED(doc)
+    Q_UNUSED(browser)
+
     if (viewer) {
         QWebPage::FindFlags options;
         if (!forward)
@@ -821,7 +864,7 @@ void CentralWidget::activateSearch()
 {
     if (tabWidget->widget(0) != m_searchWidget)
         createSearchWidget(helpEngine->searchEngine());
-    
+
     tabWidget->setCurrentWidget(m_searchWidget);
     m_searchWidget->setFocus();
 }
@@ -844,9 +887,9 @@ void CentralWidget::createSearchWidget(QHelpSearchEngine *searchEngine)
 {
     if (!m_searchWidget) {
         m_searchWidget = new SearchWidget(searchEngine, this);
-        connect(m_searchWidget, SIGNAL(requestShowLink(const QUrl&)), this, 
+        connect(m_searchWidget, SIGNAL(requestShowLink(const QUrl&)), this,
             SLOT(setSource(const QUrl&)));
-        connect(m_searchWidget, SIGNAL(requestShowLinkInNewTab(const QUrl&)), this, 
+        connect(m_searchWidget, SIGNAL(requestShowLinkInNewTab(const QUrl&)), this,
             SLOT(setSourceInNewTab(const QUrl&)));
     }
     tabWidget->insertTab(0, m_searchWidget, tr("Search"));
@@ -854,7 +897,13 @@ void CentralWidget::createSearchWidget(QHelpSearchEngine *searchEngine)
 
 void CentralWidget::removeSearchWidget()
 {
-    tabWidget->removeTab(0);    
+    tabWidget->removeTab(0);
+}
+
+QString CentralWidget::quoteTabTitle(const QString &title) const
+{
+    QString s = title;
+    return s.replace(QLatin1Char('&'), QLatin1String("&&"));
 }
 
 QT_END_NAMESPACE
