@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -48,7 +42,6 @@
 // sdk
 #include <QtDesigner/QDesignerFormEditorInterface>
 #include <QtDesigner/QExtensionManager>
-#include <QtDesigner/QDesignerTaskMenuExtension>
 
 // shared
 #include <qdesigner_command_p.h>
@@ -68,26 +61,13 @@
 #include <QtCore/QVariant>
 #include <QtCore/qdebug.h>
 
-#define NO_TOPWIDGET
+QT_BEGIN_NAMESPACE
 
+namespace qdesigner_internal {
+enum { debugWidgetSelection = 0 };
 
-namespace qdesigner_internal
-{
-
-
-class TopWidget: public InvisibleWidget
-{
-    Q_OBJECT
-public:
-    TopWidget(QWidget *parent)
-        : InvisibleWidget(parent)
-    {
-        setAttribute(Qt::WA_TransparentForMouseEvents);
-    }
-};
-
-WidgetHandle::WidgetHandle(FormWindow *parent, WidgetHandle::Type t, WidgetSelection *s)
-    : InvisibleWidget(parent->mainContainer()),
+WidgetHandle::WidgetHandle(FormWindow *parent, WidgetHandle::Type t, WidgetSelection *s) :
+    InvisibleWidget(parent->mainContainer()),
     m_widget(0),
     m_type(t),
     m_formWindow( parent),
@@ -97,19 +77,15 @@ WidgetHandle::WidgetHandle(FormWindow *parent, WidgetHandle::Type t, WidgetSelec
     setMouseTracking(false);
     setAutoFillBackground(true);
 
-    if (m_type == TaskMenu) {
-        setBackgroundRole(QPalette::Button);
-        setFixedSize(12, 12);
-    } else {
-        setBackgroundRole(m_active ? QPalette::Text : QPalette::Dark);
-        setFixedSize(6, 6);
-    }
+    setBackgroundRole(m_active ? QPalette::Text : QPalette::Dark);
+    setFixedSize(6, 6);
 
     updateCursor();
 }
 
 void WidgetHandle::updateCursor()
 {
+#ifndef QT_NO_CURSOR
     if (!m_active) {
         setCursor(Qt::ArrowCursor);
         return;
@@ -140,12 +116,10 @@ void WidgetHandle::updateCursor()
     case Left:
         setCursor(Qt::SizeHorCursor);
         break;
-    case TaskMenu:
-        setCursor(Qt::ArrowCursor);
-        break;
     default:
         Q_ASSERT(0);
     }
+#endif
 }
 
 QDesignerFormEditorInterface *WidgetHandle::core() const
@@ -159,9 +133,7 @@ QDesignerFormEditorInterface *WidgetHandle::core() const
 void WidgetHandle::setActive(bool a)
 {
     m_active = a;
-    if (m_type != TaskMenu) {
-        setBackgroundRole(m_active ? QPalette::Text : QPalette::Dark);
-    }
+    setBackgroundRole(m_active ? QPalette::Text : QPalette::Dark);
     updateCursor();
 }
 
@@ -175,16 +147,7 @@ void WidgetHandle::paintEvent(QPaintEvent *)
     QDesignerFormWindowManagerInterface *m = m_formWindow->core()->formWindowManager();
 
     QStylePainter p(this);
-    if (m_type == TaskMenu) {
-        QStyleOptionToolButton option;
-        option.init(this);
-        option.state |= QStyle::State_Raised;
-        option.arrowType = Qt::RightArrow;
-        option.toolButtonStyle = Qt::ToolButtonIconOnly;
-        option.features = QStyleOptionToolButton::Arrow;
-        option.subControls = QStyle::SC_ToolButton;
-        p.drawComplexControl(QStyle::CC_ToolButton, option);
-    } else if (m_formWindow->currentWidget() == m_widget) {
+    if (m_formWindow->currentWidget() == m_widget) {
         p.setPen(m->activeFormWindow() == m_formWindow ? Qt::blue : Qt::red);
         p.drawRect(0, 0, width() - 1, height() - 1);
     }
@@ -200,24 +163,13 @@ void WidgetHandle::mousePressEvent(QMouseEvent *e)
     if (!(m_widget && e->button() == Qt::LeftButton))
         return;
 
-    if (!(m_active || m_type == TaskMenu))
+    if (!(m_active))
         return;
 
     QWidget *container = m_widget->parentWidget();
 
     m_origPressPos = container->mapFromGlobal(e->globalPos());
     m_geom = m_origGeom = m_widget->geometry();
-
-    if (m_type == TaskMenu && e->button() == Qt::LeftButton) {
-        Q_ASSERT(m_sel->taskMenuExtension());
-
-        QMenu m(this);
-        foreach (QAction *a, m_sel->taskMenuExtension()->taskActions()) {
-            m.addAction(a);
-        }
-        m.exec(e->globalPos());
-    }
-
 }
 
 void WidgetHandle::mouseMoveEvent(QMouseEvent *e)
@@ -225,9 +177,6 @@ void WidgetHandle::mouseMoveEvent(QMouseEvent *e)
     if (!(m_widget && m_active && e->buttons() & Qt::LeftButton))
         return;
 
-    if (m_type == TaskMenu)
-        return;
-
     e->accept();
 
     QWidget *container = m_widget->parentWidget();
@@ -243,9 +192,6 @@ void WidgetHandle::mouseMoveEvent(QMouseEvent *e)
 
     switch (m_type) {
 
-    case TaskMenu:
-        break;
-
     case LeftTop: {
         if (rp.x() > pr.width() - 2 * width() || rp.y() > pr.height() - 2 * height())
             return;
@@ -375,94 +321,107 @@ void WidgetHandle::mouseReleaseEvent(QMouseEvent *e)
     if (e->button() != Qt::LeftButton || !m_active)
         return;
 
-    if (m_type == TaskMenu)
-        return;
-
     e->accept();
 
     if (!m_formWindow->hasFeature(FormWindow::EditFeature))
         return;
 
-    QLayout *lt = 0; // Check for managed layout
-    LayoutInfo::Type layoutType = m_widget->parentWidget()
-            ? LayoutInfo::layoutType(m_formWindow->core(), m_widget->parentWidget(), lt)
-            : LayoutInfo::NoLayout;
+    switch (WidgetSelection::widgetState(m_formWindow->core(), m_widget)) {
+    case WidgetSelection::UnlaidOut:
+       if (m_geom != m_widget->geometry()) {
+           SetPropertyCommand *cmd = new SetPropertyCommand(m_formWindow);
+           cmd->init(m_widget, QLatin1String("geometry"), m_widget->geometry());
+           cmd->setOldValue(m_origGeom);
+           m_formWindow->commandHistory()->push(cmd);
+           m_formWindow->emitSelectionChanged();
+       }
+       break;
+    case WidgetSelection::LaidOut:
+       break;
+    case WidgetSelection::ManagedGridLayout:
+       changeGridLayoutItemSpan();
+       break;
+    }
+}
 
-    if (layoutType == LayoutInfo::Grid) {
-        const QSize size = m_widget->parentWidget()->size();
-        QGridLayout *grid = static_cast<QGridLayout*>(m_widget->parentWidget()->layout());
+void WidgetHandle::changeGridLayoutItemSpan()
+{
+    QDesignerLayoutDecorationExtension *deco = qt_extension<QDesignerLayoutDecorationExtension*>(core()->extensionManager(), m_widget->parentWidget());
+    if (!deco)
+       return;
+    QGridLayout *grid = qobject_cast<QGridLayout*>(m_widget->parentWidget()->layout());
+    if (!grid)
+       return;
 
-        QDesignerLayoutDecorationExtension *deco = qt_extension<QDesignerLayoutDecorationExtension*>(core()->extensionManager(), m_widget->parentWidget());
+    const QSize size = m_widget->parentWidget()->size();
 
-        const int index = deco->indexOf(m_widget);
-        const QRect info = deco->itemInfo(index);
-        const int top = deco->findItemAt(info.top() - 1, info.left());
-        const int left = deco->findItemAt(info.top(), info.left() - 1);
-        const int bottom = deco->findItemAt(info.bottom() + 1, info.left());
-        const int right = deco->findItemAt(info.top(), info.right() + 1);
+    const int index = deco->indexOf(m_widget);
+    const QRect info = deco->itemInfo(index);
+    const int top = deco->findItemAt(info.top() - 1, info.left());
+    const int left = deco->findItemAt(info.top(), info.left() - 1);
+    const int bottom = deco->findItemAt(info.bottom() + 1, info.left());
+    const int right = deco->findItemAt(info.top(), info.right() + 1);
 
-        const QPoint pt = m_origGeom.center() - m_widget->geometry().center();
+    const QPoint pt = m_origGeom.center() - m_widget->geometry().center();
 
-        ChangeLayoutItemGeometry *cmd = 0;
+    ChangeLayoutItemGeometry *cmd = 0;
 
-        switch (m_type) {
-            default: break;
+    switch (m_type) {
+    default:
+       break;
 
-            case WidgetHandle::Top: {
-                if (pt.y() < 0 && info.height() > 1) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y() + 1, info.x(), info.height() - 1, info.width());
-                } else if (pt.y() > 0 && top != -1 && grid->itemAt(top)->spacerItem()) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y() - 1, info.x(), info.height() + 1, info.width());
-                }
-            } break;
+    case WidgetHandle::Top: {
+       if (pt.y() < 0 && info.height() > 1) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y() + 1, info.x(), info.height() - 1, info.width());
+       } else if (pt.y() > 0 && top != -1 && grid->itemAt(top)->spacerItem()) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y() - 1, info.x(), info.height() + 1, info.width());
+       }
+    }
+       break;
 
-            case WidgetHandle::Left: {
-                if (pt.x() < 0 && info.width() > 1) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y(), info.x() + 1, info.height(), info.width() - 1);
-                } else if (pt.x() > 0 && left != -1 && grid->itemAt(left)->spacerItem()) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y(), info.x() - 1, info.height(), info.width() + 1);
-                }
-            } break;
+    case WidgetHandle::Left: {
+       if (pt.x() < 0 && info.width() > 1) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y(), info.x() + 1, info.height(), info.width() - 1);
+       } else if (pt.x() > 0 && left != -1 && grid->itemAt(left)->spacerItem()) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y(), info.x() - 1, info.height(), info.width() + 1);
+       }
+    }
+       break;
 
-            case WidgetHandle::Right: {
-                if (pt.x() > 0 && info.width() > 1) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y(), info.x(), info.height(), info.width() - 1);
-                } else if (pt.x() < 0 && right != -1 && grid->itemAt(right)->spacerItem()) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y(), info.x(), info.height(), info.width() + 1);
-                }
-            } break;
+    case WidgetHandle::Right: {
+       if (pt.x() > 0 && info.width() > 1) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y(), info.x(), info.height(), info.width() - 1);
+       } else if (pt.x() < 0 && right != -1 && grid->itemAt(right)->spacerItem()) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y(), info.x(), info.height(), info.width() + 1);
+       }
+    }
+       break;
 
-            case WidgetHandle::Bottom: {
-                if (pt.y() > 0 && info.width() > 1) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y(), info.x(), info.height() - 1, info.width());
-                } else if (pt.y() < 0 && bottom != -1 && grid->itemAt(bottom)->spacerItem()) {
-                    cmd = new ChangeLayoutItemGeometry(m_formWindow);
-                    cmd->init(m_widget, info.y(), info.x(), info.height() + 1, info.width());
-                }
-            } break;
-        }
+    case WidgetHandle::Bottom: {
+       if (pt.y() > 0 && info.width() > 1) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y(), info.x(), info.height() - 1, info.width());
+       } else if (pt.y() < 0 && bottom != -1 && grid->itemAt(bottom)->spacerItem()) {
+           cmd = new ChangeLayoutItemGeometry(m_formWindow);
+           cmd->init(m_widget, info.y(), info.x(), info.height() + 1, info.width());
+       }
+    }
+       break;
+    }
 
-        if (cmd != 0) {
-            m_formWindow->commandHistory()->push(cmd);
-        } else {
-            grid->invalidate();
-            grid->activate();
-            m_formWindow->clearSelection(false);
-            m_formWindow->selectWidget(m_widget);
-        }
-    } else if (m_geom != m_widget->geometry()) {
-        SetPropertyCommand *cmd = new SetPropertyCommand(m_formWindow);
-        cmd->init(m_widget, QLatin1String("geometry"), m_widget->geometry());
-        cmd->setOldValue(m_origGeom);
-        m_formWindow->commandHistory()->push(cmd);
-        m_formWindow->emitSelectionChanged();
+    if (cmd != 0) {
+       m_formWindow->commandHistory()->push(cmd);
+    } else {
+       grid->invalidate();
+       grid->activate();
+       m_formWindow->clearSelection(false);
+       m_formWindow->selectWidget(m_widget);
     }
 }
 
@@ -471,10 +430,10 @@ void WidgetHandle::trySetGeometry(QWidget *w, int x, int y, int width, int heigh
     if (!m_formWindow->hasFeature(FormWindow::EditFeature))
         return;
 
-    int minw = qMax(w->minimumSizeHint().width(), w->minimumSize().width());
+    int minw = w->minimumSize().width();
     minw = qMax(minw, 2 * m_formWindow->grid().x());
 
-    int minh = qMax(w->minimumSizeHint().height(), w->minimumSize().height());
+    int minh = w->minimumSize().height();
     minh = qMax(minh, 2 * m_formWindow->grid().y());
 
     if (qMax(minw, width) > w->maximumWidth() ||
@@ -492,10 +451,10 @@ void WidgetHandle::trySetGeometry(QWidget *w, int x, int y, int width, int heigh
 
 void WidgetHandle::tryResize(QWidget *w, int width, int height)
 {
-    int minw = qMax(w->minimumSizeHint().width(), w->minimumSize().width());
+    int minw = w->minimumSize().width();
     minw = qMax(minw, 16);
 
-    int minh = qMax(w->minimumSizeHint().height(), w->minimumSize().height());
+    int minh = w->minimumSize().height();
     minh = qMax(minh, 16);
 
     w->resize(qMax(minw, width), qMax(minh, height));
@@ -503,112 +462,73 @@ void WidgetHandle::tryResize(QWidget *w, int width, int height)
 
 // ------------------------------------------------------------------------
 
-WidgetSelection::WidgetSelection(FormWindow *parent)   :
-    m_topWidget(0),
-    m_wid(0),
-    m_formWindow(parent),
-    m_taskMenu(0)
+WidgetSelection::WidgetState WidgetSelection::widgetState(const QDesignerFormEditorInterface *core, QWidget *w)
 {
-    for (int i = WidgetHandle::LeftTop; i < WidgetHandle::TypeCount; ++i) {
-        m_handles.insert(i, new WidgetHandle(m_formWindow, static_cast<WidgetHandle::Type>(i), this));
-    }
+    bool isManaged;
+    const LayoutInfo::Type  lt =  LayoutInfo::laidoutWidgetType(core, w, &isManaged);
+    if (lt == LayoutInfo::NoLayout)
+       return UnlaidOut;
+    return isManaged && lt == LayoutInfo::Grid ? ManagedGridLayout : LaidOut;
+}
 
+WidgetSelection::WidgetSelection(FormWindow *parent)   :
+    m_widget(0),
+    m_formWindow(parent)
+{
+    for (int i = WidgetHandle::LeftTop; i < WidgetHandle::TypeCount; ++i)
+        m_handles[i] = new WidgetHandle(m_formWindow, static_cast<WidgetHandle::Type>(i), this);
     hide();
 }
 
 void WidgetSelection::setWidget(QWidget *w)
 {
-    m_taskMenu = 0; // ### qt_extension<QDesignerTaskMenuExtension*>(core()->extensionManager(), w);
-
-#ifndef NO_TOPWIDGET
-    if (m_topWidget) {
-        Q_ASSERT(m_topWidget->parentWidget() != 0);
-        m_topWidget->parentWidget()->setAttribute(Qt::WA_ContentsPropagated, false);
-    }
-
-    delete m_topWidget;
-    m_topWidget = 0;
-#endif
-
-    if (m_wid != 0)
-        m_wid->removeEventFilter(this);
+    if (m_widget != 0)
+        m_widget->removeEventFilter(this);
 
     if (w == 0) {
         hide();
-        m_wid = 0;
+        m_widget = 0;
         return;
     }
 
-    m_wid = w;
+    m_widget = w;
 
-    m_wid->installEventFilter(this);
+    m_widget->installEventFilter(this);
 
-    const bool active = LayoutInfo::isWidgetLaidout(m_formWindow->core(), m_wid) == false;
-
-    for (int i = WidgetHandle::LeftTop; i < WidgetHandle::TypeCount; ++i) {
-        if (WidgetHandle *h = m_handles[i]) {
-            h->setWidget(m_wid);
-            h->setActive(active);
-        }
-    }
-
-    QLayout *layout = LayoutInfo::managedLayout(m_formWindow->core(), m_formWindow->designerWidget(m_wid->parentWidget()));
-    if (QGridLayout *grid = qobject_cast<QGridLayout*>(layout)) {
-        const int index = grid->indexOf(m_wid);
-        if (index == -1) {
-#if defined(QD_DEBUG)
-            qDebug() << "unexpected call to WidgetSelection::setWidget()" << "widget:" << m_wid << "grid:"<< grid;
-#endif
-            return;
-        }
-
-        Q_ASSERT(index != -1);
-
-        QDesignerLayoutDecorationExtension *deco = qt_extension<QDesignerLayoutDecorationExtension*>(core()->extensionManager(), m_wid->parentWidget());
-        if (deco == 0) {
-            // try with the actual layout
-            deco = qt_extension<QDesignerLayoutDecorationExtension*>(core()->extensionManager(), layout);
-        }
-
-        if (deco != 0) {
-            // bottom cell
-            m_handles[WidgetHandle::Bottom]->setActive(true);
-            // top cell
-            m_handles[WidgetHandle::Top]->setActive(true);
-            // left cell
-            m_handles[WidgetHandle::Left]->setActive(true);
-            // right cellg59
-            m_handles[WidgetHandle::Right]->setActive(true);
-        } else {
-            qDebug() << "no QDesignerLayoutDecorationExtension for widget:" << m_wid;
-        }
-    }
-
-#ifndef NO_TOPWIDGET
-    m_wid->setAttribute(Qt::WA_ContentsPropagated, true);
-    m_topWidget = new TopWidget(wid);
-    QPalette p = m_topWidget->palette();
-    p.setColor(m_topWidget->backgroundRole(), QColor(255, 0, 0, 32));
-    m_topWidget->setPalette(p);
-#endif
+    updateActive();
 
     updateGeometry();
     show();
 }
 
+void WidgetSelection::updateActive()
+{
+    const WidgetState ws = widgetState(m_formWindow->core(), m_widget);
+
+    const bool cornersActive = ws == UnlaidOut;
+    const bool edgesActive = ws == UnlaidOut || ws == ManagedGridLayout;
+
+    for (int i = WidgetHandle::LeftTop; i < WidgetHandle::TypeCount; ++i)
+       if (WidgetHandle *h = m_handles[i]) {
+           h->setWidget(m_widget);
+           const bool isEdge = i == WidgetHandle::Left || i == WidgetHandle::Top || i == WidgetHandle::Right || i == WidgetHandle::Bottom;
+           h->setActive(isEdge ? edgesActive : cornersActive);
+       }
+}
+
 bool WidgetSelection::isUsed() const
 {
-    return m_wid != 0;
+    return m_widget != 0;
 }
 
 void WidgetSelection::updateGeometry()
 {
-    if (!m_wid || !m_wid->parentWidget())
+    if (!m_widget || !m_widget->parentWidget())
         return;
 
-    QPoint p = m_wid->parentWidget()->mapToGlobal(m_wid->pos());
+    QPoint p = m_widget->parentWidget()->mapToGlobal(m_widget->pos());
     p = m_formWindow->mapFromGlobal(p);
-    const QRect r(p, m_wid->size());
+    const QRect r(p, m_widget->size());
 
     const int w = 6;
     const int h = 6;
@@ -642,19 +562,10 @@ void WidgetSelection::updateGeometry()
         case WidgetHandle::Left:
             hndl->move(r.x() - w / 2, r.y() + r.height() / 2 - h / 2);
             break;
-        case WidgetHandle::TaskMenu:
-            hndl->move(r.x() + r.width() - w / 2, r.y() + h - h / 2);
-            break;
         default:
             break;
         }
     }
-
-#ifndef NO_TOPWIDGET
-    if (m_topWidget) {
-        m_topWidget->setGeometry(wid->rect());
-    }
-#endif
 }
 
 void WidgetSelection::hide()
@@ -664,11 +575,6 @@ void WidgetSelection::hide()
         if (h)
             h->hide();
     }
-
-#ifndef NO_TOPWIDGET
-    if (m_topWidget)
-        m_topWidget->hide();
-#endif
 }
 
 void WidgetSelection::show()
@@ -676,22 +582,10 @@ void WidgetSelection::show()
     for (int i = WidgetHandle::LeftTop; i < WidgetHandle::TypeCount; ++i) {
         WidgetHandle *h = m_handles[ i ];
         if (h) {
-            if (i == WidgetHandle::TaskMenu) {
-                h->setVisible(taskMenuExtension() != 0);
-                h->raise();
-            } else {
-                h->show();
-                h->raise();
-            }
+            h->show();
+            h->raise();
         }
     }
-
-#ifndef NO_TOPWIDGET
-    if (m_topWidget) {
-        m_topWidget->show();
-        m_topWidget->raise();
-    }
-#endif
 }
 
 void WidgetSelection::update()
@@ -701,16 +595,11 @@ void WidgetSelection::update()
         if (h)
             h->update();
     }
-
-#ifndef NO_TOPWIDGET
-    if (m_topWidget)
-        m_topWidget->update();
-#endif
 }
 
 QWidget *WidgetSelection::widget() const
 {
-    return m_wid;
+    return m_widget;
 }
 
 QDesignerFormEditorInterface *WidgetSelection::core() const
@@ -733,6 +622,9 @@ bool WidgetSelection::eventFilter(QObject *object, QEvent *event)
         case QEvent::Resize:
             updateGeometry();
             break;
+        case QEvent::ZOrderChange:
+            show();
+            break;
     } // end switch
 
     return false;
@@ -740,4 +632,4 @@ bool WidgetSelection::eventFilter(QObject *object, QEvent *event)
 
 }
 
-#include "widgetselection.moc"
+QT_END_NAMESPACE
