@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -99,8 +93,6 @@ QTabWidgetEventFilter::QTabWidgetEventFilter(QTabWidget *parent) :
     connect(m_actionInsertPage, SIGNAL(triggered()), this, SLOT(addPage()));
     connect(m_actionInsertPageAfter, SIGNAL(triggered()), this, SLOT(addPageAfter()));
     connect(m_actionDeletePage, SIGNAL(triggered()), this, SLOT(removeCurrentPage()));
-    connect(m_tabWidget, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentChanged(int)));
-
 }
 
 QTabWidgetEventFilter::~QTabWidgetEventFilter()
@@ -114,10 +106,16 @@ void QTabWidgetEventFilter::install(QTabWidget *tabWidget)
 
 QTabWidgetEventFilter *QTabWidgetEventFilter::eventFilterOf(const QTabWidget *tabWidget)
 {
-    QList<QTabWidgetEventFilter*> filters = qFindChildren<QTabWidgetEventFilter*>(tabWidget);
-    if (filters.empty())
-        return 0;
-    return filters.front();
+    // Look for 1st order children only..otherwise, we might get filters of nested tab widgets
+    const QObjectList children = tabWidget->children();
+    const QObjectList::const_iterator cend = children.constEnd();
+    for (QObjectList::const_iterator it = children.constBegin(); it != cend; ++it) {
+        QObject *o = *it;
+        if (!o->isWidgetType())
+            if (QTabWidgetEventFilter *ef = qobject_cast<QTabWidgetEventFilter*>(o))
+                return ef;
+    }
+    return 0;
 }
 
 QMenu *QTabWidgetEventFilter::addTabWidgetContextMenuActions(const QTabWidget *tabWidget, QMenu *popup)
@@ -177,6 +175,10 @@ bool QTabWidgetEventFilter::eventFilter(QObject *o, QEvent *e)
         break;
     case QEvent::MouseButtonPress: {
         QMouseEvent *mev = static_cast<QMouseEvent*>(e);
+        if (QDesignerFormWindowInterface *fw = formWindow()) {
+            fw->clearSelection();
+            fw->selectWidget(m_tabWidget, true);
+        }
         if (mev->button() & Qt::LeftButton) {
             m_mousePressed = true;
             m_pressPoint = mev->pos();
@@ -330,16 +332,6 @@ void QTabWidgetEventFilter::addPageAfter()
     }
 }
 
-void QTabWidgetEventFilter::slotCurrentChanged(int index)
-{
-    if (m_tabWidget->widget(index)) {
-        if (QDesignerFormWindowInterface *fw = formWindow()) {
-            fw->clearSelection();
-            fw->selectWidget(m_tabWidget, true);
-        }
-    }
-}
-
 QDesignerFormWindowInterface *QTabWidgetEventFilter::formWindow() const
 {
     return QDesignerFormWindowInterface::findFormWindow(const_cast<QTabWidget*>(m_tabWidget));
