@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -50,6 +44,7 @@
 
 #include <QtCore/QFileInfo>
 #include <QtCore/QDir>
+#include <QtCore/QSettings>
 #include <QtXml/QDomDocument>
 #include <QtGui/QMenu>
 #include <QtGui/QHeaderView>
@@ -66,6 +61,9 @@ static const char *rccFileTag = "file";
 static const char *rccAliasAttribute = "alias";
 static const char *rccPrefixAttribute = "prefix";
 static const char *rccLangAttribute = "lang";
+static const char *SplitterPosition = "SplitterPosition";
+static const char *Geometry = "Geometry";
+static const char *QrcDialogC = "QrcDialog";
 
 static QString msgOverwrite(const QString &fname)
 {
@@ -2044,17 +2042,31 @@ QtResourceEditorDialog::QtResourceEditorDialog(QDesignerDialogGuiInterface *dlgG
                     this, SLOT(slotCurrentTreeViewItemChanged(const QModelIndex &)));
 
     d_ptr->m_ui.resourceTreeView->setColumnWidth(0, 200);
-    d_ptr->m_ui.resourceTreeView->setMinimumWidth(400);
-    d_ptr->m_ui.qrcFileList->setMinimumWidth(200);
 
     d_ptr->slotCurrentTreeViewItemChanged(QModelIndex());
     d_ptr->m_removeQrcFileAction->setEnabled(false);
     d_ptr->m_moveUpQrcFileAction->setEnabled(false);
     d_ptr->m_moveDownQrcFileAction->setEnabled(false);
+
+    QSettings settings;
+    settings.beginGroup(QLatin1String(QrcDialogC));
+
+    d_ptr->m_ui.splitter->restoreState(settings.value(QLatin1String(SplitterPosition)).toByteArray());
+    if (settings.contains(QLatin1String(Geometry)))
+        setGeometry(settings.value(QLatin1String(Geometry)).toRect());
+
+    settings.endGroup();
 }
 
 QtResourceEditorDialog::~QtResourceEditorDialog()
 {
+    QSettings settings;
+    settings.beginGroup(QLatin1String(QrcDialogC));
+
+    settings.setValue(QLatin1String(SplitterPosition), d_ptr->m_ui.splitter->saveState());
+    settings.setValue(QLatin1String(Geometry), geometry());
+    settings.endGroup();
+
     delete d_ptr;
 }
 
