@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -68,6 +62,7 @@
 #include <QtGui/QMenu>
 #include <QtGui/QDrag>
 #include <QtCore/QMimeData>
+#include <QtCore/QSettings>
 #include <QtXml/QDomDocument>
 
 QT_BEGIN_NAMESPACE
@@ -78,6 +73,9 @@ static const char *typeImage = "image";
 static const char *typeStyleSheet = "stylesheet";
 static const char *typeOther = "other";
 static const char *fileAttribute = "file";
+static const char *SplitterPosition = "SplitterPosition";
+static const char *Geometry = "Geometry";
+static const char *ResourceViewDialogC = "ResourceDialog";
 
 // ---------------- ResourceListWidget: A list widget that has drag enabled
 class ResourceListWidget : public QListWidget {
@@ -147,6 +145,8 @@ public:
     void createResources(const QString &path);
     void storeExpansionState();
     void applyExpansionState();
+    void restoreSettings();
+    void saveSettings();
 
     QPixmap makeThumbnail(const QPixmap &pix) const;
 
@@ -155,6 +155,7 @@ public:
     QToolBar *m_toolBar;
     QTreeWidget *m_treeWidget;
     QListWidget *m_listWidget;
+    QSplitter *m_splitter;
     QMap<QString, QStringList>       m_pathToContents; // full path to contents file names
     QMap<QString, QTreeWidgetItem *> m_pathToItem;
     QMap<QTreeWidgetItem *, QString> m_itemToPath;
@@ -167,6 +168,7 @@ public:
     QMap<QString, bool> m_expansionState;
 
     bool m_ignoreGuiSignals;
+    QString m_settingsKey;
 };
 
 QtResourceViewPrivate::QtResourceViewPrivate(QDesignerFormEditorInterface *core) :
@@ -183,6 +185,30 @@ QtResourceViewPrivate::QtResourceViewPrivate(QDesignerFormEditorInterface *core)
 {
 }
 
+void QtResourceViewPrivate::restoreSettings()
+{
+    if (m_settingsKey.isEmpty())
+        return;
+
+    QSettings settings;
+    settings.beginGroup(m_settingsKey);
+
+    m_splitter->restoreState(settings.value(QLatin1String(SplitterPosition)).toByteArray());
+    settings.endGroup();
+}
+
+void QtResourceViewPrivate::saveSettings()
+{
+    if (m_settingsKey.isEmpty())
+        return;
+
+    QSettings settings;
+    settings.beginGroup(m_settingsKey);
+
+    settings.setValue(QLatin1String(SplitterPosition), m_splitter->saveState());
+    settings.endGroup();
+}
+
 void QtResourceViewPrivate::slotEditResources()
 {
     const QString selectedResource = QtResourceEditorDialog::editResources(m_resourceModel, m_core->dialogGui(), q_ptr);
@@ -417,16 +443,16 @@ QtResourceView::QtResourceView(QDesignerFormEditorInterface *core, QWidget *pare
     connect(d_ptr->m_copyResourcePathAction, SIGNAL(triggered()), this, SLOT(slotCopyResourcePath()));
     d_ptr->m_copyResourcePathAction->setEnabled(false);
 
-    QSplitter *splitter = new QSplitter;
-    splitter->setChildrenCollapsible(false);
-    splitter->addWidget(d_ptr->m_treeWidget);
-    splitter->addWidget(d_ptr->m_listWidget);
+    d_ptr->m_splitter = new QSplitter;
+    d_ptr->m_splitter->setChildrenCollapsible(false);
+    d_ptr->m_splitter->addWidget(d_ptr->m_treeWidget);
+    d_ptr->m_splitter->addWidget(d_ptr->m_listWidget);
 
     QLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
     layout->setSpacing(0);
     layout->addWidget(d_ptr->m_toolBar);
-    layout->addWidget(splitter);
+    layout->addWidget(d_ptr->m_splitter);
 
     d_ptr->m_treeWidget->setColumnCount(1);
     d_ptr->m_treeWidget->header()->hide();
@@ -450,6 +476,9 @@ QtResourceView::QtResourceView(QDesignerFormEditorInterface *core, QWidget *pare
 
 QtResourceView::~QtResourceView()
 {
+    if (!d_ptr->m_settingsKey.isEmpty())
+        d_ptr->saveSettings();
+
     delete d_ptr;
 }
 
@@ -500,6 +529,24 @@ void QtResourceView::selectResource(const QString &resource)
     }
 }
 
+QString QtResourceView::settingsKey() const
+{
+    return d_ptr->m_settingsKey;
+}
+
+void QtResourceView::setSettingsKey(const QString &key)
+{
+    if (d_ptr->m_settingsKey == key)
+        return;
+
+    d_ptr->m_settingsKey = key;
+
+    if (key.isEmpty())
+        return;
+
+    d_ptr->restoreSettings();
+}
+
 void QtResourceView::setResourceModel(QtResourceModel *model)
 {
     if (d_ptr->m_resourceModel) {
@@ -618,6 +665,7 @@ QtResourceViewDialogPrivate::QtResourceViewDialogPrivate(QDesignerFormEditorInte
     m_view(new QtResourceView(core)),
     m_box(new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel))
 {
+    m_view->setSettingsKey(QLatin1String(ResourceViewDialogC));
 }
 
 // ------------ QtResourceViewDialog
@@ -637,10 +685,25 @@ QtResourceViewDialog::QtResourceViewDialog(QDesignerFormEditorInterface *core, Q
     connect(d_ptr->m_view, SIGNAL(resourceSelected(QString)), this, SLOT(slotResourceSelected(QString)));
     d_ptr->setOkButtonEnabled(false);
     d_ptr->m_view->setResourceModel(core->resourceModel());
+
+    QSettings settings;
+    settings.beginGroup(QLatin1String(ResourceViewDialogC));
+
+    if (settings.contains(QLatin1String(Geometry)))
+        setGeometry(settings.value(QLatin1String(Geometry)).toRect());
+
+    settings.endGroup();
 }
 
 QtResourceViewDialog::~QtResourceViewDialog()
 {
+    QSettings settings;
+    settings.beginGroup(QLatin1String(ResourceViewDialogC));
+
+    settings.setValue(QLatin1String(Geometry), geometry());
+
+    settings.endGroup();
+
     delete d_ptr;
 }
 
