@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -33,6 +47,8 @@
 
 #include <stdio.h>
 
+QT_BEGIN_NAMESPACE
+
 
 /*!
     \class QtWindowListMenu
@@ -49,16 +65,16 @@
 
     The QtWindowListMenu is added to the menubar (or any descendant of
     QMenuBar) using addTo().
-    
+
     This class inherits publicly from QMenu, so the items
     "Tile", "Cascade", "Close" and "Close All" may be modified
     or removed, and new items may be added. However, removing menu items
-    which correspond to windows on the workspace results in undefined 
+    which correspond to windows on the workspace results in undefined
     behavior.
 */
 
 /*!
-    Constructs a QtWindowListMenu object. The \a parent 
+    Constructs a QtWindowListMenu object. The \a parent
     parameter is passed to the QMenu constructor, and the \a name parameter
     is set as the object name. The
     \a workspace parameter specifies which QWorkspace object the menu
@@ -71,8 +87,8 @@
 QtWindowListMenu::QtWindowListMenu(QWorkspace *workspace, QWidget *parent,
 					    const char *name)
 	: QMenu(parent), groupWindows(this)
-{    
-    setObjectName(name);
+{
+    setObjectName(QLatin1String(name));
     m_menubar = 0;
     m_my_action = 0;
     m_close_current_action = 0;
@@ -82,8 +98,8 @@ QtWindowListMenu::QtWindowListMenu(QWorkspace *workspace, QWidget *parent,
     if (m_workspace != 0) {
 	    m_workspace->installEventFilter(this);
         connect(m_workspace, SIGNAL(windowActivated(QWidget*)),
-                this, SLOT(addWindow(QWidget*)));                                   
-            
+                this, SLOT(addWindow(QWidget*)));
+
 	    m_tile_action = addAction(tr("Tile"), m_workspace, SLOT(tile()));
 	    m_cascade_action = addAction(tr("Cascade"), m_workspace, SLOT(cascade()));
 	    addSeparator();
@@ -97,33 +113,18 @@ QtWindowListMenu::QtWindowListMenu(QWorkspace *workspace, QWidget *parent,
 /*
     If \a on is false, the window titles in the menu will have the form:
 
-    \code
-    Unnamed
-    Unnamed2
-    SomeDocument.txt
-    ...
-    \endcode
+    \snippet doc/src/snippets/code/tools.linguist.linguist.previewtool.qtwindowlistmenu.cpp 0
 
-    If \a on is true and \a amperstands if false, the window titles in the menu 
+    If \a on is true and \a amperstands if false, the window titles in the menu
     will have the form:
-    
-    \code
-    1 Unnamed
-    2 Unnamed2
-    3 SomeDocument.txt
-    ...
-    \endcode
-    
+
+    \snippet doc/src/snippets/code/tools.linguist.linguist.previewtool.qtwindowlistmenu.cpp 1
+
     If both \a on and \a amperstands are true, the window titles in the menu
     will have the form:
-    
-    \code
-    &1 Unnamed
-    &2 Unnamed2
-    &3 SomeDocument.txt
-    ...
-    \endcode
-    
+
+    \snippet doc/src/snippets/code/tools.linguist.linguist.previewtool.qtwindowlistmenu.cpp 2
+
     Calling this method has no effect on window titles that are already in the
     menu at the time when the call is made. It should therefore be called
     right after the QtWindowListMenu is created, before any windows are
@@ -138,21 +139,21 @@ void QtWindowListMenu::setNumbering(bool on, bool amperstands)
 */
 
 /*!
-    Adds this window list menu to \a menubar at position \a idx, with the 
+    Adds this window list menu to \a menubar at position \a idx, with the
     name \a text. If \a idx is -1, the window list menu is appended
-    as the last item on the menubar. Does nothing and returns null if this 
+    as the last item on the menubar. Does nothing and returns null if this
     menu is already assigned to a menubar. Otherwise returns a pointer to
-    the QAction object for the inserted menu item.  
+    the QAction object for the inserted menu item.
 */
 
 QAction *QtWindowListMenu::addTo(const QString &text, QMenuBar *menubar, int idx)
 {
-    if (menubar == 0 || m_menubar != 0) 
+    if (menubar == 0 || m_menubar != 0)
     	return 0;
     m_menubar = menubar;
 
     QList<QAction *> actions = m_menubar->actions();
-    
+
     QAction *action = 0;
     if (idx >= 0 && idx < actions.size())
         action = actions[idx];
@@ -185,15 +186,15 @@ void QtWindowListMenu::removeWindow(QWidget *w, bool windowDestroyed)
     if (!windowDestroyed) {
 	    w->removeEventFilter(this);
 	    disconnect(w, 0, this, 0);
-    }    
-    if (*it != 0) { 
+    }
+    if (*it != 0) {
         removeAction(*it);
         groupWindows.removeAction(*it);
     }
 
     m_window_list.erase(it);
 
-    if (isEmpty()) 
+    if (isEmpty())
     	setEnabled(false);
 }
 
@@ -209,43 +210,43 @@ void QtWindowListMenu::addWindow(QWidget *w)
 {
     if (w == 0) {
 	    if (m_menubar != 0 && m_close_current_action != 0)
-	        m_close_current_action->setEnabled(false);	    
+	        m_close_current_action->setEnabled(false);
 	    return;
     }
 
     if (m_menubar != 0 && m_close_current_action != 0)
     	m_close_current_action->setEnabled(true);
 
-    WindowList::iterator it = m_window_list.find(w);    
+    WindowList::iterator it = m_window_list.find(w);
     if (it == m_window_list.end()) {
 	    m_window_list[w] = 0;
 	    w->installEventFilter(this);
-	    connect(w, SIGNAL(destroyed(QObject*)), 
+	    connect(w, SIGNAL(destroyed(QObject*)),
     	    	this, SLOT(windowDestroyed(QObject*)));
     	it = m_window_list.find(w);
     }
-    
+
     if (!w->isVisible() && !w->isMinimized())
         return;
-    
+
     if (*it == 0) {
         *it = new QAction(w->windowTitle(), &groupWindows);
         (*it)->setCheckable(true);
         if (!m_default_icon.isNull())
             (*it)->setIcon(m_default_icon);
-        addAction(*it);      
+        addAction(*it);
         connect(*it, SIGNAL(toggled(bool)), this, SLOT(setSenderChecked(bool)));
-        connect(*it, SIGNAL(triggered()), w, SLOT(setFocus()));                               
+        connect(*it, SIGNAL(triggered()), w, SLOT(setFocus()));
         connect(*it, SIGNAL(triggered()), w, SLOT(show()));
     }
-    
+
     setChecked(true, *it);
     setEnabled(true);
 }
 
 /*!
-    Adds the widget \a widget to this QtWindowListMenu, and sets the icon of its menu item 
-    to be \a icon. 
+    Adds the widget \a widget to this QtWindowListMenu, and sets the icon of its menu item
+    to be \a icon.
 */
 
 void QtWindowListMenu::addWindow(QWidget *widget, const QIcon &icon)
@@ -255,8 +256,8 @@ void QtWindowListMenu::addWindow(QWidget *widget, const QIcon &icon)
 }
 
 /*!
-    Sets \a icon as the icon of the menu item belonging to the widget \a widget. If \a icon is 
-    a null icon, then the menu item's icon will be cleared instead of set.    
+    Sets \a icon as the icon of the menu item belonging to the widget \a widget. If \a icon is
+    a null icon, then the menu item's icon will be cleared instead of set.
 */
 void QtWindowListMenu::setWindowIcon(QWidget *widget, const QIcon &icon)
 {
@@ -266,7 +267,7 @@ void QtWindowListMenu::setWindowIcon(QWidget *widget, const QIcon &icon)
 }
 
 /*!
-    Sets \a icon as the default menu item icon for this QtWindowListMenu. The menu items for each of the windows 
+    Sets \a icon as the default menu item icon for this QtWindowListMenu. The menu items for each of the windows
     currently listed in the menu will get this as their current icon. New menu items added to the menu will also
     get this icon by default. If \a icon is a null icon, then the default icon will be cleared.
 */
@@ -274,7 +275,7 @@ void QtWindowListMenu::setDefaultIcon(const QIcon &icon)
 {
     m_default_icon = icon;
     WindowList::iterator it;
-    for (it=m_window_list.begin();it!=m_window_list.end();++it) 
+    for (it=m_window_list.begin();it!=m_window_list.end();++it)
         (*it)->setIcon(icon);
 }
 
@@ -325,7 +326,7 @@ bool QtWindowListMenu::eventFilter(QObject *obj, QEvent *e)
 
     	QChildEvent *child_event = (QChildEvent *) e;
 	    QObject *child = child_event->child();
-    	if (child->metaObject()->className() != "QWorkspaceChild")
+    	if (qstrcmp(child->metaObject()->className(), "QWorkspaceChild"))
 	        return false;
 
         QWidget *child_widget = qobject_cast<QWidget *>(child);
@@ -338,7 +339,7 @@ bool QtWindowListMenu::eventFilter(QObject *obj, QEvent *e)
         if (w == 0)
 	        return false;
 	    WindowList::iterator it = m_window_list.find(w);
-	    if (it == m_window_list.end()) 
+	    if (it == m_window_list.end())
             return false;
 
 	    switch (e->type()) {
@@ -349,16 +350,16 @@ bool QtWindowListMenu::eventFilter(QObject *obj, QEvent *e)
 	    case QEvent::Close:
 		    // we keep the window in the m_window_list, it might be show()n again.
             if (*it != 0) {
-	    	    removeAction(*it);		    
+	    	    removeAction(*it);
                 groupWindows.removeAction(*it);
             }
 		    *it = 0;
-		    if (isEmpty()) 
+		    if (isEmpty())
 	    	    setEnabled(false);
 		    break;
 	    case QEvent::WindowTitleChange:
-    		if (*it != 0) 
-                (*it)->setText(w->windowTitle());	    	
+    		if (*it != 0)
+                (*it)->setText(w->windowTitle());
 		    break;
 	    default: break;
 	    }
@@ -374,7 +375,7 @@ void QtWindowListMenu::windowDestroyed(QObject *obj)
     removeWindow((QWidget*)obj, true);
 }
 
-/*! 
+/*!
     Enables or disables the window list menu, according to the value
     of \a b. Normally it is not necessary to call this function, since
     QtWindowListMenu automatically enables itself whenever there is
@@ -385,7 +386,7 @@ void QtWindowListMenu::windowDestroyed(QObject *obj)
 
 void QtWindowListMenu::setEnabled(bool b)
 {
-    if (m_menubar != 0) 
+    if (m_menubar != 0)
         m_my_action->setEnabled(b);
 }
 
@@ -420,8 +421,9 @@ void QtWindowListMenu::setTileIcon(const QIcon &icon)
     Sets \a icon as the icon of the menu item which closes all windows in the workspace.
     If \a icon is a null icon, then the menu item's icon will be cleared instead of set.
 */
-void QtWindowListMenu::setCloseAllIcon(const QIcon &icon) 
+void QtWindowListMenu::setCloseAllIcon(const QIcon &icon)
 {
     m_close_all_action->setIcon(icon);
 }
 
+QT_END_NAMESPACE
