@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -286,7 +280,6 @@ void QVFb::init( int display_id, int pw, int ph, int d, int r, const QString& sk
 		view = new QVFbView( display_id, pw, ph, d, rot, skin );
 	    skin->setView( view );
 	    view->setContentsMargins( 0, 0, 0, 0 );
-	    view->setFixedSize( sw, sh);
             view->setTouchscreenEmulation(!parameters.hasMouseHover);
 	    connect(skin, SIGNAL(skinKeyPressEvent(int,QString,bool)), view, SLOT(skinKeyPressEvent(int,QString,bool)));
 	    connect(skin, SIGNAL(skinKeyReleaseEvent(int,QString,bool)), view, SLOT(skinKeyReleaseEvent(int,QString,bool)));
@@ -345,6 +338,7 @@ void QVFb::init( int display_id, int pw, int ph, int d, int r, const QString& sk
 	}
 	menuBar()->show();
 	scroller = new QScrollArea(this);
+	scroller->setFocusPolicy(Qt::NoFocus); // don't steal key events from the embedded app
 #ifdef Q_WS_X11
 	if (displayType == X11)
 	    view = new QVFbX11View( display_id, pw, ph, d, rot, scroller );
@@ -425,6 +419,11 @@ QMenu* QVFb::createViewMenu()
 	enableCursor(true);
     viewMenu->addAction( "&Refresh Rate...", this, SLOT(changeRate()) );
     viewMenu->addSeparator();
+    viewMenu->addAction( "No rotation", this, SLOT(setRot0()) );
+    viewMenu->addAction( "90\260 rotation", this, SLOT(setRot90()) );
+    viewMenu->addAction( "180\260 rotation", this, SLOT(setRot180()) );
+    viewMenu->addAction( "270\260 rotation", this, SLOT(setRot270()) );
+    viewMenu->addSeparator();
     viewMenu->addAction( "Zoom scale &0.5", this, SLOT(setZoomHalf()) );
     viewMenu->addAction( "Zoom scale 0.75", this, SLOT(setZoom075()) );
     viewMenu->addAction( "Zoom scale &1", this, SLOT(setZoom1()) );
@@ -451,10 +450,7 @@ void QVFb::setZoom(double z)
         secondaryView->setZoom(z,z*skinscaleV/skinscaleH);
 
     if (skin) {
-	skin->setZoom(z/skinscaleH);
-	view->setFixedSize(
-	    int(view->displayWidth()*z),
-	    int(view->displayHeight()*z*skinscaleV/skinscaleH));
+	skin->setTransform(QMatrix().scale(z/skinscaleH,z/skinscaleV).rotate(90*view->displayRotation()));
         if (secondaryView)
             secondaryView->setFixedSize(
                     int(secondaryView->displayWidth()*z),
@@ -462,6 +458,34 @@ void QVFb::setZoom(double z)
     }
 }
 
+void QVFb::setRotation(QVFbView::Rotation r)
+{
+    view->setRotation(r);
+    if (secondaryView)
+        secondaryView->setRotation(r);
+    setZoom(view->zoomH());
+}
+
+void QVFb::setRot0()
+{
+    setRotation(QVFbView::Rot0);
+}
+
+void QVFb::setRot90()
+{
+    setRotation(QVFbView::Rot90);
+}
+
+void QVFb::setRot180()
+{
+    setRotation(QVFbView::Rot180);
+}
+
+void QVFb::setRot270()
+{
+    setRotation(QVFbView::Rot270);
+}
+
 void QVFb::setZoomHalf()
 {
     setZoom(0.5);
@@ -552,7 +576,7 @@ void QVFb::about()
 {
     QMessageBox::about(this, "About QVFB",
 	"<h2>The Qtopia Core Virtual X11 Framebuffer</h2>"
-	"<p>This application runs under Qt/X11, emulating a simple framebuffer, "
+	"<p>This application runs under Qt for X11, emulating a simple framebuffer, "
 	"which the Qtopia Core server and clients can attach to just as if "
 	"it was a hardware Linux framebuffer. "
 	"<p>With the aid of this development tool, you can develop Qtopia Core "
