@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -340,8 +334,8 @@ bool DeviceSkinParameters::read(QTextStream &ts, ReadMode rm, QString *errorMess
         }
     }
     if (i != nareas) {
-	const QString message = DeviceSkin::tr("Mismatch in number of areas, expected %1, got %2.").arg(nareas).arg(i);
-	qWarning(message.toUtf8().constData());
+        qWarning() << DeviceSkin::tr("Mismatch in number of areas, expected %1, got %2.")
+                      .arg(nareas).arg(i);
     }
     if (debugDeviceSkin)
 	qDebug() << *this;
@@ -384,7 +378,6 @@ DeviceSkin::DeviceSkin(const DeviceSkinParameters &parameters,  QWidget *p ) :
     m_secondaryView(0),
     buttonPressed(false),
     buttonIndex(0),
-    zoom(1.0),
     cursorw(0),
     joydown(0),
     t_skinkey(new QTimer(this)),
@@ -418,9 +411,7 @@ void DeviceSkin::calcRegions()
 	QPolygon xa(m_parameters.buttonAreas[i].area.count());
 	int n = m_parameters.buttonAreas[i].area.count();
 	for (int p=0; p<n; p++) {
-	    xa.setPoint(p,
-		int(m_parameters.buttonAreas[i].area[p].x()*zoom),
-		int(m_parameters.buttonAreas[i].area[p].y()*zoom));
+	    xa.setPoint(p,transform.map(m_parameters.buttonAreas[i].area[p]));
 	}
 	if ( n == 2 ) {
 	    buttonRegions[i] = QRegion(xa.boundingRect());
@@ -445,13 +436,13 @@ void DeviceSkin::loadImages()
     if (hasCursorImage)
 	icurs =  m_parameters.skinCursor;
 
-    if ( zoom != int(zoom) ) {
-	iup = iup.scaled(int(iup.width()*zoom),int(iup.height()*zoom), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-	idown = idown.scaled(int(idown.width()*zoom),int(idown.height()*zoom), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    if (!transform.isIdentity()) {
+	iup = iup.transformed(transform, Qt::SmoothTransformation);
+	idown = idown.transformed(transform, Qt::SmoothTransformation);
 	if (hasClosedImage)
-	    iclosed = iclosed.scaled(int(idown.width()*zoom),int(idown.height()*zoom), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+	    iclosed = iclosed.transformed(transform, Qt::SmoothTransformation);
 	if (hasCursorImage)
-	    icurs = icurs.scaled(int(idown.width()*zoom),int(idown.height()*zoom), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+	    icurs = icurs.transformed(transform, Qt::SmoothTransformation);
     }
     const Qt::ImageConversionFlags conv = Qt::ThresholdAlphaDither|Qt::AvoidDither;
     skinImageUp = QPixmap::fromImage(iup);
@@ -461,17 +452,6 @@ void DeviceSkin::loadImages()
     if (hasCursorImage)
 	skinCursor = QPixmap::fromImage(icurs, conv);
 
-    if ( zoom == int(zoom) ) {
-	QMatrix scale;
-	scale = scale.scale(zoom,zoom);
-	skinImageUp = skinImageUp.transformed(scale);
-	skinImageDown = skinImageDown.transformed(scale);
-	if (hasClosedImage)
-	    skinImageClosed = skinImageClosed.transformed(scale);
-	if (hasCursorImage)
-	    skinCursor = skinCursor.transformed(scale);
-    }
-
     setFixedSize( skinImageUp.size() );
     if (!skinImageUp.mask())
 	skinImageUp.setMask(skinImageUp.createHeuristicMask());
@@ -496,16 +476,23 @@ DeviceSkin::~DeviceSkin( )
     delete cursorw;
 }
 
-void DeviceSkin::setZoom( double z )
+void DeviceSkin::setTransform( const QMatrix& wm )
 {
-    zoom = z;
+    transform = QImage::trueMatrix(wm,m_parameters.skinImageUp.width(),m_parameters.skinImageUp.height());
     calcRegions();
     loadImages();
-    if ( m_view )
-	m_view->move( int(m_parameters.screenRect.x()*zoom), int(m_parameters.screenRect.y()*zoom) );
+    if ( m_view ) {
+        QPoint p = transform.map(QPolygon(m_parameters.screenRect)).boundingRect().topLeft();
+	m_view->move(p);
+    }
     updateSecondaryScreen();
 }
 
+void DeviceSkin::setZoom( double z )
+{
+    setTransform(QMatrix().scale(z,z));
+}
+
 void DeviceSkin::updateSecondaryScreen()
 {
     if (!m_secondaryView)
@@ -514,14 +501,14 @@ void DeviceSkin::updateSecondaryScreen()
         if (m_parameters.backScreenRect.isNull()) {
             m_secondaryView->hide();
         } else {
-            m_secondaryView->move( int(m_parameters.backScreenRect.x()*zoom), int(m_parameters.backScreenRect.y()*zoom) );
+            m_secondaryView->move(transform.map(QPolygon(m_parameters.backScreenRect)).boundingRect().topLeft());
             m_secondaryView->show();
         }
     } else {
         if (m_parameters.closedScreenRect.isNull()) {
             m_secondaryView->hide();
         } else {
-            m_secondaryView->move( int(m_parameters.closedScreenRect.x()*zoom), int(m_parameters.closedScreenRect.y()*zoom) );
+            m_secondaryView->move(transform.map(QPolygon(m_parameters.closedScreenRect)).boundingRect().topLeft());
             m_secondaryView->show();
         }
     }
@@ -531,7 +518,7 @@ void DeviceSkin::setView( QWidget *v )
 {
     m_view = v;
     m_view->setFocus();
-    m_view->move( int(m_parameters.screenRect.x()*zoom), int(m_parameters.screenRect.y()*zoom) );
+    m_view->move(transform.map(QPolygon(m_parameters.screenRect)).boundingRect().topLeft());
     if ( cursorw )
 	cursorw->setView(v);
 }
@@ -797,7 +784,7 @@ CursorWindow::CursorWindow(const QImage &img, QPoint hot, QWidget* sk)
 #endif
     QPixmap p;
     p = QPixmap::fromImage(img);
-    if ( !p.mask() )
+    if (!p.mask()) {
 	if ( img.hasAlphaChannel() ) {
 	    QBitmap bm;
 	    bm = QPixmap::fromImage(img.createAlphaMask());
@@ -807,6 +794,7 @@ CursorWindow::CursorWindow(const QImage &img, QPoint hot, QWidget* sk)
 	    bm = QPixmap::fromImage(img.createHeuristicMask());
 	    p.setMask( bm );
 	}
+    }
     QPalette palette;
     palette.setBrush(backgroundRole(), QBrush(p));
     setPalette(palette);
